@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007-2016, Cameron Rich
+ * Copyright (c) 2007-2017, Cameron Rich
  * 
  * All rights reserved.
  * 
@@ -48,28 +48,6 @@ static int x509_v3_basic_constraints(const uint8_t *cert, int offset,
         X509_CTX *x509_ctx);
 static int x509_v3_key_usage(const uint8_t *cert, int offset, 
         X509_CTX *x509_ctx);
-
-/**
- * Retrieve the signature from a certificate.
- */
-static const uint8_t *get_signature(const uint8_t *asn1_sig, int *len)
-{
-    int offset = 0;
-    const uint8_t *ptr = NULL;
-
-    if (asn1_next_obj(asn1_sig, &offset, ASN1_SEQUENCE) < 0 || 
-            asn1_skip_obj(asn1_sig, &offset, ASN1_SEQUENCE))
-        goto end_get_sig;
-
-    if (asn1_sig[offset++] != ASN1_OCTET_STRING)
-        goto end_get_sig;
-    *len = get_asn1_length(asn1_sig, &offset);
-    ptr = &asn1_sig[offset];          /* all ok */
-
-end_get_sig:
-    return ptr;
-}
-
 #endif
 
 /**
@@ -246,6 +224,15 @@ static int x509_v3_subject_alt_name(const uint8_t *cert, int offset,
 
                     if (type == ASN1_CONTEXT_DNSNAME)
                     {
+                        /* sanity check the hostname due to
+https://tools.cisco.com/security/center/viewAlert.x?alertId=18852
+                         */
+                        if (strnlen((const char *)&cert[offset], dnslen) !=
+                                    dnslen)
+                        {
+                            return X509_VFY_ERROR_NO_TRUSTED_CERT;
+                        }
+
                         x509_ctx->subject_alt_dnsnames = (char**)
                                 realloc(x509_ctx->subject_alt_dnsnames, 
                                    (totalnames + 2) * sizeof(char*));
@@ -274,6 +261,7 @@ static int x509_v3_basic_constraints(const uint8_t *cert, int offset,
         X509_CTX *x509_ctx)
 {
     int ret = X509_OK;
+    int lenSeq = 0;
 
     if ((offset = asn1_is_basic_constraints(cert, offset)) == 0)
         goto end_contraints;
@@ -282,14 +270,34 @@ static int x509_v3_basic_constraints(const uint8_t *cert, int offset,
     x509_ctx->basic_constraint_is_critical = 
                     asn1_is_critical_ext(cert, &offset);
 
-    if (asn1_next_obj(cert, &offset, ASN1_OCTET_STRING) < 0 ||
-    		asn1_next_obj(cert, &offset, ASN1_SEQUENCE) < 0 ||
-    		asn1_get_bool(cert, &offset, &x509_ctx->basic_constraint_cA) < 0 ||
-    		asn1_get_int(cert, &offset,
-    		                &x509_ctx->basic_constraint_pathLenConstraint) < 0)
+    /* Assign Defaults in case not specified
+    basic_constraint_cA will already by zero by virtue of the calloc */
+    x509_ctx->basic_constraint_cA = 0;
+    /* basic_constraint_pathLenConstraint is unlimited by default. 
+    10000 is just a large number (limits.h is not already included) */
+    x509_ctx->basic_constraint_pathLenConstraint = 10000;
+    
+    if ((asn1_next_obj(cert, &offset, ASN1_OCTET_STRING) < 0) ||
+            ((lenSeq = asn1_next_obj(cert, &offset, ASN1_SEQUENCE)) < 0))
     {
         ret = X509_NOT_OK;       
     }
+    
+    /* If the Sequence Length is greater than zero, 
+    continue with the basic_constraint_cA */
+    if ((lenSeq>0)&&(asn1_get_bool(cert, &offset, 
+            &x509_ctx->basic_constraint_cA) < 0))
+    {
+        ret = X509_NOT_OK;
+    }
+    
+    /* If the Sequence Length is greater than 3, it has more content than 
+    the basic_constraint_cA bool, so grab the pathLenConstraint */
+    if ((lenSeq>3) && (asn1_get_int(cert, &offset, 
+            &x509_ctx->basic_constraint_pathLenConstraint) < 0))
+    {
+        ret = X509_NOT_OK;
+    }
 
 end_contraints:
     return ret;
@@ -310,7 +318,7 @@ static int x509_v3_key_usage(const uint8_t *cert, int offset,
     x509_ctx->key_usage_is_critical = asn1_is_critical_ext(cert, &offset);
 
     if (asn1_next_obj(cert, &offset, ASN1_OCTET_STRING) < 0 ||
-    		asn1_get_bit_string_as_int(cert, &offset, &x509_ctx->key_usage))
+            asn1_get_bit_string_as_int(cert, &offset, &x509_ctx->key_usage))
     {
         ret = X509_NOT_OK;       
     }
@@ -361,17 +369,58 @@ void x509_free(X509_CTX *x509_ctx)
 }
 
 #ifdef CONFIG_SSL_CERT_VERIFICATION
+
+static const uint8_t sig_prefix_md5[] = {0x30, 0x20, 0x30, 0x0C, 0x06, 0x08, 0x2A, 0x86, 0x48, 0x86, 0xF7, 0x0D, 0x02, 0x05, 0x05, 0x00, 0x04, 0x10};
+static const uint8_t sig_prefix_sha1[] = {0x30, 0x21, 0x30, 0x09, 0x06, 0x05, 0x2b, 0x0E, 0x03, 0x02, 0x1A, 0x05, 0x00, 0x04, 0x14};
+static const uint8_t sig_prefix_sha256[] = {0x30, 0x31, 0x30, 0x0d, 0x06, 0x09, 0x60, 0x86, 0x48, 0x01, 0x65, 0x03, 0x04, 0x02, 0x01, 0x05, 0x00, 0x04, 0x20};
+static const uint8_t sig_prefix_sha384[] = {0x30, 0x41, 0x30, 0x0d, 0x06, 0x09, 0x60, 0x86, 0x48, 0x01, 0x65, 0x03, 0x04, 0x02, 0x02, 0x05, 0x00, 0x04, 0x30};
+static const uint8_t sig_prefix_sha512[] = {0x30, 0x51, 0x30, 0x0d, 0x06, 0x09, 0x60, 0x86, 0x48, 0x01, 0x65, 0x03, 0x04, 0x02, 0x03, 0x05, 0x00, 0x04, 0x40};
+
 /**
  * Take a signature and decrypt it.
  */
-static bigint *sig_verify(BI_CTX *ctx, const uint8_t *sig, int sig_len,
-        bigint *modulus, bigint *pub_exp)
+static bigint *sig_verify(BI_CTX *ctx, const uint8_t *sig, int sig_len, 
+        uint8_t sig_type, bigint *modulus, bigint *pub_exp)
 {
-    int i, size;
+    int i;
     bigint *decrypted_bi, *dat_bi;
     bigint *bir = NULL;
     uint8_t *block = (uint8_t *)alloca(sig_len);
 
+    const uint8_t *sig_prefix = NULL; 
+    uint8_t sig_prefix_size = 0, hash_len = 0;
+    /* adjust our expections */
+    switch (sig_type)
+    {
+        case SIG_TYPE_MD5:
+            sig_prefix = sig_prefix_md5;
+            sig_prefix_size = sizeof(sig_prefix_md5);
+        break;
+        case SIG_TYPE_SHA1:
+            sig_prefix = sig_prefix_sha1;
+            sig_prefix_size = sizeof(sig_prefix_sha1);
+        break;
+        case SIG_TYPE_SHA256:
+            sig_prefix = sig_prefix_sha256;
+            sig_prefix_size = sizeof(sig_prefix_sha256);
+        break;
+        case SIG_TYPE_SHA384:
+            sig_prefix = sig_prefix_sha384;
+            sig_prefix_size = sizeof(sig_prefix_sha384);
+        break;
+        case SIG_TYPE_SHA512:
+            sig_prefix = sig_prefix_sha512;
+            sig_prefix_size = sizeof(sig_prefix_sha512);
+        break;
+    }
+
+    if (sig_prefix) 
+        hash_len = sig_prefix[sig_prefix_size - 1];
+ 
+    /* check length (#A) */
+    if (sig_len < 2 + 8 + 1 + sig_prefix_size + hash_len)
+        goto err;
+
     /* decrypt */
     dat_bi = bi_import(ctx, sig, sig_len);
     ctx->mod_offset = BIGINT_M_OFFSET;
@@ -382,22 +431,30 @@ static bigint *sig_verify(BI_CTX *ctx, const uint8_t *sig, int sig_len,
     bi_export(ctx, decrypted_bi, block, sig_len);
     ctx->mod_offset = BIGINT_M_OFFSET;
 
-    i = 10; /* start at the first possible non-padded byte */
-    while (block[i++] && i < sig_len);
-    size = sig_len - i;
-
-    /* get only the bit we want */
-    if (size > 0)
-    {
-        int len;
-        const uint8_t *sig_ptr = get_signature(&block[i], &len);
-
-        if (sig_ptr)
-        {
-            bir = bi_import(ctx, sig_ptr, len);
-        }
+    /* check the first 2 bytes */
+    if (block[0] != 0 || block[1] != 1)
+        goto err;
+    
+    /* check the padding */
+    i = 2; /* start at the first padding byte */
+    while (i < sig_len - 1 - sig_prefix_size - hash_len)
+    { /* together with (#A), we require at least 8 bytes of padding */
+        if (block[i++] != 0xFF)
+            goto err;
     }
 
+    /* check end of padding */
+    if (block[i++] != 0)
+        goto err;
+    
+    /* check the ASN.1 metadata */
+    if (memcmp(block+i, sig_prefix, sig_prefix_size))
+        goto err;
+
+    /* now we can get the hash we need */
+    bir = bi_import(ctx, block + i + sig_prefix_size, hash_len);
+
+err:
     /* save a few bytes of memory */
     bi_clear_cache(ctx);
     return bir;
@@ -461,29 +518,29 @@ int x509_verify(const CA_CERT_CTX *ca_cert_ctx, const X509_CTX *cert,
 
     if (cert->basic_constraint_present)
     {
-    	/* If the cA boolean is not asserted,
-    	   then the keyCertSign bit in the key usage extension MUST NOT be
-    	   asserted. */
-    	if (!cert->basic_constraint_cA &&
+        /* If the cA boolean is not asserted,
+           then the keyCertSign bit in the key usage extension MUST NOT be
+           asserted. */
+        if (!cert->basic_constraint_cA &&
                 IS_SET_KEY_USAGE_FLAG(cert, KEY_USAGE_KEY_CERT_SIGN))
-		{
-			ret = X509_VFY_ERROR_BASIC_CONSTRAINT;
-			goto end_verify;
-		}
+        {
+            ret = X509_VFY_ERROR_BASIC_CONSTRAINT;
+            goto end_verify;
+        }
 
         /* The pathLenConstraint field is meaningful only if the cA boolean is
            asserted and the key usage extension, if present, asserts the
            keyCertSign bit.  In this case, it gives the maximum number of 
            non-self-issued intermediate certificates that may follow this 
            certificate in a valid certification path. */
-		if (cert->basic_constraint_cA &&
+        if (cert->basic_constraint_cA &&
             (!cert->key_usage_present || 
                 IS_SET_KEY_USAGE_FLAG(cert, KEY_USAGE_KEY_CERT_SIGN)) &&
             (cert->basic_constraint_pathLenConstraint+1) < *pathLenConstraint)
-		{
-			ret = X509_VFY_ERROR_BASIC_CONSTRAINT;
-			goto end_verify;
-		}
+        {
+            ret = X509_VFY_ERROR_BASIC_CONSTRAINT;
+            goto end_verify;
+        }
     }
 
     next_cert = cert->next;
@@ -501,7 +558,10 @@ int x509_verify(const CA_CERT_CTX *ca_cert_ctx, const X509_CTX *cert,
                    to verify certificate signatures. */
                 if (cert->basic_constraint_present && 
                         !ca_cert_ctx->cert[i]->basic_constraint_cA)
+                {
+                    i++;
                     continue;
+                }
                         
                 if (asn1_compare_dn(cert->ca_cert_dn,
                                             ca_cert_ctx->cert[i]->cert_dn) == 0)
@@ -549,7 +609,7 @@ int x509_verify(const CA_CERT_CTX *ca_cert_ctx, const X509_CTX *cert,
     }
 
     /* check the signature */
-    cert_sig = sig_verify(ctx, cert->signature, cert->sig_len, 
+    cert_sig = sig_verify(ctx, cert->signature, cert->sig_len, cert->sig_type,
                         bi_clone(ctx, mod), bi_clone(ctx, expn));
 
     if (cert_sig && cert->digest)
@@ -571,7 +631,7 @@ int x509_verify(const CA_CERT_CTX *ca_cert_ctx, const X509_CTX *cert,
     /* go down the certificate chain using recursion. */
     if (next_cert != NULL)
     {
-    	(*pathLenConstraint)++; /* don't include last certificate */
+        (*pathLenConstraint)++; /* don't include last certificate */
         ret = x509_verify(ca_cert_ctx, next_cert, pathLenConstraint);
     }
 
