@@ -115,8 +115,8 @@ void device_information_service_server_init(void){
 
 
     // get service handle range
-	uint16_t start_handle;
-	uint16_t end_handle;
+    uint16_t start_handle = 0;
+    uint16_t end_handle   = 0xffff;
 	int service_found = gatt_server_get_handle_range_for_service_with_uuid16(ORG_BLUETOOTH_SERVICE_DEVICE_INFORMATION, &start_handle, &end_handle);
 	btstack_assert(service_found != 0);
 	UNUSED(service_found);
