@@ -548,7 +548,7 @@ int hfp_hf_in_band_ringtone_active(hci_con_handle_t acl_handle);
 
 /**
  * @brief Send AT command (most likely a vendor-specific command not part of standard HFP).
- * @note  Result (OK/ERROR) is reported via HFP_SUBEVENT_COMPLETE
+ * @note  Result (OK/ERROR) is reported via HFP_SUBEVENT_CUSTOM_AT_MESSAGE_SENT
  *        To receive potential unsolicited result code, add ENABLE_HFP_AT_MESSAGES to get all message via HFP_SUBEVENT_AT_MESSAGE_RECEIVED
  *
  * @param acl_handle
@@ -559,6 +559,12 @@ int hfp_hf_in_band_ringtone_active(hci_con_handle_t acl_handle);
  */
 uint8_t hfp_hf_send_at_command(hci_con_handle_t acl_handle, const char * at_command);
 
+/**
+ * @brief Register custom AT command.
+ * @param hfp_custom_at_command (with '+' prefix)
+ */
+void hfp_hf_register_custom_at_command(hfp_custom_at_command_t * custom_at_command);
+
 /**
  * @brief De-Init HFP HF
  */
