@@ -20,8 +20,8 @@
  * THIS SOFTWARE IS PROVIDED BY BLUEKITCHEN GMBH AND CONTRIBUTORS
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL MATTHIAS
- * RINGWALD OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL BLUEKITCHEN
+ * GMBH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
  * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
  * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
@@ -42,9 +42,10 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "btstack.h"
 #include "btstack_memory.h"
+#include "btstack_event.h"
 
+#include "mesh/provisioning_device.h"
 #include "mesh/mesh_crypto.h"
 #ifdef ENABLE_MESH_ADV_BEARER
 #include "mesh/pb_adv.h"
@@ -139,6 +140,7 @@ typedef enum {
     DEVICE_SEND_INPUT_COMPLETE,
     DEVICE_W4_PUB_KEY,
     DEVICE_SEND_PUB_KEY,
+    DEVICE_PUB_KEY_SENT,
     DEVICE_W4_CONFIRM,
     DEVICE_SEND_CONFIRM,
     DEVICE_W4_RANDOM,
@@ -405,6 +407,7 @@ static void provisioning_run(void){
             provisioning_send_input_complete();
             break;
         case DEVICE_SEND_PUB_KEY:
+            device_state = DEVICE_PUB_KEY_SENT;
             prov_waiting_for_outgoing_complete = 1;
             provisioning_send_public_key();
             provisioning_public_key_exchange_complete();
@@ -492,6 +495,9 @@ static void provisioning_handle_start(uint8_t * packet, uint16_t size){
                 break;
             }
             break;
+        default:
+            // TODO check
+            break;
     }
     if (!ok){
         printf("PROV_START arguments incorrect\n");
@@ -756,8 +762,10 @@ static void provisioning_handle_pdu(uint8_t packet_type, uint16_t channel, uint8
 
     switch (packet_type){
         case HCI_EVENT_PACKET:
-            if (packet[0] != HCI_EVENT_MESH_META)  break;
-            switch (packet[2]){
+        
+            if (hci_event_packet_get_type(packet) != HCI_EVENT_MESH_META)  break;
+
+            switch (hci_event_mesh_meta_get_subevent_code(packet)){
                 case MESH_SUBEVENT_PB_TRANSPORT_LINK_OPEN:
                     pb_transport_cid = mesh_subevent_pb_transport_link_open_get_pb_transport_cid(packet);
                     pb_type = mesh_subevent_pb_transport_link_open_get_pb_type(packet);
@@ -768,6 +776,7 @@ static void provisioning_handle_pdu(uint8_t packet_type, uint16_t channel, uint8
                     printf("Outgoing packet acked\n");
                     prov_waiting_for_outgoing_complete = 0;
                     if (device_state == DEVICE_W4_DONE){
+                        pb_close_link(1, 0);
                         provisioning_done();
                     }
                     break;                    
@@ -776,6 +785,8 @@ static void provisioning_handle_pdu(uint8_t packet_type, uint16_t channel, uint8
                     pb_transport_cid = MESH_PB_TRANSPORT_INVALID_CID;
                     provisioning_done();
                     break;
+                default:
+                    break;
             }
             break;
         case PROVISIONING_DATA_PACKET:
@@ -843,7 +854,7 @@ void provisioning_device_init(void){
 #ifdef ENABLE_MESH_ADV_BEARER
     // setup PB ADV
     pb_adv_init();
-    pb_adv_register_packet_handler(&provisioning_handle_pdu);
+    pb_adv_register_device_packet_handler(&provisioning_handle_pdu);
 #endif
 #ifdef ENABLE_MESH_GATT_BEARER
     // setup PB GATT
