@@ -402,3 +402,16 @@ void inject_hfp_command_to_ag(uint8_t * data, int len){
 bool hci_extended_sco_link_supported(void){
     return true;
 }
+
+bool gap_secure_connection(hci_con_handle_t con_handle){
+    UNUSED(con_handle);
+    return true;
+}
+
+uint16_t hci_remote_sco_packet_types(hci_con_handle_t con_handle){
+    UNUSED(con_handle);
+    return SCO_PACKET_TYPES_ALL;
+}
+uint16_t hci_usable_sco_packet_types(void){
+    return SCO_PACKET_TYPES_ALL;
+}
