@@ -64,8 +64,8 @@
  */
 //!\{
 #define CYW43_VERSION_MAJOR 1
-#define CYW43_VERSION_MINOR 0
-#define CYW43_VERSION_MICRO 3
+#define CYW43_VERSION_MINOR 1
+#define CYW43_VERSION_MICRO 0
 //!\}
 
 /*!
@@ -99,7 +99,7 @@
 #define CYW43_LINK_DOWN         (0)     ///< link is down
 #define CYW43_LINK_JOIN         (1)     ///< Connected to wifi
 #define CYW43_LINK_NOIP         (2)     ///< Connected to wifi, but no IP address
-#define CYW43_LINK_UP           (3)     ///< Connect to wifi with an IP address
+#define CYW43_LINK_UP           (3)     ///< Connected to wifi with an IP address
 #define CYW43_LINK_FAIL         (-1)    ///< Connection failed
 #define CYW43_LINK_NONET        (-2)    ///< No matching SSID found (could be out of range, or down)
 #define CYW43_LINK_BADAUTH      (-3)    ///< Authenticatation failure
@@ -209,6 +209,7 @@ int cyw43_send_ethernet(cyw43_t *self, int itf, size_t len, const void *buf, boo
  *
  * \see cyw43_pm_value
  * \see CYW43_DEFAULT_PM
+ * \see CYW43_NONE_PM
  * \see CYW43_AGGRESSIVE_PM
  * \see CYW43_PERFORMANCE_PM
  *
@@ -612,6 +613,7 @@ int cyw43_gpio_get(cyw43_t *self, int gpio, bool *val);
  * CYW43_PM2_POWERSAVE_MODE | Power saving with High throughput (preferred). Saves power when there is no wifi activity for some time.
  *
  * \see \ref CYW43_DEFAULT_PM
+ * \see \ref CYW43_NONE_PM
  * \see \ref CYW43_AGGRESSIVE_PM
  * \see \ref CYW43_PERFORMANCE_PM
  *
@@ -633,19 +635,25 @@ static inline uint32_t cyw43_pm_value(uint8_t pm_mode, uint16_t pm2_sleep_ret_ms
 /*!
  * \brief Default power management mode
  */
-#define CYW43_DEFAULT_PM cyw43_pm_value(CYW43_PM2_POWERSAVE_MODE, 200, 1, 1, 10)
+#define CYW43_DEFAULT_PM (CYW43_PERFORMANCE_PM)
+
+/*!
+ * \brief No power management
+ */
+#define CYW43_NONE_PM (cyw43_pm_value(CYW43_NO_POWERSAVE_MODE, 10, 0, 0, 0))
 
 /*!
  * \brief Aggressive power management mode for optimal power usage at the cost of performance
  */
-#define CYW43_AGGRESSIVE_PM cyw43_pm_value(CYW43_PM2_POWERSAVE_MODE, 2000, 1, 1, 10)
+#define CYW43_AGGRESSIVE_PM (cyw43_pm_value(CYW43_PM1_POWERSAVE_MODE, 10, 0, 0, 0))
 
 /*!
  * \brief Performance power management mode where more power is used to increase performance
  */
-#define CYW43_PERFORMANCE_PM cyw43_pm_value(CYW43_PM2_POWERSAVE_MODE, 20, 1, 1, 1)
+#define CYW43_PERFORMANCE_PM (cyw43_pm_value(CYW43_PM2_POWERSAVE_MODE, 200, 1, 1, 10))
 
 #if CYW43_ENABLE_BLUETOOTH
+
 /*!
  * \brief Initialise the Bluetooth HCI layer
  *
@@ -676,7 +684,49 @@ int cyw43_bluetooth_hci_write(uint8_t *buf, size_t len);
  * \brief Callback for the Bluetooth HCI layer to do processing
  */
 void cyw43_bluetooth_hci_process(void);
-#endif
+
+#endif // CYW43_ENABLE_BLUETOOTH
+
+#if CYW43_ENABLE_BLUETOOTH_OVER_UART
+
+/*!
+ * \brief Initialise the cyw43's Bluetooth controller.
+ *
+ * The UART must be initialised and have flow control enabled before calling this function.
+ *
+ * \return zero on success
+ */
+int cyw43_bluetooth_controller_init(void);
+
+/*!
+ * \brief Deinitialise the cyw43's Bluetooth controller.
+ *
+ * \return zero on success
+ */
+int cyw43_bluetooth_controller_deinit(void);
+
+/*!
+ * \brief Tell the Bluetooth controller to go to sleep.
+ *
+ * \return zero on success
+ */
+int cyw43_bluetooth_controller_sleep_maybe(void);
+
+/*!
+ * \brief Query whether the controller woke up.
+ *
+ * \return true if the controller woke up, false otherwise
+ */
+bool cyw43_bluetooth_controller_woken(void);
+
+/*!
+ * \brief Wake up the Bluetooth controller.
+ *
+ * \return zero on success
+ */
+int cyw43_bluetooth_controller_wakeup(void);
+
+#endif // CYW43_ENABLE_BLUETOOTH_OVER_UART
 
 //!\} // cyw43_driver doxygen group
 
