@@ -19,8 +19,8 @@
 #define CYW43_INFO(...)                     printf(__VA_ARGS__)
 #define CYW43_WARN(...)                     printf(__VA_ARGS__)
 
-#define CYW43_PIN_WL_REG_ON                 (1)
-#define CYW43_PIN_WL_RFSW_VDD               (2)
+#define CYW43_PIN_RFSW_VDD                  (1)
+#define CYW43_PIN_WL_REG_ON                 (2)
 #define CYW43_PIN_WL_SDIO_1                 (3)
 #define CYW43_PIN_WL_HOST_WAKE              (4)
 
@@ -52,31 +52,45 @@ static inline unsigned int cyw43_hal_ticks_ms(void) {
 }
 
 static inline void cyw43_delay_us(unsigned int us) {
+    (void)us;
 }
 
 static inline void cyw43_delay_ms(unsigned int ms) {
+    (void)ms;
 }
 
 static inline void cyw43_hal_get_mac(int interface, uint8_t mac[6]) {
+    (void)interface;
+    (void)mac;
 }
 
 static inline void cyw43_hal_pin_config(int pin, int mode, int pull, int alt) {
+    (void)pin;
+    (void)mode;
+    (void)pull;
+    (void)alt;
 }
 
 static inline void cyw43_hal_pin_config_irq_falling(int pin, int enable) {
+    (void)pin;
+    (void)enable;
 }
 
 static inline int cyw43_hal_pin_read(int pin) {
+    (void)pin;
     return 0;
 }
 
 static inline void cyw43_hal_pin_low(int pin) {
+    (void)pin;
 }
 
 static inline void cyw43_hal_pin_high(int pin) {
+    (void)pin;
 }
 
 static inline void cyw43_schedule_internal_poll_dispatch(void (*func)(void)) {
+    (void)func;
 }
 
 #endif // CYW43_INCLUDED_CONFIGPORT_H
