@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -70,7 +70,8 @@ typedef enum e_elc_event_ra6t1
     ELC_EVENT_DMAC5_INT               = (0x025), // DMAC transfer end 5
     ELC_EVENT_DMAC6_INT               = (0x026), // DMAC transfer end 6
     ELC_EVENT_DMAC7_INT               = (0x027), // DMAC transfer end 7
-    ELC_EVENT_DTC_COMPLETE            = (0x02A), // DTC last transfer
+    ELC_EVENT_DTC_COMPLETE            = (0x029), // DTC last transfer
+    ELC_EVENT_DTC_END                 = (0x02A), // DTC transfer end
     ELC_EVENT_ICU_SNOOZE_CANCEL       = (0x02D), // Canceling from Snooze mode
     ELC_EVENT_FCU_FIFERR              = (0x030), // Flash access error interrupt
     ELC_EVENT_FCU_FRDYI               = (0x031), // Flash ready interrupt
