@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -52,15 +52,6 @@
 void        comp_hs_int_isr(void);
 static void acmphs_hardware_initialize(acmphs_instance_ctrl_t * const p_instance_ctrl);
 
-/* Version data structure used by error logger macro. */
-static const fsp_version_t g_acmphs_version =
-{
-    .api_version_minor  = COMPARATOR_API_VERSION_MINOR,
-    .api_version_major  = COMPARATOR_API_VERSION_MAJOR,
-    .code_version_major = ACMPHS_CODE_VERSION_MAJOR,
-    .code_version_minor = ACMPHS_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global Variables
  **********************************************************************************************************************/
@@ -73,7 +64,6 @@ const comparator_api_t g_comparator_on_acmphs =
     .infoGet      = R_ACMPHS_InfoGet,
     .statusGet    = R_ACMPHS_StatusGet,
     .close        = R_ACMPHS_Close,
-    .versionGet   = R_ACMPHS_VersionGet
 };
 
 /*******************************************************************************************************************//**
@@ -338,26 +328,6 @@ fsp_err_t R_ACMPHS_Close (comparator_ctrl_t * p_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Gets the API and code version. Implements @ref comparator_api_t::versionGet().
- *
- * @retval  FSP_SUCCESS        Version information available in p_version.
- * @retval  FSP_ERR_ASSERTION  The parameter p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_ACMPHS_VersionGet (fsp_version_t * const p_version)
-{
-#if (1 == ACMPHS_CFG_PARAM_CHECKING_ENABLE)
-
-    /* Verify the pointer is not NULL. */
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    /* Return the version number */
-    p_version->version_id = g_acmphs_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup ACMPHS)
  **********************************************************************************************************************/
@@ -405,6 +375,10 @@ static void acmphs_hardware_initialize (acmphs_instance_ctrl_t * const p_instanc
     {
         R_MSTP->MSTPCRD_b.MSTPD28 = 0;
 
+        /* Read back the register to ensure that the write has completed.
+         * MREF_INTERNAL_002 */
+        FSP_REGISTER_READ(R_MSTP->MSTPCRD);
+
         /*Writes to VREFEN bit must be in critical sections to ensure the driver is reentrant for different channels.*/
         FSP_CRITICAL_SECTION_DEFINE;
         FSP_CRITICAL_SECTION_ENTER;
