@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -52,6 +52,22 @@
 #define AGT_PRV_AGTCMSR_PIN_B_OFFSET            (4U)
 #define AGT_PRV_AGTCMSR_VALID_BITS              (0x77U)
 
+#define AGT_PRV_MIN_CLOCK_FREQ                  (0U)
+
+#if (BSP_FEATURE_AGT_AGTW_CHANNEL_COUNT > 0)
+ #if (BSP_FEATURE_AGT_AGTW_CHANNEL_COUNT < (BSP_FEATURE_AGT_MAX_CHANNEL_NUM + 1))
+  #define AGT_PRV_IS_AGTW(p_instance_ctrl)    ((p_instance_ctrl)->p_cfg->channel < BSP_FEATURE_AGT_AGTW_CHANNEL_COUNT)
+ #else
+  #define AGT_PRV_IS_AGTW(p_instance_ctrl)    (true)
+ #endif
+#else
+ #define AGT_PRV_IS_AGTW(p_instance_ctrl)     (false)
+#endif
+
+#define AGT_PRV_CTRL_PTR(p_instance_ctrl)     ((agt_prv_reg_ctrl_ptr_t) (AGT_PRV_IS_AGTW((p_instance_ctrl))      \
+                                                                         ? &(p_instance_ctrl)->p_reg->AGT32.CTRL \
+                                                                         : &(p_instance_ctrl)->p_reg->AGT16.CTRL))
+
 /**********************************************************************************************************************
  * Typedef definitions
  **********************************************************************************************************************/
@@ -61,6 +77,8 @@ typedef void (BSP_CMSE_NONSECURE_CALL * agt_prv_ns_callback)(timer_callback_args
 typedef BSP_CMSE_NONSECURE_CALL void (*volatile agt_prv_ns_callback)(timer_callback_args_t * p_args);
 #endif
 
+typedef volatile R_AGTX0_AGT16_CTRL_Type * const agt_prv_reg_ctrl_ptr_t;
+
 /***********************************************************************************************************************
  * Private function prototypes
  **********************************************************************************************************************/
@@ -68,7 +86,7 @@ static void r_agt_period_register_set(agt_instance_ctrl_t * p_instance_ctrl, uin
 
 static void r_agt_hardware_cfg(agt_instance_ctrl_t * const p_instance_ctrl, timer_cfg_t const * const p_cfg);
 
-static uint32_t r_agt_clock_frequency_get(R_AGT0_Type * p_agt_regs);
+static uint32_t r_agt_clock_frequency_get(R_AGTX0_Type * p_agt_regs, bool is_agtw);
 
 static fsp_err_t r_agt_common_preamble(agt_instance_ctrl_t * p_instance_ctrl);
 
@@ -84,15 +102,6 @@ void agt_int_isr(void);
  * Private global variables
  **********************************************************************************************************************/
 
-/** Version data structure. */
-static const fsp_version_t s_agt_version =
-{
-    .api_version_minor  = TIMER_API_VERSION_MINOR,
-    .api_version_major  = TIMER_API_VERSION_MAJOR,
-    .code_version_minor = AGT_CODE_VERSION_MINOR,
-    .code_version_major = AGT_CODE_VERSION_MAJOR,
-};
-
 /* The period for even channels must be known to calculate the frequency of odd channels if the count source is AGT
  * underflow. */
 static uint32_t gp_prv_agt_periods[BSP_FEATURE_AGT_MAX_CHANNEL_NUM + 1];
@@ -116,7 +125,6 @@ const timer_api_t g_timer_on_agt =
     .statusGet    = R_AGT_StatusGet,
     .callbackSet  = R_AGT_CallbackSet,
     .close        = R_AGT_Close,
-    .versionGet   = R_AGT_VersionGet
 };
 
 /*******************************************************************************************************************//**
@@ -157,22 +165,25 @@ fsp_err_t R_AGT_Open (timer_ctrl_t * const p_ctrl, timer_cfg_t const * const p_c
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 #endif
 
-    uint32_t base_address = (uint32_t) R_AGT0 + (p_cfg->channel * ((uint32_t) R_AGT1 - (uint32_t) R_AGT0));
-    p_instance_ctrl->p_reg = (R_AGT0_Type *) base_address;
+    uint32_t base_address = (uint32_t) R_AGTX0 + (p_cfg->channel * ((uint32_t) R_AGTX1 - (uint32_t) R_AGTX0));
+    p_instance_ctrl->p_reg = (R_AGTX0_Type *) base_address;
+
     p_instance_ctrl->p_cfg = p_cfg;
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
     /* Power on the AGT channel. */
     R_BSP_MODULE_START(FSP_IP_AGT, p_cfg->channel);
 
     /* Clear AGTCR. This stops the timer if it is running and clears the flags. */
-    p_instance_ctrl->p_reg->AGTCR = 0U;
+    p_reg_ctrl->AGTCR = 0U;
 
     /* The timer is stopped in sync with the count clock, or in sync with PCLK in event and external count modes. */
-    FSP_HARDWARE_REGISTER_WAIT(0U, p_instance_ctrl->p_reg->AGTCR_b.TCSTF);
+    FSP_HARDWARE_REGISTER_WAIT(0U, p_reg_ctrl->AGTCR_b.TCSTF);
 
     /* Clear AGTMR2 before AGTMR1 is set. Reference Note 3 in section 25.2.6 "AGT Mode Register 2 (AGTMR2)"
      * of the RA6M3 manual R01UH0886EJ0100. */
-    p_instance_ctrl->p_reg->AGTMR2 = 0U;
+    p_reg_ctrl->AGTMR2 = 0U;
 
     /* Set count source and divider and configure pins. */
     r_agt_hardware_cfg(p_instance_ctrl, p_cfg);
@@ -213,8 +224,19 @@ fsp_err_t R_AGT_Start (timer_ctrl_t * const p_ctrl)
     fsp_err_t err = r_agt_common_preamble(p_instance_ctrl);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
+    /* Reload period register for one-shot timers. This must be done here instead of in the underflow interrupt because
+     * setting AGTCR.TSTOP causes AGT to be reset after 3 cycles of the count source. When the AGT count source is much
+     * slower than the core clock, 3 cycles of the count source is too long to wait in an interrupt. */
+    if (TIMER_MODE_ONE_SHOT == p_instance_ctrl->p_cfg->mode)
+    {
+        /* Set counter to period minus one. */
+        r_agt_period_register_set(p_instance_ctrl, p_instance_ctrl->period);
+    }
+
     /* Start timer */
-    p_instance_ctrl->p_reg->AGTCR = AGT_PRV_AGTCR_START_TIMER;
+    p_reg_ctrl->AGTCR = AGT_PRV_AGTCR_START_TIMER;
 
 #if AGT_CFG_OUTPUT_SUPPORT_ENABLE
 
@@ -224,9 +246,18 @@ fsp_err_t R_AGT_Start (timer_ctrl_t * const p_ctrl)
     {
         /* Verify the timer is started before modifying any other AGT registers. Reference section 25.4.1 "Count
          * Operation Start and Stop Control" in the RA6M3 manual R01UH0886EJ0100. */
-        FSP_HARDWARE_REGISTER_WAIT(1U, p_instance_ctrl->p_reg->AGTCR_b.TCSTF);
-        p_instance_ctrl->p_reg->AGTCMA = UINT16_MAX;
-        p_instance_ctrl->p_reg->AGTCMB = UINT16_MAX;
+        FSP_HARDWARE_REGISTER_WAIT(1U, p_reg_ctrl->AGTCR_b.TCSTF);
+
+        if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+        {
+            p_instance_ctrl->p_reg->AGT32.AGTCMA = UINT32_MAX;
+            p_instance_ctrl->p_reg->AGT32.AGTCMB = UINT32_MAX;
+        }
+        else
+        {
+            p_instance_ctrl->p_reg->AGT16.AGTCMA = UINT16_MAX;
+            p_instance_ctrl->p_reg->AGT16.AGTCMB = UINT16_MAX;
+        }
     }
 #endif
 
@@ -250,8 +281,10 @@ fsp_err_t R_AGT_Stop (timer_ctrl_t * const p_ctrl)
     fsp_err_t err = r_agt_common_preamble(p_instance_ctrl);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
     /* Stop timer */
-    p_instance_ctrl->p_reg->AGTCR = AGT_PRV_AGTCR_STOP_TIMER;
+    p_reg_ctrl->AGTCR = AGT_PRV_AGTCR_STOP_TIMER;
 
     return FSP_SUCCESS;
 }
@@ -271,7 +304,14 @@ fsp_err_t R_AGT_Reset (timer_ctrl_t * const p_ctrl)
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
     /* Reset counter to period minus one. */
-    p_instance_ctrl->p_reg->AGT = (uint16_t) (p_instance_ctrl->period - 1U);
+    if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+    {
+        p_instance_ctrl->p_reg->AGT32.AGT = (uint32_t) (p_instance_ctrl->period - 1U);
+    }
+    else
+    {
+        p_instance_ctrl->p_reg->AGT16.AGT = (uint16_t) (p_instance_ctrl->period - 1U);
+    }
 
     return FSP_SUCCESS;
 }
@@ -294,11 +334,20 @@ fsp_err_t R_AGT_Enable (timer_ctrl_t * const p_ctrl)
     FSP_ERROR_RETURN(AGT_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
 #endif
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
     /* Reset counter to period minus one. */
-    p_instance_ctrl->p_reg->AGT = (uint16_t) (p_instance_ctrl->period - 1U);
+    if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+    {
+        p_instance_ctrl->p_reg->AGT32.AGT = (uint32_t) (p_instance_ctrl->period - 1U);
+    }
+    else
+    {
+        p_instance_ctrl->p_reg->AGT16.AGT = (uint16_t) (p_instance_ctrl->period - 1U);
+    }
 
     /* Enable captures. */
-    p_instance_ctrl->p_reg->AGTCR = AGT_PRV_AGTCR_START_TIMER;
+    p_reg_ctrl->AGTCR = AGT_PRV_AGTCR_START_TIMER;
 
     return FSP_SUCCESS;
 }
@@ -321,8 +370,10 @@ fsp_err_t R_AGT_Disable (timer_ctrl_t * const p_ctrl)
     FSP_ERROR_RETURN(AGT_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
 #endif
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
     /* Disable captures. */
-    p_instance_ctrl->p_reg->AGTCR = AGT_PRV_AGTCR_STOP_TIMER;
+    p_reg_ctrl->AGTCR = AGT_PRV_AGTCR_STOP_TIMER;
 
     return FSP_SUCCESS;
 }
@@ -348,16 +399,19 @@ fsp_err_t R_AGT_Disable (timer_ctrl_t * const p_ctrl)
 fsp_err_t R_AGT_PeriodSet (timer_ctrl_t * const p_ctrl, uint32_t const period_counts)
 {
     agt_instance_ctrl_t * p_instance_ctrl = (agt_instance_ctrl_t *) p_ctrl;
-#if AGT_CFG_PARAM_CHECKING_ENABLE
-
-    /* Validate period parameter. */
-    FSP_ASSERT(0U != period_counts);
-    FSP_ASSERT(period_counts <= AGT_MAX_PERIOD);
-#endif
 
     fsp_err_t err = r_agt_common_preamble(p_instance_ctrl);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
+#if AGT_CFG_PARAM_CHECKING_ENABLE
+    if (!AGT_PRV_IS_AGTW(p_instance_ctrl))
+    {
+        /* Validate period parameter. */
+        FSP_ASSERT(0U != period_counts);
+        FSP_ASSERT(period_counts <= AGT_MAX_PERIOD_16BIT);
+    }
+#endif
+
     /* Set period. */
     r_agt_period_register_set(p_instance_ctrl, period_counts);
 
@@ -389,21 +443,23 @@ fsp_err_t R_AGT_DutyCycleSet (timer_ctrl_t * const p_ctrl, uint32_t const duty_c
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
  #if AGT_CFG_PARAM_CHECKING_ENABLE
-    FSP_ERROR_RETURN(duty_cycle_counts < (p_instance_ctrl->period), FSP_ERR_INVALID_ARGUMENT);
+    if (0U != p_instance_ctrl->period)
+    {
+        FSP_ERROR_RETURN(duty_cycle_counts < (p_instance_ctrl->period), FSP_ERR_INVALID_ARGUMENT);
+    }
  #endif
 
-    uint32_t temp_duty_cycle_counts         = duty_cycle_counts;
-    uint32_t agtcmsr_agtoab_start_level_bit = 1U << 2 << (4 * pin);
-    agt_extended_cfg_t const * p_extend     = (agt_extended_cfg_t const *) p_instance_ctrl->p_cfg->p_extend;
-    if (p_extend->agtoab_settings & agtcmsr_agtoab_start_level_bit)
-    {
-        /* Invert duty cycle if this pin starts high since the high portion is at the beginning of the cycle. */
-        temp_duty_cycle_counts = p_instance_ctrl->period - temp_duty_cycle_counts;
-    }
-
     /* Set duty cycle. */
-    volatile uint16_t * const p_agtcm = &p_instance_ctrl->p_reg->AGTCMA;
-    p_agtcm[pin] = (uint16_t) temp_duty_cycle_counts;
+    if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+    {
+        volatile uint32_t * const p_agtcm = &p_instance_ctrl->p_reg->AGT32.AGTCMA;
+        p_agtcm[pin] = duty_cycle_counts;
+    }
+    else
+    {
+        volatile uint16_t * const p_agtcm = &p_instance_ctrl->p_reg->AGT16.AGTCMA;
+        p_agtcm[pin] = (uint16_t) duty_cycle_counts;
+    }
 
     return FSP_SUCCESS;
 #else
@@ -443,13 +499,24 @@ fsp_err_t R_AGT_InfoGet (timer_ctrl_t * const p_ctrl, timer_info_t * const p_inf
     if (AGT_CLOCK_AGT_UNDERFLOW == p_extend->count_source)
     {
         /* Clock frequency of this channel is the clock frequency divided by the timer period of the source channel. */
-        R_AGT0_Type * p_source_channel_reg = p_instance_ctrl->p_reg - (R_AGT1 - R_AGT0);
-        p_info->clock_frequency = r_agt_clock_frequency_get(p_source_channel_reg) /
-                                  gp_prv_agt_periods[p_instance_ctrl->p_cfg->channel - 1];
+
+        /* Source instance is the channel immediately preceding this one. */
+        if (0U == gp_prv_agt_periods[p_instance_ctrl->p_cfg->channel - 1])
+        {
+            p_info->clock_frequency = AGT_PRV_MIN_CLOCK_FREQ;
+        }
+        else
+        {
+            R_AGTX0_Type * p_source_channel_reg = (R_AGTX0_Type *) ((uint32_t) p_instance_ctrl->p_reg -
+                                                                    ((uint32_t) R_AGTX1 - (uint32_t) R_AGTX0));
+            p_info->clock_frequency =
+                r_agt_clock_frequency_get(p_source_channel_reg, AGT_PRV_IS_AGTW(p_instance_ctrl)) /
+                gp_prv_agt_periods[p_instance_ctrl->p_cfg->channel - 1];
+        }
     }
     else
     {
-        p_info->clock_frequency = r_agt_clock_frequency_get(p_instance_ctrl->p_reg);
+        p_info->clock_frequency = r_agt_clock_frequency_get(p_instance_ctrl->p_reg, AGT_PRV_IS_AGTW(p_instance_ctrl));
     }
 
     /* AGT supports only counting down direction */
@@ -479,11 +546,14 @@ fsp_err_t R_AGT_StatusGet (timer_ctrl_t * const p_ctrl, timer_status_t * const p
     fsp_err_t err = r_agt_common_preamble(p_instance_ctrl);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
     /* Read the state. */
-    p_status->state = (timer_state_t) p_instance_ctrl->p_reg->AGTCR_b.TCSTF;
+    p_status->state = (timer_state_t) p_reg_ctrl->AGTCR_b.TCSTF;
 
     /* Read counter value */
-    p_status->counter = p_instance_ctrl->p_reg->AGT;
+    p_status->counter =
+        AGT_PRV_IS_AGTW(p_instance_ctrl) ? p_instance_ctrl->p_reg->AGT32.AGT : p_instance_ctrl->p_reg->AGT16.AGT;
 
     return FSP_SUCCESS;
 }
@@ -555,13 +625,15 @@ fsp_err_t R_AGT_Close (timer_ctrl_t * const p_ctrl)
     fsp_err_t err = r_agt_common_preamble(p_instance_ctrl);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
     /* Cleanup the device: Stop counter, disable interrupts, and power down if no other channels are in use. */
 
     /* Stop timer */
-    p_instance_ctrl->p_reg->AGTCR = AGT_PRV_AGTCR_FORCE_STOP;
+    p_reg_ctrl->AGTCR = AGT_PRV_AGTCR_FORCE_STOP;
 
     /* Clear AGT output. */
-    p_instance_ctrl->p_reg->AGTIOC = 0U;
+    p_reg_ctrl->AGTIOC = 0U;
 
     if (FSP_INVALID_VECTOR != p_instance_ctrl->p_cfg->cycle_end_irq)
     {
@@ -574,25 +646,6 @@ fsp_err_t R_AGT_Close (timer_ctrl_t * const p_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Sets driver version based on compile time macros.  Implements @ref timer_api_t::versionGet.
- *
- * @retval     FSP_SUCCESS          Version in p_version.
- * @retval     FSP_ERR_ASSERTION    The parameter p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_AGT_VersionGet (fsp_version_t * const p_version)
-{
-#if AGT_CFG_PARAM_CHECKING_ENABLE
-
-    /* Verify parameters are valid */
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = s_agt_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /** @} (end addtogroup AGT) */
 
 /***********************************************************************************************************************
@@ -605,7 +658,7 @@ fsp_err_t R_AGT_VersionGet (fsp_version_t * const p_version)
  * Parameter checking for R_AGT_Open.
  *
  * @param[in] p_instance_ctrl          Pointer to instance control structure.
- * @param[in]  p_cfg              Configuration structure for this instance
+ * @param[in] p_cfg                    Configuration structure for this instance
  *
  * @retval FSP_SUCCESS                 Initialization was successful and timer has started.
  * @retval FSP_ERR_ASSERTION           A required input pointer is NULL or the period is not in the valid range of
@@ -630,10 +683,13 @@ static fsp_err_t r_agt_open_param_checking (agt_instance_ctrl_t * p_instance_ctr
         FSP_ERROR_RETURN(p_cfg->cycle_end_irq >= 0, FSP_ERR_IRQ_BSP_DISABLED);
     }
 
-    FSP_ASSERT(0U != p_cfg->period_counts);
+    if (!AGT_PRV_IS_AGTW(p_instance_ctrl))
+    {
+        FSP_ASSERT(0U != p_cfg->period_counts);
 
-    /* Validate period parameter. */
-    FSP_ASSERT(p_cfg->period_counts <= AGT_MAX_PERIOD);
+        /* Validate period parameter. */
+        FSP_ASSERT(p_cfg->period_counts <= AGT_MAX_PERIOD_16BIT);
+    }
 
     /* Validate channel number. */
     FSP_ERROR_RETURN(((1U << p_cfg->channel) & BSP_FEATURE_AGT_VALID_CHANNEL_MASK), FSP_ERR_IP_CHANNEL_NOT_PRESENT);
@@ -642,6 +698,16 @@ static fsp_err_t r_agt_open_param_checking (agt_instance_ctrl_t * p_instance_ctr
     agt_extended_cfg_t const * p_extend = (agt_extended_cfg_t const *) p_cfg->p_extend;
     FSP_ASSERT((AGT_CLOCK_AGT_UNDERFLOW != p_extend->count_source) || (p_cfg->channel & 1U));
 
+    /* Devices with RTCCR.TCEN support P402/P403 as count sources. */
+ #if !BSP_FEATURE_RTC_HAS_TCEN
+    if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+    {
+        /* Return error for MCUs that do not support P402 and P403 as count sources*/
+        FSP_ASSERT(AGT_CLOCK_P402 != p_extend->count_source);
+        FSP_ASSERT(AGT_CLOCK_P403 != p_extend->count_source);
+    }
+ #endif
+
     /* Validate divider. */
     if (AGT_CLOCK_PCLKB == p_extend->count_source)
     {
@@ -681,10 +747,12 @@ static fsp_err_t r_agt_common_preamble (agt_instance_ctrl_t * p_instance_ctrl)
     FSP_ERROR_RETURN(AGT_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
 #endif
 
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+
     /* Ensure timer state reflects expected status. Reference section 25.4.1 "Count Operation Start and Stop Control"
      * in the RA6M3 manual R01UH0886EJ0100. */
-    uint32_t agtcr_tstart = p_instance_ctrl->p_reg->AGTCR_b.TSTART;
-    FSP_HARDWARE_REGISTER_WAIT(agtcr_tstart, p_instance_ctrl->p_reg->AGTCR_b.TCSTF);
+    uint32_t agtcr_tstart = p_reg_ctrl->AGTCR_b.TSTART;
+    FSP_HARDWARE_REGISTER_WAIT(agtcr_tstart, p_reg_ctrl->AGTCR_b.TCSTF);
 
     return FSP_SUCCESS;
 }
@@ -700,21 +768,24 @@ static fsp_err_t r_agt_common_preamble (agt_instance_ctrl_t * p_instance_ctrl)
 static void r_agt_hardware_cfg (agt_instance_ctrl_t * const p_instance_ctrl, timer_cfg_t const * const p_cfg)
 {
     /* Update the divider for PCLKB. */
-    agt_extended_cfg_t const * p_extend = (agt_extended_cfg_t const *) p_cfg->p_extend;
-    uint32_t count_source_int           = (uint32_t) p_extend->count_source;
+    agt_prv_reg_ctrl_ptr_t     p_reg_ctrl = AGT_PRV_CTRL_PTR(p_instance_ctrl);
+    agt_extended_cfg_t const * p_extend   = (agt_extended_cfg_t const *) p_cfg->p_extend;
+    uint32_t count_source_int             = (uint32_t) p_extend->count_source;
     uint32_t agtmr2  = 0U;
     uint32_t agtcmsr = 0U;
     uint32_t tedgsel = 0U;
     uint32_t agtioc  = p_extend->agtio_filter;
-    uint32_t mode    = p_extend->measurement_mode & R_AGT0_AGTMR1_TMOD_Msk;
-    uint32_t edge    = 0U;
+
+    uint32_t mode = p_extend->measurement_mode & R_AGTX0_AGT16_CTRL_AGTMR1_TMOD_Msk;
+
+    uint32_t edge = 0U;
     if (AGT_CLOCK_PCLKB == p_extend->count_source)
     {
         if (TIMER_SOURCE_DIV_1 != p_cfg->source_div)
         {
             /* Toggle the second bit if the count_source_int is not 0 to map PCLKB / 8 to 1 and PCLKB / 2 to 3. */
             count_source_int   = p_cfg->source_div ^ 2U;
-            count_source_int <<= R_AGT0_AGTMR1_TCK_Pos;
+            count_source_int <<= R_AGTX0_AGT16_CTRL_AGTMR1_TCK_Pos;
         }
     }
 
@@ -722,12 +793,21 @@ static void r_agt_hardware_cfg (agt_instance_ctrl_t * const p_instance_ctrl, tim
     else if (AGT_CLOCK_AGTIO & p_extend->count_source)
     {
         /* If the count source is external, configure the AGT for event counter mode. */
-        mode                             = AGT_PRV_AGTMR1_TMOD_EVENT_COUNTER;
-        count_source_int                 = 0U;
-        edge                            |= (p_extend->trigger_edge & R_AGT0_AGTMR1_TEDGPL_Msk);
-        agtioc                          |= (p_extend->enable_pin & R_AGT0_AGTIOC_TIOGT_Msk);
-        p_instance_ctrl->p_reg->AGTISR   = (p_extend->enable_pin & R_AGT0_AGTISR_EEPS_Msk);
-        p_instance_ctrl->p_reg->AGTIOSEL = (uint8_t) (p_extend->count_source & (uint8_t) ~AGT_CLOCK_AGTIO);
+        mode             = AGT_PRV_AGTMR1_TMOD_EVENT_COUNTER;
+        count_source_int = 0U;
+
+        edge              |= (p_extend->trigger_edge & R_AGTX0_AGT16_CTRL_AGTMR1_TEDGPL_Msk);
+        agtioc            |= (p_extend->enable_pin & R_AGTX0_AGT16_CTRL_AGTIOC_TIOGT_Msk);
+        p_reg_ctrl->AGTISR = (p_extend->enable_pin & R_AGTX0_AGT16_CTRL_AGTISR_EEPS_Msk);
+        if (AGT_PRV_IS_AGTW(p_instance_ctrl) && BSP_FEATURE_AGT_USE_AGTIOSEL_ALT)
+        {
+            /* The ALT register is only used for devices with an AGTW whose AGTIOSEL is at offset 0x0F. */
+            p_reg_ctrl->AGTIOSEL_ALT = (uint8_t) (p_extend->count_source & (uint8_t) ~AGT_CLOCK_AGTIO);
+        }
+        else
+        {
+            p_reg_ctrl->AGTIOSEL = (uint8_t) (p_extend->count_source & (uint8_t) ~AGT_CLOCK_AGTIO);
+        }
     }
 #endif
     else if (AGT_CLOCK_AGT_UNDERFLOW != p_extend->count_source)
@@ -753,33 +833,41 @@ static void r_agt_hardware_cfg (agt_instance_ctrl_t * const p_instance_ctrl, tim
     if (TIMER_MODE_PWM == p_instance_ctrl->p_cfg->mode)
     {
         uint32_t inverted_duty_cycle = p_instance_ctrl->p_cfg->period_counts -
-                                       p_instance_ctrl->p_cfg->duty_cycle_counts;
+                                       p_instance_ctrl->p_cfg->duty_cycle_counts - 1;
         uint32_t agtcma = p_instance_ctrl->p_cfg->duty_cycle_counts;
         uint32_t agtcmb = p_instance_ctrl->p_cfg->duty_cycle_counts;
-        if (AGT_PIN_CFG_START_LEVEL_HIGH == p_extend->agtoa)
+        if (AGT_PIN_CFG_START_LEVEL_HIGH == p_extend->agtoab_settings_b.agtoa)
         {
             agtcma = inverted_duty_cycle;
         }
 
-        if (AGT_PIN_CFG_START_LEVEL_HIGH == p_extend->agtob)
+        if (AGT_PIN_CFG_START_LEVEL_HIGH == p_extend->agtoab_settings_b.agtob)
         {
             agtcmb = inverted_duty_cycle;
         }
 
-        p_instance_ctrl->p_reg->AGTCMA = (uint16_t) agtcma;
-        p_instance_ctrl->p_reg->AGTCMB = (uint16_t) agtcmb;
+        if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+        {
+            p_instance_ctrl->p_reg->AGT32.AGTCMA = agtcma;
+            p_instance_ctrl->p_reg->AGT32.AGTCMB = agtcmb;
+        }
+        else
+        {
+            p_instance_ctrl->p_reg->AGT16.AGTCMA = (uint16_t) agtcma;
+            p_instance_ctrl->p_reg->AGT16.AGTCMB = (uint16_t) agtcmb;
+        }
     }
 
     /* Configure TEDGSEL bit based on user input. */
     if (AGT_PIN_CFG_DISABLED != p_extend->agto)
     {
         /* Set the TOE bit if AGTO is enabled.  AGTO can be enabled in any mode. */
-        agtioc |= (1U << R_AGT0_AGTIOC_TOE_Pos);
+        agtioc |= (1U << R_AGTX0_AGT16_CTRL_AGTIOC_TOE_Pos);
 
         if (AGT_PIN_CFG_START_LEVEL_LOW == p_extend->agto)
         {
             /* Configure the start level of AGTO. */
-            tedgsel |= (1U << R_AGT0_AGTIOC_TEDGSEL_Pos);
+            tedgsel |= (1U << R_AGTX0_AGT16_CTRL_AGTIOC_TEDGSEL_Pos);
         }
     }
 #endif
@@ -798,17 +886,17 @@ static void r_agt_hardware_cfg (agt_instance_ctrl_t * const p_instance_ctrl, tim
         else
         {
             /* Use the trigger edge for pulse period or event counting modes. */
-            tedgsel = (p_extend->trigger_edge & R_AGT0_AGTIOC_TEDGSEL_Msk);
+            tedgsel = (p_extend->trigger_edge & R_AGTX0_AGT16_CTRL_AGTIOC_TEDGSEL_Msk);
         }
     }
 #endif
 
     agtioc |= tedgsel;
 
-    p_instance_ctrl->p_reg->AGTIOC  = (uint8_t) agtioc;
-    p_instance_ctrl->p_reg->AGTCMSR = (uint8_t) agtcmsr;
-    p_instance_ctrl->p_reg->AGTMR1  = (uint8_t) agtmr1;
-    p_instance_ctrl->p_reg->AGTMR2  = (uint8_t) agtmr2;
+    p_reg_ctrl->AGTIOC  = (uint8_t) agtioc;
+    p_reg_ctrl->AGTCMSR = (uint8_t) agtcmsr;
+    p_reg_ctrl->AGTMR1  = (uint8_t) agtmr1;
+    p_reg_ctrl->AGTMR2  = (uint8_t) agtmr2;
 }
 
 /*******************************************************************************************************************//**
@@ -823,13 +911,13 @@ static void r_agt_period_register_set (agt_instance_ctrl_t * p_instance_ctrl, ui
     p_instance_ctrl->period = period_counts;
     gp_prv_agt_periods[p_instance_ctrl->p_cfg->channel] = period_counts;
 
-    uint16_t period_reg = (uint16_t) (period_counts - 1U);
+    uint32_t period_reg = (period_counts - 1U);
 
 #if AGT_CFG_OUTPUT_SUPPORT_ENABLE
-    uint16_t duty_cycle_counts = 0U;
+    uint32_t duty_cycle_counts = 0U;
     if (TIMER_MODE_PERIODIC == p_instance_ctrl->p_cfg->mode)
     {
-        duty_cycle_counts = (uint16_t) (period_counts >> 1);
+        duty_cycle_counts = (period_counts >> 1);
     }
     else if (TIMER_MODE_ONE_SHOT == p_instance_ctrl->p_cfg->mode)
     {
@@ -842,26 +930,44 @@ static void r_agt_period_register_set (agt_instance_ctrl_t * p_instance_ctrl, ui
 
     if (TIMER_MODE_PWM != p_instance_ctrl->p_cfg->mode)
     {
-        p_instance_ctrl->p_reg->AGTCMA = duty_cycle_counts;
-        p_instance_ctrl->p_reg->AGTCMB = duty_cycle_counts;
+        if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+        {
+            p_instance_ctrl->p_reg->AGT32.AGTCMA = duty_cycle_counts;
+            p_instance_ctrl->p_reg->AGT32.AGTCMB = duty_cycle_counts;
+        }
+        else
+        {
+            p_instance_ctrl->p_reg->AGT16.AGTCMA = (uint16_t) duty_cycle_counts;
+            p_instance_ctrl->p_reg->AGT16.AGTCMB = (uint16_t) duty_cycle_counts;
+        }
     }
 #endif
 
     /* Set counter to period minus one. */
-    p_instance_ctrl->p_reg->AGT = period_reg;
+    if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+    {
+        p_instance_ctrl->p_reg->AGT32.AGT = period_reg;
+    }
+    else
+    {
+        p_instance_ctrl->p_reg->AGT16.AGT = (uint16_t) period_reg;
+    }
 }
 
 /*******************************************************************************************************************//**
  * Obtains the clock frequency of AGT for all clock sources except AGT0 underflow, with divisor applied.
  *
  * @param[in]  p_agt_regs         Registers of AGT channel used
+ * @param[in]  is_agtw            Specifies this AGT channel is using the AGTW peripheral.
  *
  * @return Source clock frequency of AGT in Hz, divider applied.
  **********************************************************************************************************************/
-static uint32_t r_agt_clock_frequency_get (R_AGT0_Type * p_agt_regs)
+static uint32_t r_agt_clock_frequency_get (R_AGTX0_Type * p_agt_regs, bool is_agtw)
 {
+    agt_prv_reg_ctrl_ptr_t p_agt_regs_ctrl = is_agtw ? &p_agt_regs->AGT32.CTRL : &p_agt_regs->AGT16.CTRL;
+
     uint32_t           clock_freq_hz    = 0U;
-    uint8_t            count_source_int = p_agt_regs->AGTMR1_b.TCK;
+    uint8_t            count_source_int = p_agt_regs_ctrl->AGTMR1_b.TCK;
     timer_source_div_t divider          = TIMER_SOURCE_DIV_1;
     if (0U == (count_source_int & (~AGT_SOURCE_CLOCK_PCLKB_BITS)))
     {
@@ -883,7 +989,7 @@ static uint32_t r_agt_clock_frequency_get (R_AGT0_Type * p_agt_regs)
          * support AGT0 underflow as count source.  */
         clock_freq_hz = FSUB_FREQUENCY_HZ;
 
-        divider = (timer_source_div_t) p_agt_regs->AGTMR2_b.CKS;
+        divider = (timer_source_div_t) p_agt_regs_ctrl->AGTMR2_b.CKS;
     }
 
     clock_freq_hz >>= divider;
@@ -905,10 +1011,11 @@ void agt_int_isr (void)
     R_BSP_IrqStatusClear(irq);
 
     /* Recover ISR context saved in open. */
-    agt_instance_ctrl_t * p_instance_ctrl = (agt_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
+    agt_instance_ctrl_t  * p_instance_ctrl = (agt_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
+    agt_prv_reg_ctrl_ptr_t p_reg_ctrl      = AGT_PRV_CTRL_PTR(p_instance_ctrl);
 
     /* Save AGTCR to determine the source of the interrupt. */
-    uint32_t agtcr = p_instance_ctrl->p_reg->AGTCR;
+    uint32_t agtcr = p_reg_ctrl->AGTCR;
 
     /* If the channel is configured to be one-shot mode, stop the timer. */
     if (TIMER_MODE_ONE_SHOT == p_instance_ctrl->p_cfg->mode)
@@ -917,20 +1024,18 @@ void agt_int_isr (void)
 
         /* Forcibly stopping the timer resets AGTCMSR, AGTCMA, and AGTCMB. AGTCMA and AGTCMB are based on the
          * timer period, but AGTCMSR must be saved so it can be restored. */
-        uint8_t agtcmsr = p_instance_ctrl->p_reg->AGTCMSR;
+        uint8_t agtcmsr = p_reg_ctrl->AGTCMSR;
 #endif
 
-        /* Stop timer */
-        p_instance_ctrl->p_reg->AGTCR = AGT_PRV_AGTCR_FORCE_STOP;
-        agtcr &= AGT_PRV_AGTCR_STATUS_FLAGS;
-
-        /* Set counter to period minus one. */
-        r_agt_period_register_set(p_instance_ctrl, p_instance_ctrl->period);
+        /* Stop timer. This resets the timer period (AGT register). The AGT register is reconfigured in R_AGT_Start(). */
+        p_reg_ctrl->AGTCR = AGT_PRV_AGTCR_FORCE_STOP;
+        agtcr            &= AGT_PRV_AGTCR_STATUS_FLAGS;
+        p_reg_ctrl->AGTCR = (uint8_t) agtcr;
 
 #if AGT_CFG_OUTPUT_SUPPORT_ENABLE
 
         /* Restore AGTCMSR. */
-        p_instance_ctrl->p_reg->AGTCMSR = agtcmsr;
+        p_reg_ctrl->AGTCMSR = agtcmsr;
 #endif
     }
 
@@ -954,7 +1059,7 @@ void agt_int_isr (void)
             callback_args = *p_args;
         }
 
-        if (agtcr & R_AGT0_AGTCR_TUNDF_Msk)
+        if (agtcr & R_AGTX0_AGT16_CTRL_AGTCR_TUNDF_Msk)
         {
             p_args->event = TIMER_EVENT_CYCLE_END;
         }
@@ -964,14 +1069,28 @@ void agt_int_isr (void)
         {
             p_args->event = TIMER_EVENT_CAPTURE_A;
             uint32_t reload_value = p_instance_ctrl->period - 1U;
-            p_args->capture = reload_value - p_instance_ctrl->p_reg->AGT;
+            if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+            {
+                p_args->capture = reload_value - p_instance_ctrl->p_reg->AGT32.AGT;
+            }
+            else
+            {
+                p_args->capture = reload_value - p_instance_ctrl->p_reg->AGT16.AGT;
+            }
 
             /* The AGT counter is not reset in pulse width measurement mode. Reset it by software. Note that this
              * will restart the counter if a new capture has already started. Application writers must ensure that
              * this interrupt processing completes before the next capture begins. */
-            if (AGT_PRV_AGTMR1_TMOD_PULSE_WIDTH == p_instance_ctrl->p_reg->AGTMR1_b.TMOD)
+            if (AGT_PRV_AGTMR1_TMOD_PULSE_WIDTH == p_reg_ctrl->AGTMR1_b.TMOD)
             {
-                p_instance_ctrl->p_reg->AGT = (uint16_t) reload_value;
+                if (AGT_PRV_IS_AGTW(p_instance_ctrl))
+                {
+                    p_instance_ctrl->p_reg->AGT32.AGT = reload_value;
+                }
+                else
+                {
+                    p_instance_ctrl->p_reg->AGT16.AGT = (uint16_t) reload_value;
+                }
             }
             else
             {
@@ -1010,10 +1129,13 @@ void agt_int_isr (void)
             /* Restore callback memory in case this is a nested interrupt. */
             *p_instance_ctrl->p_callback_memory = callback_args;
         }
+
+        /* Retreive AGTCR in case it was modified in the callback. */
+        agtcr = p_reg_ctrl->AGTCR;
     }
 
     /* Clear flags in AGTCR. */
-    p_instance_ctrl->p_reg->AGTCR = (uint8_t) (agtcr & ~AGT_PRV_AGTCR_STATUS_FLAGS);
+    p_reg_ctrl->AGTCR = (uint8_t) (agtcr & ~AGT_PRV_AGTCR_STATUS_FLAGS);
 
     /* Restore context if RTOS is used */
     FSP_CONTEXT_RESTORE
