@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -100,15 +100,6 @@ static void r_cac_isr_handler(cac_event_t event, uint32_t clear_mask);
 static const char g_module_name[] = "cac";
 #endif
 
-/** Version data structure used by error logger macro. */
-static const fsp_version_t g_cac_version =
-{
-    .api_version_minor  = CAC_API_VERSION_MINOR,
-    .api_version_major  = CAC_API_VERSION_MAJOR,
-    .code_version_major = CAC_CODE_VERSION_MAJOR,
-    .code_version_minor = CAC_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global Variables
  **********************************************************************************************************************/
@@ -122,7 +113,6 @@ const cac_api_t g_cac_on_cac =
     .read             = R_CAC_Read,
     .callbackSet      = R_CAC_CallbackSet,
     .close            = R_CAC_Close,
-    .versionGet       = R_CAC_VersionGet
 };
 
 /*******************************************************************************************************************//**
@@ -336,23 +326,6 @@ fsp_err_t R_CAC_Close (cac_ctrl_t * const p_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Get the API and code version information.
- *
- * @retval FSP_SUCCESS              Version info returned.
- * @retval FSP_ERR_ASSERTION        An argument is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_CAC_VersionGet (fsp_version_t * const p_version)
-{
-#if CAC_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_cac_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup CAC)
  **********************************************************************************************************************/
@@ -515,11 +488,13 @@ static void r_cac_isr_handler (cac_event_t event, uint32_t clear_mask)
  **********************************************************************************************************************/
 void cac_ferri_isr (void)
 {
-    FSP_CONTEXT_SAVE;
-
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
+    /* Call isr handler */
     r_cac_isr_handler(CAC_EVENT_FREQUENCY_ERROR, CAC_PRV_CAICR_FERRFCL_MASK);
 
-    FSP_CONTEXT_RESTORE;
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -527,11 +502,13 @@ void cac_ferri_isr (void)
  **********************************************************************************************************************/
 void cac_ovfi_isr (void)
 {
-    FSP_CONTEXT_SAVE;
-
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
+    /* Call isr handler */
     r_cac_isr_handler(CAC_EVENT_COUNTER_OVERFLOW, CAC_PRV_CAICR_OVFFCL_MASK);
 
-    FSP_CONTEXT_RESTORE;
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -539,9 +516,11 @@ void cac_ovfi_isr (void)
  **********************************************************************************************************************/
 void cac_mendi_isr (void)
 {
-    FSP_CONTEXT_SAVE;
-
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
+    /* Call isr handler */
     r_cac_isr_handler(CAC_EVENT_MEASUREMENT_COMPLETE, CAC_PRV_CAICR_MENDFCL_MASK);
 
-    FSP_CONTEXT_RESTORE;
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
 }
