@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -112,7 +112,7 @@ static void      r_dmac_config_transfer_info(dmac_instance_ctrl_t * p_ctrl, tran
 
 #if DMAC_CFG_PARAM_CHECKING_ENABLE
 static fsp_err_t r_dma_open_parameter_checking(dmac_instance_ctrl_t * const p_ctrl, transfer_cfg_t const * const p_cfg);
-static fsp_err_t r_dmac_info_paramter_checking(transfer_info_t const * const p_info);
+static fsp_err_t r_dmac_reconfigure_paramter_checking(transfer_info_t const * const p_info);
 static fsp_err_t r_dmac_enable_parameter_checking(dmac_instance_ctrl_t * const p_ctrl);
 
 #endif
@@ -121,15 +121,6 @@ static fsp_err_t r_dmac_enable_parameter_checking(dmac_instance_ctrl_t * const p
  * Private global variables
  **********************************************************************************************************************/
 
-/** Version data structure used by error logger macro. */
-static const fsp_version_t g_dmac_version =
-{
-    .api_version_minor  = TRANSFER_API_VERSION_MINOR,
-    .api_version_major  = TRANSFER_API_VERSION_MAJOR,
-    .code_version_major = DMAC_CODE_VERSION_MAJOR,
-    .code_version_minor = DMAC_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Exported global variables
  **********************************************************************************************************************/
@@ -146,7 +137,6 @@ const transfer_api_t g_transfer_on_dmac =
     .enable        = R_DMAC_Enable,
     .disable       = R_DMAC_Disable,
     .close         = R_DMAC_Close,
-    .versionGet    = R_DMAC_VersionGet,
 };
 
 /*******************************************************************************************************************//**
@@ -211,7 +201,7 @@ fsp_err_t R_DMAC_Reconfigure (transfer_ctrl_t * const p_api_ctrl, transfer_info_
 #if DMAC_CFG_PARAM_CHECKING_ENABLE
     FSP_ASSERT(p_ctrl != NULL);
     FSP_ERROR_RETURN(p_ctrl->open == DMAC_ID, FSP_ERR_NOT_OPEN);
-    err = r_dmac_info_paramter_checking(p_info);
+    err = r_dmac_reconfigure_paramter_checking(p_info);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 #endif
 
@@ -414,8 +404,12 @@ fsp_err_t R_DMAC_Close (transfer_ctrl_t * const p_api_ctrl)
     dmac_extended_cfg_t * p_extend = (dmac_extended_cfg_t *) p_ctrl->p_cfg->p_extend;
 
     /* Disable DMAC transfers on this channel. */
+#if !BSP_FEATURE_DMAC_HAS_DELSR
     R_ICU->DELSR[p_extend->channel] = ELC_EVENT_NONE;
-    p_ctrl->p_reg->DMCNT            = 0;
+#else
+    R_DMA->DELSR[p_extend->channel] = ELC_EVENT_NONE;
+#endif
+    p_ctrl->p_reg->DMCNT = 0;
 
     if (NULL != p_extend->p_callback)
     {
@@ -429,25 +423,6 @@ fsp_err_t R_DMAC_Close (transfer_ctrl_t * const p_api_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Set driver version based on compile time macros.
- *
- * @retval FSP_SUCCESS              Successful close.
- * @retval FSP_ERR_ASSERTION        An input parameter is invalid.
- **********************************************************************************************************************/
-fsp_err_t R_DMAC_VersionGet (fsp_version_t * const p_version)
-{
-#if DMAC_CFG_PARAM_CHECKING_ENABLE
-
-    /* Verify parameters are valid */
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_dmac_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup DMAC)
  **********************************************************************************************************************/
@@ -488,11 +463,20 @@ static void r_dmac_prv_disable (dmac_instance_ctrl_t * p_ctrl)
 
     /* Disable the transfers. Reference Figure 17.12  "Register setting procedure" in the RA6M3 Hardware manual
      * R01UH0886EJ0100. */
+#if !BSP_FEATURE_DMAC_HAS_DELSR
     R_ICU->DELSR[p_extend->channel] = ELC_EVENT_NONE;
-    p_ctrl->p_reg->DMCNT            = 0;
+#else
+    R_DMA->DELSR[p_extend->channel] = ELC_EVENT_NONE;
+#endif
+
+    p_ctrl->p_reg->DMCNT = 0;
 
     /* Configure the activation source. */
+#if !BSP_FEATURE_DMAC_HAS_DELSR
     R_ICU->DELSR[p_extend->channel] = p_extend->activation_source;
+#else
+    R_DMA->DELSR[p_extend->channel] = p_extend->activation_source;
+#endif
 
     /* Disable software start. */
     p_ctrl->p_reg->DMREQ = 0;
@@ -518,19 +502,21 @@ static void r_dmac_config_transfer_info (dmac_instance_ctrl_t * p_ctrl, transfer
     r_dmac_prv_disable(p_ctrl);
 
     /* Configure the Transfer Data Size (1,2,4) bytes. */
-    dmtmd |= (uint32_t) (p_info->size << DMAC_PRV_DMTMD_SZ_OFFSET);
+    dmtmd |= (uint32_t) (p_info->transfer_settings_word_b.size << DMAC_PRV_DMTMD_SZ_OFFSET);
 
     /* Configure source and destination address mode. */
-    dmamd |= (uint32_t) (p_info->src_addr_mode << DMAC_PRV_DMAMD_SM_OFFSET);
-    dmamd |= (uint32_t) (p_info->dest_addr_mode << DMAC_PRV_DMAMD_DM_OFFSET);
+    dmamd |= (uint32_t) (p_info->transfer_settings_word_b.src_addr_mode << DMAC_PRV_DMAMD_SM_OFFSET);
+    dmamd |= (uint32_t) (p_info->transfer_settings_word_b.dest_addr_mode << DMAC_PRV_DMAMD_DM_OFFSET);
 
     /* Configure the transfer mode. */
-    dmtmd |= (uint32_t) p_info->mode << DMAC_PRV_DMTMD_MD_OFFSET;
+    dmtmd |= (uint32_t) p_info->transfer_settings_word_b.mode << DMAC_PRV_DMTMD_MD_OFFSET;
 
     /* Configure the transfer count. */
     dmcra = p_info->length;
 
-    if ((TRANSFER_MODE_BLOCK == p_info->mode) || (TRANSFER_MODE_REPEAT == p_info->mode))
+    if ((TRANSFER_MODE_BLOCK == p_info->transfer_settings_word_b.mode) ||
+        (TRANSFER_MODE_REPEAT == p_info->transfer_settings_word_b.mode) ||
+        (TRANSFER_MODE_REPEAT_BLOCK == p_info->transfer_settings_word_b.mode))
     {
         /* Configure the reload count. */
         dmcra |= dmcra << DMAC_PRV_DMCRA_HIGH_OFFSET;
@@ -539,8 +525,12 @@ static void r_dmac_config_transfer_info (dmac_instance_ctrl_t * p_ctrl, transfer
         /* Configure the block count. */
         dmcrb = p_info->num_blocks;
 
-        /* Configure the repeat area */
-        dmtmd |= (uint32_t) (p_info->repeat_area << DMAC_PRV_DMTMD_DTS_OFFSET);
+        if ((TRANSFER_MODE_BLOCK == p_info->transfer_settings_word_b.mode) ||
+            (TRANSFER_MODE_REPEAT == p_info->transfer_settings_word_b.mode))
+        {
+            /* Configure the repeat area */
+            dmtmd |= (uint32_t) (p_info->transfer_settings_word_b.repeat_area << DMAC_PRV_DMTMD_DTS_OFFSET);
+        }
     }
     else                               /* TRANSFER_MODE_NORMAL */
     {
@@ -559,7 +549,12 @@ static void r_dmac_config_transfer_info (dmac_instance_ctrl_t * p_ctrl, transfer
         /* Enable transfer end interrupt requests. */
         dmint |= DMAC_PRV_DMINT_DTIE_MASK;
 
-        if (TRANSFER_IRQ_EACH == p_info->irq)
+        /* Enable the transfer end escape interrupt requests.
+         * Repeat size end and Extended Repeat area overflow requests are not
+         * used with Repeat-Block mode. Reference section 16.2.9 "DMINT : DMA Interrupt Setting Register"
+         * of RA6M4 hardware manual R01UH0890EJ0110. */
+        if ((TRANSFER_IRQ_EACH == p_info->transfer_settings_word_b.irq) &&
+            (TRANSFER_MODE_REPEAT_BLOCK != p_info->transfer_settings_word_b.mode))
         {
             /* Enable the transfer end escape interrupt requests
              * (Repeat size end and Extended Repeat area overflow requests). */
@@ -570,6 +565,51 @@ static void r_dmac_config_transfer_info (dmac_instance_ctrl_t * p_ctrl, transfer
         R_BSP_IrqCfgEnable(p_extend->irq, p_extend->ipl, p_ctrl);
     }
 
+#if BSP_FEATURE_DMAC_HAS_REPEAT_BLOCK_MODE
+    uint32_t dmsbs = 0;
+    uint32_t dmdbs = 0;
+
+    if (TRANSFER_MODE_REPEAT_BLOCK == p_info->transfer_settings_word_b.mode)
+    {
+        uint16_t num_of_blocks = p_info->num_blocks;
+        uint16_t size_of_block;
+        size_of_block = p_info->length;
+        uint16_t src_buffer_size;
+        uint16_t dest_buffer_size;
+        if (TRANSFER_ADDR_MODE_OFFSET == p_info->transfer_settings_word_b.src_addr_mode)
+        {
+            src_buffer_size = num_of_blocks;
+            dmamd          |= R_DMAC0_DMAMD_SADR_Msk;
+        }
+        else
+        {
+            src_buffer_size = p_extend->src_buffer_size;
+        }
+
+        if (TRANSFER_ADDR_MODE_OFFSET == p_info->transfer_settings_word_b.dest_addr_mode)
+        {
+            dest_buffer_size = num_of_blocks;
+            dmamd           |= R_DMAC0_DMAMD_DADR_Msk;
+        }
+        else
+        {
+            dest_buffer_size = (uint16_t) (num_of_blocks * size_of_block);
+        }
+
+        dmsbs  = src_buffer_size;
+        dmsbs |= dmsbs << R_DMAC0_DMSBS_DMSBSH_Pos;
+
+        dmdbs  = dest_buffer_size;
+        dmdbs |= dmdbs << R_DMAC0_DMDBS_DMDBSH_Pos;
+
+        p_ctrl->p_reg->DMSRR = (uint32_t) p_info->p_src;
+        p_ctrl->p_reg->DMDRR = (uint32_t) p_info->p_dest;
+    }
+
+    p_ctrl->p_reg->DMSBS = dmsbs;
+    p_ctrl->p_reg->DMDBS = dmdbs;
+#endif
+
     /* Write register settings. */
     p_ctrl->p_reg->DMAMD = (uint16_t) dmamd;
     p_ctrl->p_reg->DMTMD = (uint16_t) dmtmd;
@@ -610,7 +650,7 @@ static fsp_err_t r_dma_open_parameter_checking (dmac_instance_ctrl_t * const p_c
         FSP_ERROR_RETURN(p_extend->irq >= 0, FSP_ERR_IRQ_BSP_DISABLED);
     }
 
-    fsp_err_t err = r_dmac_info_paramter_checking(p_cfg->p_info);
+    fsp_err_t err = r_dmac_reconfigure_paramter_checking(p_cfg->p_info);
     FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
 
     return FSP_SUCCESS;
@@ -624,15 +664,18 @@ static fsp_err_t r_dma_open_parameter_checking (dmac_instance_ctrl_t * const p_c
  * @retval FSP_SUCCESS              The transfer info is valid.
  * @retval FSP_ERR_ASSERTION        A transfer info setting is invalid.
  **********************************************************************************************************************/
-static fsp_err_t r_dmac_info_paramter_checking (transfer_info_t const * const p_info)
+static fsp_err_t r_dmac_reconfigure_paramter_checking (transfer_info_t const * const p_info)
 {
     FSP_ASSERT(p_info != NULL);
 
-    if (TRANSFER_MODE_NORMAL != p_info->mode)
+    if (TRANSFER_MODE_NORMAL != p_info->transfer_settings_word_b.mode)
     {
         FSP_ASSERT(p_info->length <= DMAC_REPEAT_BLOCK_MAX_LENGTH);
     }
 
+    FSP_ASSERT((TRANSFER_MODE_REPEAT_BLOCK != p_info->transfer_settings_word_b.mode) ||
+               (TRANSFER_IRQ_EACH != p_info->transfer_settings_word_b.irq));
+
     return FSP_SUCCESS;
 }
 
