@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -85,7 +85,7 @@
 #define IIC_MASTER_FUNCTION_ENABLE_INIT_SETTINGS    (0x77U)
 #define IIC_MASTER_STATUS_REGISTER_2_ERR_MASK       (0x1FU)
 #define IIC_MASTER_BUS_MODE_REGISTER_1_MASK         (0x08U)
-#define IIC_MASTER_BUS_MODE_REGISTER_2_MASK         (0x06U)
+#define IIC_MASTER_BUS_MODE_REGISTER_2_MASK         (0x04U)
 #define IIC_MASTER_SYSDIVCK_ICLK_MASK               (0x0F000000U)
 #define IIC_MASTER_SYSDIVCK_PCLKB_MASK              (0x00000F00U)
 #define IIC_MASTER_PRV_SCL_SDA_NOT_DRIVEN           (0x1FU)
@@ -157,10 +157,9 @@ static fsp_err_t iic_master_read_write(i2c_master_ctrl_t * const p_api_ctrl,
 static void iic_master_notify(iic_master_instance_ctrl_t * const p_ctrl, i2c_master_event_t const event);
 
 #if IIC_MASTER_CFG_DTC_ENABLE
-static fsp_err_t iic_master_transfer_open(iic_master_instance_ctrl_t * p_ctrl, i2c_master_cfg_t const * const p_cfg);
-static fsp_err_t iic_master_transfer_configure(iic_master_instance_ctrl_t * p_ctrl,
-                                               transfer_instance_t const  * p_transfer,
-                                               iic_master_transfer_dir_t    direction);
+static fsp_err_t iic_master_transfer_open(i2c_master_cfg_t const * const p_cfg);
+static fsp_err_t iic_master_transfer_configure(transfer_instance_t const * p_transfer,
+                                               iic_master_transfer_dir_t   direction);
 
 #endif
 
@@ -180,13 +179,6 @@ static void      iic_master_txi_send_address(iic_master_instance_ctrl_t * const
 /***********************************************************************************************************************
  * Private global variables
  **********************************************************************************************************************/
-static fsp_version_t const g_iic_master_version =
-{
-    .api_version_minor  = I2C_MASTER_API_VERSION_MINOR,
-    .api_version_major  = I2C_MASTER_API_VERSION_MAJOR,
-    .code_version_major = IIC_MASTER_CODE_VERSION_MAJOR,
-    .code_version_minor = IIC_MASTER_CODE_VERSION_MINOR
-};
 
 /***********************************************************************************************************************
  * Global variables
@@ -201,7 +193,7 @@ i2c_master_api_t const g_i2c_master_on_iic =
     .abort           = R_IIC_MASTER_Abort,
     .slaveAddressSet = R_IIC_MASTER_SlaveAddressSet,
     .close           = R_IIC_MASTER_Close,
-    .versionGet      = R_IIC_MASTER_VersionGet,
+    .statusGet       = R_IIC_MASTER_StatusGet,
     .callbackSet     = R_IIC_MASTER_CallbackSet
 };
 
@@ -254,8 +246,6 @@ fsp_err_t R_IIC_MASTER_Open (i2c_master_ctrl_t * const p_api_ctrl, i2c_master_cf
 
     p_ctrl->p_reg = (R_IIC0_Type *) ((uint32_t) R_IIC0 + (p_cfg->channel * ((uint32_t) R_IIC1 - (uint32_t) R_IIC0)));
 
-    p_ctrl->timeout_mode = ((iic_master_extended_cfg_t *) p_cfg->p_extend)->timeout_mode;
-
     /* Record the pointer to the configuration structure for later use */
     p_ctrl->p_cfg             = p_cfg;
     p_ctrl->slave             = p_cfg->slave;
@@ -273,7 +263,7 @@ fsp_err_t R_IIC_MASTER_Open (i2c_master_ctrl_t * const p_api_ctrl, i2c_master_cf
 #if IIC_MASTER_CFG_DTC_ENABLE
 
     /* Open the IIC transfer interface if available */
-    err = iic_master_transfer_open(p_ctrl, p_cfg);
+    err = iic_master_transfer_open(p_cfg);
     if (FSP_SUCCESS != err)
     {
         R_BSP_MODULE_STOP(FSP_IP_IIC, p_cfg->channel);
@@ -470,6 +460,26 @@ fsp_err_t R_IIC_MASTER_CallbackSet (i2c_master_ctrl_t * const          p_api_ctr
     return FSP_SUCCESS;
 }
 
+/*******************************************************************************************************************//**
+ * Provides driver status.
+ *
+ * @retval     FSP_SUCCESS                   Status stored in p_status.
+ * @retval     FSP_ERR_ASSERTION             NULL pointer.
+ **********************************************************************************************************************/
+fsp_err_t R_IIC_MASTER_StatusGet (i2c_master_ctrl_t * const p_api_ctrl, i2c_master_status_t * p_status)
+{
+    iic_master_instance_ctrl_t * p_ctrl = (iic_master_instance_ctrl_t *) p_api_ctrl;
+
+#if IIC_MASTER_CFG_PARAM_CHECKING_ENABLE
+    FSP_ASSERT(p_ctrl != NULL);
+    FSP_ASSERT(p_status != NULL);
+#endif
+
+    p_status->open = (IIC_MASTER_OPEN == p_ctrl->open);
+
+    return FSP_SUCCESS;
+}
+
 /*******************************************************************************************************************//**
  * Closes the I2C device. May power down IIC peripheral.
  * This function will safely terminate any in-progress I2C transfers.
@@ -523,23 +533,6 @@ fsp_err_t R_IIC_MASTER_Close (i2c_master_ctrl_t * const p_api_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Gets version information and stores it in the provided version structure.
- *
- * @retval  FSP_SUCCESS                 Successful version get.
- * @retval  FSP_ERR_ASSERTION           p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_IIC_MASTER_VersionGet (fsp_version_t * const p_version)
-{
-#if IIC_MASTER_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(p_version != NULL);
-#endif
-
-    p_version->version_id = g_iic_master_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup IIC_MASTER)
  **********************************************************************************************************************/
@@ -705,45 +698,28 @@ static void iic_master_notify (iic_master_instance_ctrl_t * const p_ctrl, i2c_ma
  **********************************************************************************************************************/
 static void iic_master_abort_seq_master (iic_master_instance_ctrl_t * const p_ctrl, bool iic_reset)
 {
-    /* Check if there is an in-progress transfer associated with the match or an error event occurred */
-    if ((0U != p_ctrl->remain) || (p_ctrl->restarted) || (true == p_ctrl->err))
+    /* Safely stop the hardware from operating. */
+
+    /* Reset the peripheral */
+    if (true == iic_reset)
     {
-        /* Reset the peripheral */
-        if (true == iic_reset)
-        {
-            /* Disable channel interrupts */
-            p_ctrl->p_reg->ICIER = 0x00;
+        /* Disable channel interrupts */
+        p_ctrl->p_reg->ICIER = 0x00;
 
-            /* Do I2C internal reset to clear all the transaction states and release the bus */
-            p_ctrl->p_reg->ICCR1 = (uint8_t) IIC_MASTER_PRV_SCL_SDA_NOT_DRIVEN;
-
-            /* Reset */
-            p_ctrl->p_reg->ICCR1 = (uint8_t) (IIC_MASTER_ICCR1_IICRST_BIT_MASK | IIC_MASTER_PRV_SCL_SDA_NOT_DRIVEN);
-
-            /* Clear pending interrupt in ICU and NVIC. It is ok to re-enable interrupts  at NVIC here. */
-            R_BSP_IrqEnable(p_ctrl->p_cfg->eri_irq);
-            R_BSP_IrqEnable(p_ctrl->p_cfg->rxi_irq);
-            R_BSP_IrqEnable(p_ctrl->p_cfg->tei_irq);
-            R_BSP_IrqEnable(p_ctrl->p_cfg->txi_irq);
-
-            /* Release peripheral from internal reset */
-            p_ctrl->p_reg->ICCR1 =
-                (uint8_t) (IIC_MASTER_ICCR1_ICE_BIT_MASK | IIC_MASTER_ICCR1_IICRST_BIT_MASK |
-                           IIC_MASTER_PRV_SCL_SDA_NOT_DRIVEN);
-
-            /* Reset */
-            p_ctrl->p_reg->ICCR1 = (uint8_t) (IIC_MASTER_ICCR1_ICE_BIT_MASK | IIC_MASTER_PRV_SCL_SDA_NOT_DRIVEN);
-        }
-
-        /* Update the transfer descriptor to show no longer in-progress and an error */
-        p_ctrl->remain = 0U;
-
-        /* Update the transfer descriptor to make sure interrupts no longer process */
-        p_ctrl->addr_loaded = p_ctrl->addr_total;
-        p_ctrl->loaded      = p_ctrl->total;
-        p_ctrl->restarted   = false;
+        /* This helper function would do a full IIC reset
+         * followed by re-initializing the required peripheral registers. */
+        iic_master_open_hw_master(p_ctrl, p_ctrl->p_cfg);
     }
 
+    /* Update the transfer descriptor to show no longer in-progress and an error */
+    p_ctrl->remain = 0U;
+
+    /* Update the transfer descriptor to make sure interrupts no longer process */
+    p_ctrl->addr_loaded = p_ctrl->addr_total;
+    p_ctrl->loaded      = p_ctrl->total;
+    p_ctrl->restarted   = false;
+    p_ctrl->restart     = false;
+
     /* Enable Interrupts: TMOIE, ALIE, NAKIE, RIE, TIE.
      * Disable Interrupt: TEIE, STIE, SPIE
      * (see Section 36.2.8 'I2C Bus Interrupt Enable Register (ICIER)' of the RA6M3 manual R01UH0886EJ0100).
@@ -795,8 +771,12 @@ static void iic_master_open_hw_master (iic_master_instance_ctrl_t * const p_ctrl
      * Only Set/Clear TMOS here to select long or short mode.
      * (see Section 36.2.4 'I2C Bus Mode Register 2 (ICMR2)' of the RA6M3 manual R01UH0886EJ0100).
      */
-    p_ctrl->p_reg->ICMR2 = IIC_MASTER_BUS_MODE_REGISTER_2_MASK |
-                           (uint8_t) (IIC_MASTER_TIMEOUT_MODE_SHORT == p_ctrl->timeout_mode);
+    p_ctrl->p_reg->ICMR2 = (uint8_t) (IIC_MASTER_BUS_MODE_REGISTER_2_MASK |
+                                      (uint8_t) (IIC_MASTER_TIMEOUT_MODE_SHORT ==
+                                                 ((iic_master_extended_cfg_t *) p_ctrl->p_cfg->p_extend)->timeout_mode)
+                                      |
+                                      (uint8_t) (((iic_master_extended_cfg_t *) p_ctrl->p_cfg->p_extend)->
+                                                 timeout_scl_low << R_IIC0_ICMR2_TMOL_Pos));
 
     /* ICFER Register Settings:
      * 1. Enable timeout function.
@@ -900,8 +880,12 @@ static fsp_err_t iic_master_run_hw_master (iic_master_instance_ctrl_t * const p_
      * Only Set/Clear TMOS here to select long or short mode.
      * (see Section 36.2.4 'I2C Bus Mode Register 2 (ICMR2)' of the RA6M3 manual R01UH0886EJ0100).
      */
-    p_ctrl->p_reg->ICMR2 = IIC_MASTER_BUS_MODE_REGISTER_2_MASK |
-                           (uint8_t) (IIC_MASTER_TIMEOUT_MODE_SHORT == p_ctrl->timeout_mode);
+    p_ctrl->p_reg->ICMR2 = (uint8_t) (IIC_MASTER_BUS_MODE_REGISTER_2_MASK |
+                                      (uint8_t) (IIC_MASTER_TIMEOUT_MODE_SHORT ==
+                                                 ((iic_master_extended_cfg_t *) p_ctrl->p_cfg->p_extend)->timeout_mode)
+                                      |
+                                      (uint8_t) (((iic_master_extended_cfg_t *) p_ctrl->p_cfg->p_extend)->
+                                                 timeout_scl_low << R_IIC0_ICMR2_TMOL_Pos));
 
     /* Enable timeout function */
     p_ctrl->p_reg->ICFER_b.TMOE = 1U;
@@ -1211,7 +1195,8 @@ static void iic_master_err_master (iic_master_instance_ctrl_t * p_ctrl)
         p_ctrl->p_reg->ICCR2  = (uint8_t) IIC_MASTER_ICCR2_SP_BIT_MASK; /* It is safe to write 0's to other bits. */
         /* Allow timeouts to be generated on the low value of SCL using either long or short mode */
         p_ctrl->p_reg->ICMR2 = (uint8_t) 0x02U |
-                               (uint8_t) (IIC_MASTER_TIMEOUT_MODE_SHORT == p_ctrl->timeout_mode);
+                               (uint8_t) (IIC_MASTER_TIMEOUT_MODE_SHORT ==
+                                          ((iic_master_extended_cfg_t *) p_ctrl->p_cfg->p_extend)->timeout_mode);
         p_ctrl->p_reg->ICFER_b.TMOE = 1;
 
         /* This interrupt will be fired again when wither stop condition is sent
@@ -1443,19 +1428,19 @@ static void iic_master_txi_send_address (iic_master_instance_ctrl_t * const p_ct
  * @retval      FSP_SUCCESS                Transfer interface initialized successfully.
  * @retval      FSP_ERR_ASSERTION          Pointer to transfer instance for I2C receive in p_cfg is NULL.
  **********************************************************************************************************************/
-static fsp_err_t iic_master_transfer_open (iic_master_instance_ctrl_t * p_ctrl, i2c_master_cfg_t const * const p_cfg)
+static fsp_err_t iic_master_transfer_open (i2c_master_cfg_t const * const p_cfg)
 {
     fsp_err_t err = FSP_SUCCESS;
 
     if (NULL != p_cfg->p_transfer_rx)
     {
-        err = iic_master_transfer_configure(p_ctrl, p_cfg->p_transfer_rx, IIC_MASTER_TRANSFER_DIR_READ);
+        err = iic_master_transfer_configure(p_cfg->p_transfer_rx, IIC_MASTER_TRANSFER_DIR_READ);
         FSP_ERROR_RETURN(FSP_SUCCESS == err, err);
     }
 
     if (NULL != p_cfg->p_transfer_tx)
     {
-        err = iic_master_transfer_configure(p_ctrl, p_cfg->p_transfer_tx, IIC_MASTER_TRANSFER_DIR_WRITE);
+        err = iic_master_transfer_configure(p_cfg->p_transfer_tx, IIC_MASTER_TRANSFER_DIR_WRITE);
         if (FSP_SUCCESS != err)
         {
             if (NULL != p_cfg->p_transfer_rx)
@@ -1478,37 +1463,28 @@ static fsp_err_t iic_master_transfer_open (iic_master_instance_ctrl_t * p_ctrl,
  * @retval        FSP_SUCCESS                Transfer interface is configured with valid parameters.
  * @retval        FSP_ERR_ASSERTION          Pointer to transfer instance for I2C receive in p_cfg is NULL.
  **********************************************************************************************************************/
-static fsp_err_t iic_master_transfer_configure (iic_master_instance_ctrl_t * p_ctrl,
-                                                transfer_instance_t const  * p_transfer,
-                                                iic_master_transfer_dir_t    direction)
+static fsp_err_t iic_master_transfer_configure (transfer_instance_t const * p_transfer,
+                                                iic_master_transfer_dir_t   direction)
 {
     fsp_err_t err;
-    IRQn_Type irq;
 
     /* Set default transfer info and open receive transfer module, if enabled. */
  #if (IIC_MASTER_CFG_PARAM_CHECKING_ENABLE)
     FSP_ASSERT(NULL != p_transfer->p_api);
-    FSP_ASSERT(NULL != p_transfer->p_ctrl);
     FSP_ASSERT(NULL != p_transfer->p_cfg);
     FSP_ASSERT(NULL != p_transfer->p_cfg->p_info);
  #endif
     transfer_info_t * p_cfg = p_transfer->p_cfg->p_info;
     if (IIC_MASTER_TRANSFER_DIR_READ == direction)
     {
-        irq = p_ctrl->p_cfg->rxi_irq;
         p_cfg->transfer_settings_word = IIC_MASTER_DTC_RX_TRANSFER_SETTINGS;
     }
     else
     {
-        irq = p_ctrl->p_cfg->txi_irq;
         p_cfg->transfer_settings_word = IIC_MASTER_DTC_TX_TRANSFER_SETTINGS;
     }
 
-    transfer_cfg_t       cfg = *(p_transfer->p_cfg);
-    dtc_extended_cfg_t * p_dtc_extended_configuration = (dtc_extended_cfg_t *) (cfg.p_extend);
-    p_dtc_extended_configuration->activation_source = irq;
-
-    err = p_transfer->p_api->open(p_transfer->p_ctrl, &cfg);
+    err = p_transfer->p_api->open(p_transfer->p_ctrl, p_transfer->p_cfg);
     FSP_ERROR_RETURN((FSP_SUCCESS == err), err);
 
     return FSP_SUCCESS;
@@ -1528,12 +1504,17 @@ static fsp_err_t iic_master_transfer_configure (iic_master_instance_ctrl_t * p_c
  **********************************************************************************************************************/
 void iic_master_rxi_isr (void)
 {
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
     /* Clear the IR flag */
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
 
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     iic_master_instance_ctrl_t * p_ctrl = (iic_master_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
     iic_master_rxi_master(p_ctrl);
+
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1544,12 +1525,17 @@ void iic_master_rxi_isr (void)
  **********************************************************************************************************************/
 void iic_master_txi_isr (void)
 {
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
     /* Clear the IR flag */
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
 
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     iic_master_instance_ctrl_t * p_ctrl = (iic_master_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
     iic_master_txi_master(p_ctrl);
+
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1560,12 +1546,18 @@ void iic_master_txi_isr (void)
  **********************************************************************************************************************/
 void iic_master_tei_isr (void)
 {
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
+
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     iic_master_instance_ctrl_t * p_ctrl = (iic_master_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
     iic_master_tei_master(p_ctrl);
 
     /* Clear the IR flag */
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
+
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1576,10 +1568,16 @@ void iic_master_tei_isr (void)
  **********************************************************************************************************************/
 void iic_master_eri_isr (void)
 {
+    /* Save context if RTOS is used */
+    FSP_CONTEXT_SAVE
+
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     iic_master_instance_ctrl_t * p_ctrl = (iic_master_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
     iic_master_err_master(p_ctrl);
 
     /* Clear the IR flag */
     R_BSP_IrqStatusClear(R_FSP_CurrentIrqGet());
+
+    /* Restore context if RTOS is used */
+    FSP_CONTEXT_RESTORE
 }
