@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -149,15 +149,6 @@ static void iic_err_slave(iic_slave_instance_ctrl_t * p_ctrl);
  * Private global variables
  *********************************************************************************************************************/
 
-/* Version data structure used by error logger macro. */
-static fsp_version_t const g_iic_slave_version =
-{
-    .api_version_minor  = I2C_SLAVE_API_VERSION_MINOR,
-    .api_version_major  = I2C_SLAVE_API_VERSION_MAJOR,
-    .code_version_major = IIC_SLAVE_CODE_VERSION_MAJOR,
-    .code_version_minor = IIC_SLAVE_CODE_VERSION_MINOR
-};
-
 /**********************************************************************************************************************
  * Global variables
  *********************************************************************************************************************/
@@ -169,7 +160,6 @@ i2c_slave_api_t const g_i2c_slave_on_iic =
     .read        = R_IIC_SLAVE_Read,
     .write       = R_IIC_SLAVE_Write,
     .close       = R_IIC_SLAVE_Close,
-    .versionGet  = R_IIC_SLAVE_VersionGet,
     .callbackSet = R_IIC_SLAVE_CallbackSet
 };
 
@@ -188,6 +178,8 @@ i2c_slave_api_t const g_i2c_slave_on_iic =
  * @retval  FSP_SUCCESS                       I2C slave device opened successfully.
  * @retval  FSP_ERR_ALREADY_OPEN              Module is already open.
  * @retval  FSP_ERR_IP_CHANNEL_NOT_PRESENT    Channel is not available on this MCU.
+ * @retval  FSP_ERR_INVALID_ARGUMENT          Error interrupt priority is lower than
+ *                                            Transmit, Receive and Transmit End interrupt priority
  * @retval  FSP_ERR_ASSERTION                 Parameter check failure due to one or more reasons below:
  *                                            1. p_api_ctrl or p_cfg is NULL.
  *                                            2. extended parameter is NULL.
@@ -211,6 +203,7 @@ fsp_err_t R_IIC_SLAVE_Open (i2c_slave_ctrl_t * const p_api_ctrl, i2c_slave_cfg_t
     FSP_ERROR_RETURN(BSP_FEATURE_IIC_VALID_CHANNEL_MASK & (1 << p_cfg->channel), FSP_ERR_IP_CHANNEL_NOT_PRESENT);
 
     FSP_ERROR_RETURN(IIC_SLAVE_OPEN != p_ctrl->open, FSP_ERR_ALREADY_OPEN);
+    FSP_ERROR_RETURN(p_cfg->eri_ipl <= p_cfg->ipl, FSP_ERR_INVALID_ARGUMENT);
 
     /* If rate is configured as Fast mode plus, check whether the channel supports it */
     if (I2C_SLAVE_RATE_FASTPLUS == p_cfg->rate)
@@ -235,7 +228,7 @@ fsp_err_t R_IIC_SLAVE_Open (i2c_slave_ctrl_t * const p_api_ctrl, i2c_slave_cfg_t
      * 'Initial Settings' of the RA6M3 manual R01UH0886EJ0100). */
     iic_open_hw_slave(p_ctrl);
 
-    R_BSP_IrqCfgEnable(p_ctrl->p_cfg->eri_irq, p_ctrl->p_cfg->ipl, p_ctrl);
+    R_BSP_IrqCfgEnable(p_ctrl->p_cfg->eri_irq, p_ctrl->p_cfg->eri_ipl, p_ctrl);
     R_BSP_IrqCfgEnable(p_ctrl->p_cfg->txi_irq, p_ctrl->p_cfg->ipl, p_ctrl);
     R_BSP_IrqCfgEnable(p_ctrl->p_cfg->tei_irq, p_ctrl->p_cfg->ipl, p_ctrl);
     R_BSP_IrqCfgEnable(p_ctrl->p_cfg->rxi_irq, p_ctrl->p_cfg->ipl, p_ctrl);
@@ -386,23 +379,6 @@ fsp_err_t R_IIC_SLAVE_Close (i2c_slave_ctrl_t * const p_api_ctrl)
     return FSP_SUCCESS;
 }
 
-/**********************************************************************************************************************
- * DEPRECATED Gets version information and stores it in the provided version structure.
- *
- * @retval  FSP_SUCCESS                 Successful version get.
- * @retval  FSP_ERR_ASSERTION           p_version is NULL.
- *********************************************************************************************************************/
-fsp_err_t R_IIC_SLAVE_VersionGet (fsp_version_t * const p_version)
-{
-#if IIC_SLAVE_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(p_version != NULL);
-#endif
-
-    p_version->version_id = g_iic_slave_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /******************************************************************************************************************//**
  * @} (end addtogroup IIC_SLAVE)
  *********************************************************************************************************************/
@@ -461,12 +437,9 @@ static fsp_err_t iic_slave_read_write (i2c_slave_ctrl_t * const p_api_ctrl,
     p_ctrl->p_reg->ICMR3_b.ACKWP = 1;  /* Write Enable */
     p_ctrl->p_reg->ICMR3_b.ACKBT = 0;  /* Write */
 
-    /* Enable timeouts. Timeouts are disabled at the end of a IIC Slave transaction. */
-    /* Allow timeouts to be generated on the low value of SCL using long count mode */
-    p_ctrl->p_reg->ICMR2 = IIC_SLAVE_BUS_MODE_REGISTER_2_MASK;
-
-    /* Enable timeout function */
-    p_ctrl->p_reg->ICFER_b.TMOE = 1;
+    /* Timeouts are enabled by the driver code at the end of an IIC Slave callback.
+     * Do not enable them here to prevent time restricting the application code.
+     */
 
     p_ctrl->transaction_completed = false;
 
@@ -626,10 +599,31 @@ static void iic_open_hw_slave (iic_slave_instance_ctrl_t * const p_ctrl)
                                                   cks_value &
                                                   IIC_SLAVE_INTERNAL_REF_CLOCK_SELECT_MAX) << 4U));
 
-    /* Set the digital filter.
-     * ACKBT should be set to 0 after reset to send out an ACK upon slave address match.
-     */
-    p_ctrl->p_reg->ICMR3 = (uint8_t) (digital_filter_stages > 0U ? (digital_filter_stages - 1U) : 0U);
+    /* 1. Set the digital filter.
+     * 2. ACKBT should be set to 0 after reset to send out an ACK upon slave address match.
+     * 3. Set WAIT bit based on user config.
+     * Refer Section 36.2.5 ICMR3 : I2C Bus Mode Register 3 :
+     * 'WAIT bit (WAIT)' and 'RDRFS bit (RDRF Flag Set Timing Select)'
+     * of the RA6M3 manual R01UH0886EJ0100.
+     * Since RDRFS = 0:
+     * - SCLn line will *not* be held low at the falling edge of the 8th clock cycle.
+     * - RDRF flag will be set at the rising edge of the 9th clock cycle. (Cause of iic_rxi_slave)
+     * This means that iic_rxi_slave will be invoked during the 9th clock cycle (High) if there is no preemption.
+     * Set the WAIT = 1 so that the SCLn line is held low from the falling edge of the 9th clock cycle.
+     * This is done to support clock stretching during the 'iic_slave_initiate_transaction'/user event callback (more often)
+     * and if iic_rxi_slave can get preempted.
+     *
+     * Note 1: If the preemption happens after the Read API is called in the user event callback,
+     *         WAIT = 1 will be able to handle that scenario,
+     *         however if the preemption happens before, the slave will timeout if the Read API
+     *         is not called within 'Long Timeout Mode' duration.
+     *
+     * Note 2: When WAIT = 1, this driver no longer supports data reception utilizing the double buffer HW setup.
+     *
+     * Note 3: WAIT bit is dont-care during transmission.
+     * */
+    p_ctrl->p_reg->ICMR3 = (uint8_t) ((uint8_t) (digital_filter_stages > 0U ? (digital_filter_stages - 1U) : 0U) |
+                                      (uint8_t) (p_ctrl->p_cfg->clock_stretching_enable << R_IIC0_ICMR3_WAIT_Pos));
 
     p_ctrl->p_reg->ICIER = (uint8_t) ((uint8_t) IIC_RXI_EN_BIT | (uint8_t) IIC_TXI_EN_BIT);
 
@@ -686,12 +680,16 @@ static void iic_slave_initiate_transaction (iic_slave_instance_ctrl_t * p_ctrl,
         {
             /* Enable the Start condition detection to trigger ERI ISR */
 
-            /* Since address match is detected, enable STOP detection.
-             * This has been done already for Slave Read at the beginning of RXI ISR to handle 0 byte master writes.
-             * It is ok to clear the stop condition flag again for the case of Slave Read.
-             *
-             * Clear the Start and Stop condition flag for Slave Read/Write operation */
-            p_ctrl->p_reg->ICSR2 &= ((uint8_t) ~((uint8_t) ICSR2_STOP_BIT | (uint8_t) ICSR2_START_BIT));
+            /* Since address match is detected, enable STOP and RESTART detection for Master Read Slave Write.
+             * This must be done conditionally only for Master Read Slave Write to prevent clearing the start bit
+             * in case a restart occurred (and got captured) while we were in the user callback.
+             * This capturing is made possible in the 'iic_rxi_slave' after the dummy read.
+             */
+            if (IIC_SLAVE_TRANSFER_DIR_MASTER_READ_SLAVE_WRITE == p_ctrl->direction)
+            {
+                /* Clear the Start and Stop condition flag for Slave Read/Write operation */
+                p_ctrl->p_reg->ICSR2 &= ((uint8_t) ~((uint8_t) ICSR2_STOP_BIT | (uint8_t) ICSR2_START_BIT));
+            }
 
             /* Enable the Start and Stop condition detection interrupt */
             p_ctrl->p_reg->ICIER = (uint8_t) ((uint8_t) IIC_STP_EN_BIT |
@@ -777,21 +775,36 @@ static void iic_rxi_slave (iic_slave_instance_ctrl_t * p_ctrl)
     {
         p_ctrl->do_dummy_read = true;
 
-        volatile uint8_t dummy = p_ctrl->p_reg->ICDRR;
-        (void) dummy;
+        volatile uint8_t address_and_intent = p_ctrl->p_reg->ICDRR;
 
         /* The below code enables/services 0 byte writes from Master.*/
 
-        /* Since address match detected, enable STOP detection */
-        /* Clear the Stop condition flag */
-        p_ctrl->p_reg->ICSR2 &= (uint8_t) ~(ICSR2_STOP_BIT);
+        /* Since address match detected, enable STOP detection in case of Master Read Slave Write Operation;
+         * and enable STOP and START (RESTART) detection in case of Master Write Slave Read Operation.
+         * This is done so that RESTART handling is not maissed if the user callback takes long and the Master
+         * issues the restart on the bus.
+         */
+        if (address_and_intent & 1U)
+        {
+            p_ctrl->p_reg->ICSR2 &= (uint8_t) ~(ICSR2_STOP_BIT);
+        }
+        else
+        {
+            p_ctrl->p_reg->ICSR2 &= ((uint8_t) ~((uint8_t) ICSR2_STOP_BIT | (uint8_t) ICSR2_START_BIT));
+        }
 
         /* Enable the Stop condition detection interrupt.
          * In case this is a greater than 0 byte write from Master and MasterWriteSlaveRead API is called
          * in the callback with valid parameters, this flag will be appropriately updated by helper function -
-         * iic_slave_initiate_transaction. */
+         * iic_slave_initiate_transaction.
+         * Start condition is enabled here for Master Write Slave Read case to trigger an interrupt on detecting
+         * a restart on the bus when slave is processing a long user callback.
+         * This enablement is harmless for Master Read Slave Write operation as its Start bit is not cleared
+         * (set during this address match).
+         * */
         p_ctrl->p_reg->ICIER = (uint8_t) ((uint8_t) IIC_RXI_EN_BIT |
                                           (uint8_t) IIC_TXI_EN_BIT |
+                                          (uint8_t) IIC_STR_EN_BIT |
                                           (uint8_t) IIC_STP_EN_BIT);
     }
     else
@@ -840,11 +853,7 @@ static void iic_rxi_slave (iic_slave_instance_ctrl_t * p_ctrl)
              * with a read more event in callback */
             else if (p_ctrl->total == p_ctrl->loaded)
             {
-                /* Reset the status indication flag. This allows the API invocation to be successful with in callback */
-                p_ctrl->slave_busy = false;
-
                 iic_slave_callback_request(p_ctrl, I2C_SLAVE_EVENT_RX_MORE_REQUEST);
-
 #if IIC_SLAVE_CFG_PARAM_CHECKING_ENABLE
                 if (IIC_SLAVE_TRANSFER_DIR_MASTER_WRITE_SLAVE_READ != p_ctrl->direction)
                 {
