@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -78,15 +78,6 @@ static fsp_err_t qspi_program_param_check(qspi_instance_ctrl_t * p_instance_ctrl
  * Private global variables
  **********************************************************************************************************************/
 
-/** Version data structure used by error logger macro. */
-static const fsp_version_t g_qspi_version =
-{
-    .api_version_minor  = SPI_FLASH_API_VERSION_MINOR,
-    .api_version_major  = SPI_FLASH_API_VERSION_MAJOR,
-    .code_version_major = QSPI_CODE_VERSION_MAJOR,
-    .code_version_minor = QSPI_CODE_VERSION_MINOR
-};
-
 #if QSPI_CFG_SUPPORT_EXTENDED_SPI_MULTI_LINE_PROGRAM
 
 /* Page program command.  Index by [data_lines].  data_lines is 0 for 1 data line, 1 for 2 data lines, or
@@ -113,6 +104,7 @@ const spi_flash_api_t g_qspi_on_spi_flash =
     .open           = R_QSPI_Open,
     .directWrite    = R_QSPI_DirectWrite,
     .directRead     = R_QSPI_DirectRead,
+    .directTransfer = R_QSPI_DirectTransfer,
     .spiProtocolSet = R_QSPI_SpiProtocolSet,
     .write          = R_QSPI_Write,
     .erase          = R_QSPI_Erase,
@@ -120,8 +112,8 @@ const spi_flash_api_t g_qspi_on_spi_flash =
     .xipEnter       = R_QSPI_XipEnter,
     .xipExit        = R_QSPI_XipExit,
     .bankSet        = R_QSPI_BankSet,
+    .autoCalibrate  = R_QSPI_AutoCalibrate,
     .close          = R_QSPI_Close,
-    .versionGet     = R_QSPI_VersionGet,
 };
 
 /***********************************************************************************************************************
@@ -268,6 +260,24 @@ fsp_err_t R_QSPI_DirectRead (spi_flash_ctrl_t * p_ctrl, uint8_t * const p_dest,
     return FSP_SUCCESS;
 }
 
+/*******************************************************************************************************************//**
+ * Read/Write raw data directly with the OctaFlash/OctaRAM device. Unsupported by QSPI.
+ *
+ * Implements @ref spi_flash_api_t::directTransfer.
+ *
+ * @retval FSP_ERR_UNSUPPORTED         API not supported by QSPI.
+ **********************************************************************************************************************/
+fsp_err_t R_QSPI_DirectTransfer (spi_flash_ctrl_t                  * p_ctrl,
+                                 spi_flash_direct_transfer_t * const p_transfer,
+                                 spi_flash_direct_transfer_dir_t     direction)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+    FSP_PARAMETER_NOT_USED(p_transfer);
+    FSP_PARAMETER_NOT_USED(direction);
+
+    return FSP_ERR_UNSUPPORTED;
+}
+
 /*******************************************************************************************************************//**
  * Enters XIP (execute in place) mode.
  *
@@ -583,6 +593,19 @@ fsp_err_t R_QSPI_SpiProtocolSet (spi_flash_ctrl_t * p_ctrl, spi_flash_protocol_t
     return FSP_SUCCESS;
 }
 
+/*******************************************************************************************************************//**
+ * Auto-calibrate the OctaRAM device using the preamble pattern. Unsupported by QSPI.
+ * Implements @ref spi_flash_api_t::autoCalibrate.
+ *
+ * @retval FSP_ERR_UNSUPPORTED         API not supported by QSPI
+ **********************************************************************************************************************/
+fsp_err_t R_QSPI_AutoCalibrate (spi_flash_ctrl_t * p_ctrl)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+
+    return FSP_ERR_UNSUPPORTED;
+}
+
 /*******************************************************************************************************************//**
  * Close the QSPI driver module.
  *
@@ -609,26 +632,6 @@ fsp_err_t R_QSPI_Close (spi_flash_ctrl_t * p_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Get the driver version based on compile time macros.
- *
- * Implements @ref spi_flash_api_t::versionGet.
- *
- * @retval     FSP_SUCCESS          Successful close.
- * @retval     FSP_ERR_ASSERTION    p_version is NULL.
- *
- **********************************************************************************************************************/
-fsp_err_t R_QSPI_VersionGet (fsp_version_t * const p_version)
-{
-#if QSPI_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_qspi_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup QSPI)
  **********************************************************************************************************************/
