@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -26,61 +26,58 @@
 /***********************************************************************************************************************
  * Macro definitions
  **********************************************************************************************************************/
-#define RTC_MASK_MSB                        (0x0F)
-#define RTC_MASK_LSB                        (0xF0)
+#define RTC_MASK_MSB                      (0x0F)
+#define RTC_MASK_LSB                      (0xF0)
 
-#define RTC_FIRST_DAY_OF_A_MONTH            (1)
+#define RTC_FIRST_DAY_OF_A_MONTH          (1)
 
 /* Day of week : valid range between 0 to 6. */
-#define RTC_DAYS_IN_A_WEEK                  (6)
+#define RTC_DAYS_IN_A_WEEK                (6)
 
 /* Month : valid range between 0 to 11.*/
-#define RTC_MONTHS_IN_A_YEAR                (11)
-#define RTC_LAST_DAY_OF_LEAP_FEB_MONTH      (29)
-#define RTC_LAST_DAY_OF_A_MONTH             (31)
-#define RTC_YEAR_VALUE_MIN                  (100)
-#define RTC_YEAR_VALUE_MAX                  (199)
+#define RTC_MONTHS_IN_A_YEAR              (11)
+#define RTC_LAST_DAY_OF_LEAP_FEB_MONTH    (29)
+#define RTC_LAST_DAY_OF_A_MONTH           (31)
+#define RTC_YEAR_VALUE_MIN                (100)
+#define RTC_YEAR_VALUE_MAX                (199)
 
 /* Seconds : valid range between 0 to 59.*/
-#define RTC_SECONDS_IN_A_MINUTE             (59)
+#define RTC_SECONDS_IN_A_MINUTE           (59)
 
 /* Minute : valid range between 0 to 59. */
-#define RTC_MINUTES_IN_A_HOUR               (59)
+#define RTC_MINUTES_IN_A_HOUR             (59)
 
 /* Hours : valid range between 0 to 23. */
-#define RTC_HOURS_IN_A_DAY                  (23)
+#define RTC_HOURS_IN_A_DAY                (23)
 
 /* In Zeller algorithm value of (-[Y/100] + [Y/400]) is 15 for Y = 2000 to Y = 2099) */
-#define RTC_ZELLER_ALGM_CONST_FIFTEEN       (15)
+#define RTC_ZELLER_ALGM_CONST_FIFTEEN     (15)
 
 /* Macro definitions for February and March months */
-#define RTC_FEBRUARY_MONTH                  (2U)
-#define RTC_MARCH_MONTH                     (3U)
+#define RTC_FEBRUARY_MONTH                (2U)
+#define RTC_MARCH_MONTH                   (3U)
 
-#define RTC_TIME_H_MONTH_OFFSET             (1)
+#define RTC_TIME_H_MONTH_OFFSET           (1)
 
 /*The RTC has a 100 year calendar to match the starting year 2000, year offset(1900) is added like 117 + 1900 = 2017 */
-#define RTC_TIME_H_YEAR_OFFSET              (1900)
+#define RTC_TIME_H_YEAR_OFFSET            (1900)
 
 /** "RTC" in ASCII, used to determine if device is open. */
-#define RTC_OPEN                            (0x00525443ULL)
+#define RTC_OPEN                          (0x00525443ULL)
 
-#define RTC_MAX_ERROR_ADJUSTMENT_VALUE      (0x3FU)
+#define RTC_MAX_ERROR_ADJUSTMENT_VALUE    (0x3FU)
 
-#define RTC_RHRCNT_HOUR_MASK                (0x3f)
-#define RTC_COMPARE_ENB_BIT                 (7U)
-#define RTC_MASK_8TH_BIT                    (0x7F)
+#define RTC_RHRCNT_HOUR_MASK              (0x3f)
+#define RTC_COMPARE_ENB_BIT               (7U)
+#define RTC_MASK_8TH_BIT                  (0x7F)
 
 /* As per HW manual, value of Year is between 0 to 99, the RTC has a 100 year calendar from 2000 to 2099.
  * But as per C standards, tm_year is years since 1900.*/
-#define RTC_C_TIME_OFFSET                   (100)
+#define RTC_C_TIME_OFFSET                 (100)
 
 /* See section 26.2.20 Frequency Register (RFRH/RFRL)" of the RA6M3 manual R01UH0886EJ0100) */
-#define RTC_RFRL_MIN_VALUE_LOCO             (0x7U)
-#define RTC_RFRL_MAX_VALUE_LOCO             (0x1FFU)
-
-#define RTC_SUB_CLK_STABLIZATION_TIME_MS    (100)
-#define RTC_LOCO_STABLIZATION_TIME_US       (190)
+#define RTC_RFRL_MIN_VALUE_LOCO           (0x7U)
+#define RTC_RFRL_MAX_VALUE_LOCO           (0x1FFU)
 
 /***********************************************************************************************************************
  * Typedef definitions
@@ -104,15 +101,6 @@ void           rtc_carry_isr(void);
  * Private global variables
  **********************************************************************************************************************/
 
-/** Version data structure used by error logger macro. */
-static const fsp_version_t s_rtc_version =
-{
-    .api_version_minor  = RTC_API_VERSION_MINOR,
-    .api_version_major  = RTC_API_VERSION_MAJOR,
-    .code_version_major = RTC_CODE_VERSION_MAJOR,
-    .code_version_minor = RTC_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global Variables
  **********************************************************************************************************************/
@@ -122,6 +110,7 @@ const rtc_api_t g_rtc_on_rtc =
 {
     .open               = R_RTC_Open,
     .close              = R_RTC_Close,
+    .clockSourceSet     = R_RTC_ClockSourceSet,
     .calendarTimeGet    = R_RTC_CalendarTimeGet,
     .calendarTimeSet    = R_RTC_CalendarTimeSet,
     .calendarAlarmGet   = R_RTC_CalendarAlarmGet,
@@ -130,7 +119,6 @@ const rtc_api_t g_rtc_on_rtc =
     .infoGet            = R_RTC_InfoGet,
     .errorAdjustmentSet = R_RTC_ErrorAdjustmentSet,
     .callbackSet        = R_RTC_CallbackSet,
-    .versionGet         = R_RTC_VersionGet,
 };
 
 #if RTC_CFG_PARAM_CHECKING_ENABLE
@@ -235,21 +223,16 @@ fsp_err_t R_RTC_Open (rtc_ctrl_t * const p_ctrl, rtc_cfg_t const * const p_cfg)
 
     p_instance_ctrl->carry_isr_triggered = false;
 
+#if RTC_CFG_OPEN_SET_CLOCK_SOURCE
+
+    /* Set the clock source for RTC.
+     * The count source must be selected only once before making the initial settings of the RTC registers
+     * at power on. (see section 26.2.19 RTC Control Register 4 (RCR4) of the RA6M3 manual R01UH0886EJ0100)*/
+    r_rtc_set_clock_source(p_instance_ctrl, p_cfg);
+#endif
+
     r_rtc_config_rtc_interrupts(p_instance_ctrl, p_cfg);
 
-    /* Check if the RTC is already running */
-    if (R_RTC->RCR2_b.START == 0)
-    {
-        /* Initialize registers. */
-        R_RTC->RCR1 = 0U;
-        R_RTC->RCR2 = 0U;
-
-        /* Set the clock source for RTC.
-         * The count source must be selected only once before making the initial settings of the RTC registers
-         * at power on. (see section 26.2.19 RTC Control Register 4 (RCR4) of the RA6M3 manual R01UH0886EJ0100)*/
-        r_rtc_set_clock_source(p_instance_ctrl, p_cfg);
-    }
-
     /** Mark driver as open by initializing it to "RTC" in its ASCII equivalent. */
     p_instance_ctrl->open = RTC_OPEN;
 
@@ -303,6 +286,34 @@ fsp_err_t R_RTC_Close (rtc_ctrl_t * const p_ctrl)
     return FSP_SUCCESS;
 }
 
+/*******************************************************************************************************************//**
+ * Sets the RTC clock source. Implements @ref rtc_api_t::clockSourceSet.
+ *
+ * Example:
+ * @snippet r_rtc_example.c R_RTC_ClockSourceSet
+ *
+ * @retval FSP_SUCCESS          Initialization was successful and RTC has started.
+ * @retval FSP_ERR_ASSERTION    Invalid p_ctrl or p_cfg pointer.
+ * @retval FSP_ERR_NOT_OPEN     Driver is not opened.
+ **********************************************************************************************************************/
+fsp_err_t R_RTC_ClockSourceSet (rtc_ctrl_t * const p_ctrl)
+{
+    rtc_instance_ctrl_t * p_instance_ctrl = (rtc_instance_ctrl_t *) p_ctrl;
+
+    /* Parameter checking */
+#if RTC_CFG_PARAM_CHECKING_ENABLE
+    FSP_ASSERT(NULL != p_instance_ctrl);
+    FSP_ERROR_RETURN(RTC_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
+#endif
+
+    /* Set the clock source for RTC.
+     * The count source must be selected only once before making the initial settings of the RTC registers
+     * at power on. (see section 26.2.19 RTC Control Register 4 (RCR4) of the RA6M3 manual R01UH0886EJ0100)*/
+    r_rtc_set_clock_source(p_instance_ctrl, p_instance_ctrl->p_cfg);
+
+    return FSP_SUCCESS;
+}
+
 /*******************************************************************************************************************//**
  * Set the calendar time.
  *
@@ -693,25 +704,6 @@ fsp_err_t R_RTC_ErrorAdjustmentSet (rtc_ctrl_t * const p_ctrl, rtc_error_adjustm
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Get driver version based on compile time macros.
- *
- * Implements @ref rtc_api_t::versionGet
- *
- * @retval     FSP_SUCCESS          Successful close.
- * @retval     FSP_ERR_ASSERTION    The parameter p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_RTC_VersionGet (fsp_version_t * p_version)
-{
-#if RTC_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(p_version);
-#endif
-
-    p_version->version_id = s_rtc_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * Updates the user callback and has option of providing memory for callback structure.
  * Implements rtc_api_t::callbackSet
@@ -813,23 +805,12 @@ static void r_rtc_set_clock_source (rtc_instance_ctrl_t * const p_ctrl, rtc_cfg_
     /* Select the count source (RCKSEL) */
     R_RTC->RCR4 = (uint8_t) p_ctrl->p_cfg->clock_source;
 
-    /* Supply 6 clocks of the count source (LOCO, 183us, 32kHZ).
+    /* Supply 6 clocks of the count source (LOCO/SOSC, 183us, 32kHZ).
      * See 26.3.2 "Clock and Count Mode Setting Procedure" of the RA6M3 manual R01UH0886EJ0100)*/
-    if (RTC_CLOCK_SOURCE_SUBCLK == p_ctrl->p_cfg->clock_source)
-    {
-        R_BSP_SoftwareDelay(RTC_SUB_CLK_STABLIZATION_TIME_MS, BSP_DELAY_UNITS_MILLISECONDS);
-    }
-    else
-    {
-        R_BSP_SoftwareDelay(RTC_LOCO_STABLIZATION_TIME_US, BSP_DELAY_UNITS_MICROSECONDS);
-    }
+    R_BSP_SoftwareDelay(BSP_PRV_RTC_RESET_DELAY_US, BSP_DELAY_UNITS_MICROSECONDS);
 
-    /* Set the START bit to 0 */
     r_rtc_start_bit_update(0U);
 
-    /* Force RTC to 24 hour mode. Set HR24 bit in the RCR2 register */
-    R_RTC->RCR2_b.HR24 = 1U;
-
     if (RTC_CLOCK_SOURCE_LOCO == p_ctrl->p_cfg->clock_source)
     {
         /* Write 0 before writing to the RFRL register after a cold start. (see section 26.2.20
@@ -839,18 +820,35 @@ static void r_rtc_set_clock_source (rtc_instance_ctrl_t * const p_ctrl, rtc_cfg_
         R_RTC->RFRL = (uint16_t) p_cfg->freq_compare_value_loco;
     }
 
-    /* Clear the the CNTMD bit in the RCR2 register */
-    R_RTC->RCR2_b.CNTMD = 0U;
-
-    /* Wait for the CNTMD bit to become 0 */
+    R_RTC->RCR2 = 0;
 
     /* When setting the count mode, execute an RTC software reset and start again from the initial settings.
      * This bit is updated synchronously with the count source, and its value is fixed before the RTC software
      * reset is completed (see section 26.2.18 "RTC Control Register 2 (RCR2)" of the RA6M3 manual R01UH0886EJ0100)*/
     FSP_HARDWARE_REGISTER_WAIT(R_RTC->RCR2_b.CNTMD, RTC_CALENDAR_MODE);
 
-    /* Execute RTC software reset */
     r_rtc_software_reset();
+
+    /* Disable RTC interrupts */
+    R_RTC->RCR1 = 0;
+
+    /* Force RTC to 24 hour mode. Set HR24 bit in the RCR2 register */
+    R_RTC->RCR2_b.HR24 = 1U;
+
+    /*
+     * See 23.6.5 "Notes on Writing to and Reading from Registers" of the RA6M5 manual R01UH0891EJ0120.
+     * The value written is reflected when fourth read operations are performed after writing.
+     */
+    FSP_HARDWARE_REGISTER_WAIT(R_RTC->RCR2_b.HR24, 1);
+
+#if BSP_FEATURE_RTC_HAS_TCEN
+    for (uint8_t index = 0U; index < BSP_FEATURE_RTC_RTCCR_CHANNELS; index++)
+    {
+        /* RTCCRn.TCEN must be cleared after reset. */
+        R_RTC->RTCCR[index].RTCCR_b.TCEN = 0U;
+        FSP_HARDWARE_REGISTER_WAIT(R_RTC->RTCCR[index].RTCCR_b.TCEN, 0);
+    }
+#endif
 }
 
 /*******************************************************************************************************************//**
@@ -1354,13 +1352,13 @@ static void r_rtc_error_adjustment_set (rtc_error_adjustment_cfg_t const * const
 void rtc_alarm_periodic_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type             irq    = R_FSP_CurrentIrqGet();
     rtc_instance_ctrl_t * p_ctrl = (rtc_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
 
     /* Call the callback routine if one is available */
-    if (NULL != p_ctrl->p_cfg->p_callback)
+    if (NULL != p_ctrl->p_callback)
     {
         /* Set data to identify callback to user, then call user callback. */
         rtc_event_t event;
@@ -1381,7 +1379,7 @@ void rtc_alarm_periodic_isr (void)
     R_BSP_IrqStatusClear(irq);
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1393,7 +1391,7 @@ void rtc_alarm_periodic_isr (void)
 void rtc_carry_isr (void)
 {
     /* Save context if RTOS is used */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type             irq    = R_FSP_CurrentIrqGet();
     rtc_instance_ctrl_t * p_ctrl = (rtc_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -1404,7 +1402,7 @@ void rtc_carry_isr (void)
     R_BSP_IrqStatusClear(irq);
 
     /* Restore context if RTOS is used */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
