@@ -50,8 +50,18 @@ Private global variables and functions
 
 fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyIndex, const uint32_t *InData_Text, uint32_t *OutData_Text)
 {
-    uint32_t iLoop = 0u, iLoop1 = 0u, iLoop2 = 0u, jLoop = 0u, kLoop = 0u, oLoop = 0u, oLoop1 = 0u, oLoop2 = 0u, KEY_ADR = 0u, OFS_ADR = 0u, MAX_CNT2 = 0u;
-    uint32_t dummy = 0u;
+    uint32_t iLoop    = 0U;
+    uint32_t iLoop1   = 0U;
+    uint32_t iLoop2   = 0U;
+    int32_t  jLoop    = 0U;
+    uint32_t kLoop    = 0U;
+    uint32_t oLoop    = 0U;
+    uint32_t oLoop1   = 0U;
+    uint32_t oLoop2   = 0U;
+    uint32_t dummy    = 0U;
+    uint32_t KEY_ADR  = 0U;
+    uint32_t OFS_ADR  = 0U;
+    uint32_t MAX_CNT2 = 0U;
     (void)iLoop;
     (void)iLoop1;
     (void)iLoop2;
@@ -64,60 +74,60 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
     (void)KEY_ADR;
     (void)OFS_ADR;
     (void)MAX_CNT2;
-    if (0x0u != (SCE->REG_1B8H & 0x1eu))
+    if (0x0U != (SCE->REG_1B8H & 0x1eU))
     {
         return FSP_ERR_CRYPTO_SCE_RESOURCE_CONFLICT;
     }
-    SCE->REG_84H = 0x00007903u;
-    SCE->REG_108H = 0x00000000u;
-    SCE->REG_104H = 0x00000068u;
-    SCE->REG_E0H = 0x800100e0u;
+    SCE->REG_84H = 0x00007903U;
+    SCE->REG_108H = 0x00000000U;
+    SCE->REG_104H = 0x00000068U;
+    SCE->REG_E0H = 0x800100e0U;
     /* WAIT_LOOP */
-    while (1u != SCE->REG_104H_b.B31)
+    while (1U != SCE->REG_104H_b.B31)
     {
         /* waiting */
     }
     SCE->REG_100H = InData_KeyIndex[0];
-    SCE->REG_104H = 0x00000058u;
-    SCE->REG_E0H = 0x800103a0u;
+    SCE->REG_104H = 0x00000058U;
+    SCE->REG_E0H = 0x800103a0U;
     /* WAIT_LOOP */
-    while (1u != SCE->REG_104H_b.B31)
+    while (1U != SCE->REG_104H_b.B31)
     {
         /* waiting */
     }
-    SCE->REG_100H = change_endian_long(0x00000079u);
-    HW_SCE_p_func101(0x9930b009u, 0x81e95a8cu, 0xe8edfc49u, 0xa9c2f412u);
+    SCE->REG_100H = change_endian_long(0x00000079U);
+    HW_SCE_p_func101(0x9930b009U, 0x81e95a8cU, 0xe8edfc49U, 0xa9c2f412U);
     HW_SCE_p_func043();
-    SCE->REG_ECH = 0x0000b4e0u;
-    SCE->REG_ECH = 0x0000000eu;
-    SCE->REG_104H = 0x00000058u;
-    SCE->REG_E0H = 0x800103a0u;
+    SCE->REG_ECH = 0x0000b4e0U;
+    SCE->REG_ECH = 0x0000000eU;
+    SCE->REG_104H = 0x00000058U;
+    SCE->REG_E0H = 0x800103a0U;
     /* WAIT_LOOP */
-    while (1u != SCE->REG_104H_b.B31)
+    while (1U != SCE->REG_104H_b.B31)
     {
         /* waiting */
     }
-    SCE->REG_100H = change_endian_long(0x00000079u);
-    HW_SCE_p_func101(0x6b0497cfu, 0x2c4fe92bu, 0x51befe47u, 0xb7bd24b5u);
+    SCE->REG_100H = change_endian_long(0x00000079U);
+    HW_SCE_p_func101(0x6b0497cfU, 0x2c4fe92bU, 0x51befe47U, 0xb7bd24b5U);
     HW_SCE_p_func044();
-    SCE->REG_104H = 0x00000052u;
-    SCE->REG_C4H = 0x00040804u;
+    SCE->REG_104H = 0x00000052U;
+    SCE->REG_C4H = 0x00040804U;
     /* WAIT_LOOP */
-    while (1u != SCE->REG_104H_b.B31)
+    while (1U != SCE->REG_104H_b.B31)
     {
         /* waiting */
     }
-    SCE->REG_100H = change_endian_long(0x00000000u);
-    SCE->REG_28H = 0x009f0001u;
-    SCE->REG_104H = 0x00006362u;
-    SCE->REG_D0H = 0x40001800u;
-    SCE->REG_C4H = 0x02e08887u;
-    SCE->REG_00H = 0x00003283u;
-    SCE->REG_2CH = 0x00000010u;
+    SCE->REG_100H = change_endian_long(0x00000000U);
+    SCE->REG_28H = 0x009f0001U;
+    SCE->REG_104H = 0x00006362U;
+    SCE->REG_D0H = 0x40001800U;
+    SCE->REG_C4H = 0x02e08887U;
+    SCE->REG_00H = 0x00003283U;
+    SCE->REG_2CH = 0x00000010U;
     for(iLoop=0; iLoop<32; iLoop=iLoop+4)
     {
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
@@ -127,17 +137,17 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
         SCE->REG_100H = InData_KeyIndex[iLoop+1 + 3];
     }
     /* WAIT_LOOP */
-    while (0u != SCE->REG_00H_b.B25)
+    while (0U != SCE->REG_00H_b.B25)
     {
         /* waiting */
     }
-    SCE->REG_1CH = 0x00001800u;
-    SCE->REG_00H = 0x00003283u;
-    SCE->REG_2CH = 0x00000012u;
+    SCE->REG_1CH = 0x00001800U;
+    SCE->REG_00H = 0x00003283U;
+    SCE->REG_2CH = 0x00000012U;
     for(iLoop=32; iLoop<64; iLoop=iLoop+4)
     {
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
@@ -147,17 +157,17 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
         SCE->REG_100H = InData_KeyIndex[iLoop+1 + 3];
     }
     /* WAIT_LOOP */
-    while (0u != SCE->REG_00H_b.B25)
+    while (0U != SCE->REG_00H_b.B25)
     {
         /* waiting */
     }
-    SCE->REG_1CH = 0x00001800u;
-    SCE->REG_00H = 0x00003283u;
-    SCE->REG_2CH = 0x00000014u;
+    SCE->REG_1CH = 0x00001800U;
+    SCE->REG_00H = 0x00003283U;
+    SCE->REG_2CH = 0x00000014U;
     for(iLoop=64; iLoop<96; iLoop=iLoop+4)
     {
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
@@ -167,13 +177,13 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
         SCE->REG_100H = InData_KeyIndex[iLoop+1 + 3];
     }
     /* WAIT_LOOP */
-    while (0u != SCE->REG_00H_b.B25)
+    while (0U != SCE->REG_00H_b.B25)
     {
         /* waiting */
     }
-    SCE->REG_1CH = 0x00001800u;
+    SCE->REG_1CH = 0x00001800U;
     /* WAIT_LOOP */
-    while (1u != SCE->REG_104H_b.B31)
+    while (1U != SCE->REG_104H_b.B31)
     {
         /* waiting */
     }
@@ -181,26 +191,26 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
     SCE->REG_100H = InData_KeyIndex[iLoop+1 + 1];
     SCE->REG_100H = InData_KeyIndex[iLoop+1 + 2];
     SCE->REG_100H = InData_KeyIndex[iLoop+1 + 3];
-    SCE->REG_E0H = 0x80010280u;
-    SCE->REG_00H = 0x00008207u;
+    SCE->REG_E0H = 0x80010280U;
+    SCE->REG_00H = 0x00008207U;
     /* WAIT_LOOP */
-    while (0u != SCE->REG_00H_b.B25)
+    while (0U != SCE->REG_00H_b.B25)
     {
         /* waiting */
     }
-    SCE->REG_1CH = 0x00001800u;
-    SCE->REG_00H = 0x0000020fu;
+    SCE->REG_1CH = 0x00001800U;
+    SCE->REG_00H = 0x0000020fU;
     /* WAIT_LOOP */
-    while (0u != SCE->REG_00H_b.B25)
+    while (0U != SCE->REG_00H_b.B25)
     {
         /* waiting */
     }
-    SCE->REG_1CH = 0x00001800u;
-    SCE->REG_104H = 0x00000362u;
-    SCE->REG_D0H = 0x40000000u;
-    SCE->REG_C4H = 0x000087b5u;
+    SCE->REG_1CH = 0x00001800U;
+    SCE->REG_104H = 0x00000362U;
+    SCE->REG_D0H = 0x40000000U;
+    SCE->REG_C4H = 0x000087b5U;
     /* WAIT_LOOP */
-    while (1u != SCE->REG_104H_b.B31)
+    while (1U != SCE->REG_104H_b.B31)
     {
         /* waiting */
     }
@@ -208,23 +218,23 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
     SCE->REG_100H = InData_KeyIndex[iLoop+5 + 1];
     SCE->REG_100H = InData_KeyIndex[iLoop+5 + 2];
     SCE->REG_100H = InData_KeyIndex[iLoop+5 + 3];
-    SCE->REG_C4H = 0x00900c45u;
-    SCE->REG_00H = 0x00002213u;
+    SCE->REG_C4H = 0x00900c45U;
+    SCE->REG_00H = 0x00002213U;
     /* WAIT_LOOP */
-    while (0u != SCE->REG_00H_b.B25)
+    while (0U != SCE->REG_00H_b.B25)
     {
         /* waiting */
     }
-    SCE->REG_1CH = 0x00001800u;
-    HW_SCE_p_func100(0x7ee8691bu, 0x37b5f60au, 0x87859dc1u, 0x394206a8u);
-    SCE->REG_1CH = 0x00400000u;
-    SCE->REG_1D0H = 0x00000000u;
-    if (1u == (SCE->REG_1CH_b.B22))
+    SCE->REG_1CH = 0x00001800U;
+    HW_SCE_p_func100(0x7ee8691bU, 0x37b5f60aU, 0x87859dc1U, 0x394206a8U);
+    SCE->REG_1CH = 0x00400000U;
+    SCE->REG_1D0H = 0x00000000U;
+    if (1U == (SCE->REG_1CH_b.B22))
     {
-        HW_SCE_p_func102(0x1e94bb70u, 0xd0807b52u, 0xb19b60a0u, 0x875879ffu);
-        SCE->REG_1B8H = 0x00000040u;
+        HW_SCE_p_func102(0x1e94bb70U, 0xd0807b52U, 0xb19b60a0U, 0x875879ffU);
+        SCE->REG_1B8H = 0x00000040U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_18H_b.B12)
+        while (0U != SCE->REG_18H_b.B12)
         {
             /* waiting */
         }
@@ -232,88 +242,88 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
     }
     else
     {
-        HW_SCE_p_func100(0x115bdcb3u, 0x073a2576u, 0xa28bdb20u, 0x2f2d587au);
+        HW_SCE_p_func100(0x115bdcb3U, 0x073a2576U, 0xa28bdb20U, 0x2f2d587aU);
         HW_SCE_p_func103();
-        HW_SCE_p_func100(0xa970f4fau, 0xb28af495u, 0x5d28b925u, 0x2ec6dfa3u);
-        SCE->REG_104H = 0x00000052u;
-        SCE->REG_C4H = 0x010c0c04u;
+        HW_SCE_p_func100(0xa970f4faU, 0xb28af495U, 0x5d28b925U, 0x2ec6dfa3U);
+        SCE->REG_104H = 0x00000052U;
+        SCE->REG_C4H = 0x010c0c04U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x00000000u);
-        HW_SCE_p_func100(0x4350ff0fu, 0x54672d5au, 0x3e9ea952u, 0xed9785dau);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_100H = change_endian_long(0x00000000U);
+        HW_SCE_p_func100(0x4350ff0fU, 0x54672d5aU, 0x3e9ea952U, 0xed9785daU);
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x018e0c4cu);
+        SCE->REG_100H = change_endian_long(0x018e0c4cU);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x830263b0u, 0x987f3967u, 0xdd7089eau, 0xfb6164b3u);
-        SCE->REG_00H = 0x00002383u;
-        SCE->REG_2CH = 0x00000020u;
+        HW_SCE_p_func100(0x830263b0U, 0x987f3967U, 0xdd7089eaU, 0xfb6164b3U);
+        SCE->REG_00H = 0x00002383U;
+        SCE->REG_2CH = 0x00000020U;
         HW_SCE_p_func319(752);
-        HW_SCE_p_func100(0x7d8ff34eu, 0x39614ffau, 0x02d73beeu, 0x32051da9u);
+        HW_SCE_p_func100(0x7d8ff34eU, 0x39614ffaU, 0x02d73beeU, 0x32051da9U);
         HW_SCE_p_func314(752+32);
-        HW_SCE_p_func100(0x336798e0u, 0x6d49a1fbu, 0x49bd8f75u, 0x8a0e9fa7u);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        HW_SCE_p_func100(0x336798e0U, 0x6d49a1fbU, 0x49bd8f75U, 0x8a0e9fa7U);
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x010273a4u);
+        SCE->REG_100H = change_endian_long(0x010273a4U);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0xa0287871u, 0x20908695u, 0x4fda4e72u, 0x8d0d67a8u);
-        SCE->REG_00H = 0x00002383u;
-        SCE->REG_2CH = 0x00000022u;
+        HW_SCE_p_func100(0xa0287871U, 0x20908695U, 0x4fda4e72U, 0x8d0d67a8U);
+        SCE->REG_00H = 0x00002383U;
+        SCE->REG_2CH = 0x00000022U;
         HW_SCE_p_func319(716);
-        HW_SCE_p_func100(0xe3e3d8acu, 0xa1e30561u, 0x83e21b2eu, 0x7d239563u);
+        HW_SCE_p_func100(0xe3e3d8acU, 0xa1e30561U, 0x83e21b2eU, 0x7d239563U);
         HW_SCE_p_func314(716+32);
-        HW_SCE_p_func100(0xfa3af305u, 0xdb097dcfu, 0xf809dec6u, 0xfd840cdeu);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        HW_SCE_p_func100(0xfa3af305U, 0xdb097dcfU, 0xf809dec6U, 0xfd840cdeU);
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x019410dfu);
+        SCE->REG_100H = change_endian_long(0x019410dfU);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x9fd08737u, 0x4f2d0f36u, 0x1b1a4873u, 0xf3b346f4u);
-        SCE->REG_00H = 0x00002383u;
-        SCE->REG_2CH = 0x00000024u;
+        HW_SCE_p_func100(0x9fd08737U, 0x4f2d0f36U, 0x1b1a4873U, 0xf3b346f4U);
+        SCE->REG_00H = 0x00002383U;
+        SCE->REG_2CH = 0x00000024U;
         HW_SCE_p_func319(680);
-        HW_SCE_p_func100(0xe3cbffc7u, 0xa0ff85e1u, 0x18893f9fu, 0xae2c8b0eu);
+        HW_SCE_p_func100(0xe3cbffc7U, 0xa0ff85e1U, 0x18893f9fU, 0xae2c8b0eU);
         HW_SCE_p_func314(680+32);
-        SCE->REG_00H = 0x0000037fu;
-        SCE->REG_2CH = 0x00000024u;
+        SCE->REG_00H = 0x0000037fU;
+        SCE->REG_2CH = 0x00000024U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_00H_b.B25)
+        while (0U != SCE->REG_00H_b.B25)
         {
             /* waiting */
         }
-        SCE->REG_1CH = 0x00001800u;
-        SCE->REG_E0H = 0x800103e0u;
-        SCE->REG_00H = 0x00008307u;
+        SCE->REG_1CH = 0x00001800U;
+        SCE->REG_E0H = 0x800103e0U;
+        SCE->REG_00H = 0x00008307U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_00H_b.B25)
+        while (0U != SCE->REG_00H_b.B25)
         {
             /* waiting */
         }
-        SCE->REG_1CH = 0x00001800u;
-        SCE->REG_ECH = 0x3800dbe0u;
-        SCE->REG_E0H = 0x00000080u;
-        SCE->REG_1CH = 0x00260000u;
-        SCE->REG_2CH = 0x00000010u;
-        SCE->REG_104H = 0x00001f67u;
+        SCE->REG_1CH = 0x00001800U;
+        SCE->REG_ECH = 0x3800dbe0U;
+        SCE->REG_E0H = 0x00000080U;
+        SCE->REG_1CH = 0x00260000U;
+        SCE->REG_2CH = 0x00000010U;
+        SCE->REG_104H = 0x00001f67U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
@@ -349,17 +359,17 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
         SCE->REG_100H = InData_Text[29];
         SCE->REG_100H = InData_Text[30];
         SCE->REG_100H = InData_Text[31];
-        SCE->REG_24H = 0x0000a0d0u;
+        SCE->REG_24H = 0x0000a0d0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_28H = 0x00bf0001u;
-        SCE->REG_2CH = 0x00000014u;
-        SCE->REG_104H = 0x00003f67u;
+        SCE->REG_28H = 0x00bf0001U;
+        SCE->REG_2CH = 0x00000014U;
+        SCE->REG_104H = 0x00003f67U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
@@ -427,269 +437,269 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
         SCE->REG_100H = InData_Text[93];
         SCE->REG_100H = InData_Text[94];
         SCE->REG_100H = InData_Text[95];
-        SCE->REG_28H = 0x009f0001u;
-        HW_SCE_p_func100(0x3b932c9du, 0xe60b45f9u, 0x4c68dc70u, 0xbab75753u);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_28H = 0x009f0001U;
+        HW_SCE_p_func100(0x3b932c9dU, 0xe60b45f9U, 0x4c68dc70U, 0xbab75753U);
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x019de420u);
+        SCE->REG_100H = change_endian_long(0x019de420U);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0xf14dc81du, 0x08c983d3u, 0x2ab61a1eu, 0x451526acu);
-        SCE->REG_00H = 0x00002383u;
-        SCE->REG_2CH = 0x00000020u;
+        HW_SCE_p_func100(0xf14dc81dU, 0x08c983d3U, 0x2ab61a1eU, 0x451526acU);
+        SCE->REG_00H = 0x00002383U;
+        SCE->REG_2CH = 0x00000020U;
         HW_SCE_p_func319(72);
-        HW_SCE_p_func100(0x2038a22au, 0xb18b5053u, 0xaeaa8fb6u, 0x146a776cu);
+        HW_SCE_p_func100(0x2038a22aU, 0xb18b5053U, 0xaeaa8fb6U, 0x146a776cU);
         HW_SCE_p_func314(72+32);
-        HW_SCE_p_func100(0x98d4795du, 0xc5730533u, 0x8758a926u, 0x59185715u);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        HW_SCE_p_func100(0x98d4795dU, 0xc5730533U, 0x8758a926U, 0x59185715U);
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x019969f4u);
+        SCE->REG_100H = change_endian_long(0x019969f4U);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x219de09du, 0x3123024fu, 0x16875a12u, 0x75a53b8eu);
-        SCE->REG_00H = 0x00002383u;
-        SCE->REG_2CH = 0x00000025u;
+        HW_SCE_p_func100(0x219de09dU, 0x3123024fU, 0x16875a12U, 0x75a53b8eU);
+        SCE->REG_00H = 0x00002383U;
+        SCE->REG_2CH = 0x00000025U;
         HW_SCE_p_func319(36);
-        HW_SCE_p_func100(0x95492014u, 0xb970b606u, 0x4ce340ceu, 0x17ca043au);
+        HW_SCE_p_func100(0x95492014U, 0xb970b606U, 0x4ce340ceU, 0x17ca043aU);
         HW_SCE_p_func314(36+32);
-        HW_SCE_p_func100(0x815aba79u, 0x0c7e88ddu, 0xaa881027u, 0x49e7c658u);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        HW_SCE_p_func100(0x815aba79U, 0x0c7e88ddU, 0xaa881027U, 0x49e7c658U);
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x01fe1091u);
+        SCE->REG_100H = change_endian_long(0x01fe1091U);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x50c99eb5u, 0xb362b304u, 0xa260fd0cu, 0xd13b0444u);
-        SCE->REG_00H = 0x00002383u;
-        SCE->REG_2CH = 0x00000024u;
+        HW_SCE_p_func100(0x50c99eb5U, 0xb362b304U, 0xa260fd0cU, 0xd13b0444U);
+        SCE->REG_00H = 0x00002383U;
+        SCE->REG_2CH = 0x00000024U;
         HW_SCE_p_func319(0);
-        HW_SCE_p_func100(0x99efb969u, 0xc88fe10cu, 0x3a83bfc6u, 0xd056ba30u);
+        HW_SCE_p_func100(0x99efb969U, 0xc88fe10cU, 0x3a83bfc6U, 0xd056ba30U);
         HW_SCE_p_func314(0+32);
-        HW_SCE_p_func100(0x037788a3u, 0x79be5549u, 0xe46f539eu, 0x5aab9302u);
-        SCE->REG_28H = 0x00bf0001u;
-        SCE->REG_24H = 0x000040d0u;
+        HW_SCE_p_func100(0x037788a3U, 0x79be5549U, 0xe46f539eU, 0x5aab9302U);
+        SCE->REG_28H = 0x00bf0001U;
+        SCE->REG_24H = 0x000040d0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x000005c0u;
+        SCE->REG_24H = 0x000005c0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x04001991u;
+        SCE->REG_24H = 0x04001991U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x000049c1u;
+        SCE->REG_24H = 0x000049c1U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x02001191u;
+        SCE->REG_24H = 0x02001191U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_1CH = 0x00a10000u;
-        SCE->REG_24H = 0x000005c0u;
+        SCE->REG_1CH = 0x00a10000U;
+        SCE->REG_24H = 0x000005c0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x00000581u;
+        SCE->REG_24H = 0x00000581U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x0000c0c1u;
+        SCE->REG_24H = 0x0000c0c1U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_28H = 0x009f0001u;
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_28H = 0x009f0001U;
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x019410dfu);
+        SCE->REG_100H = change_endian_long(0x019410dfU);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x526c5725u, 0x2b7bafbcu, 0x6f8db96cu, 0xeb735ef5u);
-        SCE->REG_00H = 0x00003283u;
-        SCE->REG_2CH = 0x00000010u;
+        HW_SCE_p_func100(0x526c5725U, 0x2b7bafbcU, 0x6f8db96cU, 0xeb735ef5U);
+        SCE->REG_00H = 0x00003283U;
+        SCE->REG_2CH = 0x00000010U;
         HW_SCE_p_func320(680);
-        SCE->REG_24H = 0x000011c0u;
+        SCE->REG_24H = 0x000011c0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x010273a4u);
+        SCE->REG_100H = change_endian_long(0x010273a4U);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x0865271cu, 0x120ff1a1u, 0x71f5a98au, 0xfccde033u);
-        SCE->REG_00H = 0x00003283u;
-        SCE->REG_2CH = 0x00000011u;
+        HW_SCE_p_func100(0x0865271cU, 0x120ff1a1U, 0x71f5a98aU, 0xfccde033U);
+        SCE->REG_00H = 0x00003283U;
+        SCE->REG_2CH = 0x00000011U;
         HW_SCE_p_func320(716);
-        SCE->REG_24H = 0x000016c0u;
+        SCE->REG_24H = 0x000016c0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x018e0c4cu);
+        SCE->REG_100H = change_endian_long(0x018e0c4cU);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0xaf4abd00u, 0x732a43fdu, 0xf1b0a12cu, 0x8b129d76u);
-        SCE->REG_00H = 0x00003283u;
-        SCE->REG_2CH = 0x00000012u;
+        HW_SCE_p_func100(0xaf4abd00U, 0x732a43fdU, 0xf1b0a12cU, 0x8b129d76U);
+        SCE->REG_00H = 0x00003283U;
+        SCE->REG_2CH = 0x00000012U;
         HW_SCE_p_func320(752);
-        SCE->REG_24H = 0x000060d0u;
+        SCE->REG_24H = 0x000060d0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_28H = 0x00bf0001u;
-        SCE->REG_24H = 0x000080d0u;
+        SCE->REG_28H = 0x00bf0001U;
+        SCE->REG_24H = 0x000080d0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x04001991u;
+        SCE->REG_24H = 0x04001991U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x060049c1u;
+        SCE->REG_24H = 0x060049c1U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x02001191u;
+        SCE->REG_24H = 0x02001191U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x000049c1u;
+        SCE->REG_24H = 0x000049c1U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_28H = 0x009f0001u;
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_28H = 0x009f0001U;
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x01fe1091u);
+        SCE->REG_100H = change_endian_long(0x01fe1091U);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x31290a2bu, 0xbf7356c4u, 0x4d0cccfau, 0x22e1373fu);
-        SCE->REG_00H = 0x00003283u;
-        SCE->REG_2CH = 0x00000014u;
+        HW_SCE_p_func100(0x31290a2bU, 0xbf7356c4U, 0x4d0cccfaU, 0x22e1373fU);
+        SCE->REG_00H = 0x00003283U;
+        SCE->REG_2CH = 0x00000014U;
         HW_SCE_p_func320(0);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x019969f4u);
+        SCE->REG_100H = change_endian_long(0x019969f4U);
         HW_SCE_p_func080();
-        HW_SCE_p_func100(0x8c99cd47u, 0x2868da89u, 0x91452e8eu, 0x7963c836u);
-        SCE->REG_00H = 0x00003283u;
-        SCE->REG_2CH = 0x00000015u;
+        HW_SCE_p_func100(0x8c99cd47U, 0x2868da89U, 0x91452e8eU, 0x7963c836U);
+        SCE->REG_00H = 0x00003283U;
+        SCE->REG_2CH = 0x00000015U;
         HW_SCE_p_func320(36);
-        SCE->REG_104H = 0x00000058u;
-        SCE->REG_E0H = 0x80010020u;
+        SCE->REG_104H = 0x00000058U;
+        SCE->REG_E0H = 0x80010020U;
         /* WAIT_LOOP */
-        while (1u != SCE->REG_104H_b.B31)
+        while (1U != SCE->REG_104H_b.B31)
         {
             /* waiting */
         }
-        SCE->REG_100H = change_endian_long(0x019de420u);
+        SCE->REG_100H = change_endian_long(0x019de420U);
         HW_SCE_p_func080();
-        SCE->REG_00H = 0x00003283u;
-        SCE->REG_2CH = 0x00000010u;
+        SCE->REG_00H = 0x00003283U;
+        SCE->REG_2CH = 0x00000010U;
         HW_SCE_p_func320(72);
-        SCE->REG_24H = 0x0000a0d0u;
+        SCE->REG_24H = 0x0000a0d0U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_28H = 0x00bf0001u;
-        SCE->REG_24H = 0x04001991u;
+        SCE->REG_28H = 0x00bf0001U;
+        SCE->REG_24H = 0x04001991U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x060049c1u;
+        SCE->REG_24H = 0x060049c1U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_24H = 0x02001191u;
+        SCE->REG_24H = 0x02001191U;
         /* WAIT_LOOP */
-        while (0u != SCE->REG_24H_b.B21)
+        while (0U != SCE->REG_24H_b.B21)
         {
             /* waiting */
         }
-        SCE->REG_1CH = 0x00210000u;
-        HW_SCE_p_func100(0x3578337cu, 0xf2829ff4u, 0xcfc2f8a8u, 0xf4ebc9bau);
-        SCE->REG_1CH = 0x00400000u;
-        SCE->REG_1D0H = 0x00000000u;
-        if (1u == (SCE->REG_1CH_b.B22))
+        SCE->REG_1CH = 0x00210000U;
+        HW_SCE_p_func100(0x3578337cU, 0xf2829ff4U, 0xcfc2f8a8U, 0xf4ebc9baU);
+        SCE->REG_1CH = 0x00400000U;
+        SCE->REG_1D0H = 0x00000000U;
+        if (1U == (SCE->REG_1CH_b.B22))
         {
-            HW_SCE_p_func102(0xa3c643d5u, 0xbeb0bc69u, 0xc8cb1884u, 0x31c8ab72u);
-            SCE->REG_1B8H = 0x00000040u;
+            HW_SCE_p_func102(0xa3c643d5U, 0xbeb0bc69U, 0xc8cb1884U, 0x31c8ab72U);
+            SCE->REG_1B8H = 0x00000040U;
             /* WAIT_LOOP */
-            while (0u != SCE->REG_18H_b.B12)
+            while (0U != SCE->REG_18H_b.B12)
             {
                 /* waiting */
             }
@@ -697,16 +707,16 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
         }
         else
         {
-            SCE->REG_ECH = 0x0000b7a0u;
-            SCE->REG_ECH = 0x00000079u;
-            HW_SCE_p_func101(0xee77e57cu, 0x9533b284u, 0x8d1c3bc5u, 0x7dafdaabu);
+            SCE->REG_ECH = 0x0000b7a0U;
+            SCE->REG_ECH = 0x00000079U;
+            HW_SCE_p_func101(0xee77e57cU, 0x9533b284U, 0x8d1c3bc5U, 0x7dafdaabU);
             HW_SCE_p_func325();
-            SCE->REG_28H = 0x009f0001u;
-            HW_SCE_p_func100(0x89f73d3fu, 0x7ca8dee1u, 0x9173e011u, 0x633d40e3u);
-            SCE->REG_2CH = 0x00000020u;
-            SCE->REG_04H = 0x00000382u;
+            SCE->REG_28H = 0x009f0001U;
+            HW_SCE_p_func100(0x89f73d3fU, 0x7ca8dee1U, 0x9173e011U, 0x633d40e3U);
+            SCE->REG_2CH = 0x00000020U;
+            SCE->REG_04H = 0x00000382U;
             /* WAIT_LOOP */
-            while (1u != SCE->REG_04H_b.B30)
+            while (1U != SCE->REG_04H_b.B30)
             {
                 /* waiting */
             }
@@ -742,12 +752,12 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
             OutData_Text[29] = SCE->REG_100H;
             OutData_Text[30] = SCE->REG_100H;
             OutData_Text[31] = SCE->REG_100H;
-            SCE->REG_28H = 0x00bf0001u;
-            HW_SCE_p_func100(0xa42466f5u, 0x57bd3bb3u, 0xb6f415b2u, 0xe32c0359u);
-            SCE->REG_2CH = 0x00000022u;
-            SCE->REG_04H = 0x00000302u;
+            SCE->REG_28H = 0x00bf0001U;
+            HW_SCE_p_func100(0xa42466f5U, 0x57bd3bb3U, 0xb6f415b2U, 0xe32c0359U);
+            SCE->REG_2CH = 0x00000022U;
+            SCE->REG_04H = 0x00000302U;
             /* WAIT_LOOP */
-            while (1u != SCE->REG_04H_b.B30)
+            while (1U != SCE->REG_04H_b.B30)
             {
                 /* waiting */
             }
@@ -815,10 +825,10 @@ fsp_err_t HW_SCE_Rsa3072ModularExponentEncryptSub(const uint32_t *InData_KeyInde
             OutData_Text[93] = SCE->REG_100H;
             OutData_Text[94] = SCE->REG_100H;
             OutData_Text[95] = SCE->REG_100H;
-            HW_SCE_p_func102(0xfeb44e6eu, 0x7548637du, 0x57cf5ec8u, 0xef21b7b0u);
-            SCE->REG_1B8H = 0x00000040u;
+            HW_SCE_p_func102(0xfeb44e6eU, 0x7548637dU, 0x57cf5ec8U, 0xef21b7b0U);
+            SCE->REG_1B8H = 0x00000040U;
             /* WAIT_LOOP */
-            while (0u != SCE->REG_18H_b.B12)
+            while (0U != SCE->REG_18H_b.B12)
             {
                 /* waiting */
             }
