@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -49,15 +49,6 @@
  * Private global variables.
  **********************************************************************************************************************/
 
-/** SPI HAL module version data structure */
-static const fsp_version_t g_sci_spi_version =
-{
-    .api_version_major  = SPI_API_VERSION_MAJOR,
-    .api_version_minor  = SPI_API_VERSION_MINOR,
-    .code_version_major = SCI_SPI_CODE_VERSION_MAJOR,
-    .code_version_minor = SCI_SPI_CODE_VERSION_MINOR
-};
-
 const spi_api_t g_spi_on_sci =
 {
     .open        = R_SCI_SPI_Open,
@@ -65,7 +56,6 @@ const spi_api_t g_spi_on_sci =
     .write       = R_SCI_SPI_Write,
     .writeRead   = R_SCI_SPI_WriteRead,
     .close       = R_SCI_SPI_Close,
-    .versionGet  = R_SCI_SPI_VersionGet,
     .callbackSet = R_SCI_SPI_CallbackSet
 };
 
@@ -430,23 +420,6 @@ fsp_err_t R_SCI_SPI_Close (spi_ctrl_t * const p_api_ctrl)
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Get the version information of the underlying driver. Implements @ref spi_api_t::versionGet.
- * @param      p_version          Pointer to version structure.
- * @retval     FSP_SUCCESS        Successful version get.
- * @retval     FSP_ERR_ASSERTION  The parameter p_version is NULL.
- **********************************************************************************************************************/
-fsp_err_t R_SCI_SPI_VersionGet (fsp_version_t * p_version)
-{
-#if SCI_SPI_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_sci_spi_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * Calculate the register settings required to achieve the desired bitrate.
  *
@@ -757,13 +730,13 @@ static fsp_err_t r_sci_spi_write_read_common (sci_spi_instance_ctrl_t * const p_
         {
             /* If the source is NULL transmit using a dummy value using FIXED mode. */
             static uint8_t tx_dummy = 0;
-            p_transfer->p_cfg->p_info->src_addr_mode = TRANSFER_ADDR_MODE_FIXED;
-            p_transfer->p_cfg->p_info->p_src         = &tx_dummy;
+            p_transfer->p_cfg->p_info->transfer_settings_word_b.src_addr_mode = TRANSFER_ADDR_MODE_FIXED;
+            p_transfer->p_cfg->p_info->p_src = &tx_dummy;
         }
         else
         {
-            p_transfer->p_cfg->p_info->src_addr_mode = TRANSFER_ADDR_MODE_INCREMENTED;
-            p_transfer->p_cfg->p_info->p_src         = p_src;
+            p_transfer->p_cfg->p_info->transfer_settings_word_b.src_addr_mode = TRANSFER_ADDR_MODE_INCREMENTED;
+            p_transfer->p_cfg->p_info->p_src = p_src;
         }
 
         /* Enable the transfer instance. */
@@ -928,7 +901,7 @@ static void r_sci_spi_call_callback (sci_spi_instance_ctrl_t * p_ctrl, spi_event
 void sci_spi_txi_isr (void)
 {
     /* Save context if RTOS is used. */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     R_BSP_IrqStatusClear(irq);
     sci_spi_instance_ctrl_t * p_ctrl = (sci_spi_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -944,7 +917,7 @@ void sci_spi_txi_isr (void)
     }
 
     /* Restore context if RTOS is used. */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -958,7 +931,7 @@ void sci_spi_txi_isr (void)
 void sci_spi_rxi_isr (void)
 {
     /* Save context if RTOS is used. */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type irq = R_FSP_CurrentIrqGet();
     R_BSP_IrqStatusClear(irq);
@@ -982,7 +955,7 @@ void sci_spi_rxi_isr (void)
     }
 
     /* Restore context if RTOS is used. */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -994,7 +967,7 @@ void sci_spi_rxi_isr (void)
 void sci_spi_tei_isr (void)
 {
     /* Save context if RTOS is used. */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type                 irq    = R_FSP_CurrentIrqGet();
     sci_spi_instance_ctrl_t * p_ctrl = (sci_spi_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -1008,7 +981,7 @@ void sci_spi_tei_isr (void)
     R_BSP_IrqStatusClear(irq);
 
     /* Restore context if RTOS is used. */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
 
 /*******************************************************************************************************************//**
@@ -1020,7 +993,7 @@ void sci_spi_tei_isr (void)
 void sci_spi_eri_isr (void)
 {
     /* Save context if RTOS is used. */
-    FSP_CONTEXT_SAVE;
+    FSP_CONTEXT_SAVE
 
     IRQn_Type                 irq    = R_FSP_CurrentIrqGet();
     sci_spi_instance_ctrl_t * p_ctrl = (sci_spi_instance_ctrl_t *) R_FSP_IsrContextGet(irq);
@@ -1042,5 +1015,5 @@ void sci_spi_eri_isr (void)
     R_BSP_IrqStatusClear(irq);
 
     /* Restore context if RTOS is used. */
-    FSP_CONTEXT_RESTORE;
+    FSP_CONTEXT_RESTORE
 }
