@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -41,9 +41,9 @@
  #if (BSP_CFG_RTOS == 0)
 usb_dma_int_t gs_usb_cstd_dma_int;
  #endif                                                                   /* (BSP_CFG_RTOS == 0) */
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
 static usb_utr_t g_usb_cstd_int_dma[USB_INT_BUFSIZE];
- #endif                                                                   /* #if (BSP_CFG_RTOS == 2)*/
+ #endif                                                                   /* #if (BSP_CFG_RTOS != 0)*/
 
 usb_utr_t * get_usb_int_buf_dma(void);
 
@@ -71,7 +71,7 @@ uint32_t g_fifo_address[USB_NUM_USBIP][USB_FIFO_ACCESS_NUM_MAX][USB_FIFO_ACCSESS
     {
         /* IP1 */
 
-  #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+  #if defined(USB_HIGH_SPEED_MODULE)
 
         /* Little */
    #if USB_CFG_ENDIAN == USB_CFG_LITTLE
@@ -92,14 +92,14 @@ uint32_t g_fifo_address[USB_NUM_USBIP][USB_FIFO_ACCESS_NUM_MAX][USB_FIFO_ACCSESS
         {(uint32_t) &USB_M1->D1FIFO, (uint32_t) &USB_M1->D1FIFOL,
          (uint32_t) &USB_M1->D1FIFOLL}  /* USBA D1FIFO adr Big */
    #endif /* USB_CFG_ENDIAN == USB_CFG_BIG */
-  #else /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #else /* defined (USB_HIGH_SPEED_MODULE) */
         {(uint32_t) 0,               (uint32_t) &USB_M1->CFIFOL,
          (uint32_t) &USB_M1->CFIFOLL},  /* USB0 CFIFO  address */
         {(uint32_t) 0,               (uint32_t) &USB_M1->D0FIFOL,
          (uint32_t) &USB_M1->D0FIFOLL}, /* USB0 D0FIFO address */
         {(uint32_t) 0,               (uint32_t) &USB_M1->D1FIFOL,
          (uint32_t) &USB_M1->D1FIFOLL},
-  #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #endif /* defined (USB_HIGH_SPEED_MODULE) */
     }
  #endif                                /* USB_NUM_USBIP == 2 */
 };
@@ -145,11 +145,11 @@ void usb_cstd_dma_send_start (usb_utr_t * ptr, uint16_t pipe, uint16_t useport)
     }
     else
     {
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
         dma_size &= ~USB_BIT_MBW32;
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
         dma_size &= ~USB_BIT_MBW16;
- #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif /* defined (USB_HIGH_SPEED_MODULE) */
     }
 
     if (0U != dma_size)
@@ -172,14 +172,14 @@ void usb_cstd_dma_send_start (usb_utr_t * ptr, uint16_t pipe, uint16_t useport)
             }
             else
             {
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
 
                 /* fraction size(1-3) */
                 g_usb_cstd_dma_fraction_size[ip][ch] = g_usb_cstd_dma_size[ip][ch] & USB_BIT_MBW32;
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
                 /* fraction size(1-3) */
                 g_usb_cstd_dma_fraction_size[ip][ch] = g_usb_cstd_dma_size[ip][ch] & USB_BIT_MBW16;
- #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif /* defined (USB_HIGH_SPEED_MODULE) */
             }
 
             g_usb_cstd_dma_fraction_adr[ip][ch] = (uint32_t) (p_data_ptr + dma_size); /* fraction data address */
@@ -340,17 +340,39 @@ void usb_cstd_dfifo_end (usb_utr_t * ptr, uint16_t useport)
     if (g_usb_usbmode[ptr->ip] == USB_MODE_PERI)
     {
  #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
+  #if (BSP_CFG_RTOS == 1)
+        if (g_usb_pstd_data_cnt[pipe] < g_usb_cstd_dma_size[ip][channel])
+        {
+            g_usb_pstd_data_cnt[pipe] = 0U;
+        }
+        else
+        {
+            g_usb_pstd_data_cnt[pipe] -= g_usb_cstd_dma_size[ip][channel];
+        }
 
+  #else                                /* BSP_CFG_RTOS == 1 */
         /* received data size */
         g_usb_pstd_data_cnt[pipe] -= g_usb_cstd_dma_size[ip][channel];
+  #endif /* BSP_CFG_RTOS == 1 */
  #endif                                /* (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_REPI */
     }
     else
     {
  #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
+  #if (BSP_CFG_RTOS == 1)
+        if (g_usb_hstd_data_cnt[ptr->ip][pipe] < g_usb_cstd_dma_size[ip][channel])
+        {
+            g_usb_hstd_data_cnt[ptr->ip][pipe] = 0U;
+        }
+        else
+        {
+            g_usb_hstd_data_cnt[ptr->ip][pipe] -= g_usb_cstd_dma_size[ip][channel];
+        }
 
+  #else                                /* BSP_CFG_RTOS == 1 */
         /* received data size */
         g_usb_hstd_data_cnt[ptr->ip][pipe] -= g_usb_cstd_dma_size[ip][channel];
+  #endif /* BSP_CFG_RTOS == 1 */
  #endif                                /* (USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST */
     }
 }
@@ -573,16 +595,19 @@ void usb_cstd_dma_send_continue (usb_utr_t * ptr, uint16_t useport)
                     g_usb_cstd_dma_fraction_size[ip][channel] = g_usb_cstd_dma_size[ip][channel] & USB_BIT_MBW16; /* fraction size(1-3) */
                     dma_size = (uint16_t) (dma_size & ~USB_BIT_MBW16);
                 }
+
+ #if USB_NUM_USBIP == 2
                 else
                 {
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+  #if defined(USB_HIGH_SPEED_MODULE)
                     g_usb_cstd_dma_fraction_size[ip][channel] = g_usb_cstd_dma_size[ip][channel] & USB_BIT_MBW32; /* fraction size(1-3) */
                     dma_size = (uint16_t) (dma_size & ~USB_BIT_MBW32);
- #else                                                                                                            /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #else                                                                                                           /* defined (USB_HIGH_SPEED_MODULE) */
                     g_usb_cstd_dma_fraction_size[ip][channel] = g_usb_cstd_dma_size[ip][channel] & USB_BIT_MBW16; /* fraction size(1-3) */
                     dma_size = (uint16_t) (dma_size & ~USB_BIT_MBW16);
- #endif                                                                                                           /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #endif                                                                                                          /* defined (USB_HIGH_SPEED_MODULE) */
                 }
+ #endif /* USB_NUM_USBIP == 2 */
 
                 g_usb_cstd_dma_fraction_adr[ip][channel] = (uint32_t) (p_src_adr + dma_size);                     /* fraction data address */
 
@@ -638,7 +663,7 @@ void usb_cstd_dma_send_continue (usb_utr_t * ptr, uint16_t useport)
 uint16_t usb_cstd_dma_get_ir_vect (usb_utr_t * ptr, uint16_t use_port)
 {
     uint16_t ip;
-    uint16_t vect;
+    uint16_t vect = USB_NULL;
 
     ip = ptr->ip;
 
@@ -646,38 +671,50 @@ uint16_t usb_cstd_dma_get_ir_vect (usb_utr_t * ptr, uint16_t use_port)
     {
         if (USB_D0USE == use_port)
         {
+ #if defined(ELC_EVENT_USBFS_FIFO_0)
             vect = ELC_EVENT_USBFS_FIFO_0;
+ #endif                                /* define(ELC_EVENT_USBFS_FIFO_0) */
         }
         else
         {
+ #if defined(ELC_EVENT_USBFS_FIFO_1)
             vect = ELC_EVENT_USBFS_FIFO_1;
+ #endif                                /* ELC_EVENT_USBFS_FIFO_1 */
         }
     }
 
  #if USB_NUM_USBIP == 2
     else
     {
-  #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+  #if defined(USB_HIGH_SPEED_MODULE)
         if (USB_D0USE == use_port)
         {
+   #if defined(ELC_EVENT_USBHS_FIFO_0)
             vect = ELC_EVENT_USBHS_FIFO_0;
+   #endif                              /* defined(ELC_EVENT_USBHS_FIFO_0) */
         }
         else
         {
+   #if defined(ELC_EVENT_USBHS_FIFO_1)
             vect = ELC_EVENT_USBHS_FIFO_1;
+   #endif                              /* defined(ELC_EVENT_USBHS_FIFO_1) */
         }
-  #endif                               /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #endif                               /* defined (USB_HIGH_SPEED_MODULE) */
 
-  #if ((!defined(BSP_MCU_GROUP_RA6M3)) && (!defined(BSP_MCU_GROUP_RA6M5)))
+  #if (!defined(USB_HIGH_SPEED_MODULE))
         if (USB_D0USE == use_port)
         {
+   #if defined(ELC_EVENT_USBFS_FIFO_0)
             vect = ELC_EVENT_USBFS_FIFO_0;
+   #endif                              /* defined(ELC_EVENT_USBFS_FIFO_0) */
         }
         else
         {
+   #if defined(ELC_EVENT_USBFS_FIFO_1)
             vect = ELC_EVENT_USBFS_FIFO_1;
+   #endif                              /* defined(ELC_EVENT_USBFS_FIFO_1) */
         }
-  #endif                               /* ((!defined(BSP_MCU_GROUP_RA6M3)) && (!defined(BSP_MCU_GROUP_RA6M5))) */
+  #endif                               /* (!defined(USB_HIGH_SPEED_MODULE)) */
     }
  #endif                                /* USB_NUM_USBIP == 2 */
 
@@ -706,44 +743,56 @@ void usb_cstd_dma_clear_ir (usb_utr_t * ptr, uint16_t use_port)
     {
         if (USB_D0USE == use_port)
         {
+ #if defined(VECTOR_NUMBER_USBFS_FIFO_0)
             irq = (IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_0;
             R_BSP_IrqStatusClear(irq);
+ #endif                                /* defined(VECTOR_NUMBER_USBFS_FIFO_0) */
         }
         else
         {
+ #if defined(VECTOR_NUMBER_USBFS_FIFO_1)
             irq = (IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_1;
             R_BSP_IrqStatusClear(irq);
+ #endif                                /* defined(VECTOR_NUMBER_USBFS_FIFO_1) */
         }
     }
 
  #if USB_NUM_USBIP == 2
     else
     {
-  #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+  #if defined(USB_HIGH_SPEED_MODULE)
         if (USB_D0USE == use_port)
         {
+   #if defined(VECTOR_NUMBER_USBHS_FIFO_0)
             irq = (IRQn_Type) VECTOR_NUMBER_USBHS_FIFO_0;
             R_BSP_IrqStatusClear(irq);
+   #endif                              /* defined(VECTOR_NUMBER_USBHS_FIFO_0) */
         }
         else
         {
+   #if defined(VECTOR_NUMBER_USBHS_FIFO_1)
             irq = (IRQn_Type) VECTOR_NUMBER_USBHS_FIFO_1;
             R_BSP_IrqStatusClear(irq);
+   #endif                              /* defined(VECTOR_NUMBER_USBHS_FIFO_1) */
         }
-  #endif                               /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+  #endif                               /* defined (USB_HIGH_SPEED_MODULE) */
 
-  #if ((!defined(BSP_MCU_GROUP_RA6M3)) && (!defined(BSP_MCU_GROUP_RA6M5)))
+  #if (!defined(USB_HIGH_SPEED_MODULE))
         if (USB_D0USE == use_port)
         {
+   #if defined(VECTOR_NUMBER_USBFS_FIFO_0)
             irq = (IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_0;
             R_BSP_IrqStatusClear(irq);
+   #endif                              /* defined(VECTOR_NUMBER_USBFS_FIFO_0) */
         }
         else
         {
+   #if defined(VECTOR_NUMBER_USBFS_FIFO_1)
             irq = (IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_1;
             R_BSP_IrqStatusClear(irq);
+   #endif                              /* defined(VECTOR_NUMBER_USBFS_FIFO_1) */
         }
-  #endif                               /* ((!defined(BSP_MCU_GROUP_RA6M3)) && (!defined(BSP_MCU_GROUP_RA6M5))) */
+  #endif                               /* (!defined(USB_HIGH_SPEED_MODULE)) */
     }
  #endif                                /* USB_NUM_USBIP == 2 */
 }
@@ -794,32 +843,42 @@ uint8_t usb_cstd_dma_ref_ch_no (usb_utr_t * p_utr, uint16_t use_port)
  ******************************************************************************/
 void usb_cstd_dma_send_complete (uint8_t ip_no, uint16_t use_port)
 {
-    usb_cfg_t * p_cfg;
+    usb_cfg_t * p_cfg = USB_NULL;
     usb_utr_t   utr;
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
   #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
     usb_utr_t * p_host;
   #endif
   #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI)
     usb_utr_t * p_peri;
   #endif                               /* #if ((USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI) */
- #endif                                /* #if (BSP_CFG_RTOS == 2) */
+ #endif                                /* #if (BSP_CFG_RTOS != 0) */
 
     if (ip_no)
     {
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
-        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBHS_FIFO_1); // @@
- #else /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
-        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_1); // @@
- #endif /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #if defined(USB_HIGH_SPEED_MODULE)
+  #if defined(VECTOR_NUMBER_USBHS_FIFO_1)
+        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBHS_FIFO_1);
+  #endif                               /* defined(VECTOR_NUMBER_USBHS_FIFO_1) */
+ #else /* defined(USB_HIGH_SPEED_MODULE) */
+  #if defined(VECTOR_NUMBER_USBFS_FIFO_1)
+        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_1);
+  #endif                               /* defined(VECTOR_NUMBER_USBFS_FIFO_1) */
+ #endif                                /* defined(USB_HIGH_SPEED_MODULE) */
     }
     else
     {
-        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_1); // @@
+ #if defined(VECTOR_NUMBER_USBFS_FIFO_1)
+        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_FIFO_1);
+ #endif                                /* defined(VECTOR_NUMBER_USBFS_FIFO_1) */
     }
 
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
+  #if USB_NUM_USBIP == 2
     if (USB_MODE_HOST == g_usb_usbmode[ip_no])
+  #else                                /* USB_NUM_USBIP == 2 */
+    if (USB_MODE_HOST == g_usb_usbmode[0])
+  #endif /* USB_NUM_USBIP == 2 */
     {
   #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
         utr.ip  = ip_no;
@@ -858,14 +917,18 @@ void usb_cstd_dma_send_complete (uint8_t ip_no, uint16_t use_port)
   #endif                               /* ( (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI ) */
     }
 
- #else  /* (BSP_CFG_RTOS == 2) */
+ #else  /* (BSP_CFG_RTOS != 0) */
     gs_usb_cstd_dma_int.buf[gs_usb_cstd_dma_int.wp].ip        = ip_no;
     gs_usb_cstd_dma_int.buf[gs_usb_cstd_dma_int.wp].fifo_type = use_port;
     gs_usb_cstd_dma_int.wp = (uint8_t) (((uint8_t) (gs_usb_cstd_dma_int.wp + 1)) % USB_INT_BUFSIZE);
     gs_usb_cstd_dma_int.buf[gs_usb_cstd_dma_int.wp].p_cfg = p_cfg;
 
     utr.ip = ip_no;
+  #if USB_NUM_USBIP == 2
     if (USB_MODE_HOST == g_usb_usbmode[utr.ip])
+  #else                                /* USB_NUM_USBIP == 2 */
+    if (USB_MODE_HOST == g_usb_usbmode[0])
+  #endif /* USB_NUM_USBIP == 2 */
     {
   #if ((USB_CFG_MODE & USB_CFG_HOST) == USB_CFG_HOST)
         utr.ipp = usb_hstd_get_usb_ip_adr(utr.ip);
@@ -879,7 +942,7 @@ void usb_cstd_dma_send_complete (uint8_t ip_no, uint16_t use_port)
         hw_usb_clear_dreqe(&utr, use_port); /* DMA Transfer request disable */
   #endif /* ( (USB_CFG_MODE & USB_CFG_PERI) == USB_CFG_PERI ) */
     }
- #endif /* (BSP_CFG_RTOS == 2) */
+ #endif /* (BSP_CFG_RTOS != 0) */
 }
 
 /******************************************************************************
@@ -1033,7 +1096,7 @@ void usb_cstd_dma_rcv_setting (usb_utr_t * ptr, uint32_t des_addr, uint16_t usep
          * At the beginning of transfer, clear the interrupt flag of the activation source
          * to 0.
          * Transfer Request source is software. *//* Set Transfer data configuration. */
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
         if (USB_IP1 == ip)
         {
             ptr->p_transfer_rx->p_cfg->p_info->p_src = (void *) hw_usb_get_dxfifo_adr(ptr,
@@ -1049,12 +1112,12 @@ void usb_cstd_dma_rcv_setting (usb_utr_t * ptr, uint32_t des_addr, uint16_t usep
             block_size = (uint16_t) (((g_usb_cstd_dma_fifo[ip][dma_ch] - 1) / 2) + 1);
         }
 
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
         ptr->p_transfer_rx->p_cfg->p_info->p_src = (void *) hw_usb_get_dxfifo_adr(ptr,
                                                                                   useport,
                                                                                   USB_FIFO_ACCESS_TYPE_16BIT);
         block_size = (uint16_t) (((g_usb_cstd_dma_fifo[ip][dma_ch] - 1) / 2) + 1);
- #endif                                /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif                                /* defined (USB_HIGH_SPEED_MODULE) */
 
         ptr->p_transfer_rx->p_cfg->p_info->p_dest     = (void *) des_addr;
         ptr->p_transfer_rx->p_cfg->p_info->length     = block_size;
@@ -1103,7 +1166,7 @@ void usb_cstd_dma_send_setting (usb_utr_t * ptr, uint32_t src_adr, uint16_t usep
             block_size = g_usb_cstd_dma_fifo[ip][dma_ch];
         }
 
- #if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+ #if defined(USB_HIGH_SPEED_MODULE)
         if ((0 == (transfer_size & 0x03)) && (USB_IP1 == ip))
         {
             ptr->p_transfer_tx->p_cfg->p_info->p_dest = (void *) hw_usb_get_dxfifo_adr(ptr,
@@ -1119,12 +1182,12 @@ void usb_cstd_dma_send_setting (usb_utr_t * ptr, uint32_t src_adr, uint16_t usep
             block_size = (block_size / USB_BIT_16_WIDTH);
         }
 
- #else                                 /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #else                                 /* defined (USB_HIGH_SPEED_MODULE) */
         ptr->p_transfer_tx->p_cfg->p_info->p_dest = (void *) hw_usb_get_dxfifo_adr(ptr,
                                                                                    useport,
                                                                                    USB_FIFO_ACCESS_TYPE_16BIT);
         block_size = (block_size / USB_BIT_16_WIDTH);
- #endif                                /* defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5) */
+ #endif                                /* defined (USB_HIGH_SPEED_MODULE) */
 
         active_cnt = 0;
 
@@ -1247,7 +1310,7 @@ uint16_t usb_cstd_dma_get_crtb (usb_utr_t * p_utr)
  * End of function usb_cstd_dma_get_crtb
  ******************************************************************************/
 
- #if (BSP_CFG_RTOS == 2)
+ #if (BSP_CFG_RTOS != 0)
 
 /******************************************************************************
  * Function Name   : get_usb_int_buf_dma
@@ -1271,7 +1334,7 @@ usb_utr_t * get_usb_int_buf_dma (void)
 /******************************************************************************
  * End of function get_usb_int_buf_dma
  ******************************************************************************/
- #endif                                /* #if (BSP_CFG_RTOS == 2) */
+ #endif                                /* #if (BSP_CFG_RTOS != 0) */
 
 #endif                                 /* USB_CFG_DMA == USB_CFG_ENABLE */
 
