@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -270,7 +270,7 @@ fsp_err_t R_USB_HMSC_StorageReadSector (uint16_t        drive_number,
     uint32_t    trans_byte;
     usb_utr_t   ptr;
     uint16_t    err_code;
-    usb_cfg_t * p_cfg;
+    usb_cfg_t * p_cfg = USB_NULL;
 
 #if USB_CFG_PARAM_CHECKING_ENABLE == BSP_CFG_PARAM_CHECKING_ENABLE
     FSP_ASSERT(buff)
@@ -291,19 +291,22 @@ fsp_err_t R_USB_HMSC_StorageReadSector (uint16_t        drive_number,
 
     if (ptr.ip)
     {
-#if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+#if defined(VECTOR_NUMBER_USBHS_USB_INT_RESUME)
         p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBHS_USB_INT_RESUME);
-#else
-        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_INT);
-#endif
+#endif                                 /* #if defined(VECTOR_NUMBER_USBHS_USB_INT_RESUME) */
     }
     else
     {
+#if defined(VECTOR_NUMBER_USBFS_INT)
         p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_INT);
+#endif                                 /* #if defined(VECTOR_NUMBER_USBFS_INT) */
     }
 
-    ptr.p_transfer_rx = p_cfg->p_transfer_rx;
-    ptr.p_transfer_tx = p_cfg->p_transfer_tx;
+    if (USB_NULL != p_cfg)
+    {
+        ptr.p_transfer_rx = p_cfg->p_transfer_rx;
+        ptr.p_transfer_tx = p_cfg->p_transfer_tx;
+    }
 
     g_usb_hmsc_strg_process[ptr.ip] = USB_MSG_HMSC_STRG_RW_END;
     err_code = usb_hmsc_read10(&ptr, drive_number, buff, sector_number, sector_count, trans_byte);
@@ -345,7 +348,7 @@ fsp_err_t R_USB_HMSC_StorageWriteSector (uint16_t              drive_number,
     uint32_t    trans_byte;
     usb_utr_t   ptr;
     uint16_t    err_code;
-    usb_cfg_t * p_cfg;
+    usb_cfg_t * p_cfg = USB_NULL;
 
 #if USB_CFG_PARAM_CHECKING_ENABLE == BSP_CFG_PARAM_CHECKING_ENABLE
     FSP_ASSERT(buff)
@@ -366,19 +369,22 @@ fsp_err_t R_USB_HMSC_StorageWriteSector (uint16_t              drive_number,
 
     if (ptr.ip)
     {
-#if defined(BSP_MCU_GROUP_RA6M3) || defined(BSP_MCU_GROUP_RA6M5)
+#if defined(VECTOR_NUMBER_USBHS_USB_INT_RESUME)
         p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBHS_USB_INT_RESUME);
-#else
-        p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_INT);
-#endif
+#endif                                 /* #if defined(VECTOR_NUMBER_USBHS_USB_INT_RESUME) */
     }
     else
     {
+#if defined(VECTOR_NUMBER_USBFS_INT)
         p_cfg = (usb_cfg_t *) R_FSP_IsrContextGet((IRQn_Type) VECTOR_NUMBER_USBFS_INT);
+#endif                                 /* #if defined(VECTOR_NUMBER_USBFS_INT) */
     }
 
-    ptr.p_transfer_rx = p_cfg->p_transfer_rx;
-    ptr.p_transfer_tx = p_cfg->p_transfer_tx;
+    if (USB_NULL != p_cfg)
+    {
+        ptr.p_transfer_rx = p_cfg->p_transfer_rx;
+        ptr.p_transfer_tx = p_cfg->p_transfer_tx;
+    }
 
     g_usb_hmsc_strg_process[ptr.ip] = USB_MSG_HMSC_STRG_RW_END;
     err_code = usb_hmsc_write10(&ptr, drive_number, buff, sector_number, sector_count, trans_byte);
