@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -70,14 +70,6 @@ static fsp_err_t rm_freertos_plus_fat_wait_event(rm_freertos_plus_fat_instance_c
                                                  uint32_t                               timeout);
 static fsp_err_t rm_freertos_plus_fat_wait_for_device(rm_freertos_plus_fat_instance_ctrl_t * p_instance_ctrl);
 
-const fsp_version_t g_rm_freertos_plus_fat_version =
-{
-    .api_version_major  = RM_FREERTOS_PLUS_FAT_API_VERSION_MAJOR,
-    .api_version_minor  = RM_FREERTOS_PLUS_FAT_API_VERSION_MINOR,
-    .code_version_major = RM_FREERTOS_PLUS_FAT_CODE_VERSION_MAJOR,
-    .code_version_minor = RM_FREERTOS_PLUS_FAT_CODE_VERSION_MINOR
-};
-
 /** FAT HAL API mapping for FreeRTOS_plus_FAT Controller interface */
 const rm_freertos_plus_fat_api_t g_fat_on_freertos =
 {
@@ -87,7 +79,6 @@ const rm_freertos_plus_fat_api_t g_fat_on_freertos =
     .diskDeinit = RM_FREERTOS_PLUS_FAT_DiskDeinit,
     .infoGet    = RM_FREERTOS_PLUS_FAT_InfoGet,
     .close      = RM_FREERTOS_PLUS_FAT_Close,
-    .versionGet = RM_FREERTOS_PLUS_FAT_VersionGet,
 };
 
 /*******************************************************************************************************************//**
@@ -274,6 +265,7 @@ fsp_err_t RM_FREERTOS_PLUS_FAT_DiskDeinit (rm_freertos_plus_fat_ctrl_t * const p
 #endif
 
     FF_DeleteIOManager(p_disk->pxIOManager);
+    p_disk->pxIOManager            = NULL;
     p_disk->xStatus.bIsInitialised = 0U;
 
     return FSP_SUCCESS;
@@ -287,6 +279,7 @@ fsp_err_t RM_FREERTOS_PLUS_FAT_DiskDeinit (rm_freertos_plus_fat_ctrl_t * const p
  * @retval FSP_SUCCESS           Information stored in p_info.
  * @retval FSP_ERR_ASSERTION     An input parameter was invalid.
  * @retval FSP_ERR_NOT_OPEN      Module not open.
+ * @retval FSP_ERR_NOT_FOUND     The value of p_iomanager is NULL.
  **********************************************************************************************************************/
 fsp_err_t RM_FREERTOS_PLUS_FAT_InfoGet (rm_freertos_plus_fat_ctrl_t * const p_ctrl,
                                         FF_Disk_t * const                   p_disk,
@@ -304,12 +297,18 @@ fsp_err_t RM_FREERTOS_PLUS_FAT_InfoGet (rm_freertos_plus_fat_ctrl_t * const p_ct
 #endif
 
     FF_IOManager_t * p_iomanager = p_disk->pxIOManager;
+
     p_info->type = (rm_freertos_plus_fat_type_t) p_iomanager->xPartition.ucType;
 
+    if (0U == p_disk->xStatus.bIsInitialised)
+    {
+        return FSP_ERR_NOT_FOUND;
+    }
+
     FF_Error_t ff_error;
     FF_GetFreeSize(p_iomanager, &ff_error);
 
-    uint64_t free_sectors = p_iomanager->xPartition.ulFreeClusterCount * p_iomanager->xPartition.ulSectorsPerCluster;
+    uint64_t free_sectors = (p_iomanager->xPartition.ulFreeClusterCount * p_iomanager->xPartition.ulSectorsPerCluster);
     p_info->sector_size         = p_iomanager->usSectorSize;
     p_info->free_sectors        = (uint32_t) free_sectors;
     p_info->sectors_per_cluster = p_iomanager->xPartition.ulSectorsPerCluster;
@@ -350,25 +349,6 @@ fsp_err_t RM_FREERTOS_PLUS_FAT_Close (rm_freertos_plus_fat_ctrl_t * const p_ctrl
     return FSP_SUCCESS;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Returns the version of this module.
- *
- * Implements @ref rm_freertos_plus_fat_api_t::versionGet().
- *
- * @retval FSP_SUCCESS        Success.
- * @retval FSP_ERR_ASSERTION  Failed in acquiring version information.
- **********************************************************************************************************************/
-fsp_err_t RM_FREERTOS_PLUS_FAT_VersionGet (fsp_version_t * const p_version)
-{
-#if RM_FREERTOS_PLUS_FAT_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_version);
-#endif
-
-    p_version->version_id = g_rm_freertos_plus_fat_version.version_id;
-
-    return FSP_SUCCESS;
-}
-
 /*******************************************************************************************************************//**
  * @} (end addtogroup FREERTOS_PLUS_FAT)
  **********************************************************************************************************************/
@@ -411,7 +391,7 @@ int32_t rm_freertos_plus_fat_read (uint8_t * p_data, uint32_t sector, uint32_t n
 
     if (FSP_SUCCESS != err)
     {
-        return FF_ERR_IOMAN_DRIVER_FATAL_ERROR;
+        return (int32_t) (FF_ERR_IOMAN_DRIVER_FATAL_ERROR | FF_ERRFLAG);
     }
 
     lReturnCode = FF_ERR_NONE;
@@ -457,7 +437,7 @@ int32_t rm_freertos_plus_fat_write (uint8_t * p_data, uint32_t sector, uint32_t
 
     if (FSP_SUCCESS != err)
     {
-        return FF_ERR_IOMAN_DRIVER_FATAL_ERROR;
+        return (int32_t) (FF_ERR_IOMAN_DRIVER_FATAL_ERROR | FF_ERRFLAG);
     }
 
     lReturnCode = FF_ERR_NONE;
