@@ -36,11 +36,11 @@ class SenmlRecord(SenmlBase):
         :param kwargs:  optional parameters:
             - value: the value to store in the record
             - time: the timestamp to use (when was the value measured)
-            - name: the name of hte record
+            - name: the name of the record
             - unit: unit value
             - sum: sum value
             - update_time: max time before sensor will provide an updated reading
-            - callback: a callback function taht will be called when actuator data has been found. Expects no params
+            - callback: a callback function that will be called when actuator data has been found. Expects no params
         """
         self.__parent = None  # using double __ cause it's a field for an internal property
         self._unit = None  # declare and init internal fields
@@ -106,7 +106,7 @@ class SenmlRecord(SenmlBase):
 
     @value.setter
     def value(self, value):
-        """set the current value. Will not automatically update the time stamp. This has to be done seperatly for more
+        """set the current value. Will not automatically update the time stamp. This has to be done separately for more
         finegrained control
         Note: when the value is a float, you can control rounding in the rendered output by using the function
         round() while assigning the value. ex: record.value = round(12.2 / 1.5423, 2)
@@ -188,7 +188,7 @@ class SenmlRecord(SenmlBase):
         elif isinstance(self._value, bytearray):
             if (
                 naming_map["vd"] == "vd"
-            ):  # neeed to make a distinction between json (needs base64) and cbor (needs binary)
+            ):  # need to make a distinction between json (needs base64) and cbor (needs binary)
                 result[naming_map["vd"]] = binascii.b2a_base64(self._value, newline=False).decode(
                     "utf8"
                 )
@@ -216,7 +216,7 @@ class SenmlRecord(SenmlBase):
 
     def _from_raw(self, raw, naming_map):
         """
-        extracts te data from the raw record. Used during parsing of incoming data.
+        extracts the data from the raw record. Used during parsing of incoming data.
         :param raw: a raw senml record which still contains the original field names
         :param naming_map: used to map cbor names to json field names
         :return:
