@@ -1,4 +1,4 @@
-import utime
+import time
 from . import simple
 
 
@@ -7,7 +7,7 @@ class MQTTClient(simple.MQTTClient):
     DEBUG = False
 
     def delay(self, i):
-        utime.sleep(self.DELAY)
+        time.sleep(self.DELAY)
 
     def log(self, in_reconnect, e):
         if self.DEBUG:
