@@ -1,4 +1,5 @@
-"""Heap queue algorithm (a.k.a. priority queue).
+"""
+Heap queue algorithm (a.k.a. priority queue).
 
 Heaps are arrays for which a[k] <= a[2*k+1] and a[k] <= a[2*k+2] for
 all k, counting elements from 0.  For the sake of comparison,
@@ -7,13 +8,13 @@ property of a heap is that a[0] is always its smallest element.
 
 Usage:
 
-heap = []            # creates an empty heap
-heappush(heap, item) # pushes a new item on the heap
-item = heappop(heap) # pops the smallest item from the heap
-item = heap[0]       # smallest item on the heap without popping it
-heapify(x)           # transforms list into a heap, in-place, in linear time
-item = heapreplace(heap, item) # pops and returns smallest item, and adds
-                               # new item; the heap size is unchanged
+    heap = []            # creates an empty heap
+    heappush(heap, item) # pushes a new item on the heap
+    item = heappop(heap) # pops the smallest item from the heap
+    item = heap[0]       # smallest item on the heap without popping it
+    heapify(x)           # transforms list into a heap, in-place, in linear time
+    item = heapreplace(heap, item) # pops and returns smallest item, and adds
+                                   # new item; the heap size is unchanged
 
 Our API differs from textbook heap algorithms as follows:
 
@@ -40,7 +41,7 @@ non-existing elements are considered to be infinite.  The interesting
 property of a heap is that a[0] is always its smallest element.
 
 The strange invariant above is meant to be an efficient memory
-representation for a tournament.  The numbers below are `k', not a[k]:
+representation for a tournament.  The numbers below are 'k', not a[k]::
 
                                    0
 
@@ -53,7 +54,7 @@ representation for a tournament.  The numbers below are `k', not a[k]:
     15 16   17 18   19 20   21 22   23 24   25 26   27 28   29 30
 
 
-In the tree above, each cell `k' is topping `2*k+1' and `2*k+2'.  In
+In the tree above, each cell 'k' is topping '2*k+1' and '2*k+2'.  In
 an usual binary tournament we see in sports, each cell is the winner
 over the two cells it tops, and we can trace the winner down the tree
 to see all opponents s/he had.  However, in many computer applications
@@ -108,7 +109,7 @@ vanishes, you switch heaps and start a new run.  Clever and quite
 effective!
 
 In a word, heaps are useful memory structures to know.  I use them in
-a few applications, and I think it is good to keep a `heap' module
+a few applications, and I think it is good to keep a `heap` module
 around. :-)
 
 --------------------
@@ -377,7 +378,7 @@ except ImportError:
 def merge(*iterables):
     """Merge multiple sorted inputs into a single sorted output.
 
-    Similar to sorted(itertools.chain(*iterables)) but returns a generator,
+    Similar to `sorted(itertools.chain(*iterables))` but returns a generator,
     does not pull the data into memory all at once, and assumes that each of
     the input streams is already sorted (smallest to largest).
 
