@@ -141,7 +141,7 @@ void CLOCK_AttachClk(clock_attach_id_t connection)
                 break;
             }
             item = (uint16_t)GET_ID_ITEM(tmp32);
-            if (item)
+            if (item != 0U)
             {
                 mux = GET_ID_ITEM_MUX(item);
                 sel = GET_ID_ITEM_SEL(item);
@@ -151,7 +151,7 @@ void CLOCK_AttachClk(clock_attach_id_t connection)
                 }
                 else
                 {
-                    pClkSel[mux] = sel;
+                    ((volatile uint32_t *)pClkSel)[mux] = sel;
                 }
             }
             tmp32 = GET_ID_NEXT_ITEM(tmp32); /* pick up next descriptor */
@@ -187,15 +187,15 @@ clock_attach_id_t CLOCK_GetClockAttachId(clock_attach_id_t attachId)
     for (i = 0U; i < 2U; i++)
     {
         mux = GET_ID_ITEM_MUX(tmp32);
-        if (tmp32)
+        if (tmp32 != 0UL)
         {
             if (mux == CM_ASYNCAPB)
             {
-                actualSel = ASYNC_SYSCON->ASYNCAPBCLKSELA;
+                actualSel = (uint8_t)(ASYNC_SYSCON->ASYNCAPBCLKSELA);
             }
             else
             {
-                actualSel = pClkSel[mux];
+                actualSel = (uint8_t)(((volatile uint32_t *)pClkSel)[mux]);
             }
 
             /* Consider the combination of two registers */
@@ -223,15 +223,15 @@ void CLOCK_SetClkDiv(clock_div_name_t div_name, uint32_t divided_by_value, bool
     pClkDiv = &(SYSCON->SYSTICKCLKDIV);
     if (reset)
     {
-        pClkDiv[div_name] = 1U << 29U;
+        ((volatile uint32_t *)pClkDiv)[(uint8_t)div_name] = 1UL << 29U;
     }
-    if (divided_by_value == 0U) /* halt */
+    if (divided_by_value == 0UL) /* halt */
     {
-        pClkDiv[div_name] = 1U << 30U;
+        ((volatile uint32_t *)pClkDiv)[(uint8_t)div_name] = 1UL << 30U;
     }
     else
     {
-        pClkDiv[div_name] = (divided_by_value - 1U);
+        ((volatile uint32_t *)pClkDiv)[(uint8_t)div_name] = (divided_by_value - 1UL);
     }
 }
 
@@ -274,7 +274,7 @@ status_t CLOCK_SetupFROClocking(uint32_t iFreq)
         SYSCON->FROCTRL &= ~SYSCON_FROCTRL_HSPDCLK(1);
     }
 
-    return 0U;
+    return kStatus_Success;
 }
 
 /*! brief	Return Frequency of FRO 12MHz
@@ -282,7 +282,7 @@ status_t CLOCK_SetupFROClocking(uint32_t iFreq)
  */
 uint32_t CLOCK_GetFro12MFreq(void)
 {
-    return (SYSCON->PDRUNCFG[0] & SYSCON_PDRUNCFG_PDEN_FRO_MASK) ? 0U : 12000000U;
+    return ((SYSCON->PDRUNCFG[0] & SYSCON_PDRUNCFG_PDEN_FRO_MASK) != 0UL) ? 0U : 12000000U;
 }
 
 /*! brief	Return Frequency of External Clock
@@ -298,13 +298,14 @@ uint32_t CLOCK_GetExtClkFreq(void)
 uint32_t CLOCK_GetWdtOscFreq(void)
 {
     uint8_t freq_sel, div_sel;
-    if (SYSCON->PDRUNCFG[kPDRUNCFG_PD_WDT_OSC >> 8UL] & (1UL << (kPDRUNCFG_PD_WDT_OSC & 0xffU)))
+    if ((SYSCON->PDRUNCFG[(uint32_t)kPDRUNCFG_PD_WDT_OSC >> 8UL] & (1UL << ((uint32_t)kPDRUNCFG_PD_WDT_OSC & 0xffU))) !=
+        0UL)
     {
-        return 0U;
+        return 0UL;
     }
     else
     {
-        div_sel = ((SYSCON->WDTOSCCTRL & 0x1f) + 1) << 1;
+        div_sel = (uint8_t)(((SYSCON->WDTOSCCTRL & 0x1fU) + 1UL) << 1U);
         freq_sel =
             wdtFreqLookup[((SYSCON->WDTOSCCTRL & SYSCON_WDTOSCCTRL_FREQSEL_MASK) >> SYSCON_WDTOSCCTRL_FREQSEL_SHIFT)];
         return ((uint32_t)freq_sel * 50000U) / ((uint32_t)div_sel);
@@ -317,12 +318,13 @@ uint32_t CLOCK_GetWdtOscFreq(void)
  */
 uint32_t CLOCK_GetFroHfFreq(void)
 {
-    if ((SYSCON->PDRUNCFG[0] & SYSCON_PDRUNCFG_PDEN_FRO_MASK) || !(SYSCON->FROCTRL & SYSCON_FROCTRL_HSPDCLK_MASK))
+    if (((SYSCON->PDRUNCFG[0] & SYSCON_PDRUNCFG_PDEN_FRO_MASK) != 0UL) ||
+        ((SYSCON->FROCTRL & SYSCON_FROCTRL_HSPDCLK_MASK) == 0UL))
     {
         return 0U;
     }
 
-    if (SYSCON->FROCTRL & SYSCON_FROCTRL_SEL_MASK)
+    if ((SYSCON->FROCTRL & SYSCON_FROCTRL_SEL_MASK) != 0UL)
     {
         return 96000000U;
     }
@@ -375,6 +377,7 @@ uint32_t CLOCK_GetCoreSysClkFreq(void)
             }
             else
             {
+                /* Add comment to prevent the case of MISRA C-2012 rule 15.7. */
             }
             break;
         case 2U:
@@ -386,6 +389,7 @@ uint32_t CLOCK_GetCoreSysClkFreq(void)
             break;
 
         default:
+            assert(false);
             break;
     }
 
@@ -452,6 +456,7 @@ uint32_t CLOCK_GetFlexCommClkFreq(uint32_t id)
             break;
 
         default:
+            assert(false);
             break;
     }
 
@@ -481,6 +486,7 @@ uint32_t CLOCK_GetAdcClkFreq(void)
             freq = 0U;
             break;
         default:
+            assert(false);
             break;
     }
 
@@ -511,6 +517,7 @@ uint32_t CLOCK_GetFRGInputClock(void)
             break;
 
         default:
+            assert(false);
             break;
     }
 
@@ -546,11 +553,11 @@ uint32_t CLOCK_GetDmicClkFreq(void)
             freq = CLOCK_GetWdtOscFreq();
             break;
         default:
+            assert(false);
             break;
     }
 
     return freq / ((SYSCON->DMICCLKDIV & 0xffU) + 1U);
-    ;
 }
 
 /*! brief	Set output of the Fractional baud rate generator
@@ -562,14 +569,14 @@ uint32_t CLOCK_SetFRGClock(uint32_t freq)
     uint32_t input = CLOCK_GetFRGInputClock();
     uint32_t mul;
 
-    if ((freq > 48000000) || (freq > input) || (input / freq >= 2))
+    if ((freq > 48000000UL) || (freq > input) || (input / freq >= 2UL))
     {
         /* FRG output frequency should be less than equal to 48MHz */
         return 0;
     }
     else
     {
-        mul             = ((uint64_t)(input - freq) * 256) / ((uint64_t)freq);
+        mul             = (uint32_t)((((uint64_t)input - freq) * 256UL) / ((uint64_t)freq));
         SYSCON->FRGCTRL = (mul << SYSCON_FRGCTRL_MULT_SHIFT) | SYSCON_FRGCTRL_DIV_MASK;
         return 1;
     }
@@ -585,9 +592,9 @@ uint32_t CLOCK_GetFrgClkFreq(void)
 
     if ((SYSCON->FRGCTRL & SYSCON_FRGCTRL_DIV_MASK) == SYSCON_FRGCTRL_DIV_MASK)
     {
-        freq = ((uint64_t)CLOCK_GetFRGInputClock() * (SYSCON_FRGCTRL_DIV_MASK + 1)) /
-               ((SYSCON_FRGCTRL_DIV_MASK + 1) +
-                ((SYSCON->FRGCTRL & SYSCON_FRGCTRL_MULT_MASK) >> SYSCON_FRGCTRL_MULT_SHIFT));
+        freq = (uint32_t)(((uint64_t)CLOCK_GetFRGInputClock() * (SYSCON_FRGCTRL_DIV_MASK + 1U)) /
+                          ((SYSCON_FRGCTRL_DIV_MASK + 1U) +
+                           ((SYSCON->FRGCTRL & SYSCON_FRGCTRL_MULT_MASK) >> SYSCON_FRGCTRL_MULT_SHIFT)));
     }
     else
     {
@@ -608,12 +615,13 @@ uint32_t CLOCK_GetUsbClkFreq(void)
     {
         freq = CLOCK_GetFroHfFreq();
     }
-    else if (SYSCON->USBCLKSEL == 1)
+    else if (SYSCON->USBCLKSEL == 1U)
     {
         freq = CLOCK_GetPllOutFreq();
     }
     else
     {
+        /* Add comment to prevent the case of MISRA C-2012 rule 15.7. */
     }
 
     return freq / ((SYSCON->USBCLKDIV & 0xffU) + 1U);
@@ -651,42 +659,12 @@ uint32_t CLOCK_GetFreq(clock_name_t clockName)
         case kCLOCK_Frg:
             freq = CLOCK_GetFrgClkFreq();
             break;
-        case kCLOCK_Dmic:
-            freq = CLOCK_GetDmicClkFreq();
-            break;
-
         case kCLOCK_AsyncApbClk:
             freq = CLOCK_GetAsyncApbClkFreq();
             break;
-
         case kCLOCK_FlexI2S:
             freq = CLOCK_GetI2SMClkFreq();
             break;
-
-        case kCLOCK_Flexcomm0:
-            freq = CLOCK_GetFlexCommClkFreq(0U);
-            break;
-        case kCLOCK_Flexcomm1:
-            freq = CLOCK_GetFlexCommClkFreq(1U);
-            break;
-        case kCLOCK_Flexcomm2:
-            freq = CLOCK_GetFlexCommClkFreq(2U);
-            break;
-        case kCLOCK_Flexcomm3:
-            freq = CLOCK_GetFlexCommClkFreq(3U);
-            break;
-        case kCLOCK_Flexcomm4:
-            freq = CLOCK_GetFlexCommClkFreq(4U);
-            break;
-        case kCLOCK_Flexcomm5:
-            freq = CLOCK_GetFlexCommClkFreq(5U);
-            break;
-        case kCLOCK_Flexcomm6:
-            freq = CLOCK_GetFlexCommClkFreq(6U);
-            break;
-        case kCLOCK_Flexcomm7:
-            freq = CLOCK_GetFlexCommClkFreq(7U);
-            break;
         default:
             freq = 0U;
             break;
@@ -723,10 +701,14 @@ void CLOCK_SetFLASHAccessCyclesForFreq(uint32_t iFreq)
     {
         CLOCK_SetFLASHAccessCycles(kCLOCK_Flash5Cycle);
     }
-    else
+    else if (iFreq <= 100000000U)
     {
         CLOCK_SetFLASHAccessCycles(kCLOCK_Flash6Cycle);
     }
+    else
+    {
+        CLOCK_SetFLASHAccessCycles(kCLOCK_Flash7Cycle);
+    }
 }
 
 /* Find encoded NDEC value for raw N value, max N = NVALMAX */
@@ -784,13 +766,14 @@ static uint32_t pllDecodeN(uint32_t NDEC)
         default:
             x = 0x080U;
             n = 0xFFFFFFFFU;
-            for (i = NVALMAX; ((i >= 3U) && (n == 0xFFFFFFFFU)); i--)
+            for (i = NVALMAX; i >= 3U; i--)
             {
                 x = (((x ^ (x >> 2U) ^ (x >> 3U) ^ (x >> 4U)) & 1U) << 7U) | ((x >> 1U) & 0x7FU);
                 if ((x & (PLL_NDEC_VAL_M >> PLL_NDEC_VAL_P)) == NDEC)
                 {
                     /* Decoded value of NDEC */
                     n = i;
+                    break;
                 }
             }
             break;
@@ -854,13 +837,14 @@ static uint32_t pllDecodeP(uint32_t PDEC)
         default:
             x = 0x10U;
             p = 0xFFFFFFFFU;
-            for (i = PVALMAX; ((i >= 3U) && (p == 0xFFFFFFFFU)); i--)
+            for (i = PVALMAX; i >= 3U; i--)
             {
                 x = (((x ^ (x >> 2U)) & 1U) << 4U) | ((x >> 1U) & 0xFU);
                 if ((x & (PLL_PDEC_VAL_M >> PLL_PDEC_VAL_P)) == PDEC)
                 {
                     /* Decoded value of PDEC */
                     p = i;
+                    break;
                 }
             }
             break;
@@ -924,13 +908,14 @@ static uint32_t pllDecodeM(uint32_t MDEC)
         default:
             x = 0x04000U;
             m = 0xFFFFFFFFU;
-            for (i = MVALMAX; ((i >= 3U) && (m == 0xFFFFFFFFU)); i--)
+            for (i = MVALMAX; i >= 3U; i--)
             {
-                x = (((x ^ (x >> 1U)) & 1) << 14U) | ((x >> 1U) & 0x3FFFU);
+                x = (((x ^ (x >> 1U)) & 1U) << 14U) | ((x >> 1U) & 0x3FFFU);
                 if ((x & (PLL_SSCG0_MDEC_VAL_M >> PLL_SSCG0_MDEC_VAL_P)) == MDEC)
                 {
                     /* Decoded value of MDEC */
                     m = i;
+                    break;
                 }
             }
             break;
@@ -1113,7 +1098,7 @@ static pll_error_t CLOCK_GetPllConfigInternal(
             return kStatus_PLL_InputTooLow;
         }
         /* PLL input in SS mode must be under 4MHz */
-        pllPreDivider = finHz / ((PLL_MIN_IN_SSMODE + PLL_MAX_IN_SSMODE) / 2);
+        pllPreDivider = finHz / ((PLL_MIN_IN_SSMODE + PLL_MAX_IN_SSMODE) / 2U);
         if (pllPreDivider > NVALMAX)
         {
             return kStatus_PLL_InputTooHigh;
@@ -1188,30 +1173,32 @@ static pll_error_t CLOCK_GetPllConfigInternal(
         }
 
         /* Setup filtering */
-        pllFindSel(pllMultiplier, pllBypassFBDIV2, &pllSelP, &pllSelI, &pllSelR);
+        pllFindSel(pllMultiplier, (bool)pllBypassFBDIV2, &pllSelP, &pllSelI, &pllSelR);
         bandsel  = 1U;
         uplimoff = 0U;
 
         /* Get encoded value for M (mult) and use manual filter, disable SS mode */
         pSetup->syspllssctrl[0] =
-            (PLL_SSCG0_MDEC_VAL_SET(pllEncodeM(pllMultiplier)) | (1U << SYSCON_SYSPLLSSCTRL0_SEL_EXT_SHIFT));
+            (PLL_SSCG0_MDEC_VAL_SET(pllEncodeM(pllMultiplier)) | (1UL << SYSCON_SYSPLLSSCTRL0_SEL_EXT_SHIFT));
 
         /* Power down SSC, not used */
-        pSetup->syspllssctrl[1] = (1U << SYSCON_SYSPLLSSCTRL1_PD_SHIFT);
+        pSetup->syspllssctrl[1] = (1UL << SYSCON_SYSPLLSSCTRL1_PD_SHIFT);
     }
     else
     {
         uint64_t fc;
 
         /* Filtering will be handled by SSC */
-        pllSelR = pllSelI = pllSelP = 0U;
-        bandsel                     = 0U;
-        uplimoff                    = 1U;
+        pllSelR  = 0U;
+        pllSelI  = 0U;
+        pllSelP  = 0U;
+        bandsel  = 0U;
+        uplimoff = 1U;
 
         /* The PLL multiplier will get very close and slightly under the
            desired target frequency. A small fractional component can be
            added to fine tune the frequency upwards to the target. */
-        fc = ((uint64_t)(fccoHz % (multFccoDiv * nDivOutHz)) << 11U) / (multFccoDiv * nDivOutHz);
+        fc = (((uint64_t)fccoHz % ((uint64_t)multFccoDiv * nDivOutHz)) << 11U) / ((uint64_t)multFccoDiv * nDivOutHz);
 
         /* MDEC set by SSC */
         pSetup->syspllssctrl[0U] = 0U;
@@ -1228,7 +1215,7 @@ static pll_error_t CLOCK_GetPllConfigInternal(
     pSetup->syspllctrl = (pllSelR << SYSCON_SYSPLLCTRL_SELR_SHIFT) |                  /* Filter coefficient */
                          (pllSelI << SYSCON_SYSPLLCTRL_SELI_SHIFT) |                  /* Filter coefficient */
                          (pllSelP << SYSCON_SYSPLLCTRL_SELP_SHIFT) |                  /* Filter coefficient */
-                         (0 << SYSCON_SYSPLLCTRL_BYPASS_SHIFT) |                      /* PLL bypass mode disabled */
+                         (0UL << SYSCON_SYSPLLCTRL_BYPASS_SHIFT) |                    /* PLL bypass mode disabled */
                          (pllBypassFBDIV2 << SYSCON_SYSPLLCTRL_BYPASSCCODIV2_SHIFT) | /* Extra M / 2 divider? */
                          (uplimoff << SYSCON_SYSPLLCTRL_UPLIMOFF_SHIFT) |             /* SS/fractional mode disabled */
                          (bandsel << SYSCON_SYSPLLCTRL_BANDSEL_SHIFT) |        /* Manual bandwidth selection enabled */
@@ -1379,7 +1366,7 @@ uint32_t CLOCK_GetSystemPLLOutFromSetup(pll_setup_t *pSetup)
          * 2. M divider
          * If using the SS, use the multiplier.
          */
-        if (pSetup->syspllssctrl[1] & (SYSCON_SYSPLLSSCTRL1_PD_MASK))
+        if ((pSetup->syspllssctrl[1] & (SYSCON_SYSPLLSSCTRL1_PD_MASK)) != 0UL)
         {
             /* MDEC used for rate */
             mMult    = findPllMMult(pSetup->syspllctrl, pSetup->syspllssctrl[0]);
@@ -1394,7 +1381,7 @@ uint32_t CLOCK_GetSystemPLLOutFromSetup(pll_setup_t *pSetup)
             workRate = (uint64_t)inPllRate * (uint64_t)mMult;
 
             /* Adjust by fractional */
-            fract    = (uint64_t)(pSetup->syspllssctrl[1] & PLL_SSCG1_MD_FRACT_M) >> PLL_SSCG1_MD_FRACT_P;
+            fract    = ((uint64_t)(pSetup->syspllssctrl[1]) & PLL_SSCG1_MD_FRACT_M) >> PLL_SSCG1_MD_FRACT_P;
             workRate = workRate + ((inPllRate * fract) / 0x800U);
         }
 
@@ -1477,7 +1464,7 @@ pll_error_t CLOCK_SetupPLLData(pll_config_t *pControl, pll_setup_t *pSetup)
     pll_error_t pllError;
 
     /* Determine input rate for the PLL */
-    if ((pControl->flags & PLL_CONFIGFLAG_USEINRATE) != 0U)
+    if ((pControl->flags & PLL_CONFIGFLAG_USEINRATE) != 0UL)
     {
         inRate = pControl->inputRate;
     }
@@ -1486,7 +1473,7 @@ pll_error_t CLOCK_SetupPLLData(pll_config_t *pControl, pll_setup_t *pSetup)
         inRate = CLOCK_GetSystemPLLInClockRate();
     }
 
-    if ((pSetup->flags & PLL_SETUPFLAG_USEFEEDBACKDIV2) != 0U)
+    if ((pSetup->flags & PLL_SETUPFLAG_USEFEEDBACKDIV2) != 0UL)
     {
         useFbDiv2 = true;
     }
@@ -1503,7 +1490,7 @@ pll_error_t CLOCK_SetupPLLData(pll_config_t *pControl, pll_setup_t *pSetup)
         pSetup->syspllssctrl[1] |= (uint32_t)pControl->ss_mf | (uint32_t)pControl->ss_mr | (uint32_t)pControl->ss_mc;
         if (pControl->mfDither)
         {
-            pSetup->syspllssctrl[1] |= (1U << SYSCON_SYSPLLSSCTRL1_DITHER_SHIFT);
+            pSetup->syspllssctrl[1] |= (1UL << SYSCON_SYSPLLSSCTRL1_DITHER_SHIFT);
         }
     }
 
@@ -1531,44 +1518,41 @@ pll_error_t CLOCK_SetupSystemPLLPrec(pll_setup_t *pSetup, uint32_t flagcfg)
     /* Write PLL setup data */
     SYSCON->SYSPLLCTRL    = pSetup->syspllctrl;
     SYSCON->SYSPLLNDEC    = pSetup->syspllndec;
-    SYSCON->SYSPLLNDEC    = pSetup->syspllndec | (1U << SYSCON_SYSPLLNDEC_NREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLNDEC    = pSetup->syspllndec | (1UL << SYSCON_SYSPLLNDEC_NREQ_SHIFT); /* latch */
     SYSCON->SYSPLLPDEC    = pSetup->syspllpdec;
-    SYSCON->SYSPLLPDEC    = pSetup->syspllpdec | (1U << SYSCON_SYSPLLPDEC_PREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLPDEC    = pSetup->syspllpdec | (1UL << SYSCON_SYSPLLPDEC_PREQ_SHIFT); /* latch */
     SYSCON->SYSPLLSSCTRL0 = pSetup->syspllssctrl[0];
-    SYSCON->SYSPLLSSCTRL0 = pSetup->syspllssctrl[0] | (1U << SYSCON_SYSPLLSSCTRL0_MREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLSSCTRL0 = pSetup->syspllssctrl[0] | (1UL << SYSCON_SYSPLLSSCTRL0_MREQ_SHIFT); /* latch */
     SYSCON->SYSPLLSSCTRL1 = pSetup->syspllssctrl[1];
-    SYSCON->SYSPLLSSCTRL1 = pSetup->syspllssctrl[1] | (1U << SYSCON_SYSPLLSSCTRL1_MDREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLSSCTRL1 = pSetup->syspllssctrl[1] | (1UL << SYSCON_SYSPLLSSCTRL1_MDREQ_SHIFT); /* latch */
 
     /* Flags for lock or power on */
-    if ((pSetup->flags & (PLL_SETUPFLAG_POWERUP | PLL_SETUPFLAG_WAITLOCK)) != 0U)
+    if ((pSetup->flags & (PLL_SETUPFLAG_POWERUP | PLL_SETUPFLAG_WAITLOCK)) != 0UL)
     {
         /* If turning the PLL back on, perform the following sequence to accelerate PLL lock */
-        volatile uint32_t delayX;
-        uint32_t maxCCO    = (1U << 18U) | 0x5dd2U; /* CCO = 1.6Ghz + MDEC enabled*/
-        uint32_t curSSCTRL = SYSCON->SYSPLLSSCTRL0 & ~(1U << 17U);
+        uint32_t maxCCO    = (1UL << 18U) | 0x5dd2U; /* CCO = 1.6Ghz + MDEC enabled*/
+        uint32_t curSSCTRL = SYSCON->SYSPLLSSCTRL0 & ~(1UL << 17U);
 
         /* Initialize  and power up PLL */
         SYSCON->SYSPLLSSCTRL0 = maxCCO;
         POWER_DisablePD(kPDRUNCFG_PD_SYS_PLL0);
 
         /* Set mreq to activate */
-        SYSCON->SYSPLLSSCTRL0 = maxCCO | (1U << 17U);
+        SYSCON->SYSPLLSSCTRL0 = maxCCO | (1UL << 17U);
 
         /* Delay for 72 uSec @ 12Mhz */
-        for (delayX = 0U; delayX < 172U; ++delayX)
-        {
-        }
+        SDK_DelayAtLeastUs(72U, SDK_DEVICE_MAXIMUM_CPU_CLOCK_FREQUENCY);
 
         /* clear mreq to prepare for restoring mreq */
         SYSCON->SYSPLLSSCTRL0 = curSSCTRL;
 
         /* set original value back and activate */
-        SYSCON->SYSPLLSSCTRL0 = curSSCTRL | (1U << 17U);
+        SYSCON->SYSPLLSSCTRL0 = curSSCTRL | (1UL << 17U);
 
         /* Enable peripheral states by setting low */
         POWER_DisablePD(kPDRUNCFG_PD_SYS_PLL0);
     }
-    if ((pSetup->flags & PLL_SETUPFLAG_WAITLOCK) != 0U)
+    if ((pSetup->flags & PLL_SETUPFLAG_WAITLOCK) != 0UL)
     {
         while (CLOCK_IsSystemPLLLocked() == false)
         {
@@ -1579,7 +1563,7 @@ pll_error_t CLOCK_SetupSystemPLLPrec(pll_setup_t *pSetup, uint32_t flagcfg)
     CLOCK_GetSystemPLLOutFromSetupUpdate(pSetup);
 
     /* System voltage adjustment, occurs prior to setting main system clock */
-    if ((pSetup->flags & PLL_SETUPFLAG_ADGVOLT) != 0U)
+    if ((pSetup->flags & PLL_SETUPFLAG_ADGVOLT) != 0UL)
     {
         POWER_SetVoltageForFreq(s_Pll_Freq);
     }
@@ -1606,44 +1590,41 @@ pll_error_t CLOCK_SetPLLFreq(const pll_setup_t *pSetup)
     /* Write PLL setup data */
     SYSCON->SYSPLLCTRL    = pSetup->syspllctrl;
     SYSCON->SYSPLLNDEC    = pSetup->syspllndec;
-    SYSCON->SYSPLLNDEC    = pSetup->syspllndec | (1U << SYSCON_SYSPLLNDEC_NREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLNDEC    = pSetup->syspllndec | (1UL << SYSCON_SYSPLLNDEC_NREQ_SHIFT); /* latch */
     SYSCON->SYSPLLPDEC    = pSetup->syspllpdec;
-    SYSCON->SYSPLLPDEC    = pSetup->syspllpdec | (1U << SYSCON_SYSPLLPDEC_PREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLPDEC    = pSetup->syspllpdec | (1UL << SYSCON_SYSPLLPDEC_PREQ_SHIFT); /* latch */
     SYSCON->SYSPLLSSCTRL0 = pSetup->syspllssctrl[0];
-    SYSCON->SYSPLLSSCTRL0 = pSetup->syspllssctrl[0] | (1U << SYSCON_SYSPLLSSCTRL0_MREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLSSCTRL0 = pSetup->syspllssctrl[0] | (1UL << SYSCON_SYSPLLSSCTRL0_MREQ_SHIFT); /* latch */
     SYSCON->SYSPLLSSCTRL1 = pSetup->syspllssctrl[1];
-    SYSCON->SYSPLLSSCTRL1 = pSetup->syspllssctrl[1] | (1U << SYSCON_SYSPLLSSCTRL1_MDREQ_SHIFT); /* latch */
+    SYSCON->SYSPLLSSCTRL1 = pSetup->syspllssctrl[1] | (1UL << SYSCON_SYSPLLSSCTRL1_MDREQ_SHIFT); /* latch */
 
     /* Flags for lock or power on */
-    if ((pSetup->flags & (PLL_SETUPFLAG_POWERUP | PLL_SETUPFLAG_WAITLOCK)) != 0)
+    if ((pSetup->flags & (PLL_SETUPFLAG_POWERUP | PLL_SETUPFLAG_WAITLOCK)) != 0UL)
     {
         /* If turning the PLL back on, perform the following sequence to accelerate PLL lock */
-        volatile uint32_t delayX;
-        uint32_t maxCCO    = (1U << 18U) | 0x5dd2U; /* CCO = 1.6Ghz + MDEC enabled*/
-        uint32_t curSSCTRL = SYSCON->SYSPLLSSCTRL0 & ~(1U << 17U);
+        uint32_t maxCCO    = (1UL << 18U) | 0x5dd2U; /* CCO = 1.6Ghz + MDEC enabled*/
+        uint32_t curSSCTRL = SYSCON->SYSPLLSSCTRL0 & ~(1UL << 17U);
 
         /* Initialize  and power up PLL */
         SYSCON->SYSPLLSSCTRL0 = maxCCO;
         POWER_DisablePD(kPDRUNCFG_PD_SYS_PLL0);
 
         /* Set mreq to activate */
-        SYSCON->SYSPLLSSCTRL0 = maxCCO | (1U << 17U);
+        SYSCON->SYSPLLSSCTRL0 = maxCCO | (1UL << 17U);
 
         /* Delay for 72 uSec @ 12Mhz */
-        for (delayX = 0U; delayX < 172U; ++delayX)
-        {
-        }
+        SDK_DelayAtLeastUs(72U, SDK_DEVICE_MAXIMUM_CPU_CLOCK_FREQUENCY);
 
         /* clear mreq to prepare for restoring mreq */
         SYSCON->SYSPLLSSCTRL0 = curSSCTRL;
 
         /* set original value back and activate */
-        SYSCON->SYSPLLSSCTRL0 = curSSCTRL | (1U << 17U);
+        SYSCON->SYSPLLSSCTRL0 = curSSCTRL | (1UL << 17U);
 
         /* Enable peripheral states by setting low */
         POWER_DisablePD(kPDRUNCFG_PD_SYS_PLL0);
     }
-    if ((pSetup->flags & PLL_SETUPFLAG_WAITLOCK) != 0U)
+    if ((pSetup->flags & PLL_SETUPFLAG_WAITLOCK) != 0UL)
     {
         while (CLOCK_IsSystemPLLLocked() == false)
         {
@@ -1753,10 +1734,10 @@ void CLOCK_SetupSystemPLLMult(uint32_t multiply_by, uint32_t input_freq)
     SYSCON->SYSPLLCTRL = SYSCON_SYSPLLCTRL_BANDSEL(1) | directo | SYSCON_SYSPLLCTRL_BYPASSCCODIV2(1) |
                          (selr << SYSCON_SYSPLLCTRL_SELR_SHIFT) | (seli << SYSCON_SYSPLLCTRL_SELI_SHIFT) |
                          (selp << SYSCON_SYSPLLCTRL_SELP_SHIFT);
-    SYSCON->SYSPLLPDEC = pdec | (1U << 7U);  /* set Pdec value and assert preq */
-    SYSCON->SYSPLLNDEC = ndec | (1U << 10U); /* set Pdec value and assert preq */
+    SYSCON->SYSPLLPDEC = pdec | (1UL << 7U);  /* set Pdec value and assert preq */
+    SYSCON->SYSPLLNDEC = ndec | (1UL << 10U); /* set Pdec value and assert preq */
     SYSCON->SYSPLLSSCTRL0 =
-        (1U << 18U) | (1U << 17U) | mdec; /* select non sscg MDEC value, assert mreq and select mdec value */
+        (1UL << 18U) | (1UL << 17U) | mdec; /* select non sscg MDEC value, assert mreq and select mdec value */
 }
 bool CLOCK_EnableUsbfs0Clock(clock_usb_src_t src, uint32_t freq)
 {
@@ -1779,7 +1760,7 @@ bool CLOCK_EnableUsbfs0Clock(clock_usb_src_t src, uint32_t freq)
                 break;
         }
         /* Turn ON FRO HF and let it adjust TRIM value based on USB SOF */
-        SYSCON->FROCTRL = (SYSCON->FROCTRL & ~((0x01U << 15U) | (0xFU << 26U))) | SYSCON_FROCTRL_HSPDCLK_MASK |
+        SYSCON->FROCTRL = (SYSCON->FROCTRL & ~((0x01UL << 15U) | (0xFUL << 26U))) | SYSCON_FROCTRL_HSPDCLK_MASK |
                           SYSCON_FROCTRL_USBCLKADJ_MASK;
         /* select FRO 96 or 48 MHz */
         CLOCK_AttachClk(kFRO_HF_to_USB_CLK);
@@ -1794,79 +1775,3 @@ bool CLOCK_EnableUsbfs0Clock(clock_usb_src_t src, uint32_t freq)
 
     return ret;
 }
-
-#if (defined(__CORTEX_M) && (__CORTEX_M == 0U))
-/*!
- * brief Delay at least for several microseconds.
- * Please note that, this API will calculate the microsecond period with the maximum devices
- * supported CPU frequency, so this API will only delay for at least the given microseconds, if precise
- * delay count was needed, please implement a new timer count to achieve this function.
- *
- * param delay_us  Delay time in unit of microsecond.
- */
-__attribute__((weak)) void SDK_DelayAtLeastUs(uint32_t delay_us)
-{
-    assert(0U != delay_us);
-
-    uint32_t count = (uint32_t)USEC_TO_COUNT(delay_us, SDK_DEVICE_MAXIMUM_CPU_CLOCK_FREQUENCY);
-
-    /*
-     * Calculate the real delay count depend on the excute instructions cycles,
-     * users can change the divider value to adapt to the real IDE optimise level.
-     */
-    count = (count / 4U);
-
-    for (; count > 0UL; count--)
-    {
-        __NOP();
-    }
-}
-#else
-/*!
- * brief Use DWT to delay at least for some time.
- * Please note that, this API will calculate the microsecond period with the maximum devices
- * supported CPU frequency, so this API will only delay for at least the given microseconds, if precise
- * delay count was needed, please implement a new timer count to achieve this function.
- *
- * param delay_us  Delay time in unit of microsecond.
- */
-__attribute__((weak)) void SDK_DelayAtLeastUs(uint32_t delay_us)
-{
-    assert(0U != delay_us);
-    uint64_t count  = 0U;
-    uint32_t period = SDK_DEVICE_MAXIMUM_CPU_CLOCK_FREQUENCY / 1000000;
-
-    /* Make sure the DWT trace fucntion is enabled. */
-    if (CoreDebug_DEMCR_TRCENA_Msk != (CoreDebug_DEMCR_TRCENA_Msk & CoreDebug->DEMCR))
-    {
-        CoreDebug->DEMCR |= CoreDebug_DEMCR_TRCENA_Msk;
-    }
-
-    /* CYCCNT not supported on this device. */
-    assert(DWT_CTRL_NOCYCCNT_Msk != (DWT->CTRL & DWT_CTRL_NOCYCCNT_Msk));
-
-    /* If CYCCENT has already been enabled, read directly, otherwise, need enable it. */
-    if (DWT_CTRL_CYCCNTENA_Msk != (DWT_CTRL_CYCCNTENA_Msk & DWT->CTRL))
-    {
-        DWT->CTRL |= DWT_CTRL_CYCCNTENA_Msk;
-    }
-
-    /* Calculate the count ticks. */
-    count = DWT->CYCCNT;
-    count += (uint64_t)period * delay_us;
-
-    if (count > 0xFFFFFFFFUL)
-    {
-        count -= 0xFFFFFFFFUL;
-        /* wait for cyccnt overflow. */
-        while (count < DWT->CYCCNT)
-        {
-        }
-    }
-
-    /* Wait for cyccnt reach count value. */
-    while (count > DWT->CYCCNT)
-    {
-    }
-}
-#endif
