@@ -1,6 +1,6 @@
 /*
  * Copyright 2016 Freescale Semiconductor, Inc.
- * Copyright 2016-2020 NXP
+ * Copyright 2016-2021 NXP
  * All rights reserved.
  *
  * SPDX-License-Identifier: BSD-3-Clause
@@ -29,7 +29,7 @@
 /*! @name Driver version */
 /*@{*/
 /*! @brief IOMUXC driver version 2.0.3. */
-#define FSL_IOMUXC_DRIVER_VERSION (MAKE_VERSION(2, 0, 3))
+#define FSL_IOMUXC_DRIVER_VERSION (MAKE_VERSION(2, 0, 4))
 /*@}*/
 
 /*!
@@ -38,15 +38,6 @@
  *
  * @{
  */
-#define IOMUXC_SNVS_PMIC_ON_REQ_SNVS_LP_PMIC_ON_REQ 0x400A8000U, 0x0U, 0, 0, 0x400A8010U
-#define IOMUXC_SNVS_PMIC_ON_REQ_GPIO5_IO00 0x400A8000U, 0x5U, 0, 0, 0x400A8010U
-
-#define IOMUXC_SNVS_TEST_MODE 0, 0, 0, 0, 0x400A8004U
-
-#define IOMUXC_SNVS_POR_B 0, 0, 0, 0, 0x400A8008U
-
-#define IOMUXC_SNVS_ONOFF 0, 0, 0, 0, 0x400A800CU
-
 #define IOMUXC_GPIO_AD_14_LPI2C1_SCL 0x401F8010U, 0x0U, 0x401F81C0U, 0x0U, 0x401F80C0U
 #define IOMUXC_GPIO_AD_14_LPUART3_CTS_B 0x401F8010U, 0x1U, 0, 0, 0x401F80C0U
 #define IOMUXC_GPIO_AD_14_KPP_COL00 0x401F8010U, 0x2U, 0x401F819CU, 0x0U, 0x401F80C0U
@@ -98,7 +89,7 @@
 #define IOMUXC_GPIO_AD_09_ARM_TRACE_SWO 0x401F8024U, 0x3U, 0, 0, 0x401F80D4U
 #define IOMUXC_GPIO_AD_09_FLEXIO1_IO21 0x401F8024U, 0x4U, 0, 0, 0x401F80D4U
 #define IOMUXC_GPIO_AD_09_GPIOMUX_IO23 0x401F8024U, 0x5U, 0, 0, 0x401F80D4U
-#define IOMUXC_GPIO_AD_09_REF_32K_OUT 0x401F8024U, 0x6U, 0, 0, 0x401F80D4U
+#define IOMUXC_GPIO_AD_09_REF_CLK_32K 0x401F8024U, 0x6U, 0, 0, 0x401F80D4U
 #define IOMUXC_GPIO_AD_09_JTAG_TDO 0x401F8024U, 0x7U, 0, 0, 0x401F80D4U
 
 #define IOMUXC_GPIO_AD_08_LPI2C2_SCL 0x401F8028U, 0x0U, 0x401F81C8U, 0x0U, 0x401F80D8U
@@ -384,6 +375,15 @@
 #define IOMUXC_GPIO_00_PIT_TRIGGER00 0x401F80BCU, 0x4U, 0, 0, 0x401F816CU
 #define IOMUXC_GPIO_00_GPIOMUX_IO00 0x401F80BCU, 0x5U, 0, 0, 0x401F816CU
 
+#define IOMUXC_SNVS_PMIC_ON_REQ_SNVS_LP_PMIC_ON_REQ 0x400A8000U, 0x0U, 0, 0, 0x400A8010U
+#define IOMUXC_SNVS_PMIC_ON_REQ_GPIO5_IO00 0x400A8000U, 0x5U, 0, 0, 0x400A8010U
+
+#define IOMUXC_SNVS_TEST_MODE 0, 0, 0, 0, 0x400A8004U
+
+#define IOMUXC_SNVS_POR_B 0, 0, 0, 0, 0x400A8008U
+
+#define IOMUXC_SNVS_ONOFF 0, 0, 0, 0, 0x400A800CU
+
 /*@}*/
 
 #define IOMUXC_GPR_SAIMCLK_LOWBITMASK (0x7U)
