@@ -2,8 +2,6 @@
   ******************************************************************************
   * @file    stm32l4xx_hal_flash.c
   * @author  MCD Application Team
-  * @version V1.7.2
-  * @date    16-June-2017
   * @brief   FLASH HAL module driver.
   *          This file provides firmware functions to manage the following
   *          functionalities of the internal FLASH memory:
@@ -77,29 +75,13 @@
   ******************************************************************************
   * @attention
   *
-  * <h2><center>&copy; COPYRIGHT(c) 2017 STMicroelectronics</center></h2>
+  * <h2><center>&copy; Copyright (c) 2017 STMicroelectronics.
+  * All rights reserved.</center></h2>
   *
-  * Redistribution and use in source and binary forms, with or without modification,
-  * are permitted provided that the following conditions are met:
-  *   1. Redistributions of source code must retain the above copyright notice,
-  *      this list of conditions and the following disclaimer.
-  *   2. Redistributions in binary form must reproduce the above copyright notice,
-  *      this list of conditions and the following disclaimer in the documentation
-  *      and/or other materials provided with the distribution.
-  *   3. Neither the name of STMicroelectronics nor the names of its contributors
-  *      may be used to endorse or promote products derived from this software
-  *      without specific prior written permission.
-  *
-  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
-  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                       opensource.org/licenses/BSD-3-Clause
   *
   ******************************************************************************
   */
@@ -120,7 +102,11 @@
 
 /* Private typedef -----------------------------------------------------------*/
 /* Private defines -----------------------------------------------------------*/
+#if defined (STM32L4P5xx) || defined (STM32L4Q5xx) || defined (STM32L4R5xx) || defined (STM32L4R7xx) || defined (STM32L4R9xx) || defined (STM32L4S5xx) || defined (STM32L4S7xx) || defined (STM32L4S9xx)
+#define FLASH_NB_DOUBLE_WORDS_IN_ROW  64
+#else
 #define FLASH_NB_DOUBLE_WORDS_IN_ROW  32
+#endif
 /* Private macros ------------------------------------------------------------*/
 /* Private variables ---------------------------------------------------------*/
 /** @defgroup FLASH_Private_Variables FLASH Private Variables
@@ -129,7 +115,14 @@
 /**
   * @brief  Variable used for Program/Erase sectors under interruption
   */
-FLASH_ProcessTypeDef pFlash;
+FLASH_ProcessTypeDef pFlash = {.Lock = HAL_UNLOCKED, \
+                               .ErrorCode = HAL_FLASH_ERROR_NONE, \
+                               .ProcedureOnGoing = FLASH_PROC_NONE, \
+                               .Address = 0U, \
+                               .Bank = FLASH_BANK_1, \
+                               .Page = 0U, \
+                               .NbPagesToErase = 0U, \
+                               .CacheToReactivate = FLASH_CACHE_DISABLED};
 /**
   * @}
   */
@@ -138,10 +131,6 @@ FLASH_ProcessTypeDef pFlash;
 /** @defgroup FLASH_Private_Functions FLASH Private Functions
  * @{
  */
-HAL_StatusTypeDef    FLASH_WaitForLastOperation(uint32_t Timeout);
-extern void          FLASH_PageErase(uint32_t Page, uint32_t Banks);
-extern void          FLASH_FlushCaches(void);
-static void          FLASH_SetErrorCode(void);
 static void          FLASH_Program_DoubleWord(uint32_t Address, uint64_t Data);
 static void          FLASH_Program_Fast(uint32_t Address, uint32_t DataAddress);
 /**
@@ -170,10 +159,10 @@ static void          FLASH_Program_Fast(uint32_t Address, uint32_t DataAddress);
 
 /**
   * @brief  Program double word or fast program of a row at a specified address.
-  * @param  TypeProgram:  Indicate the way to program at a specified address.
+  * @param  TypeProgram  Indicate the way to program at a specified address.
   *                           This parameter can be a value of @ref FLASH_Type_Program
-  * @param  Address:  specifies the address to be programmed.
-  * @param  Data: specifies the data to be programmed
+  * @param  Address  specifies the address to be programmed.
+  * @param  Data specifies the data to be programmed
   *                This parameter is the data for the double word program and the address where
   *                are stored the data for the row fast program
   *
@@ -181,7 +170,7 @@ static void          FLASH_Program_Fast(uint32_t Address, uint32_t DataAddress);
   */
 HAL_StatusTypeDef HAL_FLASH_Program(uint32_t TypeProgram, uint32_t Address, uint64_t Data)
 {
-  HAL_StatusTypeDef status = HAL_ERROR;
+  HAL_StatusTypeDef status;
   uint32_t prog_bit = 0;
 
   /* Process Locked */
@@ -198,7 +187,7 @@ HAL_StatusTypeDef HAL_FLASH_Program(uint32_t TypeProgram, uint32_t Address, uint
     pFlash.ErrorCode = HAL_FLASH_ERROR_NONE;
 
     /* Deactivate the data cache if they are activated to avoid data misbehavior */
-    if(READ_BIT(FLASH->ACR, FLASH_ACR_DCEN) != RESET)
+    if(READ_BIT(FLASH->ACR, FLASH_ACR_DCEN) != 0U)
     {
       /* Disable data cache  */
       __HAL_FLASH_DATA_CACHE_DISABLE();
@@ -226,12 +215,16 @@ HAL_StatusTypeDef HAL_FLASH_Program(uint32_t TypeProgram, uint32_t Address, uint
         prog_bit = FLASH_CR_FSTPG;
       }
     }
+    else
+    {
+      /* Nothing to do */
+    }
 
     /* Wait for last operation to be completed */
     status = FLASH_WaitForLastOperation((uint32_t)FLASH_TIMEOUT_VALUE);
 
     /* If the program operation is completed, disable the PG or FSTPG Bit */
-    if (prog_bit != 0)
+    if (prog_bit != 0U)
     {
       CLEAR_BIT(FLASH->CR, prog_bit);
     }
@@ -248,10 +241,10 @@ HAL_StatusTypeDef HAL_FLASH_Program(uint32_t TypeProgram, uint32_t Address, uint
 
 /**
   * @brief  Program double word or fast program of a row at a specified address with interrupt enabled.
-  * @param  TypeProgram:  Indicate the way to program at a specified address.
+  * @param  TypeProgram  Indicate the way to program at a specified address.
   *                           This parameter can be a value of @ref FLASH_Type_Program
-  * @param  Address:  specifies the address to be programmed.
-  * @param  Data: specifies the data to be programmed
+  * @param  Address  specifies the address to be programmed.
+  * @param  Data specifies the data to be programmed
   *                This parameter is the data for the double word program and the address where
   *                are stored the data for the row fast program
   *
@@ -270,7 +263,7 @@ HAL_StatusTypeDef HAL_FLASH_Program_IT(uint32_t TypeProgram, uint32_t Address, u
   pFlash.ErrorCode = HAL_FLASH_ERROR_NONE;
 
   /* Deactivate the data cache if they are activated to avoid data misbehavior */
-  if(READ_BIT(FLASH->ACR, FLASH_ACR_DCEN) != RESET)
+  if(READ_BIT(FLASH->ACR, FLASH_ACR_DCEN) != 0U)
   {
     /* Disable data cache  */
     __HAL_FLASH_DATA_CACHE_DISABLE();
@@ -305,6 +298,10 @@ HAL_StatusTypeDef HAL_FLASH_Program_IT(uint32_t TypeProgram, uint32_t Address, u
     /* Fast program a 32 row double-word (64-bit) at a specified address */
     FLASH_Program_Fast(Address, (uint32_t)Data);
   }
+  else
+  {
+    /* Nothing to do */
+  }
 
   return status;
 }
@@ -316,11 +313,15 @@ HAL_StatusTypeDef HAL_FLASH_Program_IT(uint32_t TypeProgram, uint32_t Address, u
 void HAL_FLASH_IRQHandler(void)
 {
   uint32_t tmp_page;
+  uint32_t error;
+  FLASH_ProcedureTypeDef procedure;
 
   /* If the operation is completed, disable the PG, PNB, MER1, MER2 and PER Bit */
   CLEAR_BIT(FLASH->CR, (FLASH_CR_PG | FLASH_CR_MER1 | FLASH_CR_PER | FLASH_CR_PNB));
 #if defined (STM32L471xx) || defined (STM32L475xx) || defined (STM32L476xx) || defined (STM32L485xx) || defined (STM32L486xx) || \
-    defined (STM32L496xx) || defined (STM32L4A6xx)
+    defined (STM32L496xx) || defined (STM32L4A6xx) || \
+    defined (STM32L4P5xx) || defined (STM32L4Q5xx) || \
+    defined (STM32L4R5xx) || defined (STM32L4R7xx) || defined (STM32L4R9xx) || defined (STM32L4S5xx) || defined (STM32L4S7xx) || defined (STM32L4S9xx)
   CLEAR_BIT(FLASH->CR, FLASH_CR_MER2);
 #endif
 
@@ -331,45 +332,45 @@ void HAL_FLASH_IRQHandler(void)
   }
 
   /* Check FLASH operation error flags */
-  if((__HAL_FLASH_GET_FLAG(FLASH_FLAG_OPERR))  || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PROGERR)) ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_WRPERR)) || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PGAERR))  ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_SIZERR)) || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PGSERR))  ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_MISERR)) || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_FASTERR)) ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_RDERR))  || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_OPTVERR)) ||
-#if defined (STM32L431xx) || defined (STM32L432xx) || defined (STM32L433xx) || defined (STM32L442xx) || defined (STM32L443xx) || \
-    defined (STM32L451xx) || defined (STM32L452xx) || defined (STM32L462xx) || defined (STM32L496xx) || defined (STM32L4A6xx)
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_ECCD))   || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PEMPTY)))
-#else
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_ECCD)))
-#endif
+  error = (FLASH->SR & FLASH_FLAG_SR_ERRORS);
+
+  if (error !=0U)
   {
     /*Save the error code*/
-    FLASH_SetErrorCode();
+    pFlash.ErrorCode |= error;
+
+    /* Clear error programming flags */
+    __HAL_FLASH_CLEAR_FLAG(error);
 
     /* Flush the caches to be sure of the data consistency */
     FLASH_FlushCaches() ;
 
     /* FLASH error interrupt user callback */
-    if(pFlash.ProcedureOnGoing == FLASH_PROC_PAGE_ERASE)
+    procedure = pFlash.ProcedureOnGoing;
+    if(procedure == FLASH_PROC_PAGE_ERASE)
     {
        HAL_FLASH_OperationErrorCallback(pFlash.Page);
     }
-    else if(pFlash.ProcedureOnGoing == FLASH_PROC_MASS_ERASE)
+    else if(procedure == FLASH_PROC_MASS_ERASE)
     {
         HAL_FLASH_OperationErrorCallback(pFlash.Bank);
     }
-    else if((pFlash.ProcedureOnGoing == FLASH_PROC_PROGRAM) ||
-            (pFlash.ProcedureOnGoing == FLASH_PROC_PROGRAM_LAST))
+    else if((procedure == FLASH_PROC_PROGRAM) ||
+            (procedure == FLASH_PROC_PROGRAM_LAST))
     {
        HAL_FLASH_OperationErrorCallback(pFlash.Address);
     }
+    else
+    {
+       HAL_FLASH_OperationErrorCallback(0U);
+    }
 
     /*Stop the procedure ongoing*/
     pFlash.ProcedureOnGoing = FLASH_PROC_NONE;
   }
 
   /* Check FLASH End of Operation flag  */
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_EOP))
+  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_EOP) != 0U)
   {
     /* Clear FLASH End of Operation pending bit */
     __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_EOP);
@@ -380,7 +381,7 @@ void HAL_FLASH_IRQHandler(void)
       pFlash.NbPagesToErase--;
 
       /* Check if there are still pages to erase*/
-      if(pFlash.NbPagesToErase != 0)
+      if(pFlash.NbPagesToErase != 0U)
       {
         /* Indicate user which page has been erased*/
         HAL_FLASH_EndOfOperationCallback(pFlash.Page);
@@ -394,7 +395,7 @@ void HAL_FLASH_IRQHandler(void)
       {
         /* No more pages to Erase */
         /* Reset Address and stop Erase pages procedure */
-        pFlash.Page = 0xFFFFFFFF;
+        pFlash.Page = 0xFFFFFFFFU;
         pFlash.ProcedureOnGoing = FLASH_PROC_NONE;
 
         /* Flush the caches to be sure of the data consistency */
@@ -409,19 +410,24 @@ void HAL_FLASH_IRQHandler(void)
       /* Flush the caches to be sure of the data consistency */
       FLASH_FlushCaches() ;
 
-      if(pFlash.ProcedureOnGoing == FLASH_PROC_MASS_ERASE)
+      procedure = pFlash.ProcedureOnGoing;
+      if(procedure == FLASH_PROC_MASS_ERASE)
       {
         /* MassErase ended. Return the selected bank */
         /* FLASH EOP interrupt user callback */
         HAL_FLASH_EndOfOperationCallback(pFlash.Bank);
       }
-      else if((pFlash.ProcedureOnGoing == FLASH_PROC_PROGRAM) ||
-              (pFlash.ProcedureOnGoing == FLASH_PROC_PROGRAM_LAST))
+      else if((procedure == FLASH_PROC_PROGRAM) ||
+              (procedure == FLASH_PROC_PROGRAM_LAST))
       {
         /* Program ended. Return the selected address */
         /* FLASH EOP interrupt user callback */
         HAL_FLASH_EndOfOperationCallback(pFlash.Address);
       }
+      else
+      {
+        /* Nothing to do */
+      }
 
       /*Clear the procedure ongoing*/
       pFlash.ProcedureOnGoing = FLASH_PROC_NONE;
@@ -440,7 +446,7 @@ void HAL_FLASH_IRQHandler(void)
 
 /**
   * @brief  FLASH end of operation interrupt callback.
-  * @param  ReturnValue: The value saved in this parameter depends on the ongoing procedure
+  * @param  ReturnValue The value saved in this parameter depends on the ongoing procedure
   *                  Mass Erase: Bank number which has been requested to erase
   *                  Page Erase: Page which has been erased
   *                    (if 0xFFFFFFFF, it means that all the selected pages have been erased)
@@ -459,7 +465,7 @@ __weak void HAL_FLASH_EndOfOperationCallback(uint32_t ReturnValue)
 
 /**
   * @brief  FLASH operation error interrupt callback.
-  * @param  ReturnValue: The value saved in this parameter depends on the ongoing procedure
+  * @param  ReturnValue The value saved in this parameter depends on the ongoing procedure
   *                 Mass Erase: Bank number which has been requested to erase
   *                 Page Erase: Page number which returned an error
   *                 Program: Address which was selected for data program
@@ -500,24 +506,22 @@ __weak void HAL_FLASH_OperationErrorCallback(uint32_t ReturnValue)
   */
 HAL_StatusTypeDef HAL_FLASH_Unlock(void)
 {
+  HAL_StatusTypeDef status = HAL_OK;
 
-#if defined(STM32L451xx) || defined(STM32L452xx) || defined(STM32L462xx)
-  /* Clear OPTVERR bit when initially improperly raised */
-  __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_OPTVERR);
-#endif
-
-  if(READ_BIT(FLASH->CR, FLASH_CR_LOCK) != RESET)
+  if(READ_BIT(FLASH->CR, FLASH_CR_LOCK) != 0U)
   {
     /* Authorize the FLASH Registers access */
     WRITE_REG(FLASH->KEYR, FLASH_KEY1);
     WRITE_REG(FLASH->KEYR, FLASH_KEY2);
-  }
-  else
-  {
-    return HAL_ERROR;
+
+    /* Verify Flash is unlocked */
+    if(READ_BIT(FLASH->CR, FLASH_CR_LOCK) != 0U)
+    {
+      status = HAL_ERROR;
+    }
   }
 
-  return HAL_OK;
+  return status;
 }
 
 /**
@@ -538,7 +542,7 @@ HAL_StatusTypeDef HAL_FLASH_Lock(void)
   */
 HAL_StatusTypeDef HAL_FLASH_OB_Unlock(void)
 {
-  if(READ_BIT(FLASH->CR, FLASH_CR_OPTLOCK) != RESET)
+  if(READ_BIT(FLASH->CR, FLASH_CR_OPTLOCK) != 0U)
   {
     /* Authorizes the Option Byte register programming */
     WRITE_REG(FLASH->OPTKEYR, FLASH_OPTKEY1);
@@ -616,7 +620,6 @@ HAL_StatusTypeDef HAL_FLASH_OB_Launch(void)
   *            @arg HAL_FLASH_ERROR_RD: FLASH PCROP read error
   *            @arg HAL_FLASH_ERROR_OPTV: FLASH Option validity error
   *            @arg FLASH_FLAG_PEMPTY : FLASH Boot from not programmed flash (apply only for STM32L43x/STM32L44x devices)
-  *            @arg HAL_FLASH_ERROR_ECCD: FLASH two ECC errors have been detected
   */
 uint32_t HAL_FLASH_GetError(void)
 {
@@ -639,7 +642,7 @@ uint32_t HAL_FLASH_GetError(void)
 
 /**
   * @brief  Wait for a FLASH operation to complete.
-  * @param  Timeout: maximum flash operation timeout
+  * @param  Timeout maximum flash operation timeout
   * @retval HAL_StatusTypeDef HAL Status
   */
 HAL_StatusTypeDef FLASH_WaitForLastOperation(uint32_t Timeout)
@@ -649,6 +652,7 @@ HAL_StatusTypeDef FLASH_WaitForLastOperation(uint32_t Timeout)
      flag will be set */
 
   uint32_t tickstart = HAL_GetTick();
+  uint32_t error;
 
   while(__HAL_FLASH_GET_FLAG(FLASH_FLAG_BSY))
   {
@@ -661,20 +665,15 @@ HAL_StatusTypeDef FLASH_WaitForLastOperation(uint32_t Timeout)
     }
   }
 
-  if((__HAL_FLASH_GET_FLAG(FLASH_FLAG_OPERR))  || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PROGERR)) ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_WRPERR)) || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PGAERR))  ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_SIZERR)) || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PGSERR))  ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_MISERR)) || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_FASTERR)) ||
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_RDERR))  || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_OPTVERR)) ||
-#if defined (STM32L431xx) || defined (STM32L432xx) || defined (STM32L433xx) || defined (STM32L442xx) || defined (STM32L443xx) || \
-    defined (STM32L451xx) || defined (STM32L452xx) || defined (STM32L462xx) || defined (STM32L496xx) || defined (STM32L4A6xx)
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_ECCD))   || (__HAL_FLASH_GET_FLAG(FLASH_FLAG_PEMPTY)))
-#else
-     (__HAL_FLASH_GET_FLAG(FLASH_FLAG_ECCD)))
-#endif
+  error = (FLASH->SR & FLASH_FLAG_SR_ERRORS);
+
+  if(error != 0u)
   {
     /*Save the error code*/
-    FLASH_SetErrorCode();
+    pFlash.ErrorCode |= error;
+
+    /* Clear error programming flags */
+    __HAL_FLASH_CLEAR_FLAG(error);
 
     return HAL_ERROR;
   }
@@ -690,84 +689,10 @@ HAL_StatusTypeDef FLASH_WaitForLastOperation(uint32_t Timeout)
   return HAL_OK;
 }
 
-/**
-  * @brief  Set the specific FLASH error flag.
-  * @retval None
-  */
-static void FLASH_SetErrorCode(void)
-{
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_OPERR))
-  {
-    pFlash.ErrorCode |= HAL_FLASH_ERROR_OP;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_PROGERR))
-  {
-    pFlash.ErrorCode |= HAL_FLASH_ERROR_PROG;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_WRPERR))
-  {
-    pFlash.ErrorCode |= HAL_FLASH_ERROR_WRP;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_PGAERR))
-  {
-    pFlash.ErrorCode |= HAL_FLASH_ERROR_PGA;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_SIZERR))
-  {
-    pFlash.ErrorCode |= HAL_FLASH_ERROR_SIZ;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_PGSERR))
-  {
-    pFlash.ErrorCode |= HAL_FLASH_ERROR_PGS;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_MISERR))
-  {
-   pFlash.ErrorCode |= HAL_FLASH_ERROR_MIS;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_FASTERR))
-  {
-   pFlash.ErrorCode |= HAL_FLASH_ERROR_FAST;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_RDERR))
-  {
-   pFlash.ErrorCode |= HAL_FLASH_ERROR_RD;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_OPTVERR))
-  {
-   pFlash.ErrorCode |= HAL_FLASH_ERROR_OPTV;
-  }
-
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_ECCD))
-  {
-   pFlash.ErrorCode |= HAL_FLASH_ERROR_ECCD;
-  }
-
-#if defined (STM32L431xx) || defined (STM32L432xx) || defined (STM32L433xx) || defined (STM32L442xx) || defined (STM32L443xx) || \
-    defined (STM32L451xx) || defined (STM32L452xx) || defined (STM32L462xx) || defined (STM32L496xx) || defined (STM32L4A6xx)
-  if(__HAL_FLASH_GET_FLAG(FLASH_FLAG_PEMPTY))
-  {
-    pFlash.ErrorCode |= HAL_FLASH_ERROR_PEMPTY;
-    __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_PEMPTY);
-  }
-#endif
-
-  /* Clear error programming flags */
-  __HAL_FLASH_CLEAR_FLAG(FLASH_FLAG_ALL_ERRORS);
-}
-
 /**
   * @brief  Program double-word (64-bit) at a specified address.
-  * @param  Address: specifies the address to be programmed.
-  * @param  Data: specifies the data to be programmed.
+  * @param  Address specifies the address to be programmed.
+  * @param  Data specifies the data to be programmed.
   * @retval None
   */
 static void FLASH_Program_DoubleWord(uint32_t Address, uint64_t Data)
@@ -778,19 +703,26 @@ static void FLASH_Program_DoubleWord(uint32_t Address, uint64_t Data)
   /* Set PG bit */
   SET_BIT(FLASH->CR, FLASH_CR_PG);
 
-  /* Program the double word */
+  /* Program first word */
   *(__IO uint32_t*)Address = (uint32_t)Data;
-  *(__IO uint32_t*)(Address+4) = (uint32_t)(Data >> 32);
+
+  /* Barrier to ensure programming is performed in 2 steps, in right order
+    (independently of compiler optimization behavior) */
+  __ISB();
+
+  /* Program second word */
+  *(__IO uint32_t*)(Address+4U) = (uint32_t)(Data >> 32);
 }
 
 /**
   * @brief  Fast program a row double-word (64-bit) at a specified address.
-  * @param  Address: specifies the address to be programmed.
-  * @param  DataAddress: specifies the address where the data are stored.
+  * @param  Address specifies the address to be programmed.
+  * @param  DataAddress specifies the address where the data are stored.
   * @retval None
   */
 static void FLASH_Program_Fast(uint32_t Address, uint32_t DataAddress)
 {
+  uint32_t primask_bit;
   uint8_t row_index = (2*FLASH_NB_DOUBLE_WORDS_IN_ROW);
   __IO uint32_t *dest_addr = (__IO uint32_t*)Address;
   __IO uint32_t *src_addr = (__IO uint32_t*)DataAddress;
@@ -802,16 +734,20 @@ static void FLASH_Program_Fast(uint32_t Address, uint32_t DataAddress)
   SET_BIT(FLASH->CR, FLASH_CR_FSTPG);
 
   /* Disable interrupts to avoid any interruption during the loop */
+  primask_bit = __get_PRIMASK();
   __disable_irq();
 
   /* Program the double word of the row */
   do
   {
-    *dest_addr++ = *src_addr++;
-  } while (--row_index != 0);
+    *dest_addr = *src_addr;
+    dest_addr++;
+    src_addr++;
+    row_index--;
+  } while (row_index != 0U);
 
   /* Re-enable the interrupts */
-  __enable_irq();
+  __set_PRIMASK(primask_bit);
 }
 
 /**
