@@ -74,8 +74,7 @@ typedef struct
   uint32_t SampleShifting;            /*!< It allows to delay to 1/2 cycle the data sampling in order
                                            to take in account external signal delays.
                                            This parameter can be a value of @ref XSPI_SampleShifting */
-  uint32_t DelayHoldQuarterCycle;     /*!< It allows to hold to 1/4 cycle the data.
-                                           This parameter can be a value of @ref XSPI_DelayHoldQuarterCycle */
+  uint32_t DelayHoldQuarterCycle;     /*!< This parameter is deprecated and is not used on STM32N6xx devices */
   uint32_t ChipSelectBoundary;        /*!< It enables the transaction boundary feature and
                                            defines the boundary of bytes to release the chip select.
                                            This parameter can be a value of @ref XSPI_ChipSelectBoundary  */
@@ -458,6 +457,7 @@ typedef struct
   */
 
 /** @defgroup XSPI_DelayHoldQuarterCycle XSPI Delay Hold Quarter Cycle
+  * @note These constants are deprecated and are not expected to be used anymore.
   * @{
   */
 #define HAL_XSPI_DHQC_DISABLE                (0x00000000U)              /*!< No Delay                         */
@@ -801,6 +801,15 @@ typedef struct
   * @}
   */
 
+/** @defgroup XSPI_MaxCal XSPI Calibration Maximal Value
+  * @{
+  */
+#define HAL_XSPI_MAXCAL_NOT_REACHED        (0x00000000U)                   /*!< Memory-clock perido inside the range of DLL master                          */
+#define HAL_XSPI_MAXCAL_REACHED            ((uint32_t)XSPI_CALFCR_CALMAX)  /*!< Memory-clock period outside the range of DLL master (max delay values used) */
+/**
+  * @}
+  */
+
 /** @defgroup XSPIM_MemorySelect_Override XSPIM Memory Select Override
   * @{
   */
@@ -811,15 +820,6 @@ typedef struct
   * @}
   */
 
-/** @defgroup XSPI_MaxCal XSPI Calibration Maximal Value
-  * @{
-  */
-#define HAL_XSPI_MAXCAL_NOT_REACHED        (0x00000000U)                   /*!< Memory-clock perido inside the range of DLL master                          */
-#define HAL_XSPI_MAXCAL_REACHED            ((uint32_t)XSPI_CALFCR_CALMAX)  /*!< Memory-clock period outside the range of DLL master (max delay values used) */
-/**
-  * @}
-  */
-
 /**
   * @}
   */
@@ -1272,6 +1272,10 @@ HAL_StatusTypeDef     HAL_XSPI_SetDelayValue(XSPI_HandleTypeDef *hxspi, const XS
 
 #define IS_XSPI_TIMEOUT_PERIOD(PERIOD)            ((PERIOD) <= 0xFFFFU)
 
+#define IS_XSPI_PROG_DATA(SET_DATA, REQ_DATA)     ((SET_DATA) == (REQ_DATA))
+
+#define IS_XSPI_PROG_ADDR(SET_ADDR, REQ_ADDR)     ((SET_ADDR) == (REQ_ADDR))
+
 #define IS_XSPIM_IO_PORT(PORT)                    (((PORT) == HAL_XSPIM_IOPORT_1)   || \
                                                    ((PORT) == HAL_XSPIM_IOPORT_2))
 
