@@ -6,13 +6,12 @@
   ******************************************************************************
   * @attention
   *
-  * <h2><center>&copy; Copyright (c) 2019 STMicroelectronics.
-  * All rights reserved.</center></h2>
+  * Copyright (c) 2019 STMicroelectronics.
+  * All rights reserved.
   *
-  * This software component is licensed by ST under BSD 3-Clause license,
-  * the "License"; You may not use this file except in compliance with the
-  * License. You may obtain a copy of the License at:
-  *                        opensource.org/licenses/BSD-3-Clause
+  * This software is licensed under terms that can be found in the LICENSE file
+  * in the root directory of this software component.
+  * If no LICENSE file comes with this software, it is provided AS-IS.
   *
   ******************************************************************************
   */
@@ -22,7 +21,7 @@
 #define STM32WBxx_HAL_CORTEX_H
 
 #ifdef __cplusplus
- extern "C" {
+extern "C" {
 #endif
 
 /* Includes ------------------------------------------------------------------*/
@@ -71,7 +70,7 @@ typedef struct
                                       This parameter can be a value of @ref CORTEX_MPU_Access_Cacheable             */
   uint8_t IsBufferable;          /*!< Specifies the bufferable status of the protected region.
                                       This parameter can be a value of @ref CORTEX_MPU_Access_Bufferable            */
-}MPU_Region_InitTypeDef;
+} MPU_Region_InitTypeDef;
 /**
   * @}
   */
@@ -263,12 +262,12 @@ typedef struct
   */
 
 /** @defgroup CORTEX_Exported_Functions_Group1 Initialization and Configuration functions
- *  @brief    Initialization and Configuration functions
- * @{
- */
+  * @brief    Initialization and Configuration functions
+  * @{
+  */
 /* Initialization and Configuration functions *****************************/
 void HAL_NVIC_SetPriorityGrouping(uint32_t PriorityGroup);
-void HAL_NVIC_SetPriority(IRQn_Type IRQn,uint32_t PreemptPriority, uint32_t SubPriority);
+void HAL_NVIC_SetPriority(IRQn_Type IRQn, uint32_t PreemptPriority, uint32_t SubPriority);
 void HAL_NVIC_EnableIRQ(IRQn_Type IRQn);
 void HAL_NVIC_DisableIRQ(IRQn_Type IRQn);
 void HAL_NVIC_SystemReset(void);
@@ -278,11 +277,11 @@ uint32_t HAL_SYSTICK_Config(uint32_t TicksNumb);
   */
 
 /** @defgroup CORTEX_Exported_Functions_Group2 Peripheral Control functions
- *  @brief   Cortex control functions
- * @{
- */
+  * @brief   Cortex control functions
+  * @{
+  */
 /* Peripheral Control functions *************************************************/
-void HAL_NVIC_GetPriority(IRQn_Type IRQn, uint32_t PriorityGroup, uint32_t* pPreemptPriority, uint32_t* pSubPriority);
+void HAL_NVIC_GetPriority(IRQn_Type IRQn, uint32_t PriorityGroup, uint32_t *pPreemptPriority, uint32_t *pSubPriority);
 uint32_t HAL_NVIC_GetPriorityGrouping(void);
 uint32_t HAL_NVIC_GetPendingIRQ(IRQn_Type IRQn);
 void HAL_NVIC_SetPendingIRQ(IRQn_Type IRQn);
@@ -294,6 +293,8 @@ void HAL_SYSTICK_Callback(void);
 #if (__MPU_PRESENT == 1U)
 void HAL_MPU_Enable(uint32_t MPU_Control);
 void HAL_MPU_Disable(void);
+void HAL_MPU_EnableRegion(uint32_t RegionNumber);
+void HAL_MPU_DisableRegion(uint32_t RegionNumber);
 void HAL_MPU_ConfigRegion(MPU_Region_InitTypeDef *MPU_Init);
 #endif /* __MPU_PRESENT */
 /**
@@ -362,34 +363,34 @@ void HAL_MPU_ConfigRegion(MPU_Region_InitTypeDef *MPU_Init);
                                                    ((NUMBER) == MPU_REGION_NUMBER6) || \
                                                    ((NUMBER) == MPU_REGION_NUMBER7))
 
-#define IS_MPU_REGION_SIZE(SIZE)                  (((SIZE) == MPU_REGION_SIZE_32B)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_64B)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_128B)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_256B)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_512B)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_1KB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_2KB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_4KB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_8KB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_16KB)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_32KB)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_64KB)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_128KB) || \
-                                                   ((SIZE) == MPU_REGION_SIZE_256KB) || \
-                                                   ((SIZE) == MPU_REGION_SIZE_512KB) || \
-                                                   ((SIZE) == MPU_REGION_SIZE_1MB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_2MB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_4MB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_8MB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_16MB)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_32MB)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_64MB)  || \
-                                                   ((SIZE) == MPU_REGION_SIZE_128MB) || \
-                                                   ((SIZE) == MPU_REGION_SIZE_256MB) || \
-                                                   ((SIZE) == MPU_REGION_SIZE_512MB) || \
-                                                   ((SIZE) == MPU_REGION_SIZE_1GB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_2GB)   || \
-                                                   ((SIZE) == MPU_REGION_SIZE_4GB))
+#define IS_MPU_REGION_SIZE(SIZE)    (((SIZE) == MPU_REGION_SIZE_32B)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_64B)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_128B)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_256B)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_512B)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_1KB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_2KB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_4KB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_8KB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_16KB)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_32KB)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_64KB)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_128KB) || \
+                                     ((SIZE) == MPU_REGION_SIZE_256KB) || \
+                                     ((SIZE) == MPU_REGION_SIZE_512KB) || \
+                                     ((SIZE) == MPU_REGION_SIZE_1MB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_2MB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_4MB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_8MB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_16MB)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_32MB)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_64MB)  || \
+                                     ((SIZE) == MPU_REGION_SIZE_128MB) || \
+                                     ((SIZE) == MPU_REGION_SIZE_256MB) || \
+                                     ((SIZE) == MPU_REGION_SIZE_512MB) || \
+                                     ((SIZE) == MPU_REGION_SIZE_1GB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_2GB)   || \
+                                     ((SIZE) == MPU_REGION_SIZE_4GB))
 
 #define IS_MPU_SUB_REGION_DISABLE(SUBREGION)      ((SUBREGION) < (uint16_t)0x00FFU)
 #endif /* __MPU_PRESENT */
@@ -413,7 +414,3 @@ void HAL_MPU_ConfigRegion(MPU_Region_InitTypeDef *MPU_Init);
 #endif
 
 #endif /* STM32WBxx_HAL_CORTEX_H */
-
-
-/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
-
