@@ -35,15 +35,11 @@
 //--------------------------------------------------------------------+
 
 // List of supported sample rates
-#if defined(__RX__)
-  const uint32_t sample_rates[] = {44100, 48000};
-#else
-  const uint32_t sample_rates[] = {44100, 48000, 88200, 96000};
-#endif
+const uint32_t sample_rates[] = {44100, 48000};
 
-uint32_t current_sample_rate  = 44100;
+uint32_t current_sample_rate = 44100;
 
-#define N_SAMPLE_RATES  TU_ARRAY_SIZE(sample_rates)
+#define N_SAMPLE_RATES TU_ARRAY_SIZE(sample_rates)
 
 /* Blink pattern
  * - 25 ms   : streaming data
@@ -51,16 +47,14 @@ uint32_t current_sample_rate  = 44100;
  * - 1000 ms : device mounted
  * - 2500 ms : device is suspended
  */
-enum
-{
+enum {
   BLINK_STREAMING = 25,
   BLINK_NOT_MOUNTED = 250,
   BLINK_MOUNTED = 1000,
   BLINK_SUSPENDED = 2500,
 };
 
-enum
-{
+enum {
   VOLUME_CTRL_0_DB = 0,
   VOLUME_CTRL_10_DB = 2560,
   VOLUME_CTRL_20_DB = 5120,
@@ -79,8 +73,8 @@ static uint32_t blink_interval_ms = BLINK_NOT_MOUNTED;
 
 // Audio controls
 // Current states
-int8_t mute[CFG_TUD_AUDIO_FUNC_1_N_CHANNELS_RX + 1];       // +1 for master channel 0
-int16_t volume[CFG_TUD_AUDIO_FUNC_1_N_CHANNELS_RX + 1];    // +1 for master channel 0
+int8_t mute[CFG_TUD_AUDIO_FUNC_1_N_CHANNELS_RX + 1];   // +1 for master channel 0
+int16_t volume[CFG_TUD_AUDIO_FUNC_1_N_CHANNELS_RX + 1];// +1 for master channel 0
 
 // Buffer for microphone data
 int32_t mic_buf[CFG_TUD_AUDIO_FUNC_1_EP_IN_SW_BUF_SZ / 4];
@@ -96,25 +90,26 @@ uint8_t current_resolution;
 
 void led_blinking_task(void);
 void audio_task(void);
+void audio_control_task(void);
 
 /*------------- MAIN -------------*/
-int main(void)
-{
+int main(void) {
   board_init();
 
   // init device stack on configured roothub port
-  tud_init(BOARD_TUD_RHPORT);
+  tusb_rhport_init_t dev_init = {
+      .role = TUSB_ROLE_DEVICE,
+      .speed = TUSB_SPEED_AUTO};
+  tusb_init(BOARD_TUD_RHPORT, &dev_init);
 
-  if (board_init_after_tusb) {
-    board_init_after_tusb();
-  }
+  board_init_after_tusb();
 
   TU_LOG1("Headset running\r\n");
 
-  while (1)
-  {
-    tud_task(); // TinyUSB device task
+  while (1) {
+    tud_task();// TinyUSB device task
     audio_task();
+    audio_control_task();
     led_blinking_task();
   }
 }
@@ -124,70 +119,57 @@ int main(void)
 //--------------------------------------------------------------------+
 
 // Invoked when device is mounted
-void tud_mount_cb(void)
-{
+void tud_mount_cb(void) {
   blink_interval_ms = BLINK_MOUNTED;
 }
 
 // Invoked when device is unmounted
-void tud_umount_cb(void)
-{
+void tud_umount_cb(void) {
   blink_interval_ms = BLINK_NOT_MOUNTED;
 }
 
 // Invoked when usb bus is suspended
 // remote_wakeup_en : if host allow us  to perform remote wakeup
 // Within 7ms, device must draw an average of current less than 2.5 mA from bus
-void tud_suspend_cb(bool remote_wakeup_en)
-{
-  (void)remote_wakeup_en;
+void tud_suspend_cb(bool remote_wakeup_en) {
+  (void) remote_wakeup_en;
   blink_interval_ms = BLINK_SUSPENDED;
 }
 
 // Invoked when usb bus is resumed
-void tud_resume_cb(void)
-{
+void tud_resume_cb(void) {
   blink_interval_ms = tud_mounted() ? BLINK_MOUNTED : BLINK_NOT_MOUNTED;
 }
 
 // Helper for clock get requests
-static bool tud_audio_clock_get_request(uint8_t rhport, audio_control_request_t const *request)
-{
+static bool tud_audio_clock_get_request(uint8_t rhport, audio_control_request_t const *request) {
   TU_ASSERT(request->bEntityID == UAC2_ENTITY_CLOCK);
 
-  if (request->bControlSelector == AUDIO_CS_CTRL_SAM_FREQ)
-  {
-    if (request->bRequest == AUDIO_CS_REQ_CUR)
-    {
-      TU_LOG1("Clock get current freq %lu\r\n", current_sample_rate);
+  if (request->bControlSelector == AUDIO_CS_CTRL_SAM_FREQ) {
+    if (request->bRequest == AUDIO_CS_REQ_CUR) {
+      TU_LOG1("Clock get current freq %" PRIu32 "\r\n", current_sample_rate);
 
-      audio_control_cur_4_t curf = { (int32_t) tu_htole32(current_sample_rate) };
-      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *)request, &curf, sizeof(curf));
-    }
-    else if (request->bRequest == AUDIO_CS_REQ_RANGE)
-    {
+      audio_control_cur_4_t curf = {(int32_t) tu_htole32(current_sample_rate)};
+      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *) request, &curf, sizeof(curf));
+    } else if (request->bRequest == AUDIO_CS_REQ_RANGE) {
       audio_control_range_4_n_t(N_SAMPLE_RATES) rangef =
-      {
-        .wNumSubRanges = tu_htole16(N_SAMPLE_RATES)
-      };
+          {
+              .wNumSubRanges = tu_htole16(N_SAMPLE_RATES)};
       TU_LOG1("Clock get %d freq ranges\r\n", N_SAMPLE_RATES);
-      for(uint8_t i = 0; i < N_SAMPLE_RATES; i++)
-      {
+      for (uint8_t i = 0; i < N_SAMPLE_RATES; i++) {
         rangef.subrange[i].bMin = (int32_t) sample_rates[i];
         rangef.subrange[i].bMax = (int32_t) sample_rates[i];
         rangef.subrange[i].bRes = 0;
-        TU_LOG1("Range %d (%d, %d, %d)\r\n", i, (int)rangef.subrange[i].bMin, (int)rangef.subrange[i].bMax, (int)rangef.subrange[i].bRes);
+        TU_LOG1("Range %d (%d, %d, %d)\r\n", i, (int) rangef.subrange[i].bMin, (int) rangef.subrange[i].bMax, (int) rangef.subrange[i].bRes);
       }
 
-      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *)request, &rangef, sizeof(rangef));
+      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *) request, &rangef, sizeof(rangef));
     }
-  }
-  else if (request->bControlSelector == AUDIO_CS_CTRL_CLK_VALID &&
-           request->bRequest == AUDIO_CS_REQ_CUR)
-  {
-    audio_control_cur_1_t cur_valid = { .bCur = 1 };
+  } else if (request->bControlSelector == AUDIO_CS_CTRL_CLK_VALID &&
+             request->bRequest == AUDIO_CS_REQ_CUR) {
+    audio_control_cur_1_t cur_valid = {.bCur = 1};
     TU_LOG1("Clock get is valid %u\r\n", cur_valid.bCur);
-    return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *)request, &cur_valid, sizeof(cur_valid));
+    return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *) request, &cur_valid, sizeof(cur_valid));
   }
   TU_LOG1("Clock get request not supported, entity = %u, selector = %u, request = %u\r\n",
           request->bEntityID, request->bControlSelector, request->bRequest);
@@ -195,25 +177,21 @@ static bool tud_audio_clock_get_request(uint8_t rhport, audio_control_request_t
 }
 
 // Helper for clock set requests
-static bool tud_audio_clock_set_request(uint8_t rhport, audio_control_request_t const *request, uint8_t const *buf)
-{
-  (void)rhport;
+static bool tud_audio_clock_set_request(uint8_t rhport, audio_control_request_t const *request, uint8_t const *buf) {
+  (void) rhport;
 
   TU_ASSERT(request->bEntityID == UAC2_ENTITY_CLOCK);
   TU_VERIFY(request->bRequest == AUDIO_CS_REQ_CUR);
 
-  if (request->bControlSelector == AUDIO_CS_CTRL_SAM_FREQ)
-  {
+  if (request->bControlSelector == AUDIO_CS_CTRL_SAM_FREQ) {
     TU_VERIFY(request->wLength == sizeof(audio_control_cur_4_t));
 
-    current_sample_rate = (uint32_t) ((audio_control_cur_4_t const *)buf)->bCur;
+    current_sample_rate = (uint32_t) ((audio_control_cur_4_t const *) buf)->bCur;
 
-    TU_LOG1("Clock set current freq: %ld\r\n", current_sample_rate);
+    TU_LOG1("Clock set current freq: %" PRIu32 "\r\n", current_sample_rate);
 
     return true;
-  }
-  else
-  {
+  } else {
     TU_LOG1("Clock set request not supported, entity = %u, selector = %u, request = %u\r\n",
             request->bEntityID, request->bControlSelector, request->bRequest);
     return false;
@@ -221,33 +199,25 @@ static bool tud_audio_clock_set_request(uint8_t rhport, audio_control_request_t
 }
 
 // Helper for feature unit get requests
-static bool tud_audio_feature_unit_get_request(uint8_t rhport, audio_control_request_t const *request)
-{
+static bool tud_audio_feature_unit_get_request(uint8_t rhport, audio_control_request_t const *request) {
   TU_ASSERT(request->bEntityID == UAC2_ENTITY_SPK_FEATURE_UNIT);
 
-  if (request->bControlSelector == AUDIO_FU_CTRL_MUTE && request->bRequest == AUDIO_CS_REQ_CUR)
-  {
-    audio_control_cur_1_t mute1 = { .bCur = mute[request->bChannelNumber] };
+  if (request->bControlSelector == AUDIO_FU_CTRL_MUTE && request->bRequest == AUDIO_CS_REQ_CUR) {
+    audio_control_cur_1_t mute1 = {.bCur = mute[request->bChannelNumber]};
     TU_LOG1("Get channel %u mute %d\r\n", request->bChannelNumber, mute1.bCur);
-    return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *)request, &mute1, sizeof(mute1));
-  }
-  else if (UAC2_ENTITY_SPK_FEATURE_UNIT && request->bControlSelector == AUDIO_FU_CTRL_VOLUME)
-  {
-    if (request->bRequest == AUDIO_CS_REQ_RANGE)
-    {
+    return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *) request, &mute1, sizeof(mute1));
+  } else if (request->bControlSelector == AUDIO_FU_CTRL_VOLUME) {
+    if (request->bRequest == AUDIO_CS_REQ_RANGE) {
       audio_control_range_2_n_t(1) range_vol = {
-        .wNumSubRanges = tu_htole16(1),
-        .subrange[0] = { .bMin = tu_htole16(-VOLUME_CTRL_50_DB), tu_htole16(VOLUME_CTRL_0_DB), tu_htole16(256) }
-      };
+          .wNumSubRanges = tu_htole16(1),
+          .subrange[0] = {.bMin = tu_htole16(-VOLUME_CTRL_50_DB), tu_htole16(VOLUME_CTRL_0_DB), tu_htole16(256)}};
       TU_LOG1("Get channel %u volume range (%d, %d, %u) dB\r\n", request->bChannelNumber,
               range_vol.subrange[0].bMin / 256, range_vol.subrange[0].bMax / 256, range_vol.subrange[0].bRes / 256);
-      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *)request, &range_vol, sizeof(range_vol));
-    }
-    else if (request->bRequest == AUDIO_CS_REQ_CUR)
-    {
-      audio_control_cur_2_t cur_vol = { .bCur = tu_htole16(volume[request->bChannelNumber]) };
+      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *) request, &range_vol, sizeof(range_vol));
+    } else if (request->bRequest == AUDIO_CS_REQ_CUR) {
+      audio_control_cur_2_t cur_vol = {.bCur = tu_htole16(volume[request->bChannelNumber])};
       TU_LOG1("Get channel %u volume %d dB\r\n", request->bChannelNumber, cur_vol.bCur / 256);
-      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *)request, &cur_vol, sizeof(cur_vol));
+      return tud_audio_buffer_and_schedule_control_xfer(rhport, (tusb_control_request_t const *) request, &cur_vol, sizeof(cur_vol));
     }
   }
   TU_LOG1("Feature unit get request not supported, entity = %u, selector = %u, request = %u\r\n",
@@ -257,35 +227,29 @@ static bool tud_audio_feature_unit_get_request(uint8_t rhport, audio_control_req
 }
 
 // Helper for feature unit set requests
-static bool tud_audio_feature_unit_set_request(uint8_t rhport, audio_control_request_t const *request, uint8_t const *buf)
-{
-  (void)rhport;
+static bool tud_audio_feature_unit_set_request(uint8_t rhport, audio_control_request_t const *request, uint8_t const *buf) {
+  (void) rhport;
 
   TU_ASSERT(request->bEntityID == UAC2_ENTITY_SPK_FEATURE_UNIT);
   TU_VERIFY(request->bRequest == AUDIO_CS_REQ_CUR);
 
-  if (request->bControlSelector == AUDIO_FU_CTRL_MUTE)
-  {
+  if (request->bControlSelector == AUDIO_FU_CTRL_MUTE) {
     TU_VERIFY(request->wLength == sizeof(audio_control_cur_1_t));
 
-    mute[request->bChannelNumber] = ((audio_control_cur_1_t const *)buf)->bCur;
+    mute[request->bChannelNumber] = ((audio_control_cur_1_t const *) buf)->bCur;
 
     TU_LOG1("Set channel %d Mute: %d\r\n", request->bChannelNumber, mute[request->bChannelNumber]);
 
     return true;
-  }
-  else if (request->bControlSelector == AUDIO_FU_CTRL_VOLUME)
-  {
+  } else if (request->bControlSelector == AUDIO_FU_CTRL_VOLUME) {
     TU_VERIFY(request->wLength == sizeof(audio_control_cur_2_t));
 
-    volume[request->bChannelNumber] = ((audio_control_cur_2_t const *)buf)->bCur;
+    volume[request->bChannelNumber] = ((audio_control_cur_2_t const *) buf)->bCur;
 
     TU_LOG1("Set channel %d volume: %d dB\r\n", request->bChannelNumber, volume[request->bChannelNumber] / 256);
 
     return true;
-  }
-  else
-  {
+  } else {
     TU_LOG1("Feature unit set request not supported, entity = %u, selector = %u, request = %u\r\n",
             request->bEntityID, request->bControlSelector, request->bRequest);
     return false;
@@ -297,16 +261,14 @@ static bool tud_audio_feature_unit_set_request(uint8_t rhport, audio_control_req
 //--------------------------------------------------------------------+
 
 // Invoked when audio class specific get request received for an entity
-bool tud_audio_get_req_entity_cb(uint8_t rhport, tusb_control_request_t const *p_request)
-{
-  audio_control_request_t const *request = (audio_control_request_t const *)p_request;
+bool tud_audio_get_req_entity_cb(uint8_t rhport, tusb_control_request_t const *p_request) {
+  audio_control_request_t const *request = (audio_control_request_t const *) p_request;
 
   if (request->bEntityID == UAC2_ENTITY_CLOCK)
     return tud_audio_clock_get_request(rhport, request);
   if (request->bEntityID == UAC2_ENTITY_SPK_FEATURE_UNIT)
     return tud_audio_feature_unit_get_request(rhport, request);
-  else
-  {
+  else {
     TU_LOG1("Get request not handled, entity = %d, selector = %d, request = %d\r\n",
             request->bEntityID, request->bControlSelector, request->bRequest);
   }
@@ -314,9 +276,8 @@ bool tud_audio_get_req_entity_cb(uint8_t rhport, tusb_control_request_t const *p
 }
 
 // Invoked when audio class specific set request received for an entity
-bool tud_audio_set_req_entity_cb(uint8_t rhport, tusb_control_request_t const *p_request, uint8_t *buf)
-{
-  audio_control_request_t const *request = (audio_control_request_t const *)p_request;
+bool tud_audio_set_req_entity_cb(uint8_t rhport, tusb_control_request_t const *p_request, uint8_t *buf) {
+  audio_control_request_t const *request = (audio_control_request_t const *) p_request;
 
   if (request->bEntityID == UAC2_ENTITY_SPK_FEATURE_UNIT)
     return tud_audio_feature_unit_set_request(rhport, request, buf);
@@ -328,58 +289,35 @@ bool tud_audio_set_req_entity_cb(uint8_t rhport, tusb_control_request_t const *p
   return false;
 }
 
-bool tud_audio_set_itf_close_EP_cb(uint8_t rhport, tusb_control_request_t const * p_request)
-{
-  (void)rhport;
+bool tud_audio_set_itf_close_ep_cb(uint8_t rhport, tusb_control_request_t const *p_request) {
+  (void) rhport;
 
   uint8_t const itf = tu_u16_low(tu_le16toh(p_request->wIndex));
   uint8_t const alt = tu_u16_low(tu_le16toh(p_request->wValue));
 
-  if (ITF_NUM_AUDIO_STREAMING_SPK == itf && alt == 0)
-      blink_interval_ms = BLINK_MOUNTED;
-
-  return true;
-}
-
-bool tud_audio_set_itf_cb(uint8_t rhport, tusb_control_request_t const * p_request)
-{
-  (void)rhport;
-  uint8_t const itf = tu_u16_low(tu_le16toh(p_request->wIndex));
-  uint8_t const alt = tu_u16_low(tu_le16toh(p_request->wValue));
-
-  TU_LOG2("Set interface %d alt %d\r\n", itf, alt);
-  if (ITF_NUM_AUDIO_STREAMING_SPK == itf && alt != 0)
-      blink_interval_ms = BLINK_STREAMING;
-
-  // Clear buffer when streaming format is changed
-  spk_data_size = 0;
-  if(alt != 0)
-  {
-    current_resolution = resolutions_per_format[alt-1];
+  if (ITF_NUM_AUDIO_STREAMING_SPK == itf && alt == 0) {
+    blink_interval_ms = BLINK_MOUNTED;
   }
 
   return true;
 }
 
-bool tud_audio_rx_done_pre_read_cb(uint8_t rhport, uint16_t n_bytes_received, uint8_t func_id, uint8_t ep_out, uint8_t cur_alt_setting)
-{
-  (void)rhport;
-  (void)func_id;
-  (void)ep_out;
-  (void)cur_alt_setting;
+bool tud_audio_set_itf_cb(uint8_t rhport, tusb_control_request_t const *p_request) {
+  (void) rhport;
+  uint8_t const itf = tu_u16_low(tu_le16toh(p_request->wIndex));
+  uint8_t const alt = tu_u16_low(tu_le16toh(p_request->wValue));
 
-  spk_data_size = tud_audio_read(spk_buf, n_bytes_received);
-  return true;
-}
+  TU_LOG2("Set interface %d alt %d\r\n", itf, alt);
+  if (ITF_NUM_AUDIO_STREAMING_SPK == itf && alt != 0) {
+    blink_interval_ms = BLINK_STREAMING;
+  }
 
-bool tud_audio_tx_done_pre_load_cb(uint8_t rhport, uint8_t itf, uint8_t ep_in, uint8_t cur_alt_setting)
-{
-  (void)rhport;
-  (void)itf;
-  (void)ep_in;
-  (void)cur_alt_setting;
+  // Clear buffer when streaming format is changed
+  spk_data_size = 0;
+  if (alt != 0) {
+    current_resolution = resolutions_per_format[alt - 1];
+  }
 
-  // This callback could be used to fill microphone data separately
   return true;
 }
 
@@ -387,52 +325,87 @@ bool tud_audio_tx_done_pre_load_cb(uint8_t rhport, uint8_t itf, uint8_t ep_in, u
 // AUDIO Task
 //--------------------------------------------------------------------+
 
-void audio_task(void)
-{
+// This task simulates an audio transfer callback, one frame is sent/received every 1ms.
+// In a real application, this would be replaced with actual I2S send/receive callback.
+void audio_task(void) {
+  static uint32_t start_ms = 0;
+  uint32_t curr_ms = board_millis();
+  if (start_ms == curr_ms) return;// not enough time
+  start_ms = curr_ms;
   // When new data arrived, copy data from speaker buffer, to microphone buffer
   // and send it over
   // Only support speaker & headphone both have the same resolution
   // If one is 16bit another is 24bit be care of LOUD noise !
-  if (spk_data_size)
-  {
-    if (current_resolution == 16)
-    {
-      int16_t *src = (int16_t*)spk_buf;
-      int16_t *limit = (int16_t*)spk_buf + spk_data_size / 2;
-      int16_t *dst = (int16_t*)mic_buf;
-      while (src < limit)
-      {
+  spk_data_size = tud_audio_read(spk_buf, sizeof(spk_buf));
+  if (spk_data_size) {
+    if (current_resolution == 16) {
+      int16_t *src = (int16_t *) spk_buf;
+      int16_t *limit = (int16_t *) spk_buf + spk_data_size / 2;
+      int16_t *dst = (int16_t *) mic_buf;
+      while (src < limit) {
         // Combine two channels into one
         int32_t left = *src++;
         int32_t right = *src++;
         *dst++ = (int16_t) ((left >> 1) + (right >> 1));
       }
-      tud_audio_write((uint8_t *)mic_buf, (uint16_t) (spk_data_size / 2));
+      tud_audio_write((uint8_t *) mic_buf, (uint16_t) (spk_data_size / 2));
       spk_data_size = 0;
-    }
-    else if (current_resolution == 24)
-    {
+    } else if (current_resolution == 24) {
       int32_t *src = spk_buf;
       int32_t *limit = spk_buf + spk_data_size / 4;
       int32_t *dst = mic_buf;
-      while (src < limit)
-      {
+      while (src < limit) {
         // Combine two channels into one
         int32_t left = *src++;
         int32_t right = *src++;
         *dst++ = (int32_t) ((uint32_t) ((left >> 1) + (right >> 1)) & 0xffffff00ul);
       }
-      tud_audio_write((uint8_t *)mic_buf, (uint16_t) (spk_data_size / 2));
+      tud_audio_write((uint8_t *) mic_buf, (uint16_t) (spk_data_size / 2));
       spk_data_size = 0;
     }
   }
 }
 
+void audio_control_task(void) {
+  // Press on-board button to control volume
+  // Open host volume control, volume should switch between 10% and 100%
+
+  // Poll every 50ms
+  const uint32_t interval_ms = 50;
+  static uint32_t start_ms = 0;
+  static uint32_t btn_prev = 0;
+
+  if (board_millis() - start_ms < interval_ms) return;// not enough time
+  start_ms += interval_ms;
+
+  uint32_t btn = board_button_read();
+
+  if (!btn_prev && btn) {
+    // Adjust volume between 0dB (100%) and -30dB (10%)
+    for (int i = 0; i < CFG_TUD_AUDIO_FUNC_1_N_CHANNELS_RX + 1; i++) {
+      volume[i] = volume[i] == 0 ? -VOLUME_CTRL_30_DB : 0;
+    }
+
+    // 6.1 Interrupt Data Message
+    const audio_interrupt_data_t data = {
+        .bInfo = 0,                                      // Class-specific interrupt, originated from an interface
+        .bAttribute = AUDIO_CS_REQ_CUR,                  // Caused by current settings
+        .wValue_cn_or_mcn = 0,                           // CH0: master volume
+        .wValue_cs = AUDIO_FU_CTRL_VOLUME,               // Volume change
+        .wIndex_ep_or_int = 0,                           // From the interface itself
+        .wIndex_entity_id = UAC2_ENTITY_SPK_FEATURE_UNIT,// From feature unit
+    };
+
+    tud_audio_int_write(&data);
+  }
+
+  btn_prev = btn;
+}
+
 //--------------------------------------------------------------------+
 // BLINKING TASK
 //--------------------------------------------------------------------+
-void led_blinking_task(void)
-{
+void led_blinking_task(void) {
   static uint32_t start_ms = 0;
   static bool led_state = false;
 
