@@ -38,22 +38,24 @@ extern "C" {
 
 #include "tusb.h"
 
-#if CFG_TUSB_OS == OPT_OS_FREERTOS
-#if TUP_MCU_ESPRESSIF
-  // ESP-IDF need "freertos/" prefix in include path.
-  // CFG_TUSB_OS_INC_PATH should be defined accordingly.
-  #include "freertos/FreeRTOS.h"
-  #include "freertos/semphr.h"
-  #include "freertos/queue.h"
-  #include "freertos/task.h"
-  #include "freertos/timers.h"
-#else
-  #include "FreeRTOS.h"
-  #include "semphr.h"
-  #include "queue.h"
-  #include "task.h"
-  #include "timers.h"
-#endif
+#if CFG_TUSB_OS == OPT_OS_ZEPHYR
+  #include <zephyr/kernel.h>
+#elif CFG_TUSB_OS == OPT_OS_FREERTOS
+  #ifdef ESP_PLATFORM
+    // ESP-IDF need "freertos/" prefix in include path.
+    // CFG_TUSB_OS_INC_PATH should be defined accordingly.
+    #include "freertos/FreeRTOS.h"
+    #include "freertos/semphr.h"
+    #include "freertos/queue.h"
+    #include "freertos/task.h"
+    #include "freertos/timers.h"
+  #else
+    #include "FreeRTOS.h"
+    #include "semphr.h"
+    #include "queue.h"
+    #include "task.h"
+    #include "timers.h"
+  #endif
 #endif
 
 // Define the default baudrate
@@ -70,10 +72,10 @@ extern "C" {
 void board_init(void);
 
 // Init board after tinyusb is initialized
-void board_init_after_tusb(void) TU_ATTR_WEAK;
+void board_init_after_tusb(void);
 
 // Jump to bootloader
-void board_reset_to_bootloader(void) TU_ATTR_WEAK;
+void board_reset_to_bootloader(void);
 
 // Turn LED on or off
 void board_led_write(bool state);
@@ -87,7 +89,7 @@ void board_led_write(bool state);
 uint32_t board_button_read(void);
 
 // Get board unique ID for USB serial number. Return number of bytes. Note max_len is typically 16
-TU_ATTR_WEAK size_t board_get_unique_id(uint8_t id[], size_t max_len);
+size_t board_get_unique_id(uint8_t id[], size_t max_len);
 
 // Get characters from UART. Return number of read bytes
 int board_uart_read(uint8_t *buf, int len);
@@ -124,6 +126,10 @@ static inline uint32_t board_millis(void) {
 // Implement your own board_millis() in any of .c file
 uint32_t board_millis(void);
 
+#elif CFG_TUSB_OS == OPT_OS_ZEPHYR
+static inline uint32_t board_millis(void) {
+  return k_uptime_get_32();
+}
 #else
   #error "board_millis() is not implemented for this OS"
 #endif
@@ -146,15 +152,7 @@ static inline size_t board_usb_get_serial(uint16_t desc_str1[], size_t max_chars
   size_t uid_len;
 
   // TODO work with make, but not working with esp32s3 cmake
-  if ( board_get_unique_id ) {
-    uid_len = board_get_unique_id(uid, sizeof(uid));
-  }else {
-    // fixed serial string is 01234567889ABCDEF
-    uint32_t* uid32 = (uint32_t*) (uintptr_t) uid;
-    uid32[0] = 0x67452301;
-    uid32[1] = 0xEFCDAB89;
-    uid_len = 8;
-  }
+  uid_len = board_get_unique_id(uid, sizeof(uid));
 
   if ( uid_len > max_chars / 2 ) uid_len = max_chars / 2;
 
@@ -189,6 +187,7 @@ static inline void board_delay(uint32_t ms) {
 
 // stdio getchar() is blocking, this is non-blocking version
 int board_getchar(void);
+void board_putchar(int c);
 
 #ifdef __cplusplus
 }
