@@ -24,6 +24,11 @@
  * This file is part of the TinyUSB stack.
  */
 
+/* metadata:
+   name: Adafruit Feather nRF52840 Express
+   url: https://www.adafruit.com/product/4062
+*/
+
 #ifndef BOARD_H_
 #define BOARD_H_
 
@@ -45,6 +50,13 @@
 #define UART_RX_PIN     24
 #define UART_TX_PIN     25
 
+// SPI for USB host shield
+#define MAX3421_SCK_PIN  14
+#define MAX3421_MOSI_PIN 13
+#define MAX3421_MISO_PIN 15
+#define MAX3421_CS_PIN   27 // D10
+#define MAX3421_INTR_PIN 26 // D9
+
 #ifdef __cplusplus
  }
 #endif
