@@ -24,6 +24,11 @@
  * This file is part of the TinyUSB stack.
  */
 
+/* metadata:
+   name: STM32 F070 Nucleo
+   url: https://www.st.com/en/evaluation-tools/nucleo-f070rb.html
+*/
+
 #ifndef BOARD_H_
 #define BOARD_H_
 
