@@ -24,6 +24,10 @@
  * This file is part of the TinyUSB stack.
  */
 
+/* metadata:
+   manufacturer: Infineon
+*/
+
 #include "xmc_gpio.h"
 #include "xmc_scu.h"
 #include "xmc_uart.h"
@@ -35,13 +39,11 @@
 //--------------------------------------------------------------------+
 // Forward USB interrupt events to TinyUSB IRQ Handler
 //--------------------------------------------------------------------+
-void USB0_0_IRQHandler(void)
-{
+void USB0_0_IRQHandler(void) {
   tud_int_handler(0);
 }
 
-void board_init(void)
-{
+void board_init(void) {
   board_clock_init();
   SystemCoreClockUpdate();
 
@@ -95,33 +97,36 @@ void board_init(void)
 // Board porting API
 //--------------------------------------------------------------------+
 
-void board_led_write(bool state)
-{
-  uint32_t is_high = state ? LED_STATE_ON : (1-LED_STATE_ON);
+void board_led_write(bool state) {
+  uint32_t is_high = state ? LED_STATE_ON : (1 - LED_STATE_ON);
 
   XMC_GPIO_SetOutputLevel(LED_PIN, is_high ? XMC_GPIO_OUTPUT_LEVEL_HIGH : XMC_GPIO_OUTPUT_LEVEL_LOW);
 }
 
-uint32_t board_button_read(void)
-{
+uint32_t board_button_read(void) {
   return BUTTON_STATE_ACTIVE == XMC_GPIO_GetInput(BUTTON_PIN);
 }
 
-int board_uart_read(uint8_t* buf, int len)
-{
+size_t board_get_unique_id(uint8_t id[], size_t max_len) {
+  uint8_t const len = tu_min8(16, max_len);
+  memcpy(id, g_chipid, len);
+  return len;
+}
+
+int board_uart_read(uint8_t* buf, int len) {
 #ifdef UART_DEV
   for(int i=0;i<len;i++) {
     buf[i] = XMC_UART_CH_GetReceivedData(UART_DEV);
   }
   return len;
 #else
-  (void) buf; (void) len;
+  (void) buf;
+  (void) len;
   return 0;
 #endif
 }
 
-int board_uart_write(void const * buf, int len)
-{
+int board_uart_write(void const* buf, int len) {
 #ifdef UART_DEV
   char const* bufch = (char const*) buf;
   for(int i=0;i<len;i++) {
@@ -129,20 +134,26 @@ int board_uart_write(void const * buf, int len)
   }
   return len;
 #else
-  (void) buf; (void) len;
+  (void) buf;
+  (void) len;
   return 0;
 #endif
 }
 
-#if CFG_TUSB_OS  == OPT_OS_NONE
+#if CFG_TUSB_OS == OPT_OS_NONE
 volatile uint32_t system_ticks = 0;
-void SysTick_Handler(void)
-{
+
+void SysTick_Handler(void) {
   system_ticks++;
 }
 
-uint32_t board_millis(void)
-{
+uint32_t board_millis(void) {
   return system_ticks;
 }
+
 #endif
+
+// Required by __libc_init_array in startup code if we are compiling using
+// -nostdlib/-nostartfiles.
+//void _init(void) {
+//}
