@@ -34,12 +34,18 @@
 #include "py/persistentcode.h"
 #include "py/runtime.h"
 #include "py/gc.h"
-#include "py/stackctrl.h"
+#include "py/parsenum.h"
 #include "genhdr/mpversion.h"
 #ifdef _WIN32
 #include "ports/windows/fmode.h"
 #endif
 
+#if MICROPY_EMIT_NATIVE && MICROPY_EMIT_RV32
+#include "py/asmrv32.h"
+
+static asm_rv32_backend_options_t rv32_options = { 0 };
+#endif
+
 // Command line options, with their defaults
 static uint emit_opt = MP_EMIT_OPT_NONE;
 mp_uint_t mp_verbose_flag = 0;
@@ -54,7 +60,7 @@ static void stdout_print_strn(void *env, const char *str, size_t len) {
     (void)dummy;
 }
 
-static const mp_print_t mp_stdout_print = {NULL, stdout_print_strn};
+const mp_print_t mp_stdout_print = {NULL, stdout_print_strn};
 
 static void stderr_print_strn(void *env, const char *str, size_t len) {
     (void)env;
@@ -81,13 +87,20 @@ static int compile_and_save(const char *file, const char *output_file, const cha
             source_name = qstr_from_str(source_file);
         }
 
-        #if MICROPY_PY___FILE__
+        #if MICROPY_MODULE___FILE__
         mp_store_global(MP_QSTR___file__, MP_OBJ_NEW_QSTR(source_name));
         #endif
 
         mp_parse_tree_t parse_tree = mp_parse(lex, MP_PARSE_FILE_INPUT);
         mp_compiled_module_t cm;
         cm.context = m_new_obj(mp_module_context_t);
+        cm.arch_flags = 0;
+        #if MICROPY_EMIT_NATIVE && MICROPY_EMIT_RV32
+        if (mp_dynamic_compiler.native_arch == MP_NATIVE_ARCH_RV32IMC && mp_dynamic_compiler.backend_options != NULL) {
+            cm.arch_flags = ((asm_rv32_backend_options_t *)mp_dynamic_compiler.backend_options)->allowed_extensions;
+        }
+        #endif
+
         mp_compile_to_raw_code(&parse_tree, source_name, false, &cm);
 
         if ((output_file != NULL && strcmp(output_file, "-") == 0) ||
@@ -129,7 +142,11 @@ static int usage(char **argv) {
         "\n"
         "Target specific options:\n"
         "-msmall-int-bits=number : set the maximum bits used to encode a small-int\n"
-        "-march=<arch> : set architecture for native emitter; x86, x64, armv6, armv6m, armv7m, armv7em, armv7emsp, armv7emdp, xtensa, xtensawin\n"
+        "-march=<arch> : set architecture for native emitter;\n"
+        "                x86, x64, armv6, armv6m, armv7m, armv7em, armv7emsp,\n"
+        "                armv7emdp, xtensa, xtensawin, rv32imc, rv64imc, host, debug\n"
+        "-march-flags=<flags> : set architecture-specific flags (can be either a dec/hex/bin value or a string)\n"
+        "                       supported flags for rv32imc: zba\n"
         "\n"
         "Implementation specific options:\n", argv[0]
         );
@@ -210,9 +227,39 @@ static char *backslash_to_forwardslash(char *path) {
     return path;
 }
 
-MP_NOINLINE int main_(int argc, char **argv) {
-    mp_stack_set_limit(40000 * (sizeof(void *) / 4));
+// This will need to be reworked in case mpy-cross needs to set more bits than
+// what its small int representation allows to fit in there.
+static bool parse_integer(const char *value, mp_uint_t *integer) {
+    assert(value && "Attempting to parse a NULL string");
+    assert(integer && "Attempting to store into a NULL integer buffer");
 
+    size_t value_length = strlen(value);
+    int base = 10;
+    if (value_length > 2 && value[0] == '0') {
+        if ((value[1] | 0x20) == 'b') {
+            base = 2;
+        } else if ((value[1] | 0x20) == 'x') {
+            base = 16;
+        } else {
+            return false;
+        }
+    }
+
+    bool valid = false;
+    nlr_buf_t nlr;
+    if (nlr_push(&nlr) == 0) {
+        mp_obj_t parsed = mp_parse_num_integer(value, value_length, base, NULL);
+        if (mp_obj_is_small_int(parsed)) {
+            *integer = MP_OBJ_SMALL_INT_VALUE(parsed);
+            valid = true;
+        }
+        nlr_pop();
+    }
+
+    return valid;
+}
+
+MP_NOINLINE int main_(int argc, char **argv) {
     pre_process_options(argc, argv);
 
     char *heap = malloc(heap_size);
@@ -235,11 +282,13 @@ MP_NOINLINE int main_(int argc, char **argv) {
     // don't support native emitter unless -march is specified
     mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_NONE;
     mp_dynamic_compiler.nlr_buf_num_regs = 0;
+    mp_dynamic_compiler.backend_options = NULL;
 
     const char *input_file = NULL;
     const char *output_file = NULL;
     const char *source_file = NULL;
     bool option_parsing_active = true;
+    const char *arch_flags = NULL;
 
     // parse main options
     for (int a = 1; a < argc; a++) {
@@ -247,7 +296,7 @@ MP_NOINLINE int main_(int argc, char **argv) {
             if (strcmp(argv[a], "-X") == 0) {
                 a += 1;
             } else if (strcmp(argv[a], "--version") == 0) {
-                printf("MicroPython " MICROPY_GIT_TAG " on " MICROPY_BUILD_DATE
+                printf(MICROPY_BANNER_NAME_AND_VERSION
                     "; mpy-cross emitting mpy v" MP_STRINGIFY(MPY_VERSION) "." MP_STRINGIFY(MPY_SUB_VERSION) "\n");
                 return 0;
             } else if (strcmp(argv[a], "-v") == 0) {
@@ -312,6 +361,15 @@ MP_NOINLINE int main_(int argc, char **argv) {
                 } else if (strcmp(arch, "xtensawin") == 0) {
                     mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_XTENSAWIN;
                     mp_dynamic_compiler.nlr_buf_num_regs = MICROPY_NLR_NUM_REGS_XTENSAWIN;
+                } else if (strcmp(arch, "rv32imc") == 0) {
+                    mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_RV32IMC;
+                    mp_dynamic_compiler.nlr_buf_num_regs = MICROPY_NLR_NUM_REGS_RV32I;
+                } else if (strcmp(arch, "rv64imc") == 0) {
+                    mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_RV64IMC;
+                    mp_dynamic_compiler.nlr_buf_num_regs = MICROPY_NLR_NUM_REGS_RV64I;
+                } else if (strcmp(arch, "debug") == 0) {
+                    mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_DEBUG;
+                    mp_dynamic_compiler.nlr_buf_num_regs = 0;
                 } else if (strcmp(arch, "host") == 0) {
                     #if defined(__i386__) || defined(_M_IX86)
                     mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_X86;
@@ -322,6 +380,9 @@ MP_NOINLINE int main_(int argc, char **argv) {
                     #elif defined(__arm__) && !defined(__thumb2__)
                     mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_ARMV6;
                     mp_dynamic_compiler.nlr_buf_num_regs = MICROPY_NLR_NUM_REGS_ARM_THUMB_FP;
+                    #elif defined(__riscv) && (__riscv_xlen == 64)
+                    mp_dynamic_compiler.native_arch = MP_NATIVE_ARCH_RV64IMC;
+                    mp_dynamic_compiler.nlr_buf_num_regs = MICROPY_NLR_NUM_REGS_RV64I;
                     #else
                     mp_printf(&mp_stderr_print, "unable to determine host architecture for -march=host\n");
                     exit(1);
@@ -329,6 +390,8 @@ MP_NOINLINE int main_(int argc, char **argv) {
                 } else {
                     return usage(argv);
                 }
+            } else if (strncmp(argv[a], "-march-flags=", sizeof("-march-flags=") - 1) == 0) {
+                arch_flags = argv[a] + sizeof("-march-flags=") - 1;
             } else if (strcmp(argv[a], "--") == 0) {
                 option_parsing_active = false;
             } else {
@@ -343,6 +406,38 @@ MP_NOINLINE int main_(int argc, char **argv) {
         }
     }
 
+    if (arch_flags && mp_dynamic_compiler.native_arch != MP_NATIVE_ARCH_NONE) {
+        bool processed = false;
+        #if MICROPY_EMIT_NATIVE && MICROPY_EMIT_RV32
+        if (mp_dynamic_compiler.native_arch == MP_NATIVE_ARCH_RV32IMC) {
+            mp_dynamic_compiler.backend_options = (void *)&rv32_options;
+            mp_uint_t raw_flags = 0;
+            if (parse_integer(arch_flags, &raw_flags)) {
+                if ((raw_flags & ~((mp_uint_t)RV32_EXT_ALL)) == 0) {
+                    rv32_options.allowed_extensions = raw_flags;
+                    processed = true;
+                }
+            } else if (strncmp(arch_flags, "zba", sizeof("zba") - 1) == 0) {
+                rv32_options.allowed_extensions |= RV32_EXT_ZBA;
+                processed = true;
+            }
+        }
+        #endif
+        if (!processed) {
+            mp_printf(&mp_stderr_print, "unrecognised arch flags\n");
+            exit(1);
+        }
+    }
+
+    #if MICROPY_EMIT_NATIVE
+    if ((MP_STATE_VM(default_emit_opt) == MP_EMIT_OPT_NATIVE_PYTHON
+         || MP_STATE_VM(default_emit_opt) == MP_EMIT_OPT_VIPER)
+        && mp_dynamic_compiler.native_arch == MP_NATIVE_ARCH_NONE) {
+        mp_printf(&mp_stderr_print, "arch not specified\n");
+        exit(1);
+    }
+    #endif
+
     if (input_file == NULL) {
         mp_printf(&mp_stderr_print, "no input file\n");
         exit(1);
@@ -362,7 +457,7 @@ MP_NOINLINE int main_(int argc, char **argv) {
 }
 
 int main(int argc, char **argv) {
-    mp_stack_ctrl_init();
+    mp_cstack_init_with_sp_here(40000 * (sizeof(void *) / 4));
     return main_(argc, argv);
 }
 
