@@ -1,7 +1,8 @@
 #define MICROPY_HW_BOARD_NAME               "Arduino Nano ESP32"
 #define MICROPY_HW_MCU_NAME                 "ESP32S3"
 
-#define MICROPY_PY_MACHINE_DAC              (0)
+// Network config
+#define MICROPY_PY_NETWORK_HOSTNAME_DEFAULT "mpy-nano-esp32"
 
 #define MICROPY_HW_I2C0_SCL                 (12)
 #define MICROPY_HW_I2C0_SDA                 (11)
@@ -18,12 +19,13 @@
 #define MICROPY_HW_SPI2_SCK                 (18)
 
 #define MICROPY_HW_ENABLE_USBDEV            (1)
-#define MICROPY_HW_USB_EXTERNAL_TINYUSB     (1)
 #define MICROPY_HW_USB_CDC_1200BPS_TOUCH    (1)
 #define MICROPY_SCHEDULER_STATIC_NODES      (1)
 
-#define MICROPY_HW_USB_CUSTOM_LINE_STATE_CB             NANO_ESP32_usb_callback_line_state_changed
-void NANO_ESP32_usb_callback_line_state_changed(int itf, void *event);
+#define MICROPY_HW_USB_VID 0x2341
+#define MICROPY_HW_USB_PID 0x056B
+#define MICROPY_HW_USB_MANUFACTURER_STRING "Arduino"
+#define MICROPY_HW_USB_PRODUCT_FS_STRING "Nano ESP32"
 
 #define MICROPY_BOARD_STARTUP                           NANO_ESP32_board_startup
 void NANO_ESP32_board_startup(void);
