@@ -26,9 +26,9 @@
 #ifndef MICROPY_INCLUDED_ESP32_USB_H
 #define MICROPY_INCLUDED_ESP32_USB_H
 
-#define MICROPY_HW_USB_CDC_TX_TIMEOUT  (500)
+#define MICROPY_HW_USB_CDC_TX_TIMEOUT_MS (500)
 
-void usb_init(void);
-void usb_tx_strn(const char *str, size_t len);
+void usb_phy_init(void);
+void usb_usj_mode(void);
 
 #endif // MICROPY_INCLUDED_ESP32_USB_H
