@@ -28,17 +28,20 @@
 #include "py/mphal.h"
 #include "usb_serial_jtag.h"
 
-#if CONFIG_ESP_CONSOLE_USB_SERIAL_JTAG
+#if MICROPY_HW_ESP_USB_SERIAL_JTAG
 
 #include "hal/usb_serial_jtag_ll.h"
 #include "esp_intr_alloc.h"
 #include "soc/periph_defs.h"
 #include "freertos/portmacro.h"
 
-#define USB_SERIAL_JTAG_BUF_SIZE (64)
+// Number of bytes in the input buffer, and number of bytes for output chunking.
+#if ESP_IDF_VERSION >= ESP_IDF_VERSION_VAL(5, 3, 0)
+#define USB_SERIAL_JTAG_PACKET_SZ_BYTES (64)
+#endif
 
 static DRAM_ATTR portMUX_TYPE rx_mux = portMUX_INITIALIZER_UNLOCKED;
-static uint8_t rx_buf[USB_SERIAL_JTAG_BUF_SIZE];
+static uint8_t rx_buf[USB_SERIAL_JTAG_PACKET_SZ_BYTES];
 static volatile bool terminal_connected = false;
 
 static void usb_serial_jtag_handle_rx(void) {
@@ -48,8 +51,8 @@ static void usb_serial_jtag_handle_rx(void) {
         portENTER_CRITICAL(&rx_mux);
     }
     size_t req_len = ringbuf_free(&stdin_ringbuf);
-    if (req_len > USB_SERIAL_JTAG_BUF_SIZE) {
-        req_len = USB_SERIAL_JTAG_BUF_SIZE;
+    if (req_len > USB_SERIAL_JTAG_PACKET_SZ_BYTES) {
+        req_len = USB_SERIAL_JTAG_PACKET_SZ_BYTES;
     }
     size_t len = usb_serial_jtag_ll_read_rxfifo(rx_buf, req_len);
     for (size_t i = 0; i < len; ++i) {
@@ -68,23 +71,31 @@ static void usb_serial_jtag_handle_rx(void) {
 
 static void usb_serial_jtag_isr_handler(void *arg) {
     uint32_t flags = usb_serial_jtag_ll_get_intsts_mask();
-
-    if (flags & USB_SERIAL_JTAG_INTR_SOF) {
-        usb_serial_jtag_ll_clr_intsts_mask(USB_SERIAL_JTAG_INTR_SOF);
-    }
+    usb_serial_jtag_ll_clr_intsts_mask(flags);
 
     if (flags & USB_SERIAL_JTAG_INTR_SERIAL_OUT_RECV_PKT) {
-        usb_serial_jtag_ll_clr_intsts_mask(USB_SERIAL_JTAG_INTR_SERIAL_OUT_RECV_PKT);
         usb_serial_jtag_handle_rx();
         mp_hal_wake_main_task_from_isr();
     }
+
+    if (flags & USB_SERIAL_JTAG_INTR_SERIAL_IN_EMPTY) {
+        // As per the ESP-IDF driver, allow for the possibility the USJ just sent a full
+        // 64-bit endpoint to the host and now it's waiting for another ZLP to flush the result
+        // to the OS
+        usb_serial_jtag_ll_txfifo_flush();
+
+        // Disable this interrupt until next time we write into the FIFO
+        usb_serial_jtag_ll_disable_intr_mask(USB_SERIAL_JTAG_INTR_SERIAL_IN_EMPTY);
+    }
 }
 
 void usb_serial_jtag_init(void) {
+    // Note: Don't clear the SERIAL_IN_EMPTY interrupt, as it's possible the
+    // bootloader wrote enough data to the host that we need the interrupt to flush it.
     usb_serial_jtag_ll_clr_intsts_mask(USB_SERIAL_JTAG_INTR_SERIAL_OUT_RECV_PKT |
         USB_SERIAL_JTAG_INTR_SOF);
     usb_serial_jtag_ll_ena_intr_mask(USB_SERIAL_JTAG_INTR_SERIAL_OUT_RECV_PKT |
-        USB_SERIAL_JTAG_INTR_SOF);
+        USB_SERIAL_JTAG_INTR_SOF | USB_SERIAL_JTAG_INTR_SERIAL_IN_EMPTY);
     ESP_ERROR_CHECK(esp_intr_alloc(ETS_USB_SERIAL_JTAG_INTR_SOURCE, ESP_INTR_FLAG_LEVEL1,
         usb_serial_jtag_isr_handler, NULL, NULL));
 }
@@ -111,10 +122,11 @@ void usb_serial_jtag_tx_strn(const char *str, size_t len) {
         }
         terminal_connected = true;
         l = usb_serial_jtag_ll_write_txfifo((const uint8_t *)str, l);
-        usb_serial_jtag_ll_txfifo_flush();
         str += l;
         len -= l;
+        usb_serial_jtag_ll_ena_intr_mask(USB_SERIAL_JTAG_INTR_SERIAL_IN_EMPTY);
     }
+    usb_serial_jtag_ll_txfifo_flush();
 }
 
-#endif // CONFIG_ESP_CONSOLE_USB_SERIAL_JTAG
+#endif // MICROPY_HW_ESP_USB_SERIAL_JTAG
