@@ -25,9 +25,10 @@
  * THE SOFTWARE.
  */
 
-#include "py/runtime.h"
+// This file is never compiled standalone, it's included directly from
+// extmod/machine_pwm.c via MICROPY_PY_MACHINE_PWM_INCLUDEFILE.
+
 #include "py/mphal.h"
-#include "modmachine.h"
 #include "pin.h"
 #include "fsl_clock.h"
 #include "fsl_iomuxc.h"
@@ -44,6 +45,8 @@
 typedef struct _machine_pwm_obj_t {
     mp_obj_base_t base;
     PWM_Type *instance;
+    const machine_pin_obj_t *pwm_pin;
+    const machine_pin_af_obj_t *pwm_pin_af_obj;
     bool is_flexpwm;
     uint8_t complementary;
     uint8_t module;
@@ -69,9 +72,9 @@ static char *ERRMSG_FREQ = "PWM frequency too low";
 static char *ERRMSG_INIT = "PWM set-up failed";
 static char *ERRMSG_VALUE = "value larger than period";
 
-STATIC void mp_machine_pwm_start(machine_pwm_obj_t *self);
+static void mp_machine_pwm_start(machine_pwm_obj_t *self);
 
-STATIC void mp_machine_pwm_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void mp_machine_pwm_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     machine_pwm_obj_t *self = MP_OBJ_TO_PTR(self_in);
     if (self->is_flexpwm) {
         mp_printf(print, "<FLEXPWM module=%u submodule=%u ", self->module, self->submodule);
@@ -102,7 +105,7 @@ STATIC void mp_machine_pwm_print(const mp_print_t *print, mp_obj_t self_in, mp_p
 
 // Utility functions for decoding and converting
 //
-STATIC uint32_t duty_ns_to_duty_u16(uint32_t freq, uint32_t duty_ns) {
+static uint32_t duty_ns_to_duty_u16(uint32_t freq, uint32_t duty_ns) {
     uint64_t duty = (uint64_t)duty_ns * freq * PWM_FULL_SCALE / 1000000000ULL;
     if (duty > PWM_FULL_SCALE) {
         mp_raise_ValueError(MP_ERROR_TEXT(ERRMSG_VALUE));
@@ -110,7 +113,7 @@ STATIC uint32_t duty_ns_to_duty_u16(uint32_t freq, uint32_t duty_ns) {
     return (uint32_t)duty;
 }
 
-STATIC uint8_t module_decode(char channel) {
+static uint8_t module_decode(char channel) {
     switch (channel) {
         case '0':
             return kPWM_Module_0;
@@ -125,7 +128,7 @@ STATIC uint8_t module_decode(char channel) {
     }
 }
 
-STATIC uint8_t channel_decode(char channel) {
+static uint8_t channel_decode(char channel) {
     switch (channel) {
         case 'A':
             return kPWM_PwmA;
@@ -139,7 +142,7 @@ STATIC uint8_t channel_decode(char channel) {
 }
 
 // decode the AF objects module and Port number. Returns NULL if it is not a FLEXPWM object
-STATIC const machine_pin_af_obj_t *af_name_decode_flexpwm(const machine_pin_af_obj_t *af_obj,
+static const machine_pin_af_obj_t *af_name_decode_flexpwm(const machine_pin_af_obj_t *af_obj,
     uint8_t *module, uint8_t *submodule, uint8_t *channel) {
     const char *str;
     size_t len;
@@ -157,7 +160,7 @@ STATIC const machine_pin_af_obj_t *af_name_decode_flexpwm(const machine_pin_af_o
 }
 
 #ifdef FSL_FEATURE_SOC_TMR_COUNT
-STATIC uint8_t qtmr_decode(char channel) {
+static uint8_t qtmr_decode(char channel) {
     switch (channel) {
         case '0':
             return kQTMR_Channel_0;
@@ -173,7 +176,7 @@ STATIC uint8_t qtmr_decode(char channel) {
 }
 
 // decode the AF objects module and Port number. Returns NULL if it is not a QTMR object
-STATIC const machine_pin_af_obj_t *af_name_decode_qtmr(const machine_pin_af_obj_t *af_obj, uint8_t *module, uint8_t *channel) {
+static const machine_pin_af_obj_t *af_name_decode_qtmr(const machine_pin_af_obj_t *af_obj, uint8_t *module, uint8_t *channel) {
     const char *str;
     size_t len;
     str = (char *)qstr_data(af_obj->name, &len);
@@ -189,9 +192,10 @@ STATIC const machine_pin_af_obj_t *af_name_decode_qtmr(const machine_pin_af_obj_
 }
 #endif
 
-STATIC bool is_board_pin(const machine_pin_obj_t *pin) {
-    for (int i = 0; i < num_board_pins; i++) {
-        if (pin == machine_pin_board_pins[i]) {
+static bool is_board_pin(const machine_pin_obj_t *pin) {
+    const mp_map_t *board_map = &machine_pin_board_pins_locals_dict.map;
+    for (uint i = 0; i < board_map->alloc; i++) {
+        if (pin == MP_OBJ_TO_PTR(board_map->table[i].value)) {
             return true;
         }
     }
@@ -200,7 +204,7 @@ STATIC bool is_board_pin(const machine_pin_obj_t *pin) {
 
 // Functions for configuring the PWM Device
 //
-STATIC int calc_prescaler(uint32_t clock, uint32_t freq) {
+static int calc_prescaler(uint32_t clock, uint32_t freq) {
     float temp = (float)clock / (float)PWM_FULL_SCALE / (float)freq;
     for (int prescale = 0; prescale < 8; prescale++, temp /= 2) {
         if (temp <= 1) {
@@ -211,7 +215,7 @@ STATIC int calc_prescaler(uint32_t clock, uint32_t freq) {
     return -1;
 }
 
-STATIC void configure_flexpwm(machine_pwm_obj_t *self) {
+static void configure_flexpwm(machine_pwm_obj_t *self) {
     pwm_signal_param_u16_t pwmSignal;
 
     // Initialize PWM module.
@@ -237,7 +241,9 @@ STATIC void configure_flexpwm(machine_pwm_obj_t *self) {
             pwmConfig.pairOperation = kPWM_Independent;
         }
         pwmConfig.clockSource = kPWM_BusClock;
+        #if !defined(FSL_FEATURE_PWM_HAS_NO_WAITEN) || (!FSL_FEATURE_PWM_HAS_NO_WAITEN)
         pwmConfig.enableWait = false;
+        #endif
         pwmConfig.initializationControl = self->sync ? kPWM_Initialize_MasterSync : kPWM_Initialize_LocalSync;
 
         if (PWM_Init(self->instance, self->submodule, &pwmConfig) == kStatus_Fail) {
@@ -253,6 +259,8 @@ STATIC void configure_flexpwm(machine_pwm_obj_t *self) {
         PWM_SetupFaultDisableMap(self->instance, self->submodule, self->channel2, kPWM_faultchannel_1, 0);
     }
 
+    // clear the load okay bit for the submodules in case there is a pending load
+    PWM_SetPwmLdok(self->instance, 1 << self->submodule, false);
     if (self->channel1 != kPWM_PwmX) {  // Only for A/B channels
         // Initialize the channel parameters
         pwmSignal.pwmChannel = self->channel1;
@@ -281,6 +289,17 @@ STATIC void configure_flexpwm(machine_pwm_obj_t *self) {
             self->instance->SM[self->submodule].CTRL &= ~(PWM_CTRL_DBLEN_MASK | PWM_CTRL_SPLIT_MASK);
         }
     } else {
+        if (self->duty_u16 == 0) {
+            // For duty_u16 == 0 just set the output to GPIO mode
+            if (self->invert) {
+                mp_hal_pin_high(self->pwm_pin);
+            } else {
+                mp_hal_pin_low(self->pwm_pin);
+            }
+            IOMUXC_SetPinMux(self->pwm_pin->muxRegister, PIN_AF_MODE_ALT5, 0, 0, 0, 0U);
+        } else {
+            IOMUXC_SetPinMux(self->pwm_pin->muxRegister, self->pwm_pin_af_obj->af_mode, 0, 0, 0, 0U);
+        }
         PWM_SetupPwmx_u16(self->instance, self->submodule, self->freq, self->duty_u16,
             self->invert, pwmSourceClockInHz);
         if (self->xor) {
@@ -298,7 +317,7 @@ STATIC void configure_flexpwm(machine_pwm_obj_t *self) {
 }
 
 #ifdef FSL_FEATURE_SOC_TMR_COUNT
-STATIC void configure_qtmr(machine_pwm_obj_t *self) {
+static void configure_qtmr(machine_pwm_obj_t *self) {
     qtmr_config_t qtmrConfig;
     int prescale;
     #if defined(MIMXRT117x_SERIES)
@@ -329,7 +348,7 @@ STATIC void configure_qtmr(machine_pwm_obj_t *self) {
 }
 #endif // FSL_FEATURE_SOC_TMR_COUNT
 
-STATIC void configure_pwm(machine_pwm_obj_t *self) {
+static void configure_pwm(machine_pwm_obj_t *self) {
     // Set the clock frequencies
     // Freq range is 15Hz to ~ 3 MHz.
     static bool set_frequency = true;
@@ -358,7 +377,7 @@ STATIC void configure_pwm(machine_pwm_obj_t *self) {
 
 // Micropython API functions
 //
-STATIC void mp_machine_pwm_init_helper(machine_pwm_obj_t *self,
+static void mp_machine_pwm_init_helper(machine_pwm_obj_t *self,
     size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     enum { ARG_freq, ARG_duty_u16, ARG_duty_ns, ARG_center, ARG_align,
            ARG_invert, ARG_sync, ARG_xor, ARG_deadtime };
@@ -406,12 +425,16 @@ STATIC void mp_machine_pwm_init_helper(machine_pwm_obj_t *self,
             }
             self->center = center;
         } else {  // Use alignment setting shortcut
-            if (args[ARG_align].u_int >= 0) {
+            uint32_t duty = self->duty_u16;
+            if (duty == VALUE_NOT_SET && self->duty_ns != VALUE_NOT_SET) {
+                duty = duty_ns_to_duty_u16(self->freq, self->duty_ns);
+            }
+            if (args[ARG_align].u_int >= 0 && duty != VALUE_NOT_SET && self->freq != VALUE_NOT_SET) {
                 uint8_t align = args[ARG_align].u_int & 3; // limit to 0..3
                 if (align == PWM_BEGIN) {
-                    self->center = self->duty_u16 / 2;
+                    self->center = duty / 2;
                 } else if (align == PWM_END) {
-                    self->center = PWM_FULL_SCALE - self->duty_u16 / 2;
+                    self->center = PWM_FULL_SCALE - duty / 2;
                 } else {
                     self->center = 32768; // Default value: mid.
                 }
@@ -442,7 +465,7 @@ STATIC void mp_machine_pwm_init_helper(machine_pwm_obj_t *self,
 }
 
 // PWM(pin | pin-tuple, freq, [args])
-STATIC mp_obj_t mp_machine_pwm_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t mp_machine_pwm_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     // Check number of arguments
     mp_arg_check_num(n_args, n_kw, 1, MP_OBJ_FUN_ARGS_MAX, true);
 
@@ -513,6 +536,8 @@ STATIC mp_obj_t mp_machine_pwm_make_new(const mp_obj_type_t *type, size_t n_args
 
     // Create and populate the PWM object.
     machine_pwm_obj_t *self = mp_obj_malloc(machine_pwm_obj_t, &machine_pwm_type);
+    self->pwm_pin = pin1;
+    self->pwm_pin_af_obj = af_obj1;
     self->is_flexpwm = is_flexpwm;
     self->instance = af_obj1->instance;
     self->module = module;
@@ -532,6 +557,8 @@ STATIC mp_obj_t mp_machine_pwm_make_new(const mp_obj_type_t *type, size_t n_args
 
     // Initialize the Pin(s).
     CLOCK_EnableClock(kCLOCK_Iomuxc); // just in case it was not set yet
+    // Configure PWMX channels to pin output mode to be prepared for duty_u16 == 0.
+    mp_hal_pin_output(pin1);
     IOMUXC_SetPinMux(pin1->muxRegister, af_obj1->af_mode, af_obj1->input_register, af_obj1->input_daisy,
         pin1->configRegister, 0U);
     IOMUXC_SetPinConfig(pin1->muxRegister, af_obj1->af_mode, af_obj1->input_register, af_obj1->input_daisy,
@@ -578,7 +605,7 @@ void machine_pwm_deinit_all(void) {
     #endif
 }
 
-STATIC void mp_machine_pwm_start(machine_pwm_obj_t *self) {
+static void mp_machine_pwm_start(machine_pwm_obj_t *self) {
     if (self->is_flexpwm) {
         PWM_StartTimer(self->instance, 1 << self->submodule);
     #ifdef FSL_FEATURE_SOC_TMR_COUNT
@@ -588,7 +615,7 @@ STATIC void mp_machine_pwm_start(machine_pwm_obj_t *self) {
     }
 }
 
-STATIC void mp_machine_pwm_deinit(machine_pwm_obj_t *self) {
+static void mp_machine_pwm_deinit(machine_pwm_obj_t *self) {
     if (self->is_flexpwm) {
         PWM_StopTimer(self->instance, 1 << self->submodule);
     #ifdef FSL_FEATURE_SOC_TMR_COUNT
