@@ -31,4 +31,11 @@
 // Device configuration
 #define CFG_TUSB_MCU                OPT_MCU_NRF5X
 
+// TinyUSB uses newer style errata functions, but we currently don't have the
+// latest nrfx component.  So provide macros mapping the new name to the old.
+#include "nrfx_usbd_errata.h"
+#define nrf52_errata_166 nrfx_usbd_errata_166
+#define nrf52_errata_171 nrfx_usbd_errata_171
+#define nrf52_errata_187 nrfx_usbd_errata_187
+
 #endif // MICROPY_INCLUDED_NRF_TUSB_CONFIG_H
