@@ -42,10 +42,12 @@ enum CPU_PIN {
     P300 = 0x30, P301, P302, P303, P304, P305, P306, P307, P308, P309, P310, P311, P312, P313, P314, P315,
     P400 = 0x40, P401, P402, P403, P404, P405, P406, P407, P408, P409, P410, P411, P412, P413, P414, P415,
     P500 = 0x50, P501, P502, P503, P504, P505, P506, P507, P508, P509, P510, P511, P512, P513, P514, P515,
-    P600 = 0x90, P601, P602, P603, P604, P605, P606, P607, P608, P609, P610, P611, P612, P613, P614, P615,
+    P600 = 0x60, P601, P602, P603, P604, P605, P606, P607, P608, P609, P610, P611, P612, P613, P614, P615,
     P700 = 0x70, P701, P702, P703, P704, P705, P706, P707, P708, P709, P710, P711, P712, P713, P714, P715,
     P800 = 0x80, P801, P802, P803, P804, P805, P806, P807, P808, P809, P810, P811, P812, P813, P814, P815,
     P900 = 0x90, P901, P902, P903, P904, P905, P906, P907, P908, P909, P910, P911, P912, P913, P914, P915,
+    PA00 = 0xA0, PA01, PA02, PA03, PA04, PA05, PA06, PA07, PA08, PA09, PA10, PA11, PA12, PA13, PA14, PA15,
+    PB00 = 0xB0, PB01, PB02, PB03, PB04, PB05, PB06, PB07, PB08, PB09, PB10, PB11, PB12, PB13, PB14, PB15,
     PIN_END = 0xff,
 };
 
@@ -126,35 +128,35 @@ enum AF_INDEX {
 #define PMR_MASK    (uint32_t)0x00010000
 #define PSEL_MASK   (uint32_t)0x1f000000
 
-#define _PWPR               (*(volatile uint8_t *)(0x40040D03))
+#define _PWPR               (*(volatile uint8_t *)(R_PFS_BASE + 0x503))
 
-#define _PXXPFS(port, bit)  (*(volatile uint32_t *)(0x40040800 + (0x40 * ((uint32_t)port)) + (0x4 * ((uint32_t)bit))))
-#define _PCNTR1(port)       (*(volatile uint32_t *)(0x40040000 + (0x20 * (port))))
-#define _PODR(port)         (*(volatile uint16_t *)(0x40040000 + (0x20 * (port))))
-#define _PDR(port)          (*(volatile uint16_t *)(0x40040002 + (0x20 * (port))))
-#define _PCNTR2(port)       (*(volatile uint32_t *)(0x40040004 + (0x20 * (port))))
-#define _EIDR(port)         (*(volatile uint16_t *)(0x40040004 + (0x20 * (port))))
-#define _PIDR(port)         (*(volatile uint16_t *)(0x40040006 + (0x20 * (port))))
-#define _PCNTR3(port)       (*(volatile uint32_t *)(0x40040008 + (0x20 * (port))))
-#define _PORR(port)         (*(volatile uint16_t *)(0x40040008 + (0x20 * (port))))
-#define _POSR(port)         (*(volatile uint16_t *)(0x4004000a + (0x20 * (port))))
-#define _PCNTR4(port)       (*(volatile uint32_t *)(0x4004000c + (0x20 * (port))))
-#define _EORR(port)         (*(volatile uint16_t *)(0x4004000c + (0x20 * (port))))
-#define _EOSR(port)         (*(volatile uint16_t *)(0x4004000e + (0x20 * (port))))
+#define _PXXPFS(port, bit)  (*(volatile uint32_t *)(R_PFS_BASE + (0x40 * ((uint32_t)port)) + (0x4 * ((uint32_t)bit))))
+#define _PCNTR1(port)       (*(volatile uint32_t *)(R_PORT0_BASE + (0x20 * (port))))
+#define _PODR(port)         (*(volatile uint16_t *)(R_PORT0_BASE + (0x20 * (port))))
+#define _PDR(port)          (*(volatile uint16_t *)(R_PORT0_BASE + 0x2 + (0x20 * (port))))
+#define _PCNTR2(port)       (*(volatile uint32_t *)(R_PORT0_BASE + 0x4 + (0x20 * (port))))
+#define _EIDR(port)         (*(volatile uint16_t *)(R_PORT0_BASE + 0x4 + (0x20 * (port))))
+#define _PIDR(port)         (*(volatile uint16_t *)(R_PORT0_BASE + 0x6 + (0x20 * (port))))
+#define _PCNTR3(port)       (*(volatile uint32_t *)(R_PORT0_BASE + 0x8 + (0x20 * (port))))
+#define _PORR(port)         (*(volatile uint16_t *)(R_PORT0_BASE + 0x8 + (0x20 * (port))))
+#define _POSR(port)         (*(volatile uint16_t *)(R_PORT0_BASE + 0xa + (0x20 * (port))))
+#define _PCNTR4(port)       (*(volatile uint32_t *)(R_PORT0_BASE + 0xc + (0x20 * (port))))
+#define _EORR(port)         (*(volatile uint16_t *)(R_PORT0_BASE + 0xc + (0x20 * (port))))
+#define _EOSR(port)         (*(volatile uint16_t *)(R_PORT0_BASE + 0xe + (0x20 * (port))))
 
-#define _PPXXPFS(port, bit)  ((volatile uint32_t *)(0x40040800 + (0x40 * (port)) + (0x4 * (bit))))
-#define _PPCNTR1(port)       ((volatile uint32_t *)(0x40040000 + (0x20 * (port))))
-#define _PPODR(port)         ((volatile uint16_t *)(0x40040000 + (0x20 * (port))))
-#define _PPDR(port)          ((volatile uint16_t *)(0x40040002 + (0x20 * (port))))
-#define _PPCNTR2(port)       ((volatile uint32_t *)(0x40040004 + (0x20 * (port))))
-#define _PEIDR(port)         ((volatile uint16_t *)(0x40040004 + (0x20 * (port))))
-#define _PPIDR(port)         ((volatile uint16_t *)(0x40040006 + (0x20 * (port))))
-#define _PPCNTR3(port)       ((volatile uint32_t *)(0x40040008 + (0x20 * (port))))
-#define _PPORR(port)         ((volatile uint16_t *)(0x40040008 + (0x20 * (port))))
-#define _PPOSR(port)         ((volatile uint16_t *)(0x4004000a + (0x20 * (port))))
-#define _PPCNTR4(port)       ((volatile uint32_t *)(0x4004000c + (0x20 * (port))))
-#define _PEORR(port)         ((volatile uint16_t *)(0x4004000c + (0x20 * (port))))
-#define _PEOSR(port)         ((volatile uint16_t *)(0x4004000e + (0x20 * (port))))
+#define _PPXXPFS(port, bit)  ((volatile uint32_t *)(R_PFS_BASE + (0x40 * (port)) + (0x4 * (bit))))
+#define _PPCNTR1(port)       ((volatile uint32_t *)(R_PORT0_BASE + (0x20 * (port))))
+#define _PPODR(port)         ((volatile uint16_t *)(R_PORT0_BASE + (0x20 * (port))))
+#define _PPDR(port)          ((volatile uint16_t *)(R_PORT0_BASE + 0x2 + (0x20 * (port))))
+#define _PPCNTR2(port)       ((volatile uint32_t *)(R_PORT0_BASE + 0x4 + (0x20 * (port))))
+#define _PEIDR(port)         ((volatile uint16_t *)(R_PORT0_BASE + 0x4 + (0x20 * (port))))
+#define _PPIDR(port)         ((volatile uint16_t *)(R_PORT0_BASE + 0x6 + (0x20 * (port))))
+#define _PPCNTR3(port)       ((volatile uint32_t *)(R_PORT0_BASE + 0x8 + (0x20 * (port))))
+#define _PPORR(port)         ((volatile uint16_t *)(R_PORT0_BASE + 0x8 + (0x20 * (port))))
+#define _PPOSR(port)         ((volatile uint16_t *)(R_PORT0_BASE + 0xa + (0x20 * (port))))
+#define _PPCNTR4(port)       ((volatile uint32_t *)(R_PORT0_BASE + 0xc + (0x20 * (port))))
+#define _PEORR(port)         ((volatile uint16_t *)(R_PORT0_BASE + 0xc + (0x20 * (port))))
+#define _PEOSR(port)         ((volatile uint16_t *)(R_PORT0_BASE + 0xe + (0x20 * (port))))
 
 void ra_gpio_config(uint32_t pin, uint32_t mode, uint32_t pull, uint32_t drive, uint32_t alt);
 void ra_gpio_mode_output(uint32_t pin);
@@ -169,12 +171,12 @@ uint32_t ra_gpio_get_pull(uint32_t pin);
 uint32_t ra_gpio_get_af(uint32_t pin);
 uint32_t ra_gpio_get_drive(uint32_t pin);
 
-inline static void pwpr_unprotect(void) {
+static inline void pwpr_unprotect(void) {
     _PWPR &= (uint8_t) ~0x80;
     _PWPR |= (uint8_t)0x40;
 }
 
-inline static void pwpr_protect(void) {
+static inline void pwpr_protect(void) {
     _PWPR &= (uint8_t) ~0x40;
     _PWPR |= (uint8_t)0x80;
 }
