@@ -46,15 +46,6 @@
 
 #define GPIO_IRQ_ALL (0xf)
 
-// Macros to access the state of the hardware.
-#define GPIO_GET_FUNCSEL(id) ((iobank0_hw->io[(id)].ctrl & IO_BANK0_GPIO0_CTRL_FUNCSEL_BITS) >> IO_BANK0_GPIO0_CTRL_FUNCSEL_LSB)
-#define GPIO_IS_OUT(id) (sio_hw->gpio_oe & (1 << (id)))
-#define GPIO_IS_PULL_UP(id) (padsbank0_hw->io[(id)] & PADS_BANK0_GPIO0_PUE_BITS)
-#define GPIO_IS_PULL_DOWN(id) (padsbank0_hw->io[(id)] & PADS_BANK0_GPIO0_PDE_BITS)
-
-// Open drain behaviour is simulated.
-#define GPIO_IS_OPEN_DRAIN(id) (machine_pin_open_drain_mask & (1 << (id)))
-
 #ifndef MICROPY_HW_PIN_RESERVED
 #define MICROPY_HW_PIN_RESERVED(i) (0)
 #endif
@@ -86,10 +77,14 @@ typedef struct _machine_pin_irq_obj_t {
 } machine_pin_irq_obj_t;
 
 static const mp_irq_methods_t machine_pin_irq_methods;
-extern const machine_pin_obj_t machine_pin_obj_table[NUM_BANK0_GPIOS];
+static const int num_intr_regs = sizeof(iobank0_hw->intr) / sizeof(iobank0_hw->intr[0]);
 
 // Mask with "1" indicating that the corresponding pin is in simulated open-drain mode.
+#if NUM_BANK0_GPIOS > 32
+uint64_t machine_pin_open_drain_mask;
+#else
 uint32_t machine_pin_open_drain_mask;
+#endif
 
 #if MICROPY_HW_PIN_EXT_COUNT
 static inline bool is_ext_pin(__unused const machine_pin_obj_t *self) {
@@ -100,7 +95,7 @@ static inline bool is_ext_pin(__unused const machine_pin_obj_t *self) {
 #endif
 
 static void gpio_irq(void) {
-    for (int i = 0; i < 4; ++i) {
+    for (int i = 0; i < num_intr_regs; ++i) {
         uint32_t intr = iobank0_hw->intr[i];
         if (intr) {
             for (int j = 0; j < 8; ++j) {
@@ -193,18 +188,18 @@ const machine_pin_obj_t *machine_pin_find(mp_obj_t pin) {
             return &machine_pin_obj_table[wanted_pin];
         }
     }
-    mp_raise_ValueError("invalid pin");
+    mp_raise_ValueError(MP_ERROR_TEXT("invalid pin"));
 }
 
 static void machine_pin_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     machine_pin_obj_t *self = self_in;
-    uint funcsel = GPIO_GET_FUNCSEL(self->id);
+    uint funcsel = gpio_get_function(self->id);
     qstr mode_qst;
     if (!is_ext_pin(self)) {
         if (funcsel == GPIO_FUNC_SIO) {
             if (GPIO_IS_OPEN_DRAIN(self->id)) {
                 mode_qst = MP_QSTR_OPEN_DRAIN;
-            } else if (GPIO_IS_OUT(self->id)) {
+            } else if (gpio_is_dir_out(self->id)) {
                 mode_qst = MP_QSTR_OUT;
             } else {
                 mode_qst = MP_QSTR_IN;
@@ -214,11 +209,11 @@ static void machine_pin_print(const mp_print_t *print, mp_obj_t self_in, mp_prin
         }
         mp_printf(print, "Pin(%q, mode=%q", self->name, mode_qst);
         bool pull_up = false;
-        if (GPIO_IS_PULL_UP(self->id)) {
+        if (gpio_is_pulled_up(self->id)) {
             mp_printf(print, ", pull=%q", MP_QSTR_PULL_UP);
             pull_up = true;
         }
-        if (GPIO_IS_PULL_DOWN(self->id)) {
+        if (gpio_is_pulled_down(self->id)) {
             if (pull_up) {
                 mp_printf(print, "|%q", MP_QSTR_PULL_DOWN);
             } else {
@@ -259,11 +254,11 @@ static mp_obj_t machine_pin_obj_init_helper(const machine_pin_obj_t *self, size_
     mp_arg_parse_all(n_args, pos_args, kw_args, MP_ARRAY_SIZE(allowed_args), allowed_args, args);
 
     if (is_ext_pin(self) && args[ARG_pull].u_obj != mp_const_none) {
-        mp_raise_ValueError("pulls are not supported for external pins");
+        mp_raise_ValueError(MP_ERROR_TEXT("pulls are not supported for external pins"));
     }
 
     if (is_ext_pin(self) && args[ARG_alt].u_int != GPIO_FUNC_SIO) {
-        mp_raise_ValueError("alternate functions are not supported for external pins");
+        mp_raise_ValueError(MP_ERROR_TEXT("alternate functions are not supported for external pins"));
     }
 
     // get initial value of pin (only valid for OUT and OPEN_DRAIN modes)
@@ -298,7 +293,7 @@ static mp_obj_t machine_pin_obj_init_helper(const machine_pin_obj_t *self, size_
                 mp_raise_msg_varg(&mp_type_ValueError, MP_ERROR_TEXT("invalid pin af: %d"), af);
             }
             gpio_set_function(self->id, af);
-            machine_pin_open_drain_mask &= ~(1 << self->id);
+            GPIO_DISABLE_OPEN_DRAIN(self->id);
         }
     }
 
@@ -380,7 +375,7 @@ static mp_obj_t machine_pin_low(mp_obj_t self_in) {
     } else if (GPIO_IS_OPEN_DRAIN(self->id)) {
         gpio_set_dir(self->id, GPIO_OUT);
     } else {
-        gpio_clr_mask(1u << self->id);
+        gpio_clr_mask64(1ULL << self->id);
     }
     return mp_const_none;
 }
@@ -396,7 +391,7 @@ static mp_obj_t machine_pin_high(mp_obj_t self_in) {
     } else if (GPIO_IS_OPEN_DRAIN(self->id)) {
         gpio_set_dir(self->id, GPIO_IN);
     } else {
-        gpio_set_mask(1u << self->id);
+        gpio_set_mask64(1ULL << self->id);
     }
     return mp_const_none;
 }
@@ -411,13 +406,13 @@ static mp_obj_t machine_pin_toggle(mp_obj_t self_in) {
         machine_pin_ext_set(self, self->last_output_value ^ 1);
         #endif
     } else if (GPIO_IS_OPEN_DRAIN(self->id)) {
-        if (GPIO_IS_OUT(self->id)) {
+        if (gpio_is_dir_out(self->id)) {
             gpio_set_dir(self->id, GPIO_IN);
         } else {
             gpio_set_dir(self->id, GPIO_OUT);
         }
     } else {
-        gpio_xor_mask(1u << self->id);
+        gpio_xor_mask64(1ULL << self->id);
     }
     return mp_const_none;
 }
@@ -520,8 +515,17 @@ static const mp_rom_map_elem_t machine_pin_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_ALT_SIO), MP_ROM_INT(GPIO_FUNC_SIO) },
     { MP_ROM_QSTR(MP_QSTR_ALT_PIO0), MP_ROM_INT(GPIO_FUNC_PIO0) },
     { MP_ROM_QSTR(MP_QSTR_ALT_PIO1), MP_ROM_INT(GPIO_FUNC_PIO1) },
+    #if NUM_PIOS >= 3
+    { MP_ROM_QSTR(MP_QSTR_ALT_PIO2), MP_ROM_INT(GPIO_FUNC_PIO2) },
+    #endif
     { MP_ROM_QSTR(MP_QSTR_ALT_GPCK), MP_ROM_INT(GPIO_FUNC_GPCK) },
     { MP_ROM_QSTR(MP_QSTR_ALT_USB), MP_ROM_INT(GPIO_FUNC_USB) },
+    #if PICO_RP2350
+    { MP_ROM_QSTR(MP_QSTR_ALT_HSTX), MP_ROM_INT(GPIO_FUNC_HSTX) },
+    { MP_ROM_QSTR(MP_QSTR_ALT_XIP_CS1), MP_ROM_INT(GPIO_FUNC_XIP_CS1) },
+    { MP_ROM_QSTR(MP_QSTR_ALT_CORESIGHT_TRACE), MP_ROM_INT(GPIO_FUNC_CORESIGHT_TRACE) },
+    { MP_ROM_QSTR(MP_QSTR_ALT_UART_AUX), MP_ROM_INT(GPIO_FUNC_UART_AUX) },
+    #endif
 };
 static MP_DEFINE_CONST_DICT(machine_pin_locals_dict, machine_pin_locals_dict_table);
 
