@@ -51,7 +51,7 @@
 ///     val = adc.read_core_vref()      # read MCU VREF
 
 /* ADC definitions */
-#if defined(STM32H5)
+#if defined(STM32H5) || defined(STM32N6)
 // STM32H5 features two ADC instances, ADCx and pin_adc_table are set dynamically
 #define PIN_ADC_MASK            (PIN_ADC1 | PIN_ADC2)
 #else
@@ -107,37 +107,20 @@
 #define ADC_CAL2                ((uint16_t *)(ADC_CAL_ADDRESS + 4))
 #define ADC_CAL_BITS            (12)
 
-#elif defined(STM32G0) || defined(STM32G4) || defined(STM32H5)
+#elif defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L1) || defined(STM32L4) || defined(STM32N6) || defined(STM32U5) || defined(STM32WB)
 
 #define ADC_SCALE_V             (((float)VREFINT_CAL_VREF) / 1000.0f)
-#define ADC_CAL_ADDRESS         VREFINT_CAL_ADDR
-#define ADC_CAL1                TEMPSENSOR_CAL1_ADDR
-#define ADC_CAL2                TEMPSENSOR_CAL2_ADDR
-#define ADC_CAL_BITS            (12) // UM2319/UM2570, __HAL_ADC_CALC_TEMPERATURE: 'corresponds to a resolution of 12 bits'
+#define ADC_CAL_ADDRESS         (VREFINT_CAL_ADDR)
+#define ADC_CAL1                (TEMPSENSOR_CAL1_ADDR)
+#define ADC_CAL2                (TEMPSENSOR_CAL2_ADDR)
 
-#elif defined(STM32H7)
-
-#define ADC_SCALE_V             (3.3f)
-#define ADC_CAL_ADDRESS         (0x1FF1E860)
-#define ADC_CAL1                ((uint16_t *)(0x1FF1E820))
-#define ADC_CAL2                ((uint16_t *)(0x1FF1E840))
+#if defined(STM32H7)
 #define ADC_CAL_BITS            (16)
-
-#elif defined(STM32L1)
-
-#define ADC_SCALE_V             (VREFINT_CAL_VREF / 1000.0f)
-#define ADC_CAL_ADDRESS         (VREFINT_CAL_ADDR)
-#define ADC_CAL1                (TEMPSENSOR_CAL1_ADDR)
-#define ADC_CAL2                (TEMPSENSOR_CAL2_ADDR)
-#define ADC_CAL_BITS            (12)
-
-#elif defined(STM32L4) || defined(STM32WB)
-
-#define ADC_SCALE_V             (VREFINT_CAL_VREF / 1000.0f)
-#define ADC_CAL_ADDRESS         (VREFINT_CAL_ADDR)
-#define ADC_CAL1                (TEMPSENSOR_CAL1_ADDR)
-#define ADC_CAL2                (TEMPSENSOR_CAL2_ADDR)
-#define ADC_CAL_BITS            (12)
+#elif defined(STM32U5)
+#define ADC_CAL_BITS            (14)
+#else
+#define ADC_CAL_BITS            (12) // UM2319/UM2570, __HAL_ADC_CALC_TEMPERATURE: 'corresponds to a resolution of 12 bits'
+#endif
 
 #else
 
@@ -155,7 +138,7 @@
     defined(STM32F413xx) || defined(STM32F427xx) || \
     defined(STM32F429xx) || defined(STM32F437xx) || \
     defined(STM32F439xx) || defined(STM32F446xx) || \
-    defined(STM32F479xx)
+    defined(STM32F479xx) || defined(STM32F469xx)
 #define VBAT_DIV (4)
 #elif defined(STM32F722xx) || defined(STM32F723xx) || \
     defined(STM32F732xx) || defined(STM32F733xx) || \
@@ -182,6 +165,11 @@
 #define VBAT_DIV (3)
 #elif defined(STM32L152xE)
 // STM32L152xE does not have vbat.
+#elif defined(STM32N6)
+// ADC2 VINP 16
+#define VBAT_DIV (4)
+#elif defined(STM32U5)
+#define VBAT_DIV (4)
 #else
 #error Unsupported processor
 #endif
@@ -225,6 +213,14 @@ static inline uint32_t adc_get_internal_channel(uint32_t channel) {
     if (channel == 16) {
         channel = ADC_CHANNEL_TEMPSENSOR;
     }
+    #elif defined(STM32G0)
+    if (channel == 12) {
+        channel = ADC_CHANNEL_TEMPSENSOR;
+    } else if (channel == 13) {
+        channel = ADC_CHANNEL_VREFINT;
+    } else if (channel == 14) {
+        channel = ADC_CHANNEL_VBAT;
+    }
     #elif defined(STM32G4)
     if (channel == 16) {
         channel = ADC_CHANNEL_TEMPSENSOR_ADC1;
@@ -241,11 +237,19 @@ static inline uint32_t adc_get_internal_channel(uint32_t channel) {
     } else if (channel == 18) {
         channel = ADC_CHANNEL_VBAT;
     }
+    #elif defined(STM32U5)
+    if (channel == 0) {
+        channel = ADC_CHANNEL_VREFINT;
+    } else if (channel == 18) {
+        channel = ADC_CHANNEL_VBAT;
+    } else if (channel == 19) {
+        channel = ADC_CHANNEL_TEMPSENSOR;
+    }
     #endif
     return channel;
 }
 
-STATIC bool is_adcx_channel(int channel) {
+static bool is_adcx_channel(int channel) {
     #if defined(STM32F411xE)
     // The HAL has an incorrect IS_ADC_CHANNEL macro for the F411 so we check for temp
     return IS_ADC_CHANNEL(channel) || channel == ADC_CHANNEL_TEMPSENSOR;
@@ -255,7 +259,7 @@ STATIC bool is_adcx_channel(int channel) {
     // The HAL of STM32L1 defines some channels those may not be available on package
     return __HAL_ADC_IS_CHANNEL_INTERNAL(channel)
            || (channel < MP_ARRAY_SIZE(pin_adcall_table) && pin_adcall_table[channel]);
-    #elif defined(STM32G0) || defined(STM32H7)
+    #elif defined(STM32G0) || defined(STM32H7) || defined(STM32U5)
     return __HAL_ADC_IS_CHANNEL_INTERNAL(channel)
            || IS_ADC_CHANNEL(__HAL_ADC_DECIMAL_NB_TO_CHANNEL(channel));
     #elif defined(STM32G4) || defined(STM32L4) || defined(STM32WB)
@@ -263,7 +267,7 @@ STATIC bool is_adcx_channel(int channel) {
     handle.Instance = ADCx;
     return __HAL_ADC_IS_CHANNEL_INTERNAL(channel)
            || IS_ADC_CHANNEL(&handle, __HAL_ADC_DECIMAL_NB_TO_CHANNEL(channel));
-    #elif defined(STM32H5)
+    #elif defined(STM32H5) || defined(STM32N6)
     // The first argument to the IS_ADC_CHANNEL macro is unused.
     return __HAL_ADC_IS_CHANNEL_INTERNAL(channel)
            || IS_ADC_CHANNEL(NULL, __HAL_ADC_DECIMAL_NB_TO_CHANNEL(channel));
@@ -272,11 +276,11 @@ STATIC bool is_adcx_channel(int channel) {
     #endif
 }
 
-STATIC void adc_wait_for_eoc_or_timeout(ADC_HandleTypeDef *adcHandle, int32_t timeout) {
+static void adc_wait_for_eoc_or_timeout(ADC_HandleTypeDef *adcHandle, int32_t timeout) {
     uint32_t tickstart = HAL_GetTick();
     #if defined(STM32F4) || defined(STM32F7) || defined(STM32L1)
     while ((adcHandle->Instance->SR & ADC_FLAG_EOC) != ADC_FLAG_EOC) {
-    #elif defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32WB)
+    #elif defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32N6) || defined(STM32U5) || defined(STM32WB)
     while (READ_BIT(adcHandle->Instance->ISR, ADC_FLAG_EOC) != ADC_FLAG_EOC) {
     #else
     #error Unsupported processor
@@ -287,7 +291,7 @@ STATIC void adc_wait_for_eoc_or_timeout(ADC_HandleTypeDef *adcHandle, int32_t ti
     }
 }
 
-STATIC void adcx_clock_enable(ADC_HandleTypeDef *adch) {
+static void adcx_clock_enable(ADC_HandleTypeDef *adch) {
     #if defined(STM32F0) || defined(STM32F4) || defined(STM32F7) || defined(STM32L1)
     ADCx_CLK_ENABLE();
     #elif defined(STM32H7A3xx) || defined(STM32H7A3xxQ) || defined(STM32H7B3xx) || defined(STM32H7B3xxQ)
@@ -295,7 +299,7 @@ STATIC void adcx_clock_enable(ADC_HandleTypeDef *adch) {
     __HAL_RCC_ADC_CONFIG(RCC_ADCCLKSOURCE_CLKP);
     #elif defined(STM32G0)
     __HAL_RCC_ADC_CLK_ENABLE();
-    #elif defined(STM32G4)
+    #elif defined(STM32G4) || defined(STM32N6)
     __HAL_RCC_ADC12_CLK_ENABLE();
     #elif defined(STM32H5)
     __HAL_RCC_ADC_CLK_ENABLE();
@@ -311,14 +315,21 @@ STATIC void adcx_clock_enable(ADC_HandleTypeDef *adch) {
         __HAL_RCC_ADC_CONFIG(RCC_ADCCLKSOURCE_SYSCLK);
     }
     __HAL_RCC_ADC_CLK_ENABLE();
+    #elif defined(STM32U5)
+    __HAL_RCC_ADC12_CLK_ENABLE();
     #else
     #error Unsupported processor
     #endif
 }
 
-STATIC void adcx_init_periph(ADC_HandleTypeDef *adch, uint32_t resolution) {
+static void adcx_init_periph(ADC_HandleTypeDef *adch, uint32_t resolution) {
     adcx_clock_enable(adch);
 
+    // Set ADC clock prescaler, if it's not done by HAL_ADC_Init() below.
+    #if defined(STM32N6)
+    LL_RCC_SetADCPrescaler(4 - 1); // 200MHz / 4 = 50MHz
+    #endif
+
     adch->Init.Resolution = resolution;
     adch->Init.ContinuousConvMode = DISABLE;
     adch->Init.DiscontinuousConvMode = DISABLE;
@@ -356,8 +367,12 @@ STATIC void adcx_init_periph(ADC_HandleTypeDef *adch, uint32_t resolution) {
     adch->Init.LowPowerAutoWait = DISABLE;
     adch->Init.DataAlign = ADC_DATAALIGN_RIGHT;
     adch->Init.DMAContinuousRequests = DISABLE;
-    #elif defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32L4) || defined(STM32WB)
-    #if defined(STM32G4) || defined(STM32H5)
+    #elif defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32L4) || defined(STM32U5) || defined(STM32WB)
+    #if defined(STM32G0)
+    adch->Init.SamplingTimeCommon1 = ADC_SAMPLETIME_12CYCLES_5;
+    adch->Init.SamplingTimeCommon2 = ADC_SAMPLETIME_160CYCLES_5;
+    #endif
+    #if defined(STM32G4) || defined(STM32H5) || defined(STM32U5)
     adch->Init.ClockPrescaler = ADC_CLOCK_ASYNC_DIV16;
     #else
     adch->Init.ClockPrescaler = ADC_CLOCK_ASYNC_DIV1;
@@ -368,23 +383,38 @@ STATIC void adcx_init_periph(ADC_HandleTypeDef *adch, uint32_t resolution) {
     adch->Init.OversamplingMode = DISABLE;
     adch->Init.DataAlign = ADC_DATAALIGN_RIGHT;
     adch->Init.DMAContinuousRequests = DISABLE;
+    #if defined(STM32U5)
+    adch->Init.GainCompensation = 0;
+    adch->Init.TriggerFrequencyMode = ADC_TRIGGER_FREQ_HIGH;
+    adch->Init.LeftBitShift = ADC_LEFTBITSHIFT_NONE;
+    adch->Init.ConversionDataManagement = ADC_CONVERSIONDATA_DR;
+    #endif
+    #elif defined(STM32N6)
+    adch->Init.GainCompensation = 0;
+    adch->Init.ScanConvMode = ADC_SCAN_DISABLE;
+    adch->Init.LowPowerAutoWait = DISABLE;
+    adch->Init.SamplingMode = ADC_SAMPLING_MODE_NORMAL;
+    adch->Init.ConversionDataManagement = ADC_CONVERSIONDATA_DR;
+    adch->Init.Overrun = ADC_OVR_DATA_OVERWRITTEN;
+    adch->Init.LeftBitShift = ADC_LEFTBITSHIFT_NONE;
+    adch->Init.OversamplingMode = DISABLE;
     #else
     #error Unsupported processor
     #endif
 
     HAL_ADC_Init(adch);
 
-    #if defined(STM32H7)
+    #if defined(STM32H7) || defined(STM32U5)
     HAL_ADCEx_Calibration_Start(adch, ADC_CALIB_OFFSET, ADC_SINGLE_ENDED);
     #endif
     #if defined(STM32G0)
     HAL_ADCEx_Calibration_Start(adch);
-    #elif defined(STM32G4) || defined(STM32H5) || defined(STM32L4) || defined(STM32WB)
+    #elif defined(STM32G4) || defined(STM32H5) || defined(STM32L4) || defined(STM32N6) || defined(STM32WB)
     HAL_ADCEx_Calibration_Start(adch, ADC_SINGLE_ENDED);
     #endif
 }
 
-STATIC void adc_init_single(pyb_obj_adc_t *adc_obj, ADC_TypeDef *adc) {
+static void adc_init_single(pyb_obj_adc_t *adc_obj, ADC_TypeDef *adc) {
     adc_obj->handle.Instance = adc;
     adcx_init_periph(&adc_obj->handle, ADC_RESOLUTION_12B);
 
@@ -397,14 +427,16 @@ STATIC void adc_init_single(pyb_obj_adc_t *adc_obj, ADC_TypeDef *adc) {
     #endif
 }
 
-STATIC void adc_config_channel(ADC_HandleTypeDef *adc_handle, uint32_t channel) {
+static void adc_config_channel(ADC_HandleTypeDef *adc_handle, uint32_t channel) {
     ADC_ChannelConfTypeDef sConfig;
 
-    #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32WB)
+    #if defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32N6) || defined(STM32WB)
     sConfig.Rank = ADC_REGULAR_RANK_1;
     if (__HAL_ADC_IS_CHANNEL_INTERNAL(channel) == 0) {
         channel = __HAL_ADC_DECIMAL_NB_TO_CHANNEL(channel);
     }
+    #elif defined(STM32U5)
+    sConfig.Rank = ADC_REGULAR_RANK_1;
     #else
     sConfig.Rank = 1;
     #endif
@@ -432,13 +464,13 @@ STATIC void adc_config_channel(ADC_HandleTypeDef *adc_handle, uint32_t channel)
     if (__HAL_ADC_IS_CHANNEL_INTERNAL(channel)) {
         sConfig.SamplingTime = ADC_SAMPLETIME_384CYCLES;
     } else {
-        sConfig.SamplingTime = ADC_SAMPLETIME_384CYCLES;
+        sConfig.SamplingTime = ADC_SAMPLETIME_16CYCLES;
     }
     #elif defined(STM32G0)
     if (__HAL_ADC_IS_CHANNEL_INTERNAL(channel)) {
-        sConfig.SamplingTime = ADC_SAMPLETIME_160CYCLES_5;
+        sConfig.SamplingTime = ADC_SAMPLINGTIME_COMMON_2;
     } else {
-        sConfig.SamplingTime = ADC_SAMPLETIME_12CYCLES_5;
+        sConfig.SamplingTime = ADC_SAMPLINGTIME_COMMON_1;
     }
     #elif defined(STM32G4) || defined(STM32H5) || defined(STM32L4) || defined(STM32WB)
     if (__HAL_ADC_IS_CHANNEL_INTERNAL(channel)) {
@@ -449,6 +481,27 @@ STATIC void adc_config_channel(ADC_HandleTypeDef *adc_handle, uint32_t channel)
     sConfig.SingleDiff = ADC_SINGLE_ENDED;
     sConfig.OffsetNumber = ADC_OFFSET_NONE;
     sConfig.Offset = 0;
+    #elif defined(STM32N6)
+    if (__HAL_ADC_IS_CHANNEL_INTERNAL(channel)) {
+        sConfig.SamplingTime = ADC_SAMPLETIME_246CYCLES_5;
+    } else {
+        sConfig.SamplingTime = ADC_SAMPLETIME_46CYCLES_5;
+    }
+    sConfig.SingleDiff = ADC_SINGLE_ENDED;
+    sConfig.OffsetNumber = ADC_OFFSET_NONE;
+    sConfig.Offset = 0;
+    sConfig.OffsetSignedSaturation = DISABLE;
+    sConfig.OffsetSaturation = DISABLE;
+    sConfig.OffsetSign = ADC_OFFSET_SIGN_POSITIVE;
+    #elif defined(STM32U5)
+    if (__HAL_ADC_IS_CHANNEL_INTERNAL(channel)) {
+        sConfig.SamplingTime = ADC_SAMPLETIME_391CYCLES_5;
+    } else {
+        sConfig.SamplingTime = ADC4_SAMPLETIME_3CYCLES_5;
+    }
+    sConfig.SingleDiff = ADC_SINGLE_ENDED;
+    sConfig.OffsetNumber = ADC_OFFSET_NONE;
+    sConfig.Offset = 0;
     #else
     #error Unsupported processor
     #endif
@@ -462,12 +515,15 @@ STATIC void adc_config_channel(ADC_HandleTypeDef *adc_handle, uint32_t channel)
     HAL_ADC_ConfigChannel(adc_handle, &sConfig);
 }
 
-STATIC uint32_t adc_read_channel(ADC_HandleTypeDef *adcHandle) {
+static uint32_t adc_read_channel(ADC_HandleTypeDef *adcHandle) {
     uint32_t value;
-    #if defined(STM32G4)
-    // For STM32G4 there is errata 2.7.7, "Wrong ADC result if conversion done late after
-    // calibration or previous conversion".  According to the errata, this can be avoided
-    // by performing two consecutive ADC conversions and keeping the second result.
+    #if defined(STM32G4) || defined(STM32WB)
+    // For STM32G4 errata 2.7.7 / STM32WB errata 2.7.1:
+    // "Wrong ADC result if conversion done late after calibration or previous conversion"
+    // states an incorrect reading is returned if more than 1ms has elapsed since the last
+    // reading or calibration. According to the errata, this can be avoided by performing
+    // two consecutive ADC conversions and keeping the second result.
+    // Note: On STM32WB55 @ 64Mhz each ADC read takes ~ 3us.
     for (uint8_t i = 0; i < 2; i++)
     #endif
     {
@@ -479,7 +535,7 @@ STATIC uint32_t adc_read_channel(ADC_HandleTypeDef *adcHandle) {
     return value;
 }
 
-STATIC uint32_t adc_config_and_read_channel(ADC_HandleTypeDef *adcHandle, uint32_t channel) {
+static uint32_t adc_config_and_read_channel(ADC_HandleTypeDef *adcHandle, uint32_t channel) {
     adc_config_channel(adcHandle, channel);
     uint32_t raw_value = adc_read_channel(adcHandle);
 
@@ -498,7 +554,7 @@ STATIC uint32_t adc_config_and_read_channel(ADC_HandleTypeDef *adcHandle, uint32
 /******************************************************************************/
 /* MicroPython bindings : adc object (single channel)                         */
 
-STATIC void adc_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void adc_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     pyb_obj_adc_t *self = MP_OBJ_TO_PTR(self_in);
     #if defined STM32H5
     unsigned adc_id = 1;
@@ -516,18 +572,18 @@ STATIC void adc_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t
 /// \classmethod \constructor(pin)
 /// Create an ADC object associated with the given pin.
 /// This allows you to then read analog values on that pin.
-STATIC mp_obj_t adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     // check number of arguments
     mp_arg_check_num(n_args, n_kw, 1, 1, false);
 
     // 1st argument is the pin name
     mp_obj_t pin_obj = args[0];
 
-    #if defined(STM32H5)
+    #if defined(STM32H5) || defined(STM32N6)
     // STM32H5 has two ADC instances where some pins are only available on ADC1 or ADC2 (but not both).
     // Assume we're using a channel of ADC1. Can be overridden for ADC2 later in this function.
     ADC_TypeDef *adc = ADC1;
-    const pin_obj_t *const *pin_adc_table = pin_adc1;
+    const machine_pin_obj_t *const *pin_adc_table = pin_adc1;
     uint32_t num_adc_pins = MP_ARRAY_SIZE(pin_adc1);
     #endif
     uint32_t channel;
@@ -535,12 +591,12 @@ STATIC mp_obj_t adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_
     if (mp_obj_is_int(pin_obj)) {
         channel = adc_get_internal_channel(mp_obj_get_int(pin_obj));
     } else {
-        const pin_obj_t *pin = pin_find(pin_obj);
+        const machine_pin_obj_t *pin = pin_find(pin_obj);
         if ((pin->adc_num & PIN_ADC_MASK) == 0) {
             // No ADC function on the given pin.
             mp_raise_msg_varg(&mp_type_ValueError, MP_ERROR_TEXT("Pin(%q) doesn't have ADC capabilities"), pin->name);
         }
-        #if defined(STM32H5)
+        #if defined(STM32H5) || defined(STM32N6)
         if ((pin->adc_num & PIN_ADC2) == PIN_ADC2) {
             adc = ADC2;
             pin_adc_table = pin_adc2;
@@ -555,16 +611,16 @@ STATIC mp_obj_t adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_
     }
 
     // If this channel corresponds to a pin then configure the pin in ADC mode.
-    #if defined(STM32H5)
+    #if defined(STM32H5) || defined(STM32N6)
     if (channel < num_adc_pins) {
-        const pin_obj_t *pin = pin_adc_table[channel];
+        const machine_pin_obj_t *pin = pin_adc_table[channel];
         if (pin != NULL) {
             mp_hal_pin_config(pin, MP_HAL_PIN_MODE_ADC, MP_HAL_PIN_PULL_NONE, 0);
         }
     }
     #else
     if (channel < MP_ARRAY_SIZE(pin_adc_table)) {
-        const pin_obj_t *pin = pin_adc_table[channel];
+        const machine_pin_obj_t *pin = pin_adc_table[channel];
         if (pin != NULL) {
             mp_hal_pin_config(pin, MP_HAL_PIN_MODE_ADC, MP_HAL_PIN_PULL_NONE, 0);
         }
@@ -576,7 +632,7 @@ STATIC mp_obj_t adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_
     o->base.type = &pyb_adc_type;
     o->pin_name = pin_obj;
     o->channel = channel;
-    #if defined(STM32H5)
+    #if defined(STM32H5) || defined(STM32N6)
     adc_init_single(o, adc);
     #else
     adc_init_single(o, ADCx);
@@ -587,11 +643,11 @@ STATIC mp_obj_t adc_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_
 /// \method read()
 /// Read the value on the analog pin and return it.  The returned value
 /// will be between 0 and 4095.
-STATIC mp_obj_t adc_read(mp_obj_t self_in) {
+static mp_obj_t adc_read(mp_obj_t self_in) {
     pyb_obj_adc_t *self = MP_OBJ_TO_PTR(self_in);
     return mp_obj_new_int(adc_config_and_read_channel(&self->handle, self->channel));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(adc_read_obj, adc_read);
+static MP_DEFINE_CONST_FUN_OBJ_1(adc_read_obj, adc_read);
 
 /// \method read_timed(buf, timer)
 ///
@@ -627,7 +683,7 @@ STATIC MP_DEFINE_CONST_FUN_OBJ_1(adc_read_obj, adc_read);
 ///         print(val)                      # print the value out
 ///
 /// This function does not allocate any memory.
-STATIC mp_obj_t adc_read_timed(mp_obj_t self_in, mp_obj_t buf_in, mp_obj_t freq_in) {
+static mp_obj_t adc_read_timed(mp_obj_t self_in, mp_obj_t buf_in, mp_obj_t freq_in) {
     pyb_obj_adc_t *self = MP_OBJ_TO_PTR(self_in);
 
     mp_buffer_info_t bufinfo;
@@ -667,7 +723,7 @@ STATIC mp_obj_t adc_read_timed(mp_obj_t self_in, mp_obj_t buf_in, mp_obj_t freq_
             // for subsequent samples we can just set the "start sample" bit
             #if defined(STM32F4) || defined(STM32F7) || defined(STM32L1)
             self->handle.Instance->CR2 |= (uint32_t)ADC_CR2_SWSTART;
-            #elif defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32WB)
+            #elif defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32N6) || defined(STM32U5) || defined(STM32WB)
             SET_BIT(self->handle.Instance->CR, ADC_CR_ADSTART);
             #else
             #error Unsupported processor
@@ -699,7 +755,7 @@ STATIC mp_obj_t adc_read_timed(mp_obj_t self_in, mp_obj_t buf_in, mp_obj_t freq_
 
     return mp_obj_new_int(bufinfo.len);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_3(adc_read_timed_obj, adc_read_timed);
+static MP_DEFINE_CONST_FUN_OBJ_3(adc_read_timed_obj, adc_read_timed);
 
 // read_timed_multi((adcx, adcy, ...), (bufx, bufy, ...), timer)
 //
@@ -709,7 +765,7 @@ STATIC MP_DEFINE_CONST_FUN_OBJ_3(adc_read_timed_obj, adc_read_timed);
 // the sample resolution will be reduced to 8 bits.
 //
 // This function should not allocate any heap memory.
-STATIC mp_obj_t adc_read_timed_multi(mp_obj_t adc_array_in, mp_obj_t buf_array_in, mp_obj_t tim_in) {
+static mp_obj_t adc_read_timed_multi(mp_obj_t adc_array_in, mp_obj_t buf_array_in, mp_obj_t tim_in) {
     size_t nadcs, nbufs;
     mp_obj_t *adc_array, *buf_array;
     mp_obj_get_array(adc_array_in, &nadcs, &adc_array);
@@ -777,7 +833,7 @@ STATIC mp_obj_t adc_read_timed_multi(mp_obj_t adc_array_in, mp_obj_t buf_array_i
             // ADC is started: set the "start sample" bit
             #if defined(STM32F4) || defined(STM32F7) || defined(STM32L1)
             adc->handle.Instance->CR2 |= (uint32_t)ADC_CR2_SWSTART;
-            #elif defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32WB)
+            #elif defined(STM32F0) || defined(STM32G0) || defined(STM32G4) || defined(STM32H5) || defined(STM32H7) || defined(STM32L4) || defined(STM32N6) || defined(STM32U5) || defined(STM32WB)
             SET_BIT(adc->handle.Instance->CR, ADC_CR_ADSTART);
             #else
             #error Unsupported processor
@@ -802,16 +858,16 @@ STATIC mp_obj_t adc_read_timed_multi(mp_obj_t adc_array_in, mp_obj_t buf_array_i
 
     return mp_obj_new_bool(success);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_3(adc_read_timed_multi_fun_obj, adc_read_timed_multi);
-STATIC MP_DEFINE_CONST_STATICMETHOD_OBJ(adc_read_timed_multi_obj, MP_ROM_PTR(&adc_read_timed_multi_fun_obj));
+static MP_DEFINE_CONST_FUN_OBJ_3(adc_read_timed_multi_fun_obj, adc_read_timed_multi);
+static MP_DEFINE_CONST_STATICMETHOD_OBJ(adc_read_timed_multi_obj, MP_ROM_PTR(&adc_read_timed_multi_fun_obj));
 
-STATIC const mp_rom_map_elem_t adc_locals_dict_table[] = {
+static const mp_rom_map_elem_t adc_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_read), MP_ROM_PTR(&adc_read_obj) },
     { MP_ROM_QSTR(MP_QSTR_read_timed), MP_ROM_PTR(&adc_read_timed_obj) },
     { MP_ROM_QSTR(MP_QSTR_read_timed_multi), MP_ROM_PTR(&adc_read_timed_multi_obj) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(adc_locals_dict, adc_locals_dict_table);
+static MP_DEFINE_CONST_DICT(adc_locals_dict, adc_locals_dict_table);
 
 MP_DEFINE_CONST_OBJ_TYPE(
     pyb_adc_type,
@@ -862,7 +918,7 @@ void adc_init_all(pyb_adc_all_obj_t *adc_all, uint32_t resolution, uint32_t en_m
         // only initialise those channels that are selected with the en_mask
         if (en_mask & (1 << channel)) {
             // If this channel corresponds to a pin then configure the pin in ADC mode.
-            const pin_obj_t *pin = pin_adcall_table[channel];
+            const machine_pin_obj_t *pin = pin_adcall_table[channel];
             if (pin) {
                 mp_hal_pin_config(pin, MP_HAL_PIN_MODE_ADC, MP_HAL_PIN_PULL_NONE, 0);
             }
@@ -897,7 +953,7 @@ int adc_get_resolution(ADC_HandleTypeDef *adcHandle) {
     return 12;
 }
 
-STATIC uint32_t adc_config_and_read_ref(ADC_HandleTypeDef *adcHandle, uint32_t channel) {
+static uint32_t adc_config_and_read_ref(ADC_HandleTypeDef *adcHandle, uint32_t channel) {
     uint32_t raw_value = adc_config_and_read_channel(adcHandle, channel);
     // Scale raw reading to the number of bits used by the calibration constants
     return raw_value << (ADC_CAL_BITS - adc_get_resolution(adcHandle));
@@ -911,6 +967,8 @@ int adc_read_core_temp(ADC_HandleTypeDef *adcHandle) {
     } else {
         return 0;
     }
+    #elif defined(STM32N6)
+    int32_t raw_value = 0; // TODO
     #else
     int32_t raw_value = adc_config_and_read_ref(adcHandle, ADC_CHANNEL_TEMPSENSOR);
     #endif
@@ -919,12 +977,16 @@ int adc_read_core_temp(ADC_HandleTypeDef *adcHandle) {
 
 #if MICROPY_PY_BUILTINS_FLOAT
 // correction factor for reference value
-STATIC volatile float adc_refcor = 1.0f;
+static volatile float adc_refcor = 1.0f;
 
 float adc_read_core_temp_float(ADC_HandleTypeDef *adcHandle) {
-    #if defined(STM32G4) || defined(STM32L1) || defined(STM32L4)
+    #if defined(STM32N6)
+    return 0.0f; // TODO
+    #else
+
+    #if defined(STM32G0) || defined(STM32G4) || defined(STM32L1) || defined(STM32L4) || defined(STM32U5)
     // Update the reference correction factor before reading tempsensor
-    // because TS_CAL1 and TS_CAL2 of STM32G4,L1/L4 are at VDDA=3.0V
+    // because TS_CAL1 and TS_CAL2 of STM32G0,G4,L1,L4 are at VDDA=3.0V
     adc_read_core_vref(adcHandle);
     #endif
 
@@ -936,7 +998,7 @@ float adc_read_core_temp_float(ADC_HandleTypeDef *adcHandle) {
         return 0;
     }
     float core_temp_avg_slope = (*ADC_CAL2 - *ADC_CAL1) / 100.0f;
-    #elif defined(STM32H5)
+    #elif defined(STM32H5) || defined(STM32U5) || defined(STM32WB)
     int32_t raw_value = adc_config_and_read_ref(adcHandle, ADC_CHANNEL_TEMPSENSOR);
     float core_temp_avg_slope = (*ADC_CAL2 - *ADC_CAL1) / 100.0f;
     #else
@@ -944,12 +1006,14 @@ float adc_read_core_temp_float(ADC_HandleTypeDef *adcHandle) {
     float core_temp_avg_slope = (*ADC_CAL2 - *ADC_CAL1) / 80.0f;
     #endif
     return (((float)raw_value * adc_refcor - *ADC_CAL1) / core_temp_avg_slope) + 30.0f;
+
+    #endif
 }
 
 float adc_read_core_vbat(ADC_HandleTypeDef *adcHandle) {
-    #if defined(STM32G4) || defined(STM32L4)
+    #if defined(STM32G0) || defined(STM32G4) || defined(STM32L4) || defined(STM32U5)
     // Update the reference correction factor before reading tempsensor
-    // because VREFINT of STM32G4,L4 is at VDDA=3.0V
+    // because VREFINT of STM32G0,G4,L4 is at VDDA=3.0V
     adc_read_core_vref(adcHandle);
     #endif
 
@@ -974,7 +1038,7 @@ float adc_read_core_vref(ADC_HandleTypeDef *adcHandle) {
 /******************************************************************************/
 /* MicroPython bindings : adc_all object                                      */
 
-STATIC mp_obj_t adc_all_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t adc_all_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     // check number of arguments
     mp_arg_check_num(n_args, n_kw, 1, 2, false);
 
@@ -990,7 +1054,7 @@ STATIC mp_obj_t adc_all_make_new(const mp_obj_type_t *type, size_t n_args, size_
     return MP_OBJ_FROM_PTR(o);
 }
 
-STATIC mp_obj_t adc_all_read_channel(mp_obj_t self_in, mp_obj_t channel) {
+static mp_obj_t adc_all_read_channel(mp_obj_t self_in, mp_obj_t channel) {
     pyb_adc_all_obj_t *self = MP_OBJ_TO_PTR(self_in);
     uint32_t chan = adc_get_internal_channel(mp_obj_get_int(channel));
     if (!is_adcx_channel(chan)) {
@@ -999,9 +1063,9 @@ STATIC mp_obj_t adc_all_read_channel(mp_obj_t self_in, mp_obj_t channel) {
     uint32_t data = adc_config_and_read_channel(&self->handle, chan);
     return mp_obj_new_int(data);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_2(adc_all_read_channel_obj, adc_all_read_channel);
+static MP_DEFINE_CONST_FUN_OBJ_2(adc_all_read_channel_obj, adc_all_read_channel);
 
-STATIC mp_obj_t adc_all_read_core_temp(mp_obj_t self_in) {
+static mp_obj_t adc_all_read_core_temp(mp_obj_t self_in) {
     pyb_adc_all_obj_t *self = MP_OBJ_TO_PTR(self_in);
     #if MICROPY_PY_BUILTINS_FLOAT
     float data = adc_read_core_temp_float(&self->handle);
@@ -1011,32 +1075,32 @@ STATIC mp_obj_t adc_all_read_core_temp(mp_obj_t self_in) {
     return mp_obj_new_int(data);
     #endif
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_core_temp_obj, adc_all_read_core_temp);
+static MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_core_temp_obj, adc_all_read_core_temp);
 
 #if MICROPY_PY_BUILTINS_FLOAT
-STATIC mp_obj_t adc_all_read_core_vbat(mp_obj_t self_in) {
+static mp_obj_t adc_all_read_core_vbat(mp_obj_t self_in) {
     pyb_adc_all_obj_t *self = MP_OBJ_TO_PTR(self_in);
     float data = adc_read_core_vbat(&self->handle);
     return mp_obj_new_float(data);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_core_vbat_obj, adc_all_read_core_vbat);
+static MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_core_vbat_obj, adc_all_read_core_vbat);
 
-STATIC mp_obj_t adc_all_read_core_vref(mp_obj_t self_in) {
+static mp_obj_t adc_all_read_core_vref(mp_obj_t self_in) {
     pyb_adc_all_obj_t *self = MP_OBJ_TO_PTR(self_in);
     float data = adc_read_core_vref(&self->handle);
     return mp_obj_new_float(data);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_core_vref_obj, adc_all_read_core_vref);
+static MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_core_vref_obj, adc_all_read_core_vref);
 
-STATIC mp_obj_t adc_all_read_vref(mp_obj_t self_in) {
+static mp_obj_t adc_all_read_vref(mp_obj_t self_in) {
     pyb_adc_all_obj_t *self = MP_OBJ_TO_PTR(self_in);
     adc_read_core_vref(&self->handle);
     return mp_obj_new_float(ADC_SCALE_V * adc_refcor);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_vref_obj, adc_all_read_vref);
+static MP_DEFINE_CONST_FUN_OBJ_1(adc_all_read_vref_obj, adc_all_read_vref);
 #endif
 
-STATIC const mp_rom_map_elem_t adc_all_locals_dict_table[] = {
+static const mp_rom_map_elem_t adc_all_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_read_channel), MP_ROM_PTR(&adc_all_read_channel_obj) },
     { MP_ROM_QSTR(MP_QSTR_read_core_temp), MP_ROM_PTR(&adc_all_read_core_temp_obj) },
     #if MICROPY_PY_BUILTINS_FLOAT
@@ -1046,7 +1110,7 @@ STATIC const mp_rom_map_elem_t adc_all_locals_dict_table[] = {
     #endif
 };
 
-STATIC MP_DEFINE_CONST_DICT(adc_all_locals_dict, adc_all_locals_dict_table);
+static MP_DEFINE_CONST_DICT(adc_all_locals_dict, adc_all_locals_dict_table);
 
 MP_DEFINE_CONST_OBJ_TYPE(
     pyb_adc_all_type,
