@@ -49,6 +49,7 @@
 #define MICROPY_COMP_DOUBLE_TUPLE_ASSIGN (1)
 #define MICROPY_ENABLE_COMPILER (1)
 #define MICROPY_ENABLE_EXTERNAL_IMPORT (1)
+#define MICROPY_STACK_CHECK (1)
 #define MICROPY_FULL_CHECKS (1)
 #define MICROPY_HELPER_REPL (1)
 #define MICROPY_KBD_EXCEPTION (1)
@@ -61,9 +62,5 @@
 #define MICROPY_PY_BUILTINS_RANGE_ATTRS (1)
 #define MICROPY_PY_GENERATOR_PEND_THROW (1)
 
-// Enable just the sys and os built-in modules.
-#define MICROPY_PY_SYS (1)
-#define MICROPY_PY_UOS (1)
-
-// The minimum sets this to 1 to save flash.
-#define MICROPY_QSTR_BYTES_IN_HASH (2)
+// Add just the os built-in module.
+#define MICROPY_PY_OS (1)
