@@ -1,3 +1,3 @@
 include("$(PORT_DIR)/variants/manifest.py")
 
-include("$(MPY_DIR)/extmod/uasyncio")
+include("$(MPY_DIR)/extmod/asyncio")
