@@ -49,24 +49,34 @@
 // the top-level call into C.
 static size_t external_call_depth = 0;
 
+// Emscripten defaults to a 64k C-stack, so our limit should be less than that.
+#define CSTACK_SIZE (32 * 1024)
+
 #if MICROPY_GC_SPLIT_HEAP_AUTO
 static void gc_collect_top_level(void);
 #endif
 
 void external_call_depth_inc(void) {
     ++external_call_depth;
+}
+
+void external_call_depth_dec(void) {
+    --external_call_depth;
     #if MICROPY_GC_SPLIT_HEAP_AUTO
-    if (external_call_depth == 1) {
+    if (external_call_depth == 0) {
         gc_collect_top_level();
     }
     #endif
 }
 
-void external_call_depth_dec(void) {
-    --external_call_depth;
-}
+void mp_js_init(int pystack_size, int heap_size) {
+    mp_cstack_init_with_sp_here(CSTACK_SIZE);
+
+    #if MICROPY_ENABLE_PYSTACK
+    mp_obj_t *pystack = (mp_obj_t *)malloc(pystack_size * sizeof(mp_obj_t));
+    mp_pystack_init(pystack, pystack + pystack_size);
+    #endif
 
-void mp_js_init(int heap_size) {
     #if MICROPY_ENABLE_GC
     char *heap = (char *)malloc(heap_size * sizeof(char));
     gc_init(heap, heap + heap_size);
@@ -80,11 +90,6 @@ void mp_js_init(int heap_size) {
     MP_STATE_MEM(gc_alloc_threshold) = 16 * 1024 / MICROPY_BYTES_PER_GC_BLOCK;
     #endif
 
-    #if MICROPY_ENABLE_PYSTACK
-    static mp_obj_t pystack[1024];
-    mp_pystack_init(pystack, &pystack[MP_ARRAY_SIZE(pystack)]);
-    #endif
-
     mp_init();
 
     #if MICROPY_VFS_POSIX
@@ -128,13 +133,12 @@ void mp_js_do_import(const char *name, uint32_t *out) {
             }
         }
         nlr_pop();
-        external_call_depth_dec();
         proxy_convert_mp_to_js_obj_cside(ret, out);
     } else {
         // uncaught exception
-        external_call_depth_dec();
         proxy_convert_mp_to_js_exc_cside(nlr.ret_val, out);
     }
+    external_call_depth_dec();
 }
 
 void mp_js_do_exec(const char *src, size_t len, uint32_t *out) {
@@ -148,13 +152,12 @@ void mp_js_do_exec(const char *src, size_t len, uint32_t *out) {
         mp_obj_t module_fun = mp_compile(&parse_tree, source_name, false);
         mp_obj_t ret = mp_call_function_0(module_fun);
         nlr_pop();
-        external_call_depth_dec();
         proxy_convert_mp_to_js_obj_cside(ret, out);
     } else {
         // uncaught exception
-        external_call_depth_dec();
         proxy_convert_mp_to_js_exc_cside(nlr.ret_val, out);
     }
+    external_call_depth_dec();
 }
 
 void mp_js_do_exec_async(const char *src, size_t len, uint32_t *out) {
@@ -233,7 +236,7 @@ void nlr_jump_fail(void *val) {
     }
 }
 
-void NORETURN __fatal_error(const char *msg) {
+void MP_NORETURN __fatal_error(const char *msg) {
     while (1) {
         ;
     }
