@@ -1,2 +1,2 @@
 include("$(PORT_DIR)/variants/manifest.py")
-include("$(MPY_DIR)/extmod/uasyncio")
+include("$(MPY_DIR)/extmod/asyncio")
