@@ -11,17 +11,13 @@ try:
 except AttributeError:
     print("AttributeError")
 
-print(x[1:])
-print(x[:-1])
-print(x[2:3])
-
 print(x + (10, 100, 10000))
 
 # inplace add operator
 x += (10, 11, 12)
 print(x)
 
-# construction of tuple from large iterator (tests implementation detail of uPy)
+# construction of tuple from large iterator (tests implementation detail of MicroPython)
 print(tuple(range(20)))
 
 # unsupported unary operation
