@@ -1,11 +1,10 @@
 # Test builtin execfile function using VFS.
 
 try:
-    import io, os
+    import io, os, vfs
 
     execfile
     io.IOBase
-    os.mount
 except (ImportError, NameError, AttributeError):
     print("SKIP")
     raise SystemExit
@@ -17,7 +16,9 @@ class File(io.IOBase):
         self.off = 0
 
     def ioctl(self, request, arg):
-        return 0
+        if request == 4:  # MP_STREAM_CLOSE
+            return 0
+        return -1
 
     def readinto(self, buf):
         buf[:] = memoryview(self.data)[self.off : self.off + len(buf)]
@@ -44,25 +45,21 @@ class Filesystem:
 
 # First umount any existing mount points the target may have.
 try:
-    import io, os
-
-    os.umount("/")
+    vfs.umount("/")
 except OSError:
     pass
 for path in os.listdir("/"):
-    os.umount("/" + path)
+    vfs.umount("/" + path)
 
 # Create and mount the VFS object.
 files = {
     "/test.py": "print(123)",
 }
 fs = Filesystem(files)
-os.mount(fs, "/test_mnt")
+vfs.mount(fs, "/test_mnt")
 
 # Test execfile with a file that doesn't exist.
 try:
-    import io, os
-
     execfile("/test_mnt/noexist.py")
 except OSError:
     print("OSError")
@@ -70,5 +67,32 @@ except OSError:
 # Test execfile with a file that does exist.
 execfile("/test_mnt/test.py")
 
+# Test that it only works with string arguments.
+try:
+    execfile(b"aaa")
+except TypeError:
+    print("TypeError")
+
 # Unmount the VFS object.
-os.umount(fs)
+vfs.umount(fs)
+
+
+class EvilFilesystem:
+    def mount(self, readonly, mkfs):
+        print("mount", readonly, mkfs)
+
+    def umount(self):
+        print("umount")
+
+    def open(self, file, mode):
+        return None
+
+
+fs = EvilFilesystem()
+vfs.mount(fs, "/test_mnt")
+try:
+    execfile("/test_mnt/test.py")
+    print("ExecFile succeeded")
+except OSError:
+    print("OSError")
+vfs.umount(fs)
