@@ -1,10 +1,18 @@
 # Test that we can raise and catch (preallocated) exception
 # without memory allocation.
-import micropython
+try:
+    import micropython
+
+    micropython.heap_lock
+except (ImportError, AttributeError):
+    print("SKIP")
+    raise SystemExit
 
 e = ValueError("error")
 
+
 def func():
+    micropython.heap_lock()
     try:
         # This works as is because traceback is not allocated
         # if not possible (heap is locked, no memory). If heap
@@ -16,8 +24,8 @@ def func():
         raise e
     except Exception as e2:
         print(e2)
+    micropython.heap_unlock()
+
 
-micropython.heap_lock()
 func()
 print("ok")
-micropython.heap_unlock()
