@@ -1,9 +1,9 @@
 # test that we can generate a traceback without allocating
 
-import micropython
 import sys
+
 try:
-    import uio
+    import io, micropython
 except ImportError:
     print("SKIP")
     raise SystemExit
@@ -15,24 +15,26 @@ try:
 except:
     pass
 
+
 def test():
+    micropython.heap_lock()
     global global_exc
     global_exc.__traceback__ = None
     try:
         raise global_exc
     except StopIteration:
-        print('StopIteration')
+        print("StopIteration")
+    micropython.heap_unlock()
+
 
 # call test() with heap allocation disabled
-micropython.heap_lock()
 test()
-micropython.heap_unlock()
 
 # print the exception that was raised
-buf = uio.StringIO()
+buf = io.StringIO()
 sys.print_exception(global_exc, buf)
 for l in buf.getvalue().split("\n"):
-    # uPy on pyboard prints <stdin> as file, so remove filename.
+    # MicroPython on pyboard prints <stdin> as file, so remove filename.
     if l.startswith("  File "):
         l = l.split('"')
         print(l[0], l[2])
