@@ -1,4 +1,10 @@
-import micropython as micropython
+# test micropython.opt_level()
+
+try:
+    import micropython
+except ImportError:
+    print("SKIP")
+    raise SystemExit
 
 # check we can get and set the level
 micropython.opt_level(0)
