@@ -1,8 +1,8 @@
 # tests for things that are not implemented, or have non-compliant behaviour
 
 try:
-    import uarray as array
-    import ustruct
+    import array
+    import struct
 except ImportError:
     print("SKIP")
     raise SystemExit
@@ -39,7 +39,7 @@ try:
 except NotImplementedError:
     print("NotImplementedError")
 
-# uPy raises TypeError, shold be ValueError
+# MicroPython raises TypeError, should be ValueError
 try:
     "%c" % b"\x01\x02"
 except (TypeError, ValueError):
@@ -63,12 +63,6 @@ try:
 except NotImplementedError:
     print("NotImplementedError")
 
-# str.endswith(s, start) not implemented
-try:
-    "abc".endswith("c", 1)
-except NotImplementedError:
-    print("NotImplementedError")
-
 # str subscr with step!=1 not implemented
 try:
     print("abc"[1:2:3])
@@ -105,11 +99,11 @@ try:
 except NotImplementedError:
     print("NotImplementedError")
 
-# struct pack with too many args, not checked by uPy
-print(ustruct.pack("bb", 1, 2, 3))
+# struct pack with too many args, not checked by MicroPython
+print(struct.pack("bb", 1, 2, 3))
 
-# struct pack with too few args, not checked by uPy
-print(ustruct.pack("bb", 1))
+# struct pack with too few args, not checked by MicroPython
+print(struct.pack("bb", 1))
 
 # array slice assignment with unsupported RHS
 try:
