@@ -10,10 +10,9 @@ import sys
 import argparse
 from glob import glob
 
-sys.path.append("../tools")
-import pyboard
+run_tests_module = __import__("run-tests")
 
-prepare_script_for_target = __import__("run-tests").prepare_script_for_target
+prepare_script_for_target = run_tests_module.prepare_script_for_target
 
 # Paths for host executables
 if os.name == "nt":
@@ -45,12 +44,12 @@ def run_script_on_target(target, script):
     output = b""
     err = None
 
-    if isinstance(target, pyboard.Pyboard):
+    if hasattr(target, "enter_raw_repl"):
         # Run via pyboard interface
         try:
             target.enter_raw_repl()
             output = target.exec_(script)
-        except pyboard.PyboardError as er:
+        except run_tests_module.pyboard.PyboardError as er:
             err = er
     else:
         # Run local executable
@@ -90,9 +89,9 @@ def run_benchmark_on_target(target, script):
 
 
 def run_benchmarks(args, target, param_n, param_m, n_average, test_list):
+    test_results = []
     skip_complex = run_feature_test(target, "complex") != "complex"
     skip_native = run_feature_test(target, "native_check") != "native"
-    target_had_error = False
 
     for test_file in sorted(test_list):
         print(test_file + ": ", end="")
@@ -105,12 +104,14 @@ def run_benchmarks(args, target, param_n, param_m, n_average, test_list):
             and test_file.find("viper_") != -1
         )
         if skip:
+            test_results.append((test_file, "skip", ""))
             print("SKIP")
             continue
 
         # Create test script
+        test_script = b"import sys\nsys.path.remove('')\n\n"
         with open(test_file, "rb") as f:
-            test_script = f.read()
+            test_script += f.read()
         with open(BENCH_SCRIPT_DIR + "benchrun.py", "rb") as f:
             test_script += f.read()
         test_script += b"bm_run(%u, %u)\n" % (param_n, param_m)
@@ -121,9 +122,10 @@ def run_benchmarks(args, target, param_n, param_m, n_average, test_list):
                 f.write(test_script)
 
         # Process script through mpy-cross if needed
-        if isinstance(target, pyboard.Pyboard) or args.via_mpy:
+        if hasattr(target, "enter_raw_repl") or args.via_mpy:
             crash, test_script_target = prepare_script_for_target(args, script_text=test_script)
             if crash:
+                test_results.append((test_file, "fail", "preparation"))
                 print("CRASH:", test_script_target)
                 continue
         else:
@@ -161,10 +163,13 @@ def run_benchmarks(args, target, param_n, param_m, n_average, test_list):
                 error = "FAIL truth"
 
         if error is not None:
-            if not error.startswith("SKIP"):
-                target_had_error = True
+            if error.startswith("SKIP"):
+                test_results.append((test_file, "skip", error))
+            else:
+                test_results.append((test_file, "fail", error))
             print(error)
         else:
+            test_results.append((test_file, "pass", ""))
             t_avg, t_sd = compute_stats(times)
             s_avg, s_sd = compute_stats(scores)
             print(
@@ -178,7 +183,7 @@ def run_benchmarks(args, target, param_n, param_m, n_average, test_list):
 
         sys.stdout.flush()
 
-    return target_had_error
+    return test_results
 
 
 def parse_output(filename):
@@ -189,7 +194,13 @@ def parse_output(filename):
         m = int(m.split("=")[1])
         data = []
         for l in f:
-            if ": " in l and ": SKIP" not in l and "CRASH: " not in l:
+            if (
+                ": " in l
+                and ": SKIP" not in l
+                and "CRASH: " not in l
+                and "skipped: " not in l
+                and "failed: " not in l
+            ):
                 name, values = l.strip().split(": ")
                 values = tuple(float(v) for v in values.split())
                 data.append((name,) + values)
@@ -245,17 +256,17 @@ def compute_diff(file1, file2, diff_score):
 def main():
     cmd_parser = argparse.ArgumentParser(description="Run benchmarks for MicroPython")
     cmd_parser.add_argument(
-        "-t", "--diff-time", action="store_true", help="diff time outputs from a previous run"
+        "-m", "--diff-time", action="store_true", help="diff time outputs from a previous run"
     )
     cmd_parser.add_argument(
         "-s", "--diff-score", action="store_true", help="diff score outputs from a previous run"
     )
     cmd_parser.add_argument(
-        "-p", "--pyboard", action="store_true", help="run tests via pyboard.py"
-    )
-    cmd_parser.add_argument(
-        "-d", "--device", default="/dev/ttyACM0", help="the device for pyboard.py"
+        "-t", "--test-instance", default="unix", help="the MicroPython instance to test"
     )
+    cmd_parser.add_argument("--baudrate", default=115200, help="baud rate of the serial device")
+    cmd_parser.add_argument("--user", default="micro", help="telnet login username")
+    cmd_parser.add_argument("--password", default="python", help="telnet login password")
     cmd_parser.add_argument("-a", "--average", default="8", help="averaging number")
     cmd_parser.add_argument(
         "--emit", default="bytecode", help="MicroPython emitter to use (bytecode or native)"
@@ -263,6 +274,12 @@ def main():
     cmd_parser.add_argument("--heapsize", help="heapsize to use (use default if not specified)")
     cmd_parser.add_argument("--via-mpy", action="store_true", help="compile code to .mpy first")
     cmd_parser.add_argument("--mpy-cross-flags", default="", help="flags to pass to mpy-cross")
+    cmd_parser.add_argument(
+        "-r",
+        "--result-dir",
+        default=run_tests_module.base_path("results"),
+        help="directory for test results",
+    )
     cmd_parser.add_argument(
         "N", nargs=1, help="N parameter (approximate target CPU frequency in MHz)"
     )
@@ -281,15 +298,18 @@ def main():
     M = int(args.M[0])
     n_average = int(args.average)
 
-    if args.pyboard:
-        if not args.mpy_cross_flags:
-            args.mpy_cross_flags = "-march=armv7m"
-        target = pyboard.Pyboard(args.device)
-        target.enter_raw_repl()
-    else:
+    target = run_tests_module.get_test_instance(
+        args.test_instance, args.baudrate, args.user, args.password
+    )
+    if target is None:
+        # Use the unix port of MicroPython.
         target = [MICROPYTHON, "-X", "emit=" + args.emit]
         if args.heapsize is not None:
             target.extend(["-X", "heapsize=" + args.heapsize])
+    else:
+        # Use a remote target.
+        if not args.mpy_cross_flags:
+            args.mpy_cross_flags = "-march=armv7m"
 
     if len(args.files) == 0:
         tests_skip = ("benchrun.py",)
@@ -306,13 +326,15 @@ def main():
 
     print("N={} M={} n_average={}".format(N, M, n_average))
 
-    target_had_error = run_benchmarks(args, target, N, M, n_average, tests)
+    os.makedirs(args.result_dir, exist_ok=True)
+    test_results = run_benchmarks(args, target, N, M, n_average, tests)
+    res = run_tests_module.create_test_report(args, test_results)
 
-    if isinstance(target, pyboard.Pyboard):
+    if hasattr(target, "exit_raw_repl"):
         target.exit_raw_repl()
         target.close()
 
-    if target_had_error:
+    if not res:
         sys.exit(1)
 
 
