@@ -34,7 +34,6 @@ import subprocess
 
 # Relative to top-level repo dir.
 PATHS = [
-    # C
     "drivers/ninaw10/*.[ch]",
     "extmod/*.[ch]",
     "extmod/btstack/*.[ch]",
@@ -47,14 +46,6 @@ PATHS = [
     "mpy-cross/*.[ch]",
     "ports/**/*.[ch]",
     "py/*.[ch]",
-    # Python
-    "drivers/**/*.py",
-    "examples/**/*.py",
-    "extmod/**/*.py",
-    "ports/**/*.py",
-    "py/**/*.py",
-    "tools/**/*.py",
-    "tests/**/*.py",
 ]
 
 EXCLUSIONS = [
@@ -68,35 +59,24 @@ EXCLUSIONS = [
     "ports/nrf/drivers/*.[ch]",
     "ports/nrf/modules/ble/*.[ch]",
     "ports/nrf/modules/board/*.[ch]",
-    "ports/nrf/modules/machine/*.[ch]",
     "ports/nrf/modules/music/*.[ch]",
     "ports/nrf/modules/ubluepy/*.[ch]",
     "ports/nrf/modules/os/*.[ch]",
-    "ports/nrf/modules/time/*.[ch]",
     # STM32 USB dev/host code is mostly 3rd party.
     "ports/stm32/usbdev/**/*.[ch]",
     "ports/stm32/usbhost/**/*.[ch]",
-    # Teensy core code is 3rd party.
-    "ports/teensy/core/*.[ch]",
     # STM32 build includes generated Python code.
     "ports/*/build*",
-    # not real python files
-    "tests/**/repl_*.py",
-    # needs careful attention before applying automatic formatting
-    "tests/basics/*.py",
 ]
 
 # Path to repo top-level dir.
 TOP = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
 
 UNCRUSTIFY_CFG = os.path.join(TOP, "tools/uncrustify.cfg")
-PYPROJECT_TOML = os.path.join(TOP, "pyproject.toml")
 
-C_EXTS = (
-    ".c",
-    ".h",
-)
-PY_EXTS = (".py",)
+
+class IndentationError(ValueError):
+    pass
 
 
 def list_files(paths, exclusions=None, prefix=""):
@@ -116,36 +96,39 @@ def fixup_c(filename):
     # Write out file with fixups.
     with open(filename, "w", newline="") as f:
         dedent_stack = []
-        while lines:
-            # Get next line.
-            l = lines.pop(0)
-
+        for line_number, line in enumerate(lines, 1):
             # Dedent #'s to match indent of following line (not previous line).
-            m = re.match(r"( +)#(if |ifdef |ifndef |elif |else|endif)", l)
+            m = re.match(r"( +)#(if |ifdef |ifndef |elif |else|endif)", line)
             if m:
                 indent = len(m.group(1))
                 directive = m.group(2)
                 if directive in ("if ", "ifdef ", "ifndef "):
-                    l_next = lines[0]
-                    indent_next = len(re.match(r"( *)", l_next).group(1))
-                    if indent - 4 == indent_next and re.match(r" +(} else |case )", l_next):
+                    # Line numbers are 1-based, and lists are always 0-based,
+                    # thus this retrieves the next line, not the current one
+                    line_next = lines[line_number]
+                    indent_next = len(re.match(r"( *)", line_next).group(1))
+                    if indent - 4 == indent_next and re.match(r" +(} else |case )", line_next):
                         # This #-line (and all associated ones) needs dedenting by 4 spaces.
-                        l = l[4:]
+                        line = line[4:]
                         dedent_stack.append(indent - 4)
                     else:
                         # This #-line does not need dedenting.
                         dedent_stack.append(-1)
                 else:
+                    if len(dedent_stack) == 0:
+                        raise IndentationError(
+                            f'dedent stack is empty for "{directive}" at {filename}:{line_number}'
+                        )
                     if dedent_stack[-1] >= 0:
                         # This associated #-line needs dedenting to match the #if.
                         indent_diff = indent - dedent_stack[-1]
                         assert indent_diff >= 0
-                        l = l[indent_diff:]
+                        line = line[indent_diff:]
                     if directive == "endif":
                         dedent_stack.pop()
 
             # Write out line.
-            f.write(l)
+            f.write(line)
 
         assert not dedent_stack, filename
 
@@ -184,16 +167,11 @@ def main():
     else:
         files = list_files(PATHS, EXCLUSIONS, TOP)
 
-    # Extract files matching a specific language.
-    def lang_files(exts):
-        for file in files:
-            if os.path.splitext(file)[1].lower() in exts:
-                yield file
-
     # Run tool on N files at a time (to avoid making the command line too long).
-    def batch(cmd, files, N=200):
+    def batch(cmd, N=200):
+        files_iter = iter(files)
         while True:
-            file_args = list(itertools.islice(files, N))
+            file_args = list(itertools.islice(files_iter, N))
             if not file_args:
                 break
             subprocess.check_call(cmd + file_args)
@@ -203,18 +181,19 @@ def main():
         command = ["uncrustify", "-c", UNCRUSTIFY_CFG, "-lC", "--no-backup"]
         if not args.v:
             command.append("-q")
-        batch(command, lang_files(C_EXTS))
-        for file in lang_files(C_EXTS):
+        batch(command)
+        for file in files:
             fixup_c(file)
 
-    # Format Python files with black.
+    # Format Python files with "ruff format" (using config in pyproject.toml).
     if format_py:
-        command = ["black", "--fast", "--config={}".format(PYPROJECT_TOML)]
+        command = ["ruff", "format"]
         if args.v:
             command.append("-v")
         else:
             command.append("-q")
-        batch(command, lang_files(PY_EXTS))
+        command.append(".")
+        subprocess.check_call(command, cwd=TOP)
 
 
 if __name__ == "__main__":
