@@ -35,62 +35,59 @@
 # Once the API is stabilised, the idea is that mpremote can be used both
 # as a command line tool and a library for interacting with devices.
 
-import ast, io, errno, os, re, struct, sys, time
-from collections import namedtuple
-from errno import EPERM
+import ast, io, os, re, struct, sys, time
+import serial
+import serial.tools.list_ports
+from errno import EPERM, ENOTTY
 from .console import VT_ENABLED
-from .transport import TransportError, Transport
+from .transport import TransportError, TransportExecError, Transport
 
 
-def stdout_write_bytes(b):
-    b = b.replace(b"\x04", b"")
-    sys.stdout.buffer.write(b)
-    sys.stdout.buffer.flush()
-
-
-listdir_result = namedtuple("dir_result", ["name", "st_mode", "st_ino", "st_size"])
-
-
-def reraise_filesystem_error(e, info):
-    if len(e.args) >= 3:
-        if b"OSError" in e.args[2] and b"ENOENT" in e.args[2]:
-            raise FileNotFoundError(info)
-    raise
+VID_SILICON_LABS = 0x10C4
 
 
 class SerialTransport(Transport):
-    def __init__(self, device, baudrate=115200, wait=0, exclusive=True):
+    fs_hook_mount = "/remote"  # MUST match the mount point in fs_hook_code
+
+    def __init__(self, device, baudrate=115200, wait=0, exclusive=True, timeout=None):
         self.in_raw_repl = False
         self.use_raw_paste = True
         self.device_name = device
         self.mounted = False
 
-        import serial
-        import serial.tools.list_ports
-
         # Set options, and exclusive if pyserial supports it
-        serial_kwargs = {"baudrate": baudrate, "interCharTimeout": 1}
+        serial_kwargs = {
+            "baudrate": baudrate,
+            "timeout": timeout,
+            "interCharTimeout": 1,
+        }
         if serial.__version__ >= "3.3":
             serial_kwargs["exclusive"] = exclusive
 
         delayed = False
         for attempt in range(wait + 1):
             try:
-                if device.startswith("rfc2217://"):
-                    self.serial = serial.serial_for_url(device, **serial_kwargs)
-                elif os.name == "nt":
-                    self.serial = serial.Serial(**serial_kwargs)
-                    self.serial.port = device
+                self.serial = serial.serial_for_url(device, do_not_open=True, **serial_kwargs)
+                if os.name == "nt":
                     portinfo = list(serial.tools.list_ports.grep(device))  # type: ignore
-                    if portinfo and portinfo[0].manufacturer != "Microsoft":
-                        # ESP8266/ESP32 boards use RTS/CTS for flashing and boot mode selection.
-                        # DTR False: to avoid using the reset button will hang the MCU in bootloader mode
-                        # RTS False: to prevent pulses on rts on serial.close() that would POWERON_RESET an ESPxx
-                        self.serial.dtr = False  # DTR False = gpio0 High = Normal boot
-                        self.serial.rts = False  # RTS False = EN High = MCU enabled
+                    if portinfo and getattr(portinfo[0], "vid", None) == VID_SILICON_LABS:
+                        # Silicon Labs CP210x driver on Windows has a quirk
+                        # where after a power on reset it will set DTR and RTS
+                        # at different times when the port is opened (it doesn't
+                        # happen on subsequent openings).
+                        #
+                        # To avoid issues with spurious reset on Espressif boards we clear DTR and RTS,
+                        # open the port, and then set them in an order which prevents triggering a reset.
+                        self.serial.dtr = False
+                        self.serial.rts = False
+                        self.serial.open()
+                        self.serial.dtr = True
+                        self.serial.rts = True
+
+                # On all other host/driver combinations we keep the default
+                # behaviour (pyserial will set DTR and RTS automatically on open)
+                if not self.serial.isOpen():
                     self.serial.open()
-                else:
-                    self.serial = serial.Serial(device, **serial_kwargs)
                 break
             except OSError:
                 if wait == 0:
@@ -109,16 +106,37 @@ class SerialTransport(Transport):
             print("")
 
     def close(self):
+        # ESP Windows quirk: Prevent target from resetting when Windows clears DTR before RTS
+        try:
+            self.serial.rts = False
+            self.serial.dtr = False
+        except OSError as er:
+            if er.errno == ENOTTY:
+                # Some devices (like QEMU pts) don't support RTS/DTR control
+                pass
+            else:
+                raise er
         self.serial.close()
 
-    def read_until(self, min_num_bytes, ending, timeout=10, data_consumer=None):
-        # if data_consumer is used then data is not accumulated and the ending must be 1 byte long
-        assert data_consumer is None or len(ending) == 1
+    def read_until(
+        self, min_num_bytes, ending, timeout=10, data_consumer=None, timeout_overall=None
+    ):
+        """
+        min_num_bytes: Obsolete.
+        ending: Return if 'ending' matches.
+        timeout [s]: Return if timeout between characters. None: Infinite timeout.
+        timeout_overall [s]: Return not later than timeout_overall. None: Infinite timeout.
+        data_consumer: Use callback for incoming characters.
+            If data_consumer is used then data is not accumulated and the ending must be 1 byte long
 
-        data = self.serial.read(min_num_bytes)
-        if data_consumer:
-            data_consumer(data)
-        timeout_count = 0
+        It is not visible to the caller why the function returned. It could be ending or timeout.
+        """
+        assert data_consumer is None or len(ending) == 1
+        assert isinstance(timeout, (type(None), int, float))
+        assert isinstance(timeout_overall, (type(None), int, float))
+
+        data = b""
+        begin_overall_s = begin_char_s = time.monotonic()
         while True:
             if data.endswith(ending):
                 break
@@ -129,16 +147,20 @@ class SerialTransport(Transport):
                     data = new_data
                 else:
                     data = data + new_data
-                timeout_count = 0
+                begin_char_s = time.monotonic()
             else:
-                timeout_count += 1
-                if timeout is not None and timeout_count >= 100 * timeout:
+                if timeout is not None and time.monotonic() >= begin_char_s + timeout:
+                    break
+                if (
+                    timeout_overall is not None
+                    and time.monotonic() >= begin_overall_s + timeout_overall
+                ):
                     break
                 time.sleep(0.01)
         return data
 
-    def enter_raw_repl(self, soft_reset=True):
-        self.serial.write(b"\r\x03\x03")  # ctrl-C twice: interrupt any running program
+    def enter_raw_repl(self, soft_reset=True, timeout_overall=10):
+        self.serial.write(b"\r\x03")  # ctrl-C: interrupt any running program
 
         # flush input (without relying on serial.flushInput())
         n = self.serial.inWaiting()
@@ -149,7 +171,9 @@ class SerialTransport(Transport):
         self.serial.write(b"\r\x01")  # ctrl-A: enter raw REPL
 
         if soft_reset:
-            data = self.read_until(1, b"raw REPL; CTRL-B to exit\r\n>")
+            data = self.read_until(
+                1, b"raw REPL; CTRL-B to exit\r\n>", timeout_overall=timeout_overall
+            )
             if not data.endswith(b"raw REPL; CTRL-B to exit\r\n>"):
                 print(data)
                 raise TransportError("could not enter raw repl")
@@ -159,12 +183,12 @@ class SerialTransport(Transport):
             # Waiting for "soft reboot" independently to "raw REPL" (done below)
             # allows boot.py to print, which will show up after "soft reboot"
             # and before "raw REPL".
-            data = self.read_until(1, b"soft reboot\r\n")
+            data = self.read_until(1, b"soft reboot\r\n", timeout_overall=timeout_overall)
             if not data.endswith(b"soft reboot\r\n"):
                 print(data)
                 raise TransportError("could not enter raw repl")
 
-        data = self.read_until(1, b"raw REPL; CTRL-B to exit\r\n")
+        data = self.read_until(1, b"raw REPL; CTRL-B to exit\r\n", timeout_overall=timeout_overall)
         if not data.endswith(b"raw REPL; CTRL-B to exit\r\n"):
             print(data)
             raise TransportError("could not enter raw repl")
@@ -271,7 +295,7 @@ class SerialTransport(Transport):
         self.exec_raw_no_follow(command)
         return self.follow(timeout, data_consumer)
 
-    def eval(self, expression, parse=False):
+    def eval(self, expression, parse=True):
         if parse:
             ret = self.exec("print(repr({}))".format(expression))
             ret = ret.strip()
@@ -284,7 +308,7 @@ class SerialTransport(Transport):
     def exec(self, command, data_consumer=None):
         ret, ret_err = self.exec_raw(command, data_consumer=data_consumer)
         if ret_err:
-            raise TransportError("exception", ret, ret_err)
+            raise TransportExecError(ret, ret_err.decode())
         return ret
 
     def execfile(self, filename):
@@ -292,218 +316,9 @@ class SerialTransport(Transport):
             pyfile = f.read()
         return self.exec(pyfile)
 
-    def fs_exists(self, src):
-        try:
-            self.exec("import os\nos.stat(%s)" % (("'%s'" % src) if src else ""))
-            return True
-        except TransportError:
-            return False
-
-    def fs_ls(self, src):
-        cmd = (
-            "import os\nfor f in os.ilistdir(%s):\n"
-            " print('{:12} {}{}'.format(f[3]if len(f)>3 else 0,f[0],'/'if f[1]&0x4000 else ''))"
-            % (("'%s'" % src) if src else "")
-        )
-        self.exec(cmd, data_consumer=stdout_write_bytes)
-
-    def fs_listdir(self, src=""):
-        buf = bytearray()
-
-        def repr_consumer(b):
-            buf.extend(b.replace(b"\x04", b""))
-
-        cmd = "import os\nfor f in os.ilistdir(%s):\n" " print(repr(f), end=',')" % (
-            ("'%s'" % src) if src else ""
-        )
-        try:
-            buf.extend(b"[")
-            self.exec(cmd, data_consumer=repr_consumer)
-            buf.extend(b"]")
-        except TransportError as e:
-            reraise_filesystem_error(e, src)
-
-        return [
-            listdir_result(*f) if len(f) == 4 else listdir_result(*(f + (0,)))
-            for f in ast.literal_eval(buf.decode())
-        ]
-
-    def fs_stat(self, src):
-        try:
-            self.exec("import os")
-            return os.stat_result(self.eval("os.stat(%s)" % ("'%s'" % src), parse=True))
-        except TransportError as e:
-            reraise_filesystem_error(e, src)
-
-    def fs_cat(self, src, chunk_size=256):
-        cmd = (
-            "with open('%s') as f:\n while 1:\n"
-            "  b=f.read(%u)\n  if not b:break\n  print(b,end='')" % (src, chunk_size)
-        )
-        self.exec(cmd, data_consumer=stdout_write_bytes)
-
-    def fs_readfile(self, src, chunk_size=256):
-        buf = bytearray()
-
-        def repr_consumer(b):
-            buf.extend(b.replace(b"\x04", b""))
-
-        cmd = (
-            "with open('%s', 'rb') as f:\n while 1:\n"
-            "  b=f.read(%u)\n  if not b:break\n  print(b,end='')" % (src, chunk_size)
-        )
-        try:
-            self.exec(cmd, data_consumer=repr_consumer)
-        except TransportError as e:
-            reraise_filesystem_error(e, src)
-        return ast.literal_eval(buf.decode())
-
-    def fs_writefile(self, dest, data, chunk_size=256):
-        self.exec("f=open('%s','wb')\nw=f.write" % dest)
-        while data:
-            chunk = data[:chunk_size]
-            self.exec("w(" + repr(chunk) + ")")
-            data = data[len(chunk) :]
-        self.exec("f.close()")
-
-    def fs_cp(self, src, dest, chunk_size=256, progress_callback=None):
-        if progress_callback:
-            src_size = self.fs_stat(src).st_size
-            written = 0
-        self.exec("fr=open('%s','rb')\nr=fr.read\nfw=open('%s','wb')\nw=fw.write" % (src, dest))
-        while True:
-            data_len = int(self.exec("d=r(%u)\nw(d)\nprint(len(d))" % chunk_size))
-            if not data_len:
-                break
-            if progress_callback:
-                written += data_len
-                progress_callback(written, src_size)
-        self.exec("fr.close()\nfw.close()")
-
-    def fs_get(self, src, dest, chunk_size=256, progress_callback=None):
-        if progress_callback:
-            src_size = self.fs_stat(src).st_size
-            written = 0
-        self.exec("f=open('%s','rb')\nr=f.read" % src)
-        with open(dest, "wb") as f:
-            while True:
-                data = bytearray()
-                self.exec("print(r(%u))" % chunk_size, data_consumer=lambda d: data.extend(d))
-                assert data.endswith(b"\r\n\x04")
-                try:
-                    data = ast.literal_eval(str(data[:-3], "ascii"))
-                    if not isinstance(data, bytes):
-                        raise ValueError("Not bytes")
-                except (UnicodeError, ValueError) as e:
-                    raise TransportError("fs_get: Could not interpret received data: %s" % str(e))
-                if not data:
-                    break
-                f.write(data)
-                if progress_callback:
-                    written += len(data)
-                    progress_callback(written, src_size)
-        self.exec("f.close()")
-
-    def fs_put(self, src, dest, chunk_size=256, progress_callback=None):
-        if progress_callback:
-            src_size = os.path.getsize(src)
-            written = 0
-        self.exec("f=open('%s','wb')\nw=f.write" % dest)
-        with open(src, "rb") as f:
-            while True:
-                data = f.read(chunk_size)
-                if not data:
-                    break
-                if sys.version_info < (3,):
-                    self.exec("w(b" + repr(data) + ")")
-                else:
-                    self.exec("w(" + repr(data) + ")")
-                if progress_callback:
-                    written += len(data)
-                    progress_callback(written, src_size)
-        self.exec("f.close()")
-
-    def fs_mkdir(self, dir):
-        self.exec("import os\nos.mkdir('%s')" % dir)
-
-    def fs_rmdir(self, dir):
-        self.exec("import os\nos.rmdir('%s')" % dir)
-
-    def fs_rm(self, src):
-        self.exec("import os\nos.remove('%s')" % src)
-
-    def fs_touch(self, src):
-        self.exec("f=open('%s','a')\nf.close()" % src)
-
-    def filesystem_command(self, args, progress_callback=None, verbose=False):
-        def fname_remote(src):
-            if src.startswith(":"):
-                src = src[1:]
-            # Convert all path separators to "/", because that's what a remote device uses.
-            return src.replace(os.path.sep, "/")
-
-        def fname_cp_dest(src, dest):
-            _, src = os.path.split(src)
-            if dest is None or dest == "":
-                dest = src
-            elif dest == ".":
-                dest = "./" + src
-            elif dest.endswith("/"):
-                dest += src
-            return dest
-
-        cmd = args[0]
-        args = args[1:]
-        try:
-            if cmd == "cp":
-                srcs = args[:-1]
-                dest = args[-1]
-                if dest.startswith(":"):
-                    op_remote_src = self.fs_cp
-                    op_local_src = self.fs_put
-                else:
-                    op_remote_src = self.fs_get
-                    op_local_src = lambda src, dest, **_: __import__("shutil").copy(src, dest)
-                for src in srcs:
-                    if verbose:
-                        print("cp %s %s" % (src, dest))
-                    if src.startswith(":"):
-                        op = op_remote_src
-                    else:
-                        op = op_local_src
-                    src2 = fname_remote(src)
-                    dest2 = fname_cp_dest(src2, fname_remote(dest))
-                    op(src2, dest2, progress_callback=progress_callback)
-            else:
-                ops = {
-                    "cat": self.fs_cat,
-                    "ls": self.fs_ls,
-                    "mkdir": self.fs_mkdir,
-                    "rm": self.fs_rm,
-                    "rmdir": self.fs_rmdir,
-                    "touch": self.fs_touch,
-                }
-                if cmd not in ops:
-                    raise TransportError("'{}' is not a filesystem command".format(cmd))
-                if cmd == "ls" and not args:
-                    args = [""]
-                for src in args:
-                    src = fname_remote(src)
-                    if verbose:
-                        print("%s :%s" % (cmd, src))
-                    ops[cmd](src)
-        except TransportError as er:
-            if len(er.args) > 1:
-                print(str(er.args[2], "ascii"))
-            else:
-                print(er)
-            self.exit_raw_repl()
-            self.close()
-            sys.exit(1)
-
     def mount_local(self, path, unsafe_links=False):
         fout = self.serial
-        if self.eval('"RemoteFS" in globals()') == b"False":
+        if not self.eval('"RemoteFS" in globals()'):
             self.exec(fs_hook_code)
         self.exec("__mount()")
         self.mounted = True
@@ -580,7 +395,11 @@ class SerialTransport(Transport):
         self.serial = self.serial.orig_serial
 
         # Provide a message about the remount.
-        out_callback(bytes(f"\r\nRemount local directory {self.cmd.root} at /remote\r\n", "utf8"))
+        out_callback(
+            bytes(
+                f"\r\nRemount local directory {self.cmd.root} at {self.fs_hook_mount}\r\n", "utf8"
+            )
+        )
 
         # Enter raw REPL and re-mount the remote filesystem.
         self.serial.write(b"\x01")
@@ -597,7 +416,7 @@ class SerialTransport(Transport):
 
     def umount_local(self):
         if self.mounted:
-            self.exec('os.umount("/remote")')
+            self.exec(f'os.umount("{self.fs_hook_mount}")')
             self.mounted = False
             self.serial = self.serial.orig_serial
 
@@ -609,15 +428,16 @@ fs_hook_cmds = {
     "CMD_OPEN": 4,
     "CMD_CLOSE": 5,
     "CMD_READ": 6,
-    "CMD_WRITE": 7,
-    "CMD_SEEK": 8,
-    "CMD_REMOVE": 9,
-    "CMD_RENAME": 10,
-    "CMD_MKDIR": 11,
-    "CMD_RMDIR": 12,
+    "CMD_READLINE": 7,
+    "CMD_WRITE": 8,
+    "CMD_SEEK": 9,
+    "CMD_REMOVE": 10,
+    "CMD_RENAME": 11,
+    "CMD_MKDIR": 12,
+    "CMD_RMDIR": 13,
 }
 
-fs_hook_code = """\
+fs_hook_code = f"""\
 import os, io, struct, micropython
 
 SEEK_SET = 0
@@ -797,12 +617,16 @@ class RemoteFile(io.IOBase):
         return n
 
     def readline(self):
-        l = ''
-        while 1:
-            c = self.read(1)
-            l += c
-            if c == '\\n' or c == '':
-                return l
+        c = self.cmd
+        c.begin(CMD_READLINE)
+        c.wr_s8(self.fd)
+        data = c.rd_bytes(None)
+        c.end()
+        if self.is_text:
+            data = str(data, 'utf8')
+        else:
+            data = bytes(data)
+        return data
 
     def readlines(self):
         ls = []
@@ -838,6 +662,9 @@ class RemoteFS:
     def __init__(self, cmd):
         self.cmd = cmd
 
+    def _abspath(self, path):
+        return path if path.startswith("/") else self.path + path
+
     def mount(self, readonly, mkfs):
         pass
 
@@ -859,7 +686,7 @@ class RemoteFS:
     def remove(self, path):
         c = self.cmd
         c.begin(CMD_REMOVE)
-        c.wr_str(self.path + path)
+        c.wr_str(self._abspath(path))
         res = c.rd_s32()
         c.end()
         if res < 0:
@@ -868,8 +695,8 @@ class RemoteFS:
     def rename(self, old, new):
         c = self.cmd
         c.begin(CMD_RENAME)
-        c.wr_str(self.path + old)
-        c.wr_str(self.path + new)
+        c.wr_str(self._abspath(old))
+        c.wr_str(self._abspath(new))
         res = c.rd_s32()
         c.end()
         if res < 0:
@@ -878,7 +705,7 @@ class RemoteFS:
     def mkdir(self, path):
         c = self.cmd
         c.begin(CMD_MKDIR)
-        c.wr_str(self.path + path)
+        c.wr_str(self._abspath(path))
         res = c.rd_s32()
         c.end()
         if res < 0:
@@ -887,7 +714,7 @@ class RemoteFS:
     def rmdir(self, path):
         c = self.cmd
         c.begin(CMD_RMDIR)
-        c.wr_str(self.path + path)
+        c.wr_str(self._abspath(path))
         res = c.rd_s32()
         c.end()
         if res < 0:
@@ -896,7 +723,7 @@ class RemoteFS:
     def stat(self, path):
         c = self.cmd
         c.begin(CMD_STAT)
-        c.wr_str(self.path + path)
+        c.wr_str(self._abspath(path))
         res = c.rd_s8()
         if res < 0:
             c.end()
@@ -912,7 +739,7 @@ class RemoteFS:
     def ilistdir(self, path):
         c = self.cmd
         c.begin(CMD_ILISTDIR_START)
-        c.wr_str(self.path + path)
+        c.wr_str(self._abspath(path))
         res = c.rd_s8()
         c.end()
         if res < 0:
@@ -933,7 +760,7 @@ class RemoteFS:
     def open(self, path, mode):
         c = self.cmd
         c.begin(CMD_OPEN)
-        c.wr_str(self.path + path)
+        c.wr_str(self._abspath(path))
         c.wr_str(mode)
         fd = c.rd_s8()
         c.end()
@@ -943,13 +770,12 @@ class RemoteFS:
 
 
 def __mount():
-    os.mount(RemoteFS(RemoteCommand()), '/remote')
-    os.chdir('/remote')
+    os.mount(RemoteFS(RemoteCommand()), '{SerialTransport.fs_hook_mount}')
+    os.chdir('{SerialTransport.fs_hook_mount}')
 """
 
 # Apply basic compression on hook code.
-for key, value in fs_hook_cmds.items():
-    fs_hook_code = re.sub(key, str(value), fs_hook_code)
+fs_hook_code = re.sub(r"CMD_[A-Z_]+", lambda m: str(fs_hook_cmds[m.group(0)]), fs_hook_code)
 fs_hook_code = re.sub(" *#.*$", "", fs_hook_code, flags=re.MULTILINE)
 fs_hook_code = re.sub("\n\n+", "\n", fs_hook_code)
 fs_hook_code = re.sub("    ", " ", fs_hook_code)
@@ -982,7 +808,7 @@ class PyboardCommand:
         if n == 0:
             return ""
         else:
-            return str(self.fin.read(n), "utf8")
+            return str(self.fin.read(n), "utf8", errors="backslashreplace")
 
     def wr_s8(self, i):
         self.fout.write(struct.pack("<b", i))
@@ -1089,6 +915,14 @@ class PyboardCommand:
         self.wr_bytes(buf)
         # self.log_cmd(f"read {fd} {n} -> {len(buf)}")
 
+    def do_readline(self):
+        fd = self.rd_s8()
+        buf = self.data_files[fd][0].readline()
+        if self.data_files[fd][1]:
+            buf = bytes(buf, "utf8")
+        self.wr_bytes(buf)
+        # self.log_cmd(f"readline {fd} -> {len(buf)}")
+
     def do_seek(self):
         fd = self.rd_s8()
         n = self.rd_s32()
@@ -1104,7 +938,7 @@ class PyboardCommand:
         fd = self.rd_s8()
         buf = self.rd_bytes()
         if self.data_files[fd][1]:
-            buf = str(buf, "utf8")
+            buf = str(buf, "utf8", errors="backslashreplace")
         n = self.data_files[fd][0].write(buf)
         self.wr_s32(n)
         # self.log_cmd(f"write {fd} {len(buf)} -> {n}")
@@ -1162,6 +996,7 @@ class PyboardCommand:
         fs_hook_cmds["CMD_OPEN"]: do_open,
         fs_hook_cmds["CMD_CLOSE"]: do_close,
         fs_hook_cmds["CMD_READ"]: do_read,
+        fs_hook_cmds["CMD_READLINE"]: do_readline,
         fs_hook_cmds["CMD_WRITE"]: do_write,
         fs_hook_cmds["CMD_SEEK"]: do_seek,
         fs_hook_cmds["CMD_REMOVE"]: do_remove,
