@@ -24,40 +24,21 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-# Python 2/3 compatibility code
-from __future__ import print_function
-import platform
-
-if platform.python_version_tuple()[0] == "2":
-    from binascii import hexlify as hexlify_py2
-
-    str_cons = lambda val, enc=None: str(val)
-    bytes_cons = lambda val, enc=None: bytearray(val)
-    is_str_type = lambda o: isinstance(o, str)
-    is_bytes_type = lambda o: type(o) is bytearray
-    is_int_type = lambda o: isinstance(o, int) or isinstance(o, long)  # noqa: F821
-
-    def hexlify_to_str(b):
-        x = hexlify_py2(b)
-        return ":".join(x[i : i + 2] for i in range(0, len(x), 2))
-
-else:
-    from binascii import hexlify
-
-    str_cons = str
-    bytes_cons = bytes
-    is_str_type = lambda o: isinstance(o, str)
-    is_bytes_type = lambda o: isinstance(o, bytes)
-    is_int_type = lambda o: isinstance(o, int)
-
-    def hexlify_to_str(b):
-        return str(hexlify(b, ":"), "ascii")
-
-
-# end compatibility code
-
-import sys
+import io
 import struct
+import sys
+from binascii import hexlify
+
+str_cons = str
+bytes_cons = bytes
+is_str_type = lambda o: isinstance(o, str)
+is_bytes_type = lambda o: isinstance(o, bytes)
+is_int_type = lambda o: isinstance(o, int)
+
+
+def hexlify_to_str(b):
+    return str(hexlify(b, ":"), "ascii")
+
 
 sys.path.append(sys.path[0] + "/../py")
 import makeqstrdata as qstrutil
@@ -113,6 +94,24 @@ MP_NATIVE_ARCH_ARMV7EMSP = 7
 MP_NATIVE_ARCH_ARMV7EMDP = 8
 MP_NATIVE_ARCH_XTENSA = 9
 MP_NATIVE_ARCH_XTENSAWIN = 10
+MP_NATIVE_ARCH_RV32IMC = 11
+MP_NATIVE_ARCH_RV64IMC = 12
+
+MP_NATIVE_ARCH_NAMES = [
+    "NONE",
+    "X86",
+    "X64",
+    "ARMV6",
+    "ARMV6M",
+    "ARMV7M",
+    "ARMV7EM",
+    "ARMV7EMSP",
+    "ARMV7EMDP",
+    "XTENSA",
+    "XTENSAWIN",
+    "RV32IMC",
+    "RV64IMC",
+]
 
 MP_PERSISTENT_OBJ_FUN_TABLE = 0
 MP_PERSISTENT_OBJ_NONE = 1
@@ -138,6 +137,8 @@ MP_BC_FORMAT_QSTR = 1
 MP_BC_FORMAT_VAR_UINT = 2
 MP_BC_FORMAT_OFFSET = 3
 
+MP_NATIVE_ARCH_FLAGS_PRESENT = 0x40
+
 mp_unary_op_method_name = (
     "__pos__",
     "__neg__",
@@ -302,6 +303,25 @@ class Opcode:
         MP_BC_POP_JUMP_IF_TRUE,
         MP_BC_POP_JUMP_IF_FALSE,
     )
+    ALL_OFFSET = (
+        MP_BC_UNWIND_JUMP,
+        MP_BC_JUMP,
+        MP_BC_POP_JUMP_IF_TRUE,
+        MP_BC_POP_JUMP_IF_FALSE,
+        MP_BC_JUMP_IF_TRUE_OR_POP,
+        MP_BC_JUMP_IF_FALSE_OR_POP,
+        MP_BC_SETUP_WITH,
+        MP_BC_SETUP_EXCEPT,
+        MP_BC_SETUP_FINALLY,
+        MP_BC_POP_EXCEPT_JUMP,
+        MP_BC_FOR_ITER,
+    )
+    ALL_WITH_CHILD = (
+        MP_BC_MAKE_FUNCTION,
+        MP_BC_MAKE_FUNCTION_DEFARGS,
+        MP_BC_MAKE_CLOSURE,
+        MP_BC_MAKE_CLOSURE_DEFARGS,
+    )
 
     # Create a dict mapping opcode value to opcode name.
     mapping = ["unknown" for _ in range(256)]
@@ -560,6 +580,7 @@ class CompiledModule:
         mpy_source_file,
         mpy_segments,
         header,
+        arch_flags,
         qstr_table,
         obj_table,
         raw_code,
@@ -572,6 +593,7 @@ class CompiledModule:
         self.mpy_segments = mpy_segments
         self.source_file = qstr_table[0]
         self.header = header
+        self.arch_flags = arch_flags
         self.qstr_table = qstr_table
         self.obj_table = obj_table
         self.raw_code = raw_code
@@ -649,6 +671,14 @@ class CompiledModule:
         print("mpy_source_file:", self.mpy_source_file)
         print("source_file:", self.source_file.str)
         print("header:", hexlify_to_str(self.header))
+        arch_index = (self.header[2] >> 2) & 0x2F
+        if arch_index >= len(MP_NATIVE_ARCH_NAMES):
+            arch_name = "UNKNOWN"
+        else:
+            arch_name = MP_NATIVE_ARCH_NAMES[arch_index]
+        print("arch:", arch_name)
+        if self.header[2] & MP_NATIVE_ARCH_FLAGS_PRESENT != 0:
+            print("arch_flags:", hex(self.arch_flags))
         print("qstr_table[%u]:" % len(self.qstr_table))
         for q in self.qstr_table:
             print("    %s" % q.str)
@@ -734,8 +764,8 @@ class CompiledModule:
             elif config.MICROPY_LONGINT_IMPL == config.MICROPY_LONGINT_IMPL_NONE:
                 raise FreezeError(self, "target does not support long int")
             elif config.MICROPY_LONGINT_IMPL == config.MICROPY_LONGINT_IMPL_LONGLONG:
-                # TODO
-                raise FreezeError(self, "freezing int to long-long is not implemented")
+                print("static const mp_obj_int_t %s = {{&mp_type_int}, %d};" % (obj_name, obj))
+                return "MP_ROM_PTR(&%s)" % obj_name
             elif config.MICROPY_LONGINT_IMPL == config.MICROPY_LONGINT_IMPL_MPZ:
                 neg = 0
                 if obj < 0:
@@ -886,7 +916,7 @@ class RawCode(object):
         self.escaped_name = unique_escaped_name
 
     def disassemble_children(self):
-        print("  children:", [rc.simple_name.str for rc in self.children])
+        self.print_children_annotated()
         for rc in self.children:
             rc.disassemble()
 
@@ -975,6 +1005,75 @@ class RawCode(object):
         raw_code_count += 1
         raw_code_content += 4 * 4
 
+    @staticmethod
+    def decode_lineinfo(line_info: memoryview) -> "tuple[int, int, memoryview]":
+        c = line_info[0]
+        if (c & 0x80) == 0:
+            # 0b0LLBBBBB encoding
+            return (c & 0x1F), (c >> 5), line_info[1:]
+        else:
+            # 0b1LLLBBBB 0bLLLLLLLL encoding (l's LSB in second byte)
+            return (c & 0xF), (((c << 4) & 0x700) | line_info[1]), line_info[2:]
+
+    def get_source_annotation(self, ip: int, file=None) -> dict:
+        bc_offset = ip - self.offset_opcodes
+        try:
+            line_info = memoryview(self.fun_data)[self.offset_line_info : self.offset_opcodes]
+        except AttributeError:
+            return {"file": file, "line": None}
+
+        source_line = 1
+        while line_info:
+            bc_increment, line_increment, line_info = self.decode_lineinfo(line_info)
+            if bc_offset >= bc_increment:
+                bc_offset -= bc_increment
+                source_line += line_increment
+            else:
+                break
+
+        return {"file": file, "line": source_line}
+
+    def get_label(self, ip: "int | None" = None, child_num: "int | None" = None) -> str:
+        if ip is not None:
+            assert child_num is None
+            return "%s.%d" % (self.escaped_name, ip)
+        elif child_num is not None:
+            return "%s.child%d" % (self.escaped_name, child_num)
+        else:
+            return "%s" % self.escaped_name
+
+    def print_children_annotated(self) -> None:
+        """
+        Equivalent to `print("  children:", [child.simple_name.str for child in self.children])`,
+        but also includes json markers for the start and end of each one's name in that line.
+        """
+
+        labels = ["%s.children" % self.escaped_name]
+        annotation_labels = []
+        output = io.StringIO()
+        output.write("  children: [")
+        sep = ", "
+        for i, child in enumerate(self.children):
+            if i != 0:
+                output.write(sep)
+            start_col = output.tell() + 1
+            output.write(child.simple_name.str)
+            end_col = output.tell() + 1
+            labels.append(self.get_label(child_num=i))
+            annotation_labels.append(
+                {
+                    "name": self.get_label(child_num=i),
+                    "target": child.get_label(),
+                    "range": {
+                        "startCol": start_col,
+                        "endCol": end_col,
+                    },
+                },
+            )
+        output.write("]")
+
+        print(output.getvalue(), annotations={"labels": annotation_labels}, labels=labels)
+
 
 class RawCodeBytecode(RawCode):
     def __init__(self, parent_name, qstr_table, obj_table, fun_data):
@@ -983,9 +1082,58 @@ class RawCodeBytecode(RawCode):
             parent_name, qstr_table, fun_data, 0, MP_CODE_BYTECODE
         )
 
+    def get_opcode_annotations_labels(
+        self, opcode: int, ip: int, arg: int, sz: int, arg_pos: int, arg_len: int
+    ) -> "tuple[dict, list[str]]":
+        annotations = {
+            "source": self.get_source_annotation(ip),
+            "disassembly": Opcode.mapping[opcode],
+        }
+        labels = [self.get_label(ip)]
+
+        if opcode in Opcode.ALL_OFFSET:
+            annotations["link"] = {
+                "offset": arg_pos,
+                "length": arg_len,
+                "to": ip + arg + sz,
+            }
+            annotations["labels"] = [
+                {
+                    "name": self.get_label(ip),
+                    "target": self.get_label(ip + arg + sz),
+                    "range": {
+                        "startCol": arg_pos + 1,
+                        "endCol": arg_pos + arg_len + 1,
+                    },
+                },
+            ]
+
+        elif opcode in Opcode.ALL_WITH_CHILD:
+            try:
+                child = self.children[arg]
+            except IndexError:
+                # link out-of-range child to the child array itself
+                target = "%s.children" % self.escaped_name
+            else:
+                # link resolvable child to the actual child
+                target = child.get_label()
+
+            annotations["labels"] = [
+                {
+                    "name": self.get_label(ip),
+                    "target": target,
+                    "range": {
+                        "startCol": arg_pos + 1,
+                        "endCol": arg_pos + arg_len + 1,
+                    },
+                },
+            ]
+
+        return annotations, labels
+
     def disassemble(self):
         bc = self.fun_data
-        print("simple_name:", self.simple_name.str)
+        print("simple_name:", self.simple_name.str, labels=[self.get_label()])
         print("  raw bytecode:", len(bc), hexlify_to_str(bc))
         print("  prelude:", self.prelude_signature)
         print("  args:", [self.qstr_table[i].str for i in self.names[1:]])
@@ -1001,9 +1149,22 @@ class RawCodeBytecode(RawCode):
                 pass
             else:
                 arg = ""
-            print(
-                "  %-11s %s %s" % (hexlify_to_str(bc[ip : ip + sz]), Opcode.mapping[bc[ip]], arg)
+
+            pre_arg_part = "  %-11s %s" % (
+                hexlify_to_str(bc[ip : ip + sz]),
+                Opcode.mapping[bc[ip]],
             )
+            arg_part = "%s" % arg
+            annotations, labels = self.get_opcode_annotations_labels(
+                opcode=bc[ip],
+                ip=ip,
+                arg=arg,
+                sz=sz,
+                arg_pos=len(pre_arg_part) + 1,
+                arg_len=len(arg_part),
+            )
+
+            print(pre_arg_part, arg_part, annotations=annotations, labels=labels)
             ip += sz
         self.disassemble_children()
 
@@ -1079,6 +1240,8 @@ class RawCodeNative(RawCode):
             MP_NATIVE_ARCH_X64,
             MP_NATIVE_ARCH_XTENSA,
             MP_NATIVE_ARCH_XTENSAWIN,
+            MP_NATIVE_ARCH_RV32IMC,
+            MP_NATIVE_ARCH_RV64IMC,
         ):
             self.fun_data_attributes = '__attribute__((section(".text,\\"ax\\",@progbits # ")))'
         else:
@@ -1094,13 +1257,15 @@ class RawCodeNative(RawCode):
         ):
             # ARMV6 or Xtensa -- four byte align.
             self.fun_data_attributes += " __attribute__ ((aligned (4)))"
-        elif MP_NATIVE_ARCH_ARMV6M <= config.native_arch <= MP_NATIVE_ARCH_ARMV7EMDP:
-            # ARMVxxM -- two byte align.
+        elif (
+            MP_NATIVE_ARCH_ARMV6M <= config.native_arch <= MP_NATIVE_ARCH_ARMV7EMDP
+        ) or MP_NATIVE_ARCH_RV32IMC <= config.native_arch <= MP_NATIVE_ARCH_RV64IMC:
+            # ARMVxxM or RV{32,64}IMC -- two byte align.
             self.fun_data_attributes += " __attribute__ ((aligned (2)))"
 
     def disassemble(self):
         fun_data = self.fun_data
-        print("simple_name:", self.simple_name.str)
+        print("simple_name:", self.simple_name.str, labels=[self.get_label()])
         print(
             "  raw data:",
             len(fun_data),
@@ -1353,7 +1518,7 @@ def read_mpy(filename):
         if header[1] != config.MPY_VERSION:
             raise MPYReadError(filename, "incompatible .mpy version")
         feature_byte = header[2]
-        mpy_native_arch = feature_byte >> 2
+        mpy_native_arch = (feature_byte >> 2) & 0x2F
         if mpy_native_arch != MP_NATIVE_ARCH_NONE:
             mpy_sub_version = feature_byte & 3
             if mpy_sub_version != config.MPY_SUB_VERSION:
@@ -1364,6 +1529,11 @@ def read_mpy(filename):
                 raise MPYReadError(filename, "native architecture mismatch")
         config.mp_small_int_bits = header[3]
 
+        arch_flags = 0
+        # Read the architecture-specific flag bits if present.
+        if (feature_byte & MP_NATIVE_ARCH_FLAGS_PRESENT) != 0:
+            arch_flags = reader.read_uint()
+
         # Read number of qstrs, and number of objects.
         n_qstr = reader.read_uint()
         n_obj = reader.read_uint()
@@ -1392,6 +1562,7 @@ def read_mpy(filename):
         filename,
         segments,
         header,
+        arch_flags,
         qstr_table,
         obj_table,
         raw_code,
@@ -1687,25 +1858,39 @@ def merge_mpy(compiled_modules, output_file):
             merged_mpy.extend(f.read())
     else:
         main_cm_idx = None
+        arch_flags = 0
         for idx, cm in enumerate(compiled_modules):
             feature_byte = cm.header[2]
-            mpy_native_arch = feature_byte >> 2
+            mpy_native_arch = (feature_byte >> 2) & 0x2F
             if mpy_native_arch:
                 # Must use qstr_table and obj_table from this raw_code
                 if main_cm_idx is not None:
                     raise Exception("can't merge files when more than one contains native code")
                 main_cm_idx = idx
+                arch_flags = cm.arch_flags
         if main_cm_idx is not None:
             # Shift main_cm to front of list.
             compiled_modules.insert(0, compiled_modules.pop(main_cm_idx))
 
+        if config.arch_flags is not None:
+            arch_flags = config.arch_flags
+
         header = bytearray(4)
         header[0] = ord("M")
         header[1] = config.MPY_VERSION
-        header[2] = config.native_arch << 2 | config.MPY_SUB_VERSION if config.native_arch else 0
+        header[2] = (
+            (MP_NATIVE_ARCH_FLAGS_PRESENT if arch_flags != 0 else 0)
+            | config.native_arch << 2
+            | config.MPY_SUB_VERSION
+            if config.native_arch
+            else 0
+        )
         header[3] = config.mp_small_int_bits
         merged_mpy.extend(header)
 
+        if arch_flags != 0:
+            merged_mpy.extend(mp_encode_uint(arch_flags))
+
         n_qstr = 0
         n_obj = 0
         for cm in compiled_modules:
@@ -1761,7 +1946,139 @@ def merge_mpy(compiled_modules, output_file):
             f.write(merged_mpy)
 
 
-def main():
+def extract_segments(compiled_modules, basename, kinds_arg):
+    import re
+
+    kind_str = ("META", "QSTR", "OBJ", "CODE")
+    kinds = set()
+    if kinds_arg is not None:
+        for kind in kinds_arg.upper().split(","):
+            if kind in kind_str:
+                kinds.add(kind)
+            else:
+                raise Exception('unknown segment kind "%s"' % (kind,))
+    segments = []
+    for module in compiled_modules:
+        for segment in module.mpy_segments:
+            if not kinds or kind_str[segment.kind] in kinds:
+                segments.append((module.mpy_source_file, module.source_file.str, segment))
+    count_len = len(str(len(segments)))
+    sanitiser = re.compile("[^a-zA-Z0-9_.-]")
+    for counter, entry in enumerate(segments):
+        file_name, source_file, segment = entry
+        output_name = (
+            basename
+            + "_"
+            + str(counter).rjust(count_len, "0")
+            + "_"
+            + sanitiser.sub("_", source_file)
+            + "_"
+            + kind_str[segment.kind]
+            + "_"
+            + sanitiser.sub("_", str(segment.name))
+            + ".bin"
+        )
+        with open(file_name, "rb") as source:
+            with open(output_name, "wb") as output:
+                source.seek(segment.start)
+                output.write(source.read(segment.end - segment.start))
+
+
+class PrintShim:
+    """Base class for interposing extra functionality onto the global `print` method."""
+
+    def __init__(self):
+        self.wrapped_print = None
+
+    def __enter__(self):
+        global print
+
+        if self.wrapped_print is not None:
+            raise RecursionError
+
+        self.wrapped_print = print
+        print = self
+
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        global print
+
+        if self.wrapped_print is None:
+            return
+
+        print = self.wrapped_print
+        self.wrapped_print = None
+
+        self.on_exit()
+
+    def on_exit(self):
+        pass
+
+    def __call__(self, *a, **k):
+        return self.wrapped_print(*a, **k)
+
+
+class PrintIgnoreExtraArgs(PrintShim):
+    """Just strip the `annotations` and `labels` kwargs and pass down to the underlying print."""
+
+    def __call__(self, *a, annotations: dict = {}, labels: "list[str]" = (), **k):
+        return super().__call__(*a, **k)
+
+
+class PrintJson(PrintShim):
+    """Output lines as godbolt-compatible JSON with extra annotation info from `annotations` and `labels`, rather than plain text."""
+
+    def __init__(self, fp=sys.stdout, language_id: str = "mpy"):
+        super().__init__()
+        self.fp = fp
+        self.asm = {
+            "asm": [],
+            "labelDefinitions": {},
+            "languageId": language_id,
+        }
+        self.line_number: int = 0
+        self.buf: "io.StringIO | None" = None
+
+    def on_exit(self):
+        import json
+
+        if self.buf is not None:
+            # flush last partial line
+            self.__call__()
+
+        json.dump(self.asm, self.fp)
+
+    def __call__(self, *a, annotations: dict = {}, labels: "list[str]" = (), **k):
+        # ignore prints directed to an explicit output
+        if "file" in k:
+            return super().__call__(*a, **k)
+
+        if self.buf is None:
+            self.buf = io.StringIO()
+
+        super().__call__(*a, file=sys.stderr, **k)
+
+        if "end" in k:
+            # buffer partial-line prints to collect into a single AsmResultLine
+            return super().__call__(*a, file=self.buf, **k)
+        else:
+            retval = super().__call__(*a, file=self.buf, end="", **k)
+            output = self.buf.getvalue()
+            self.buf = None
+
+        asm_line = {"text": output}
+        asm_line.update(annotations)
+        self.asm["asm"].append(asm_line)
+
+        self.line_number += 1
+        for label in labels:
+            self.asm["labelDefinitions"][label] = self.line_number
+
+        return retval
+
+
+def main(args=None):
     global global_qstrs
 
     import argparse
@@ -1774,9 +2091,23 @@ def main():
         "-d", "--disassemble", action="store_true", help="output disassembled contents of files"
     )
     cmd_parser.add_argument("-f", "--freeze", action="store_true", help="freeze files")
+    cmd_parser.add_argument(
+        "-j",
+        "--json",
+        action="store_true",
+        help="output hexdump, disassembly, and frozen code as JSON with extra metadata",
+    )
     cmd_parser.add_argument(
         "--merge", action="store_true", help="merge multiple .mpy files into one"
     )
+    cmd_parser.add_argument(
+        "-e", "--extract", metavar="BASE", type=str, help="write segments into separate files"
+    )
+    cmd_parser.add_argument(
+        "--extract-only",
+        metavar="KIND[,...]",
+        help="extract only segments of the given type (meta, qstr, obj, code)",
+    )
     cmd_parser.add_argument("-q", "--qstr-header", help="qstr header file to freeze against")
     cmd_parser.add_argument(
         "-mlongint-impl",
@@ -1791,9 +2122,15 @@ def main():
         default=16,
         help="mpz digit size used by target (default 16)",
     )
+    cmd_parser.add_argument(
+        "-march-flags",
+        metavar="F",
+        type=int,
+        help="architecture flags value to set in the output file (strips existing flags if not present)",
+    )
     cmd_parser.add_argument("-o", "--output", default=None, help="output file")
     cmd_parser.add_argument("files", nargs="+", help="input .mpy files")
-    args = cmd_parser.parse_args()
+    args = cmd_parser.parse_args(args)
 
     # set config values relevant to target machine
     config.MICROPY_LONGINT_IMPL = {
@@ -1803,6 +2140,7 @@ def main():
     }[args.mlongint_impl]
     config.MPZ_DIG_SIZE = args.mmpz_dig_size
     config.native_arch = MP_NATIVE_ARCH_NONE
+    config.arch_flags = args.march_flags
 
     # set config values for qstrs, and get the existing base set of qstrs
     # already in the firmware
@@ -1826,24 +2164,40 @@ def main():
         print(er, file=sys.stderr)
         sys.exit(1)
 
-    if args.hexdump:
-        hexdump_mpy(compiled_modules)
+    if args.json:
+        if args.freeze:
+            print_shim = PrintJson(sys.stdout, language_id="c")
+        elif args.hexdump:
+            print_shim = PrintJson(sys.stdout, language_id="stderr")
+        elif args.disassemble:
+            print_shim = PrintJson(sys.stdout, language_id="mpy")
+        else:
+            print_shim = PrintJson(sys.stdout)
+    else:
+        print_shim = PrintIgnoreExtraArgs()
 
-    if args.disassemble:
+    with print_shim:
         if args.hexdump:
-            print()
-        disassemble_mpy(compiled_modules)
+            hexdump_mpy(compiled_modules)
 
-    if args.freeze:
-        try:
-            freeze_mpy(firmware_qstr_idents, compiled_modules)
-        except FreezeError as er:
-            print(er, file=sys.stderr)
-            sys.exit(1)
+        if args.disassemble:
+            if args.hexdump:
+                print()
+            disassemble_mpy(compiled_modules)
+
+        if args.freeze:
+            try:
+                freeze_mpy(firmware_qstr_idents, compiled_modules)
+            except FreezeError as er:
+                print(er, file=sys.stderr)
+                sys.exit(1)
 
     if args.merge:
         merge_mpy(compiled_modules, args.output)
 
+    if args.extract:
+        extract_segments(compiled_modules, args.extract, args.extract_only)
+
 
 if __name__ == "__main__":
     main()
